@@ -1,5 +1,5 @@
 ;Liquid War 6 is a unique multiplayer wargame.
-;Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+;Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 ;
 ;This program is free software; you can redistribute it and/or modify
 ;it under the terms of the GNU General Public License as published by
@@ -57,17 +57,17 @@
 	m
        ))))
     
-(define lw6-menu-warp-mouse
-  (lambda ()
-    (let ((menu (lw6-current-menu)))
-      (if menu
-	  (c-lw6gfx-warp-mouse-on-menuitem (assoc-ref menu "smob") (assoc-ref menu "selected-item") (lw6-get-game-global "look"))))))
+;(define lw6-menu-warp-mouse
+;  (lambda ()
+;    (let ((menu (lw6-current-menu)))
+;      (if menu
+;	  (c-lw6gfx-warp-mouse-on-menuitem (assoc-ref menu "smob") (assoc-ref menu "selected-item") (lw6-get-game-global "look"))))))
 
-(define lw6-menu-center
-  (lambda ()
-    (let ((menu (lw6-current-menu)))
-      (if menu
-	  (c-lw6gfx-center-menu (assoc-ref menu "smob") (assoc-ref menu "selected-item") (lw6-get-game-global "look"))))))
+;(define lw6-menu-center
+;  (lambda ()
+;    (let ((menu (lw6-current-menu)))
+;      (if menu
+;	  (c-lw6gfx-center-menu (assoc-ref menu "smob") (assoc-ref menu "selected-item") (lw6-get-game-global "look"))))))
 
 (define lw6-push-menu-nowarp
   (lambda (menu)
@@ -78,14 +78,14 @@
       (lw6-menu-update-selected-item menu)
       (lw6-menu-sync menu)
       (lw6-menuitem-action (lw6-current-menuitem) "on-select")
-      (lw6-menu-center)
+      ;(lw6-menu-center)
       )))
 
 (define lw6-push-menu 
   (lambda (menu)
     (begin 
       (lw6-push-menu-nowarp menu)
-      (lw6-menu-warp-mouse)
+      ;(lw6-menu-warp-mouse)
       )))
 
 (define lw6-pop-menu 
@@ -99,8 +99,8 @@
 	    )
 	(if menu
 	    (begin
-	      (lw6-menu-center)
-	      (lw6-menu-warp-mouse)
+	      ;(lw6-menu-center)
+	      ;(lw6-menu-warp-mouse)
 	      ))))))
 
 (define lw6-current-menu 
@@ -117,6 +117,15 @@
 	  )
       (if (and items (> (length items) 0)) #t #f))))
 
+(define lw6-menu-pump-all?
+  (lambda ()
+    (let (
+	  (menu (lw6-current-menu))
+	  )
+      (if menu
+	  (lw6-menu-has-items? menu)
+	  #f))))
+
 (define lw6-current-menuitem
   (lambda ()
     (let* (
@@ -128,7 +137,7 @@
 	  #f))))
 
 (define lw6-set-menuitem!
-  (lambda (i warp-mouse)
+  (lambda (i allow-scroll)
     (let (
 	  (menuitem (lw6-current-menuitem))
 	  )
@@ -146,30 +155,31 @@
 		  (lw6-play-sound-beep-select)
 		  (lw6-menuitem-action menuitem "on-unselect")
 		  (assoc-set! menu "selected-item" new-selected-item)
+		  (assoc-set! menu "allow-scroll" allow-scroll)
 		  (lw6-menu-sync menu)
 		  (lw6-menuitem-action (lw6-current-menuitem) "on-select")
-		  (if warp-mouse (lw6-menu-warp-mouse))
+		  ;(if warp-mouse (lw6-menu-warp-mouse))
 		  #t
 		  )))))))
 
 (define lw6-prev-menuitem
-  (lambda (warp-mouse)
+  (lambda (allow-scroll)
     (let (
 	  (menu (lw6-current-menu))
 	  (menuitem (lw6-current-menuitem))
 	  )
       (if menuitem
-	  (lw6-set-menuitem! (- (assoc-ref menu "selected-item") 1) warp-mouse)
+	  (lw6-set-menuitem! (- (assoc-ref menu "selected-item") 1) allow-scroll)
 	  ))))
 
 (define lw6-next-menuitem
-  (lambda (warp-mouse)
+  (lambda (allow-scroll)
     (let (
 	  (menu (lw6-current-menu))
 	  (menuitem (lw6-current-menuitem))
 	  )
       (if menuitem
-	  (lw6-set-menuitem! (+ (assoc-ref menu "selected-item") 1) warp-mouse)
+	  (lw6-set-menuitem! (+ (assoc-ref menu "selected-item") 1) allow-scroll)
 	  ))))
 
 (define lw6-menu-action
@@ -187,8 +197,11 @@
 (define lw6-menu-template
   (lambda (title)
     (list
-     (cons "smob" (c-lw6gui-menu-new title))
+     (cons "smob" (c-lw6gui-menu-new title 
+				     (_ "Esc") 
+				     (lw6-config-is-true? lw6def-use-esc-button)))
      (cons "selected-item" 0)
+     (cons "allow-scroll" #f)
      (cons "items" (list))
      (cons "on-pop" (lambda (m) #t))
      (cons "on-push" (lambda (m) #t))
@@ -380,178 +393,174 @@
 (define lw6-menu-sync
   (lambda (menu)
     (c-lw6gui-menu-select (assoc-ref menu "smob") 
-			  (assoc-ref menu "selected-item"))
+			  (assoc-ref menu "selected-item")
+			  (assoc-ref menu "allow-scroll"))
     ))
 
-(define lw6-menu-pump-keys
+(define lw6-menu-pump-buttons
   (lambda ()
     (let
 	(
+	 (dsp (lw6-get-game-global "dsp"))
 	 (menu (lw6-current-menu))
 	 (menuitem (lw6-current-menuitem))
-	 (key (c-lw6gfx-poll-key))
-	 )
-      (if
-       (and menu key)
-       (begin
-					;(display key)
-	 (cond 
-	  (
-	   (c-lw6gfx-is-key-esc (assoc-ref key "keysym"))
-	   (if
-	    (lw6-menu-action menu "on-cancel") 
-	    (lw6-play-sound-beep-valid)
-	    )
-	   )
-	  (
-	   (c-lw6gfx-is-key-enter (assoc-ref key "keysym"))
-	   (if
-	    (lw6-menuitem-action menuitem "on-valid")
-	    (lw6-play-sound-beep-valid)
-	    )	    
-	   )
-	  (
-	   (c-lw6gfx-is-key-right (assoc-ref key "keysym"))
-	   (if
-	    (lw6-menuitem-action menuitem "on-plus")
-	    (lw6-play-sound-beep-valid)
-	    )	    
-	   )
-	  (
-	   (c-lw6gfx-is-key-left (assoc-ref key "keysym"))
-	   (if
-	    (lw6-menuitem-action menuitem "on-minus")
-	    (lw6-play-sound-beep-valid)
-	    )	    
-	   )
-	  (
-	   (c-lw6gfx-is-key-up (assoc-ref key "keysym"))
-	   (if
-	    (lw6-prev-menuitem #t)
-	    (lw6-play-sound-beep-select)
-	    )
-	   )
-	  (
-	   (c-lw6gfx-is-key-down (assoc-ref key "keysym"))
-	   (if
-	    (lw6-next-menuitem #t)
-	    (lw6-play-sound-beep-select)
-	    ))))))))
-
-(define lw6-menu-pump-joystick
-  (lambda ()
-    (let
-	(
-	 (menu (lw6-current-menu))
-	 (menuitem (lw6-current-menuitem))
-	 (joystick1-index (lw6-config-get-number lw6def-joystick1-index))
-	 (joystick1-button-a (lw6-config-get-number lw6def-joystick1-button-a))
-	 (joystick1-button-b (lw6-config-get-number lw6def-joystick1-button-b))
-	 (joystick2-index (lw6-config-get-number lw6def-joystick2-index))
-	 (joystick2-button-a (lw6-config-get-number lw6def-joystick2-button-a))
-	 (joystick2-button-b (lw6-config-get-number lw6def-joystick2-button-b))
 	 )
       (if
        menu
-       (cond 
+       (begin
+       (if (lw6-menu-pump-all?)
+	   (cond 
+	    ((or
+	      (c-lw6gui-keyboard-pop-key-up dsp)
+	      (c-lw6gui-joystick1-pop-button-up dsp)
+	      (c-lw6gui-joystick2-pop-button-up dsp))
+	     (if
+	      (lw6-prev-menuitem #f)
+	      (lw6-play-sound-beep-select)
+	      )
+	     )
+	    ((c-lw6gui-mouse-pop-wheel-up dsp)
+	     (if
+	      (lw6-prev-menuitem #t)
+	      (lw6-play-sound-beep-select)
+	      )
+	     )
+	    ((or
+	      (c-lw6gui-keyboard-pop-key-down dsp)
+	      (c-lw6gui-joystick1-pop-button-down dsp)
+	      (c-lw6gui-joystick2-pop-button-down dsp))
+	     (if
+	      (lw6-next-menuitem #f)
+	      (lw6-play-sound-beep-select)
+	      )
+	     )
+	    ((c-lw6gui-mouse-pop-wheel-down dsp)
+	     (if
+	      (lw6-next-menuitem #t)
+	      (lw6-play-sound-beep-select)
+	      )
+	     )
+	    ((or
+	      (c-lw6gui-keyboard-pop-key-left dsp)
+	      (c-lw6gui-joystick1-pop-button-left dsp)
+	      (c-lw6gui-joystick2-pop-button-left dsp))
+	     (if
+	      (lw6-menuitem-action menuitem "on-minus")
+	      (lw6-play-sound-beep-valid)
+	      ) 
+	     )
+	    ((or
+	      (c-lw6gui-keyboard-pop-key-right dsp)
+	      (c-lw6gui-joystick1-pop-button-right dsp)
+	      (c-lw6gui-joystick2-pop-button-right dsp))
+	     (if
+	      (lw6-menuitem-action menuitem "on-plus")
+	      (lw6-play-sound-beep-valid)
+	      ) 
+	     )
+	    ((or
+	      (c-lw6gui-keyboard-pop-key-enter dsp)
+	      (c-lw6gui-joystick1-pop-button-a dsp)
+	      (c-lw6gui-joystick2-pop-button-a dsp))
+	     (if
+	      (lw6-menuitem-action menuitem "on-valid")
+	      (lw6-play-sound-beep-valid)
+	      )
+	     )
+	    ))
+       (cond
 	((or
-	  (c-lw6gfx-poll-joystick-button joystick1-index joystick1-button-b)
-	  (c-lw6gfx-poll-joystick-button joystick2-index joystick2-button-b))
+	  (c-lw6gui-keyboard-pop-key-esc dsp)
+	  (c-lw6gui-mouse-pop-button-right dsp)
+	  (c-lw6gui-joystick1-pop-button-b dsp)
+	  (c-lw6gui-joystick2-pop-button-b dsp))
 	 (if
 	  (lw6-menu-action menu "on-cancel")
 	  (lw6-play-sound-beep-valid)
 	  )
 	 )
-	((or
-	  (c-lw6gfx-poll-joystick-button joystick1-index joystick1-button-a)
-	  (c-lw6gfx-poll-joystick-button joystick2-index joystick2-button-a))
-	 (if
-	  (lw6-menuitem-action menuitem "on-valid")
-	  (lw6-play-sound-beep-valid)
-	  ) 
-	 )
-	((or
-	  (c-lw6gfx-poll-joystick-right joystick1-index)
-	  (c-lw6gfx-poll-joystick-right joystick2-index))
-	 (if
-	  (lw6-menuitem-action menuitem "on-plus")
-	  (lw6-play-sound-beep-valid)
-	  ) 
-	 )
-	((or
-	  (c-lw6gfx-poll-joystick-left joystick1-index)
-	  (c-lw6gfx-poll-joystick-left joystick2-index))
-	 (if
-	  (lw6-menuitem-action menuitem "on-minus")
-	  (lw6-play-sound-beep-valid)
-	  ) 
-	 )
-	((or
-	  (c-lw6gfx-poll-joystick-up joystick1-index)
-	  (c-lw6gfx-poll-joystick-up joystick2-index))
-	 (if
-	  (lw6-prev-menuitem #t)
-	  (lw6-play-sound-beep-select)
-	  )
-	 )
-	((or
-	  (c-lw6gfx-poll-joystick-down joystick1-index)
-	  (c-lw6gfx-poll-joystick-down joystick2-index))
-	 (if
-	  (lw6-next-menuitem #t)
-	  (lw6-play-sound-beep-select)
-	  )))))))
+	((c-lw6gui-mouse-pop-button-left dsp)
+	 (let*
+	     (
+	      (mouse-state (c-lw6gui-mouse-get-state dsp))
+	      (menu-position (assoc-ref mouse-state "menu-position"))
+	      (menu-scroll (assoc-ref mouse-state "menu-scroll"))
+	      (menu-esc (assoc-ref mouse-state "menu-esc"))
+	      )
+	   (cond (
+		  (>= menu-position 0)
+		  (begin
+		    (lw6-set-menuitem! menu-position #f)
+		    (set! menuitem (lw6-current-menuitem))
+		    (if
+		     (lw6-menuitem-action menuitem "on-valid")
+		     (lw6-play-sound-beep-valid)
+		     )
+		    )
+		  )
+		 (
+		  (> menu-scroll 0)
+		  (lw6-next-menuitem #f)
+		  )
+		 (
+		  (< menu-scroll 0)
+		  (lw6-prev-menuitem #f)
+		  )
+		 (
+		  menu-esc
+		  (if
+		   (lw6-menu-action menu "on-cancel")
+		   (lw6-play-sound-beep-valid)
+		   )
+		  )
+		 )
+	   )
+	 )))))))
 
 (define lw6-menu-pump-mouse
   (lambda ()
-    (let
-	(
-	 (move (c-lw6gfx-poll-mouse-move))
-	 (button-left (c-lw6gfx-poll-mouse-button-left))
-	 (button-right (c-lw6gfx-poll-mouse-button-right))
-	 (wheel-up (c-lw6gfx-poll-mouse-wheel-up))
-	 (wheel-down (c-lw6gfx-poll-mouse-wheel-down))
-	 (mouse-state (c-lw6gfx-get-mouse-state))
-	 (menu (lw6-current-menu))
-	 (menuitem (lw6-current-menuitem))
-	 )
-      (if menu
-	  (begin
-	    (let* (
-		   (x (if move (assoc-ref move "x") (assoc-ref mouse-state "x")))
-		   (y (if move (assoc-ref move "y") (assoc-ref mouse-state "y")))
-		   (pick (c-lw6gfx-pick-menuitem (assoc-ref menu "smob") x y (lw6-get-game-global "look")))
-		   (position (assoc-ref pick "position"))
-		   (scroll (assoc-ref pick "scroll"))
-		   (changed #f)
-		   )
+    (if (and (lw6-menu-pump-all?)
+	     (not (lw6-config-is-true? lw6def-click-to-focus)))
+	(let*
+	    (
+	     (dsp (lw6-get-game-global "dsp"))
+	     (mouse-state (c-lw6gui-mouse-poll-move dsp))
+	     (menu-position (assoc-ref mouse-state "menu-position"))
+	     (menu-scroll (assoc-ref mouse-state "menu-scroll"))
+	     (menu-esc (assoc-ref mouse-state "menu-esc"))
+	     (menu (lw6-current-menu))
+	     (menu-smob (if menu (assoc-ref menu "smob")))
+	     (menuitem (lw6-current-menuitem))
+	     )
+	  (if mouse-state
 	      (begin
-		(if (and move (>= position 0))
-		    (lw6-set-menuitem! position #f))
-		(if (> scroll 0)
-		    (lw6-next-menuitem #f))
-		(if (< scroll 0)
-		    (lw6-prev-menuitem #f)))
-	    (if button-left
-		(begin
-		  (lw6-play-sound-beep-valid)
-		  (lw6-menuitem-action menuitem "on-valid")))
-	    (if button-right 
-		(begin (lw6-play-sound-beep-valid)
-		       (lw6-menu-action menu "on-cancel")))
-	    (if wheel-up
-		(begin (c-lw6gui-menu-scroll-up (assoc-ref menu "smob"))
-		       (lw6-prev-menuitem #t)))
-	    (if wheel-down
-		(begin (c-lw6gui-menu-scroll-down (assoc-ref menu "smob"))
-		       (lw6-next-menuitem #t)))))))))
+		(if (and menu menuitem)
+		    (cond (
+			   (>= menu-position 0)
+			   (lw6-set-menuitem! menu-position #f)
+			   )
+			  (
+			   (> menu-scroll 0)
+			   (lw6-next-menuitem #f)
+			   )
+			  (
+			   (< menu-scroll 0)
+			   (lw6-prev-menuitem #f)
+			   )
+			  ))
+		(if menu-smob
+		    (c-lw6gui-menu-select-esc menu-smob menu-esc))
+		))
+	  ))))
 
 (define lw6-menu
   (lambda () 
     (begin 
       (if (lw6-empty-menu-stack?)
-	  (c-lw6gfx-send-quit)
+	  (c-lw6gui-input-send-quit (lw6-get-game-global "dsp"))
 	  )
-      (lw6-menu-pump-keys)
-      (lw6-menu-pump-joystick)
-      (lw6-menu-pump-mouse))))
+      (lw6-menu-pump-buttons)
+      (lw6-menu-pump-mouse)
+      (if (not (lw6-menu-pump-all?))
+	  (lw6-zoom-pump))
+      )))
