@@ -34,25 +34,32 @@ _warning (const char *func_name)
 }
 
 int
-lw6bot_init (lw6bot_backend_t * backend, lw6bot_param_t * param)
+lw6bot_init (lw6bot_backend_t * backend, lw6bot_seed_t * seed)
 {
+  lw6bot_data_t data;
+
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->init)
     {
-      if (param->speed <= 0.0f)
+      memset (&data, 0, sizeof (lw6bot_data_t));
+      backend->seed = *seed;
+      if (backend->seed.param.speed <= 0.0f)
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("incorrect speed %0.1f"),
-		      param->speed);
-	  param->iq = 1.0f;
+		      backend->seed.param.speed);
+	  backend->seed.param.iq = 1.0f;
 	}
-      if (param->iq < 0)
+      if (backend->seed.param.iq < 0)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("incorrect iq %d"), param->iq);
-	  param->iq = 100;
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("incorrect iq %d"),
+		      backend->seed.param.iq);
+	  backend->seed.param.iq = 100;
 	}
+      data.param = backend->seed.param;
+      data.game_state = seed->game_state;
       backend->bot_context =
-	backend->init (backend->argc, backend->argv, param);
+	backend->init (backend->argc, backend->argv, &data);
     }
   else
     {
@@ -71,8 +78,15 @@ lw6bot_quit (lw6bot_backend_t * backend)
 
   if (backend->quit)
     {
-      backend->quit (backend->bot_context);
-      backend->bot_context = NULL;
+      /*
+       * It's important to check that backend is not NULL for
+       * quit can *really* be called several times on the same backend
+       */
+      if (backend->bot_context)
+	{
+	  backend->quit (backend->bot_context);
+	  backend->bot_context = NULL;
+	}
     }
   else
     {
@@ -86,12 +100,38 @@ int
 lw6bot_next_move (lw6bot_backend_t * backend, int *x, int *y)
 {
   int ret = 0;
+  lw6bot_data_t data;
 
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->next_move)
     {
-      ret = backend->next_move (backend->bot_context, x, y);
+      memset (&data, 0, sizeof (lw6bot_data_t));
+      data.param = backend->seed.param;
+      switch (backend->seed.dirty_read)
+	{
+	case LW6PIL_DIRTY_READ_NEVER:
+	case LW6PIL_DIRTY_READ_SYNC_ONLY:
+	  /*
+	   * In those cases we assume the game_state we have has been
+	   * synchronized elsewhere, typically in the display thread.
+	   */
+	  data.game_state = backend->seed.game_state;
+	  break;
+	case LW6PIL_DIRTY_READ_ALWAYS:
+	  if (backend->seed.pilot)
+	    {
+	      data.game_state = lw6pil_pilot_dirty_read (backend->seed.pilot);
+	    }
+	  break;
+	default:
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("unknown dirty read mode %d"),
+		      backend->seed.dirty_read);
+	}
+      if (data.game_state)
+	{
+	  ret = backend->next_move (backend->bot_context, x, y, &data);
+	}
     }
   else
     {
