@@ -54,7 +54,7 @@ new_data (lw6map_level_t ** level,
   int ret = 0;
 
   *level =
-    lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+    lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
   *game_struct = lw6ker_game_struct_new (*level, NULL);
   *game_state = lw6ker_game_state_new (*game_struct, NULL);
 
@@ -94,21 +94,22 @@ test_backend (lw6bot_backend_t * backend)
   lw6map_level_t *level = NULL;
   lw6ker_game_struct_t *game_struct = NULL;
   lw6ker_game_state_t *game_state = NULL;
-  lw6bot_param_t bot_param;
+  lw6bot_seed_t bot_seed;
   int x = 0, y = 0;
   int i;
   char *capture_str = NULL;
   char *repr = NULL;
 
-  memset (&bot_param, 0, sizeof (lw6bot_param_t));
+  memset (&bot_seed, 0, sizeof (lw6bot_seed_t));
 
   if (new_data (&level, &game_struct, &game_state))
     {
-      bot_param.speed = TEST_SPEED;
-      bot_param.iq = TEST_IQ;
-      bot_param.game_state = game_state;
-      bot_param.cursor_id = TEST_CURSOR_ID3;
-      if (lw6bot_init (backend, &bot_param))
+      bot_seed.param.speed = TEST_SPEED;
+      bot_seed.param.iq = TEST_IQ;
+      bot_seed.param.cursor_id = TEST_CURSOR_ID3;
+      bot_seed.game_state = game_state;
+      bot_seed.dirty_read = LW6PIL_DIRTY_READ_NEVER;
+      if (lw6bot_init (backend, &bot_seed))
 	{
 	  while (lw6ker_game_state_get_rounds (game_state) < TEST_NB_ROUNDS)
 	    {
@@ -151,7 +152,6 @@ lw6bot_test ()
   int argc = TEST_ARGC;
   char *argv[TEST_ARGC] = { TEST_ARGV0 };
   lw6bot_backend_t *backend[TEST_NB_BACKENDS];
-  lw6bot_param_t param;
   int i;
 
   if (lw6sys_false ())
@@ -169,7 +169,6 @@ lw6bot_test ()
 
   ret = 1;
 
-  memset (&param, 0, sizeof (lw6bot_param_t));
   for (i = 0; i < TEST_NB_BACKENDS; ++i)
     {
       if (backend[i])
