@@ -27,15 +27,29 @@
 #include "../dyn/dyn.h"
 #include "../map/map.h"
 #include "../ker/ker.h"
+#include "../pil/pil.h"
 
 typedef struct lw6bot_param_s
 {
   float speed;
   int iq;
-  lw6ker_game_state_t *game_state;
   u_int16_t cursor_id;
 } lw6bot_param_t;
 
+typedef struct lw6bot_data_s
+{
+  lw6ker_game_state_t *game_state;
+  lw6bot_param_t param;
+} lw6bot_data_t;
+
+typedef struct lw6bot_seed_s
+{
+  lw6ker_game_state_t *game_state;
+  lw6pil_pilot_t *pilot;
+  int dirty_read;
+  lw6bot_param_t param;
+} lw6bot_seed_t;
+
 typedef struct lw6bot_backend_s
 {
   lw6dyn_dl_handle_t *dl_handle;
@@ -43,10 +57,11 @@ typedef struct lw6bot_backend_s
   int argc;
   char **argv;
   u_int32_t id;
+  lw6bot_seed_t seed;
 
-  void *(*init) (int argc, char *argv[], lw6bot_param_t * param);
+  void *(*init) (int argc, char *argv[], lw6bot_data_t * data);
   void (*quit) (void *bot_context);
-  int (*next_move) (void *bot_context, int *x, int *y);
+  int (*next_move) (void *bot_context, int *x, int *y, lw6bot_data_t * data);
   char *(*repr) (void *bot_context, u_int32_t id);
 }
 lw6bot_backend_t;
@@ -54,7 +69,7 @@ lw6bot_backend_t;
 /*
  * In api.c
  */
-extern int lw6bot_init (lw6bot_backend_t * backend, lw6bot_param_t * param);
+extern int lw6bot_init (lw6bot_backend_t * backend, lw6bot_seed_t * seed);
 extern void lw6bot_quit (lw6bot_backend_t * backend);
 extern int lw6bot_next_move (lw6bot_backend_t * backend, int *x, int *y);
 extern char *lw6bot_repr (lw6bot_backend_t * backend);
