@@ -29,9 +29,9 @@
 #include "mod-idiot-internal.h"
 
 static void *
-_init (int argc, char *argv[], lw6bot_param_t * param)
+_init (int argc, char *argv[], lw6bot_data_t * data)
 {
-  _mod_idiot_context_t *idiot_context = _mod_idiot_init (argc, argv, param);
+  _mod_idiot_context_t *idiot_context = _mod_idiot_init (argc, argv, data);
 
   return (void *) idiot_context;
 }
@@ -48,14 +48,14 @@ _quit (void *bot_context)
 }
 
 static int
-_next_move (void *bot_context, int *x, int *y)
+_next_move (void *bot_context, int *x, int *y, lw6bot_data_t * data)
 {
   int ret = 0;
   _mod_idiot_context_t *idiot_context = (_mod_idiot_context_t *) bot_context;
 
   if (idiot_context)
     {
-      ret = _mod_idiot_next_move (idiot_context, x, y);
+      ret = _mod_idiot_next_move (idiot_context, x, y, data);
     }
 
   return ret;
