@@ -34,7 +34,6 @@
 
 typedef struct _mod_idiot_context_s
 {
-  lw6bot_param_t param;
   int last_move_round;
   int start_pos_x;
   int start_pos_y;
@@ -48,14 +47,14 @@ _mod_idiot_context_t;
  */
 extern _mod_idiot_context_t *_mod_idiot_init (int argc,
 					      char *argv[],
-					      lw6bot_param_t * param);
+					      lw6bot_data_t * data);
 extern void _mod_idiot_quit (_mod_idiot_context_t * idiot_context);
 
 /*
  * In move.c
  */
 extern int _mod_idiot_next_move (_mod_idiot_context_t * idiot_context, int *x,
-				 int *y);
+				 int *y, lw6bot_data_t * data);
 
 /*
  * In repr.c
