@@ -28,7 +28,7 @@
 #include "mod-idiot-internal.h"
 
 static int
-new_target (_mod_idiot_context_t * idiot_context)
+new_target (_mod_idiot_context_t * idiot_context, lw6bot_data_t * data)
 {
   int team_color = LW6MAP_TEAM_COLOR_INVALID;
   int x = -1;
@@ -41,7 +41,7 @@ new_target (_mod_idiot_context_t * idiot_context)
   lw6ker_fighter_t *fighter;
 
   if (lw6ker_game_state_get_cursor_info
-      (idiot_context->param.game_state, idiot_context->param.cursor_id, NULL,
+      (data->game_state, data->param.cursor_id, NULL,
        NULL, &team_color, &x, &y))
     {
       idiot_context->start_pos_x = x;
@@ -49,16 +49,12 @@ new_target (_mod_idiot_context_t * idiot_context)
 
       for (i = 0; i < _MOD_IDIOT_NB_RETRIES && !found; ++i)
 	{
-	  x =
-	    lw6sys_random (idiot_context->param.game_state->map_state.
-			   shape.w);
-	  y =
-	    lw6sys_random (idiot_context->param.game_state->map_state.
-			   shape.h);
+	  x = lw6sys_random (data->game_state->map_state.shape.w);
+	  y = lw6sys_random (data->game_state->map_state.shape.h);
 	  idiot_context->target_pos_x = x;
 	  idiot_context->target_pos_y = y;
-	  if (idiot_context->param.iq >= _MOD_IDIOT_IQ_LIMIT1
-	      && idiot_context->param.iq < _MOD_IDIOT_IQ_LIMIT2)
+	  if (data->param.iq >= _MOD_IDIOT_IQ_LIMIT1
+	      && data->param.iq < _MOD_IDIOT_IQ_LIMIT2)
 	    {
 	      // here, we don't search anymore, just choose random
 	      lw6sys_log (LW6SYS_LOG_DEBUG,
@@ -70,22 +66,20 @@ new_target (_mod_idiot_context_t * idiot_context)
 	  else
 	    {
 	      for (z = 0;
-		   z < idiot_context->param.game_state->map_state.shape.d
-		   && !found; ++z)
+		   z < data->game_state->map_state.shape.d && !found; ++z)
 		{
 		  fighter_id =
 		    lw6ker_map_state_get_fighter_id (&
-						     (idiot_context->
-						      param.game_state->
+						     (data->game_state->
 						      map_state), x, y, z);
 		  if (fighter_id >= 0)
 		    {
 		      fighter =
-			&(idiot_context->param.game_state->map_state.
+			&(data->game_state->map_state.
 			  armies.fighters[fighter_id]);
 		      if (fighter != NULL)
 			{
-			  if (idiot_context->param.iq >= _MOD_IDIOT_IQ_LIMIT2
+			  if (data->param.iq >= _MOD_IDIOT_IQ_LIMIT2
 			      && fighter->team_color != team_color)
 			    {
 			      // default behavior, find an opponent
@@ -95,7 +89,7 @@ new_target (_mod_idiot_context_t * idiot_context)
 					  fighter->team_color, x, y);
 			      found = 1;
 			    }
-			  if (idiot_context->param.iq < _MOD_IDIOT_IQ_LIMIT1
+			  if (data->param.iq < _MOD_IDIOT_IQ_LIMIT1
 			      && fighter->team_color == team_color)
 			    {
 			      // acting stupid, centering on self
@@ -130,7 +124,8 @@ new_target (_mod_idiot_context_t * idiot_context)
 }
 
 int
-_mod_idiot_next_move (_mod_idiot_context_t * idiot_context, int *x, int *y)
+_mod_idiot_next_move (_mod_idiot_context_t * idiot_context, int *x, int *y,
+		      lw6bot_data_t * data)
 {
   int ret = 0;
   int rounds = 0;
@@ -142,26 +137,24 @@ _mod_idiot_next_move (_mod_idiot_context_t * idiot_context, int *x, int *y)
   int end_of_wait;
   float average_size = 0.0f;
 
-  rounds = lw6ker_game_state_get_rounds (idiot_context->param.game_state);
+  rounds = lw6ker_game_state_get_rounds (data->game_state);
   lw6sys_log (LW6SYS_LOG_DEBUG, _("idiot bot move rounds=%d"), rounds);
 
   average_size =
-    (idiot_context->param.game_state->map_state.shape.w +
-     idiot_context->param.game_state->map_state.shape.h) / 2.0f;
+    (data->game_state->map_state.shape.w +
+     data->game_state->map_state.shape.h) / 2.0f;
   d_move =
     lw6sys_max (1,
 		(((float) _MOD_IDIOT_DEFAULT_MOVE_ROUNDS) * average_size) /
-		(((float) _MOD_IDIOT_REFERENCE_SIZE) *
-		 idiot_context->param.speed));
+		(((float) _MOD_IDIOT_REFERENCE_SIZE) * data->param.speed));
   d_wait =
     lw6sys_max (1,
 		(((float) _MOD_IDIOT_DEFAULT_WAIT_ROUNDS) * average_size) /
-		(((float) _MOD_IDIOT_REFERENCE_SIZE) *
-		 idiot_context->param.speed));
+		(((float) _MOD_IDIOT_REFERENCE_SIZE) * data->param.speed));
   if (idiot_context->last_move_round < 0
       || (rounds >= idiot_context->last_move_round + d_move + d_wait))
     {
-      new_target (idiot_context);
+      new_target (idiot_context, data);
       if (idiot_context->last_move_round >= 0)
 	{
 	  idiot_context->last_move_round += d_move + d_wait;
