@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,8 +34,8 @@ _mod_idiot_repr (_mod_idiot_context_t * idiot_context, u_int32_t id)
 
   ret =
     lw6sys_new_sprintf (_("%u idiot target=%d,%d"), id,
-			(int) idiot_context->target_pos.x,
-			(int) idiot_context->target_pos.y);
+			(int) idiot_context->target_pos_x,
+			(int) idiot_context->target_pos_y);
 
   return ret;
 }
