@@ -28,7 +28,7 @@
 #include "mod-idiot-internal.h"
 
 _mod_idiot_context_t *
-_mod_idiot_init (int argc, char *argv[], lw6bot_param_t * param)
+_mod_idiot_init (int argc, char *argv[], lw6bot_data_t * data)
 {
   _mod_idiot_context_t *idiot_context = NULL;
 
@@ -38,7 +38,6 @@ _mod_idiot_init (int argc, char *argv[], lw6bot_param_t * param)
     (_mod_idiot_context_t *) LW6SYS_CALLOC (sizeof (_mod_idiot_context_t));
   if (idiot_context)
     {
-      idiot_context->param = *param;
       idiot_context->last_move_round = -1;
       idiot_context->start_pos_x = -1;
       idiot_context->start_pos_y = -1;
