@@ -29,10 +29,9 @@
 #include "mod-random-internal.h"
 
 static void *
-_init (int argc, char *argv[], lw6bot_param_t * param)
+_init (int argc, char *argv[], lw6bot_data_t * data)
 {
-  _mod_random_context_t *random_context =
-    _mod_random_init (argc, argv, param);
+  _mod_random_context_t *random_context = _mod_random_init (argc, argv, data);
 
   return (void *) random_context;
 }
@@ -50,7 +49,7 @@ _quit (void *bot_context)
 }
 
 static int
-_next_move (void *bot_context, int *x, int *y)
+_next_move (void *bot_context, int *x, int *y, lw6bot_data_t * data)
 {
   int ret = 0;
   _mod_random_context_t *random_context =
@@ -58,7 +57,7 @@ _next_move (void *bot_context, int *x, int *y)
 
   if (random_context)
     {
-      ret = _mod_random_next_move (random_context, x, y);
+      ret = _mod_random_next_move (random_context, x, y, data);
     }
 
   return ret;
