@@ -29,7 +29,6 @@
 
 typedef struct _mod_random_context_s
 {
-  lw6bot_param_t param;
   int last_move_round;
   int pos_x;
   int pos_y;
@@ -41,14 +40,14 @@ _mod_random_context_t;
  */
 extern _mod_random_context_t *_mod_random_init (int argc,
 						char *argv[],
-						lw6bot_param_t * param);
+						lw6bot_data_t * data);
 extern void _mod_random_quit (_mod_random_context_t * random_context);
 
 /*
  * In move.c
  */
 extern int _mod_random_next_move (_mod_random_context_t * random_context,
-				  int *x, int *y);
+				  int *x, int *y, lw6bot_data_t * data);
 
 /*
  * In repr.c
