@@ -28,29 +28,30 @@
 #include "mod-random-internal.h"
 
 int
-_mod_random_next_move (_mod_random_context_t * random_context, int *x, int *y)
+_mod_random_next_move (_mod_random_context_t * random_context, int *x, int *y,
+		       lw6bot_data_t * data)
 {
   int ret = 0;
   int rounds = 0;
   int next_move_round = 0;
   int d_move;
 
-  rounds = lw6ker_game_state_get_rounds (random_context->param.game_state);
+  rounds = lw6ker_game_state_get_rounds (data->game_state);
   lw6sys_log (LW6SYS_LOG_DEBUG, _("random bot move rounds=%d"), rounds);
 
   d_move =
     lw6sys_max (1,
 		(float) _MOD_RANDOM_DEFAULT_ROUNDS_BETWEEN_MOVE /
-		random_context->param.speed);
+		data->param.speed);
   next_move_round = random_context->last_move_round + d_move;
   if (random_context->pos_x < 0 || random_context->pos_y < 0
       || rounds > next_move_round)
     {
       random_context->last_move_round = next_move_round;
       random_context->pos_x =
-	lw6sys_random (random_context->param.game_state->map_state.shape.w);
+	lw6sys_random (data->game_state->map_state.shape.w);
       random_context->pos_y =
-	lw6sys_random (random_context->param.game_state->map_state.shape.h);
+	lw6sys_random (data->game_state->map_state.shape.h);
       lw6sys_log (LW6SYS_LOG_DEBUG, _("random bot moved %d,%d"),
 		  random_context->pos_x, random_context->pos_y);
     }
