@@ -28,7 +28,7 @@
 #include "mod-random-internal.h"
 
 _mod_random_context_t *
-_mod_random_init (int argc, char *argv[], lw6bot_param_t * param)
+_mod_random_init (int argc, char *argv[], lw6bot_data_t * data)
 {
   _mod_random_context_t *random_context = NULL;
 
@@ -38,7 +38,6 @@ _mod_random_init (int argc, char *argv[], lw6bot_param_t * param)
     (_mod_random_context_t *) LW6SYS_CALLOC (sizeof (_mod_random_context_t));
   if (random_context)
     {
-      random_context->param = *param;
       random_context->last_move_round = -1;
       random_context->pos_x = -1;
       random_context->pos_y = -1;
