@@ -35,11 +35,6 @@ get_option (int argc, char *argv[], char *key)
   char *config_file = NULL;
   _lw6cfg_context_t *cfg_context = NULL;
 
-  if (strstr (key, "fullscr"))
-    {
-      D ("2");
-    }
-
   cfg_context = _lw6cfg_init (argc, argv);
   if (cfg_context)
     {
@@ -90,11 +85,6 @@ lw6cfg_unified_get_value (int argc, char *argv[], char *key)
 {
   char *ret = NULL;
 
-  if (strstr (key, "fullscr"))
-    {
-      D ("1");
-    }
-
   ret = lw6sys_arg_get_value_with_env (argc, argv, key);
 
   if (!ret)
@@ -137,7 +127,7 @@ lw6cfg_unified_get_user_dir (int argc, char *argv[])
  * @argc: number of command-line args, as passed to @main
  * @argv: arry of command-line args, as passed to @main
  *
- * Gets the user dir, taking all parameters in account, that's to
+ * Gets the log file, taking all parameters in account, that's to
  * say the "LW6_LOG_FILE" env value, the "--log-file" command-line
  * paramater and the LW6DEF_LOG_FILE config file entry.
  *
