@@ -257,12 +257,51 @@ write_xml (FILE * f, char *type, char *key, char *value)
   char *pos = NULL;
   char *guessed_type = NULL;
   char *help_string = NULL;
+  char *hlp_about = NULL;
   lw6hlp_type_t hlp_type = LW6HLP_TYPE_STR;
+  char *hlp_default_value = NULL;
+  int hlp_min_value = 0;
+  int hlp_max_value = 0;
 
   if (lw6cfg_must_be_saved (key))
     {
-      tmp =
-	lw6sys_new_sprintf ("\"%s\": %s", key, lw6hlp_about (&hlp_type, key));
+      hlp_about =
+	lw6hlp_about (&hlp_type, &hlp_default_value, &hlp_min_value,
+		      &hlp_max_value, key);
+      if (hlp_about)
+	{
+	  if (hlp_default_value)
+	    {
+	      if (hlp_min_value != 0 || hlp_max_value != 0)
+		{
+		  tmp =
+		    lw6sys_new_sprintf
+		    ("\"%s\" (default=\"%s\", min=\"%d\", max=\"%d\"): %s",
+		     key, hlp_default_value, hlp_min_value, hlp_max_value,
+		     hlp_about);
+		}
+	      else
+		{
+		  tmp =
+		    lw6sys_new_sprintf ("\"%s\" (default=\"%s\"): %s", key,
+					hlp_default_value, hlp_about);
+		}
+	    }
+	  else
+	    {
+	      if (hlp_min_value != 0 || hlp_max_value != 0)
+		{
+		  tmp =
+		    lw6sys_new_sprintf ("\"%s\" (min=\"%d\", max=\"%d\"): %s",
+					key, hlp_min_value, hlp_max_value,
+					hlp_about);
+		}
+	      else
+		{
+		  tmp = lw6sys_new_sprintf ("\"%s\": %s", key, hlp_about);
+		}
+	    }
+	}
       if (tmp)
 	{
 	  help_string =
