@@ -38,9 +38,12 @@
 #define LW6CFG_XML_TRUE "true"
 #define LW6CFG_XML_FALSE "false"
 
-// cfg-commandline.c
+// cfg-arg.c
 extern int lw6cfg_parse_command_line (void *context);
 
+// cfg-defaults.c
+extern int lw6cfg_defaults (void *cfg_context);
+
 // cfg-env.c
 extern int lw6cfg_merge_env (void *cfg_context);
 
