@@ -59,8 +59,15 @@ lw6cli_quit (lw6cli_backend_t * backend)
 
   if (backend->quit)
     {
-      backend->quit (backend->cli_context);
-      backend->cli_context = NULL;
+      /*
+       * It's important to check that backend is not NULL for
+       * quit can *really* be called several times on the same backend
+       */
+      if (backend->cli_context)
+	{
+	  backend->quit (backend->cli_context);
+	  backend->cli_context = NULL;
+	}
     }
   else
     {
