@@ -45,7 +45,7 @@ verbose_dlopen (char *file)
 
   if (ret)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("dlopen \"%s\""), file);
+      lw6sys_log (LW6SYS_LOG_INFO, _("load module \"%s\""), file);
     }
   else
     {
@@ -212,13 +212,15 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
 						     so_file);
 						  first_load = 0;
 						}
-					      else
-						{
-						  lw6sys_log (LW6SYS_LOG_INFO,
-							      _
-							      ("loaded module \"%s\""),
-							      so_file);
-						}
+
+					      lw6sys_log
+						(LW6SYS_LOG_INFO,
+						 _
+						 ("module \"%s\" loaded, looks fine"),
+						 so_file);
+					      /*
+					       * Verbose dlopen did log the so name
+					       */
 					      lw6sys_log (LW6SYS_LOG_INFO,
 							  _
 							  ("id for \"%s\" is \"%s\""),
@@ -372,7 +374,7 @@ lw6dyn_dlclose_backend (lw6dyn_dl_handle_t * handle)
        * a loaded shared library, we know *what* we're freeing,
        * which can be pretty usefull when debugging.
        */
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("dlclose 1/3 \"%s\""),
+      lw6sys_log (LW6SYS_LOG_INFO, _("unload module \"%s\""),
 		  handle->library_path);
       if (handle->handle)
 	{
@@ -387,7 +389,7 @@ lw6dyn_dlclose_backend (lw6dyn_dl_handle_t * handle)
 	    }
 	}
 
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("dlclose 2/3 \"%s\""),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("lt_dlclose done for \"%s\""),
 		  handle->library_path);
 
       if ((nb_errs = lt_dlexit ()) > 0)
@@ -397,7 +399,7 @@ lw6dyn_dlclose_backend (lw6dyn_dl_handle_t * handle)
 	  ret = 0;
 	}
 
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("dlclose 3/3 \"%s\""),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("lt_dlexit done for \"%s\""),
 		  handle->library_path);
     }
   else
