@@ -25,6 +25,12 @@
 
 #include "dyn.h"
 
+#ifdef LW6_MAC_OS_X
+#define _LW6DYN_SUFFIX "dylib"
+#else
+#define _LW6DYN_SUFFIX "so"
+#endif
+
 #define _LW6DYN_DEVEL_NB_DEPTHS 4
 extern char *_LW6DYN_DEVEL_DEPTH_STRINGS[_LW6DYN_DEVEL_NB_DEPTHS];
 
