@@ -30,6 +30,7 @@
 
 #include <dirent.h>
 #include <ctype.h>
+#include <limits.h>
 
 #define LIST_DEVEL_DIR1_FORMAT "%ssrc/lib/%s"
 #define LIST_DEVEL_DIR3_NAME ".libs"
@@ -37,11 +38,11 @@
 #define LIST_DEVEL_MOD_PREFIX_SIZE 4
 
 #define LIST_SYSTEM_DIR_FORMAT "%s/%s"
-#define LIST_SYSTEM_FILE_MATCH "libmod_(.*)-.*.so"
+#define LIST_SYSTEM_FILE_MATCH "libmod_(.*)-.*." _LW6DYN_SUFFIX
 
 #define LIST_LIBMOD_PREFIX_STR "libmod_"
 #define LIST_LIBMOD_PREFIX_SIZE 7
-#define LIST_SO_STR ".so"
+#define LIST_SO_STR "." _LW6DYN_SUFFIX
 
 static int
 add_backend (lw6sys_assoc_t ** list, char *libdir, char *filename, char *id)
