@@ -31,8 +31,8 @@
 char *_LW6DYN_DEVEL_DEPTH_STRINGS[_LW6DYN_DEVEL_NB_DEPTHS] =
   { "", "../", "../../", "../../../" };
 
-#define BACKEND_DEVEL_PATH_FORMAT "%ssrc/lib/%s/mod-%s/.libs/libmod_%s-%s.so"
-#define BACKEND_SYSTEM_PATH_FORMAT "%s/%s/libmod_%s-%s.so"
+#define BACKEND_DEVEL_PATH_FORMAT "%ssrc/lib/%s/mod-%s/.libs/libmod_%s-%s." _LW6DYN_SUFFIX
+#define BACKEND_SYSTEM_PATH_FORMAT "%s/%s/libmod_%s-%s." _LW6DYN_SUFFIX
 
 static char *
 make_devel_backend_path (char *top_level_lib, char *backend_name, int depth)
