@@ -64,13 +64,14 @@ mod_gl_background_quit (mod_gl_utils_context_t * utils_context,
 }
 
 void
-mod_gl_background_display (mod_gl_utils_context_t * utils_context,
-			   mod_gl_background_backend_t * backend,
-			   lw6gui_look_t * look)
+mod_gl_background_display_background (mod_gl_utils_context_t * utils_context,
+				      mod_gl_background_backend_t * backend,
+				      lw6gui_look_t * look)
 {
-  if (backend->display)
+  if (backend->display_background)
     {
-      backend->display (utils_context, backend->background_context, look);
+      backend->display_background (utils_context, backend->background_context,
+				   look);
     }
   else
     {
