@@ -38,17 +38,19 @@ typedef struct mod_gl_background_backend_s
   void *(*init) (mod_gl_utils_context_t * utils_context);
   void (*quit) (mod_gl_utils_context_t * utils_context,
 		void *background_context);
-  void (*display) (mod_gl_utils_context_t * utils_context,
-		   void *background_context, lw6gui_look_t * look);
+  void (*display_background) (mod_gl_utils_context_t * utils_context,
+			      void *background_context, lw6gui_look_t * look);
 }
 mod_gl_background_backend_t;
 
 /*
  * In api.c
  */
-extern void mod_gl_background_display (mod_gl_utils_context_t * utils_context,
-				       mod_gl_background_backend_t * backend,
-				       lw6gui_look_t * look);
+extern void mod_gl_background_display_background (mod_gl_utils_context_t *
+						  utils_context,
+						  mod_gl_background_backend_t
+						  * backend,
+						  lw6gui_look_t * look);
 extern int mod_gl_background_init (mod_gl_utils_context_t * utils_context,
 				   mod_gl_background_backend_t * backend);
 extern void mod_gl_background_quit (mod_gl_utils_context_t * utils_context,
