@@ -41,7 +41,8 @@ mod_gl_background_bubbles_create_backend (mod_gl_utils_context_t *
     {
       memset (backend, 0, sizeof (mod_gl_background_backend_t));
 
-      backend->display = mod_gl_background_bubbles_display;
+      backend->display_background =
+	mod_gl_background_bubbles_display_background;
       backend->init = mod_gl_background_bubbles_init;
       backend->quit = mod_gl_background_bubbles_quit;
     }
