@@ -39,7 +39,7 @@ set_background_texture_options (mod_gl_utils_context_t * utils_context,
 }
 
 static void
-background_display (mod_gl_utils_context_t * utils_context,
+display_background (mod_gl_utils_context_t * utils_context,
 		    _mod_gl_background_bubbles_context_t * bubbles_context,
 		    lw6gui_look_t * look)
 {
@@ -53,17 +53,18 @@ background_display (mod_gl_utils_context_t * utils_context,
   glLoadIdentity ();
   glTranslatef (0.0f,
 		bubbles_context->const_data.yspeed *
-		mod_gl_utils_get_ticks (utils_context) / 1000.0f, 0.0f);
+		(mod_gl_utils_timer_uptime (utils_context) % 1000000000) /
+		1000.0f, 0.0f);
 
   glBegin (GL_QUADS);
   glTexCoord2d (0.0f, 0.0f);
   glVertex3f (0.0f, 0.0f, 0.0f);	// top left
   glTexCoord2d (1.0f, 0.0f);
-  glVertex3f (utils_context->screen.width, 0.0f, 0.0f);	// top right
+  glVertex3f (utils_context->video_mode.width, 0.0f, 0.0f);	// top right
   glTexCoord2d (1.0f, 1.0f);
-  glVertex3f (utils_context->screen.width, utils_context->screen.height, 0.0f);	// bottom right
+  glVertex3f (utils_context->video_mode.width, utils_context->video_mode.height, 0.0f);	// bottom right
   glTexCoord2d (0.0f, 1.0f);
-  glVertex3f (0.0f, utils_context->screen.height, 0.0f);	// bottom left
+  glVertex3f (0.0f, utils_context->video_mode.height, 0.0f);	// bottom left
   glEnd ();
 
   glMatrixMode (GL_TEXTURE);
@@ -71,10 +72,9 @@ background_display (mod_gl_utils_context_t * utils_context,
 }
 
 static void
-background_display_bubble (mod_gl_utils_context_t * utils_context,
-			   _mod_gl_background_bubbles_context_t *
-			   bubbles_context,
-			   _mod_gl_background_bubbles_bubble_t * bubble)
+display_bubble (mod_gl_utils_context_t * utils_context,
+		_mod_gl_background_bubbles_context_t *
+		bubbles_context, _mod_gl_background_bubbles_bubble_t * bubble)
 {
   int dt;
   float y;
@@ -83,20 +83,20 @@ background_display_bubble (mod_gl_utils_context_t * utils_context,
   if (!bubble->active)
     {
       bubble->active = 1;
-      bubble->t0 = mod_gl_utils_get_ticks (utils_context);
+      bubble->t0 = mod_gl_utils_timer_uptime (utils_context);
       bubble->size =
 	lw6sys_random_float (bubbles_context->const_data.bubble_size_min,
 			     bubbles_context->const_data.bubble_size_max);
       bubble->x = lw6sys_random_float (0.0f, 1.0f);
     }
 
-  dt = mod_gl_utils_get_ticks (utils_context) - bubble->t0;
-  x_px = bubble->x * utils_context->screen.width;
+  dt = mod_gl_utils_timer_uptime (utils_context) - bubble->t0;
+  x_px = bubble->x * utils_context->video_mode.width;
   y =
     1.0f + (bubble->size / 2.0f) -
     (bubble->size * bubbles_context->const_data.bubble_yspeed * dt / 1000.0f);
-  y_px = y * utils_context->screen.height;
-  size2_px = (utils_context->screen.height * bubble->size) / 2.0f;
+  y_px = y * utils_context->video_mode.height;
+  size2_px = (utils_context->video_mode.height * bubble->size) / 2.0f;
 
   glBindTexture (GL_TEXTURE_2D, bubbles_context->texture_data.bubble);
   set_background_texture_options (utils_context, bubbles_context);
@@ -126,9 +126,9 @@ background_display_bubble (mod_gl_utils_context_t * utils_context,
 }
 
 static void
-background_display_bubbles (mod_gl_utils_context_t * utils_context,
-			    _mod_gl_background_bubbles_context_t *
-			    bubbles_context, lw6gui_look_t * look)
+display_bubbles (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_background_bubbles_context_t *
+		 bubbles_context, lw6gui_look_t * look)
 {
   int i;
 
@@ -146,26 +146,30 @@ background_display_bubbles (mod_gl_utils_context_t * utils_context,
 
   for (i = 0; i < bubbles_context->const_data.nb_bubbles; ++i)
     {
-      background_display_bubble (utils_context, bubbles_context,
-				 &(bubbles_context->state.bubbles[i]));
+      display_bubble (utils_context, bubbles_context,
+		      &(bubbles_context->state.bubbles[i]));
     }
 }
 
 void
-_mod_gl_background_bubbles_display (mod_gl_utils_context_t * utils_context,
-				    _mod_gl_background_bubbles_context_t *
-				    bubbles_context, lw6gui_look_t * look)
+_mod_gl_background_bubbles_display_background (mod_gl_utils_context_t *
+					       utils_context,
+					       _mod_gl_background_bubbles_context_t
+					       * bubbles_context,
+					       lw6gui_look_t * look)
 {
   _mod_gl_background_bubbles_colorize_if_needed (utils_context,
 						 bubbles_context, look);
-  background_display (utils_context, bubbles_context, look);
-  background_display_bubbles (utils_context, bubbles_context, look);
+  display_background (utils_context, bubbles_context, look);
+  display_bubbles (utils_context, bubbles_context, look);
 }
 
 void
-mod_gl_background_bubbles_display (mod_gl_utils_context_t * utils_context,
-				   void *bubbles_context,
-				   lw6gui_look_t * look)
+mod_gl_background_bubbles_display_background (mod_gl_utils_context_t *
+					      utils_context,
+					      void *bubbles_context,
+					      lw6gui_look_t * look)
 {
-  _mod_gl_background_bubbles_display (utils_context, bubbles_context, look);
+  _mod_gl_background_bubbles_display_background (utils_context,
+						 bubbles_context, look);
 }
