@@ -30,7 +30,7 @@
 typedef struct _mod_gl_background_bubbles_bubble_s
 {
   int active;
-  int t0;
+  int64_t t0;
   float size;
   float x;
 }
@@ -101,11 +101,12 @@ extern int _mod_gl_background_bubbles_colorize (mod_gl_utils_context_t *
 /*
  * In display.c
  */
-extern void _mod_gl_background_bubbles_display (mod_gl_utils_context_t *
-						utils_context,
-						_mod_gl_background_bubbles_context_t
-						* bubbles_context,
-						lw6gui_look_t * look);
+extern void
+_mod_gl_background_bubbles_display_background (mod_gl_utils_context_t *
+					       utils_context,
+					       _mod_gl_background_bubbles_context_t
+					       * bubbles_context,
+					       lw6gui_look_t * look);
 
 /*
  * In data.c
