@@ -29,16 +29,20 @@
 
 
 void
-_mod_gl_background_void_display (mod_gl_utils_context_t * utils_context,
-				 _mod_gl_background_void_context_t *
-				 void_context, lw6gui_look_t * look)
+_mod_gl_background_void_display_background (mod_gl_utils_context_t *
+					    utils_context,
+					    _mod_gl_background_void_context_t
+					    * void_context,
+					    lw6gui_look_t * look)
 {
   // nothing to do, just plain black... (void!)
 }
 
 void
-mod_gl_background_void_display (mod_gl_utils_context_t * utils_context,
-				void *void_context, lw6gui_look_t * look)
+mod_gl_background_void_display_background (mod_gl_utils_context_t *
+					   utils_context, void *void_context,
+					   lw6gui_look_t * look)
 {
-  _mod_gl_background_void_display (utils_context, void_context, look);
+  _mod_gl_background_void_display_background (utils_context, void_context,
+					      look);
 }
