@@ -34,11 +34,11 @@ _mod_gl_background_void_context_t;
 /*
  * In display.c
  */
-extern void _mod_gl_background_void_display (mod_gl_utils_context_t *
-					     utils_context,
-					     _mod_gl_background_void_context_t
-					     * void_context,
-					     lw6gui_look_t * look);
+extern void _mod_gl_background_void_display_background (mod_gl_utils_context_t
+							* utils_context,
+							_mod_gl_background_void_context_t
+							* void_context,
+							lw6gui_look_t * look);
 
 /*
  * In setup.c
