@@ -34,10 +34,11 @@ extern mod_gl_background_backend_t
 /*
  * In display.c
  */
-extern void mod_gl_background_void_display (mod_gl_utils_context_t *
-					    utils_context,
-					    void *background_context,
-					    lw6gui_look_t * look);
+extern void mod_gl_background_void_display_background (mod_gl_utils_context_t
+						       * utils_context,
+						       void
+						       *background_context,
+						       lw6gui_look_t * look);
 
 /*
  * In setup.c
