@@ -64,14 +64,34 @@ mod_gl_hud_quit (mod_gl_utils_context_t * utils_context,
 }
 
 void
-mod_gl_hud_display (mod_gl_utils_context_t * utils_context,
-		    mod_gl_hud_backend_t * backend,
-		    lw6gui_look_t * look, lw6ker_game_state_t * game_state)
+mod_gl_hud_display_hud (mod_gl_utils_context_t * utils_context,
+			mod_gl_hud_backend_t * backend,
+			lw6gui_look_t * look,
+			lw6ker_game_state_t * game_state,
+			lw6gui_main_cursor_t * main_cursor)
 {
-  if (backend->display)
+  if (backend->display_hud)
     {
-      backend->display (utils_context, backend->hud_context, look,
-			game_state);
+      backend->display_hud (utils_context, backend->hud_context, look,
+			    game_state, main_cursor);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+}
+
+void
+mod_gl_hud_display_score (mod_gl_utils_context_t * utils_context,
+			  mod_gl_hud_backend_t * backend,
+			  lw6gui_look_t * look,
+			  lw6ker_game_state_t * game_state,
+			  lw6gui_main_cursor_t * main_cursor)
+{
+  if (backend->display_score)
+    {
+      backend->display_score (utils_context, backend->hud_context, look,
+			      game_state, main_cursor);
     }
   else
     {
