@@ -37,19 +37,30 @@ typedef struct mod_gl_hud_backend_s
 
   void *(*init) (mod_gl_utils_context_t * utils_context);
   void (*quit) (mod_gl_utils_context_t * utils_context, void *hud_context);
-  void (*display) (mod_gl_utils_context_t * utils_context,
-		   void *hud_context, lw6gui_look_t * look,
-		   lw6ker_game_state_t * game_state);
+  void (*display_hud) (mod_gl_utils_context_t * utils_context,
+		       void *hud_context, lw6gui_look_t * look,
+		       lw6ker_game_state_t * game_state,
+		       lw6gui_main_cursor_t * main_cursor);
+  void (*display_score) (mod_gl_utils_context_t * utils_context,
+			 void *hud_context, lw6gui_look_t * look,
+			 lw6ker_game_state_t * game_state,
+			 lw6gui_main_cursor_t * main_cursor);
 }
 mod_gl_hud_backend_t;
 
 /*
  * In api.c
  */
-extern void mod_gl_hud_display (mod_gl_utils_context_t * utils_context,
-				mod_gl_hud_backend_t * backend,
-				lw6gui_look_t * look,
-				lw6ker_game_state_t * game_state);
+extern void mod_gl_hud_display_hud (mod_gl_utils_context_t * utils_context,
+				    mod_gl_hud_backend_t * backend,
+				    lw6gui_look_t * look,
+				    lw6ker_game_state_t * game_state,
+				    lw6gui_main_cursor_t * main_cursor);
+extern void mod_gl_hud_display_score (mod_gl_utils_context_t * utils_context,
+				      mod_gl_hud_backend_t * backend,
+				      lw6gui_look_t * look,
+				      lw6ker_game_state_t * game_state,
+				      lw6gui_main_cursor_t * main_cursor);
 extern int mod_gl_hud_init (mod_gl_utils_context_t * utils_context,
 			    mod_gl_hud_backend_t * backend);
 extern void mod_gl_hud_quit (mod_gl_utils_context_t * utils_context,
