@@ -39,7 +39,8 @@ mod_gl_hud_tactical_create_backend (mod_gl_utils_context_t * utils_context)
     {
       memset (backend, 0, sizeof (mod_gl_hud_backend_t));
 
-      backend->display = mod_gl_hud_tactical_display;
+      backend->display_hud = mod_gl_hud_tactical_display_hud;
+      backend->display_score = mod_gl_hud_tactical_display_score;
       backend->init = mod_gl_hud_tactical_init;
       backend->quit = mod_gl_hud_tactical_quit;
     }
