@@ -60,11 +60,11 @@ display_frame (mod_gl_utils_context_t * utils_context,
   glTexCoord2d (0.0f, 0.0f);
   glVertex3f (0.0f, 0.0f, 0.0f);	// top left
   glTexCoord2d (scale_w, 0.0f);
-  glVertex3f (utils_context->screen.width, 0.0f, 0.0f);	// top right
+  glVertex3f (utils_context->video_mode.width, 0.0f, 0.0f);	// top right
   glTexCoord2d (scale_w, scale_h);
-  glVertex3f (utils_context->screen.width, utils_context->screen.height, 0.0f);	// bottom right
+  glVertex3f (utils_context->video_mode.width, utils_context->video_mode.height, 0.0f);	// bottom right
   glTexCoord2d (0.0f, scale_h);
-  glVertex3f (0.0f, utils_context->screen.height, 0.0f);	// bottom left
+  glVertex3f (0.0f, utils_context->video_mode.height, 0.0f);	// bottom left
   glEnd ();
 
   glMatrixMode (GL_TEXTURE);
@@ -73,22 +73,49 @@ display_frame (mod_gl_utils_context_t * utils_context,
 
 
 void
-_mod_gl_hud_tactical_display (mod_gl_utils_context_t * utils_context,
-			      _mod_gl_hud_tactical_context_t *
-			      tactical_context,
-			      lw6gui_look_t * look,
-			      lw6ker_game_state_t * game_state)
+_mod_gl_hud_tactical_display_hud (mod_gl_utils_context_t * utils_context,
+				  _mod_gl_hud_tactical_context_t *
+				  tactical_context,
+				  lw6gui_look_t * look,
+				  lw6ker_game_state_t * game_state,
+				  lw6gui_main_cursor_t * main_cursor)
 {
   display_frame (utils_context, tactical_context);
 }
 
 void
-mod_gl_hud_tactical_display (mod_gl_utils_context_t * utils_context,
-			     void *hud_context,
-			     lw6gui_look_t * look,
-			     lw6ker_game_state_t * game_state)
+mod_gl_hud_tactical_display_hud (mod_gl_utils_context_t * utils_context,
+				 void *hud_context,
+				 lw6gui_look_t * look,
+				 lw6ker_game_state_t * game_state,
+				 lw6gui_main_cursor_t * main_cursor)
 {
-  _mod_gl_hud_tactical_display (utils_context,
-				(_mod_gl_hud_tactical_context_t *)
-				hud_context, look, game_state);
+  _mod_gl_hud_tactical_display_hud (utils_context,
+				    (_mod_gl_hud_tactical_context_t *)
+				    hud_context, look, game_state,
+				    main_cursor);
+}
+
+void
+_mod_gl_hud_tactical_display_score (mod_gl_utils_context_t * utils_context,
+				    _mod_gl_hud_tactical_context_t *
+				    tactical_context,
+				    lw6gui_look_t * look,
+				    lw6ker_game_state_t * game_state,
+				    lw6gui_main_cursor_t * main_cursor)
+{
+  //
+}
+
+void
+mod_gl_hud_tactical_display_score (mod_gl_utils_context_t * utils_context,
+				   void *hud_context,
+				   lw6gui_look_t * look,
+				   lw6ker_game_state_t * game_state,
+				   lw6gui_main_cursor_t * main_cursor)
+{
+  _mod_gl_hud_tactical_display_score (utils_context,
+				      (_mod_gl_hud_tactical_context_t *)
+				      hud_context, look, game_state,
+				      main_cursor);
 }
