@@ -34,10 +34,21 @@ extern mod_gl_hud_backend_t
 /*
  * In display.c
  */
-extern void mod_gl_hud_tactical_display (mod_gl_utils_context_t *
-					 utils_context, void *hud_context,
-					 lw6gui_look_t * look,
-					 lw6ker_game_state_t * game_state);
+extern void mod_gl_hud_tactical_display_hud (mod_gl_utils_context_t *
+					     utils_context, void *hud_context,
+					     lw6gui_look_t * look,
+					     lw6ker_game_state_t *
+					     game_state,
+					     lw6gui_main_cursor_t *
+					     main_cursor);
+extern void mod_gl_hud_tactical_display_score (mod_gl_utils_context_t *
+					       utils_context,
+					       void *hud_context,
+					       lw6gui_look_t * look,
+					       lw6ker_game_state_t *
+					       game_state,
+					       lw6gui_main_cursor_t *
+					       main_cursor);
 
 /*
  * In setup.c
