@@ -41,11 +41,8 @@ mod_gl_menu_cylinder_create_backend (mod_gl_utils_context_t * utils_context)
 
       backend->init = mod_gl_menu_cylinder_init;
       backend->quit = mod_gl_menu_cylinder_quit;
-      backend->display = mod_gl_menu_cylinder_display;
-      backend->pick_item = mod_gl_menu_cylinder_pick_item;
-      backend->warp_mouse_on_menuitem =
-	mod_gl_menu_cylinder_warp_mouse_on_menuitem;
-      backend->center = mod_gl_menu_cylinder_center;
+      backend->display_menu = mod_gl_menu_cylinder_display_menu;
+      backend->display_progress = mod_gl_menu_cylinder_display_progress;
     }
 
   return backend;
