@@ -66,8 +66,8 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			     &const_data->cyl_height);
       lw6cfg_read_xml_float (key, value, "oscil-range1",
 			     &const_data->oscil_range1);
-      lw6cfg_read_xml_float (key, value, "rotate-offset",
-			     &const_data->rotate_offset);
+      lw6cfg_read_xml_float (key, value, "texture-offset",
+			     &const_data->texture_offset);
       lw6cfg_read_xml_float (key, value, "sphere-radius1",
 			     &const_data->sphere_radius1);
       lw6cfg_read_xml_float (key, value, "sphere-between1",
@@ -78,6 +78,16 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			     &const_data->progress_radius);
       lw6cfg_read_xml_float (key, value, "progress-cyl-height",
 			     &const_data->progress_cyl_height);
+      lw6cfg_read_xml_float (key, value, "esc-offset",
+			     &const_data->esc_offset);
+      lw6cfg_read_xml_float (key, value, "esc-radius",
+			     &const_data->esc_radius);
+      lw6cfg_read_xml_float (key, value, "esc-cyl-height",
+			     &const_data->esc_cyl_height);
+      lw6cfg_read_xml_float (key, value, "esc-cyl-height-offset",
+			     &const_data->esc_cyl_height_offset);
+      lw6cfg_read_xml_float (key, value, "esc-rotate",
+			     &const_data->esc_rotate);
     }
 }
 
