@@ -47,10 +47,10 @@ prepare_view (mod_gl_utils_context_t * utils_context,
 static void
 draw_cylinder (mod_gl_utils_context_t * utils_context,
 	       _mod_gl_menu_cylinder_context_t * cylinder_context,
-	       int i, int n, float ratio)
+	       int i, int n, float relative_text_width)
 {
   _mod_gl_menu_cylinder_draw_cylinder (utils_context, cylinder_context,
-				       GL_RENDER, i, n, ratio);
+				       GL_RENDER, i, n, relative_text_width);
 }
 
 static void
@@ -141,7 +141,16 @@ draw_button (mod_gl_utils_context_t * utils_context,
   SDL_Color fg_color;
   int ret = 0;
   SDL_Rect text_rect;
-  SDL_Rect outline_rect;
+  SDL_Rect blit_rect;
+  int outline_w;
+  float texture_scale;
+  float draw_esc_offset;
+  float draw_esc_radius;
+  float draw_esc_cyl_height;
+  float draw_esc_cyl_height_offset;
+  float draw_esc_rotate;
+  float relative_text_width;
+  float screen_ratio;
 
   outline_surface =
     mod_gl_utils_get_button_from_menucache (utils_context, look, menuitem);
@@ -159,12 +168,10 @@ draw_button (mod_gl_utils_context_t * utils_context,
 	  if (text_surface != NULL)
 	    {
 	      utils_context->surface_counter.new_counter++;	// TTF_Render...
+	      outline_w = text_surface->w +
+		2 * utils_context->const_data.menu_font_size;
 	      outline_surface =
-		mod_gl_utils_create_surface (utils_context,
-					     text_surface->w +
-					     2 *
-					     utils_context->
-					     const_data.menu_font_size,
+		mod_gl_utils_create_surface (utils_context, outline_w,
 					     MOD_GL_UTILS_MENU_TEXTURE_H);
 	      if (outline_surface != NULL)
 		{
@@ -172,15 +179,15 @@ draw_button (mod_gl_utils_context_t * utils_context,
 		  text_rect.y = 0;
 		  text_rect.w = text_surface->w;
 		  text_rect.h = text_surface->h;
-		  outline_rect.x = (outline_surface->w - text_surface->w) / 2;
-		  outline_rect.y = (outline_surface->h - text_surface->h) / 2;
-		  outline_rect.w = outline_surface->w;
-		  outline_rect.h = outline_surface->h;
+		  blit_rect.x = (outline_surface->w - text_surface->w) / 2;
+		  blit_rect.y = (outline_surface->h - text_surface->h) / 2;
+		  blit_rect.w = text_surface->w;
+		  blit_rect.h = text_surface->h;
 
 		  mod_gl_utils_clear_surface_with_color (outline_surface,
 							 bg_color);
 		  SDL_BlitSurface (text_surface, &text_rect, outline_surface,
-				   &outline_rect);
+				   &blit_rect);
 
 		  if (!mod_gl_utils_store_button_in_menucache
 		      (utils_context, look, menuitem, outline_surface))
@@ -208,23 +215,20 @@ draw_button (mod_gl_utils_context_t * utils_context,
   if (outline_surface != NULL)
     {
       text_texture =
-	mod_gl_utils_surface2texture_xywh_using_cache (utils_context,
-						       outline_surface,
-						       (MOD_GL_UTILS_MENU_TEXTURE_W
-							-
-							outline_surface->w) /
-						       2,
-						       (MOD_GL_UTILS_MENU_TEXTURE_H
-							-
-							outline_surface->h) /
-						       2,
-						       MOD_GL_UTILS_MENU_TEXTURE_W,
-						       MOD_GL_UTILS_MENU_TEXTURE_H,
-						       menuitem->label,
-						       lw6gui_menuitem_checksum
-						       (menuitem, look));
+	mod_gl_utils_surface2texture_using_cache (utils_context,
+						  outline_surface,
+						  menuitem->label,
+						  lw6gui_menuitem_checksum
+						  (menuitem, look));
       if (text_texture)
 	{
+	  relative_text_width =
+	    ((float) outline_surface->w) /
+	    ((float) MOD_GL_UTILS_MENU_TEXTURE_W);
+	  screen_ratio =
+	    ((float) utils_context->video_mode.width) /
+	    ((float) utils_context->video_mode.height);
+	  texture_scale = mod_gl_utils_texture_scale (outline_surface->w);
 	  glEnable (GL_TEXTURE_2D);
 	  glColor3f (1.0f, 1.0f, 1.0f);
 	  glBindTexture (GL_TEXTURE_2D, text_texture);
@@ -232,16 +236,37 @@ draw_button (mod_gl_utils_context_t * utils_context,
 	  glMatrixMode (GL_TEXTURE);
 	  glPushMatrix ();
 	  glLoadIdentity ();
-	  glScalef (1.0f, -1.0f, 1.0f);
+	  glScalef (texture_scale, -1.0f, 1.0f);
 	  glTranslatef (0.0f,
-			-0.25f + cylinder_context->const_data.rotate_offset,
+			-0.25f + cylinder_context->const_data.texture_offset,
 			0.0f);
 	  glRotatef (-90.0f, 0.0f, 0.0f, 1.0f);
 
-	  draw_cylinder (utils_context, cylinder_context, i, n,
-			 ((float) MOD_GL_UTILS_MENU_TEXTURE_W) /
-			 ((float) outline_surface->w));
-
+	  if (i >= 0)
+	    {
+	      draw_cylinder (utils_context, cylinder_context, i, n,
+			     relative_text_width);
+	    }
+	  else
+	    {
+	      draw_esc_offset = cylinder_context->const_data.esc_offset;
+	      draw_esc_radius = cylinder_context->const_data.esc_radius;
+	      draw_esc_cyl_height =
+		relative_text_width *
+		cylinder_context->const_data.esc_cyl_height * screen_ratio;
+	      draw_esc_cyl_height_offset =
+		cylinder_context->const_data.esc_cyl_height_offset *
+		screen_ratio;
+	      draw_esc_rotate = cylinder_context->const_data.esc_rotate;
+	      _mod_gl_menu_cylinder_draw_fixed_cylinder (utils_context,
+							 cylinder_context,
+							 GL_RENDER,
+							 draw_esc_offset,
+							 draw_esc_radius,
+							 draw_esc_cyl_height,
+							 draw_esc_cyl_height_offset,
+							 draw_esc_rotate);
+	    }
 	  glMatrixMode (GL_TEXTURE);
 	  glPopMatrix ();
 
@@ -294,10 +319,10 @@ draw_spheres (mod_gl_utils_context_t * utils_context,
  * Display a menu.
  */
 void
-_mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
-			       _mod_gl_menu_cylinder_context_t *
-			       cylinder_context, lw6gui_look_t * look,
-			       lw6gui_menu_t * menu, float progress)
+_mod_gl_menu_cylinder_display_menu (mod_gl_utils_context_t * utils_context,
+				    _mod_gl_menu_cylinder_context_t *
+				    cylinder_context, lw6gui_look_t * look,
+				    lw6gui_menu_t * menu)
 {
   int i, j, n;
   int blink_state;
@@ -313,7 +338,7 @@ _mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
 				    const_data.max_displayed_items);
 
   blink_state =
-    mod_gl_utils_get_ticks (utils_context) /
+    mod_gl_utils_timer_uptime (utils_context) /
     (cylinder_context->const_data.sphere_blink_period / 2) % 2;
   n = menu->nb_items_displayed + 2;
   if (menu->first_item_displayed > 0)
@@ -321,18 +346,62 @@ _mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
       draw_spheres (utils_context, cylinder_context, 0, n,
 		    blink_state, cylinder_context->const_data.nb_spheres);
     }
-  for (i = 0; i < menu->nb_items_displayed; ++i)
-    {
-      j = i + menu->first_item_displayed;
-      menuitem = menu->items[j];
-      draw_button (utils_context, cylinder_context, look, menuitem, i + 1, n);
-    }
   if (menu->first_item_displayed + menu->nb_items_displayed < menu->nb_items)
     {
       draw_spheres (utils_context, cylinder_context, n - 1, n,
 		    blink_state ? 0 : 1,
 		    cylinder_context->const_data.nb_spheres);
     }
+  for (i = 0; i < menu->nb_items_displayed; ++i)
+    {
+      j = i + menu->first_item_displayed;
+      menuitem = menu->items[j];
+      draw_button (utils_context, cylinder_context, look, menuitem, i + 1, n);
+    }
+  if (menu->esc_item->enabled)
+    {
+      draw_button (utils_context, cylinder_context, look, menu->esc_item, -1,
+		   n);
+    }
+}
+
+void
+mod_gl_menu_cylinder_display_menu (mod_gl_utils_context_t * utils_context,
+				   void *cylinder_context,
+				   lw6gui_look_t * look, lw6gui_menu_t * menu)
+{
+  _mod_gl_menu_cylinder_display_menu (utils_context,
+				      (_mod_gl_menu_cylinder_context_t *)
+				      cylinder_context, look, menu);
+  /*
+   * It's really better to pick *after* drawing for the first
+   * step will generate bitmaps in cache, and those bitmaps we
+   * need later when picking to scale things
+   */
+  _mod_gl_menu_cylinder_pick_item (utils_context,
+				   (_mod_gl_menu_cylinder_context_t *)
+				   cylinder_context,
+				   look,
+				   &(utils_context->input.mouse.
+				     menu_position),
+				   &(utils_context->input.mouse.menu_scroll),
+				   &(utils_context->input.mouse.menu_esc),
+				   menu, utils_context->input.mouse.x,
+				   utils_context->input.mouse.y);
+}
+
+void
+_mod_gl_menu_cylinder_display_progress (mod_gl_utils_context_t *
+					utils_context,
+					_mod_gl_menu_cylinder_context_t *
+					cylinder_context,
+					lw6gui_look_t * look, float progress)
+{
+  mod_gl_utils_set_render_mode_3d_menu (utils_context);
+  mod_gl_utils_texture_1x1_update (utils_context, look);
+
+  prepare_view (utils_context, cylinder_context);
+
   if (progress > 0.0f && progress < 1.0f)	// strict, to disable it when complete
     {
       _mod_gl_menu_cylinder_draw_progress (utils_context, cylinder_context,
@@ -341,11 +410,11 @@ _mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
 }
 
 void
-mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
-			      void *cylinder_context, lw6gui_look_t * look,
-			      lw6gui_menu_t * menu, float progress)
+mod_gl_menu_cylinder_display_progress (mod_gl_utils_context_t * utils_context,
+				       void *cylinder_context,
+				       lw6gui_look_t * look, float progress)
 {
-  _mod_gl_menu_cylinder_display (utils_context,
-				 (_mod_gl_menu_cylinder_context_t *)
-				 cylinder_context, look, menu, progress);
+  _mod_gl_menu_cylinder_display_progress (utils_context,
+					  (_mod_gl_menu_cylinder_context_t *)
+					  cylinder_context, look, progress);
 }
