@@ -48,9 +48,10 @@ void
 _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
 				     _mod_gl_menu_cylinder_context_t *
 				     cylinder_context, GLenum mode, int i,
-				     int n, float ratio)
+				     int n, float relative_text_width)
 {
   GLUquadricObj *cyl;
+  int64_t dt;
 
   cyl = gluNewQuadric ();
   if (cyl != NULL)
@@ -67,21 +68,23 @@ _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
 	}
 
       radius = cylinder_context->const_data.radius1 / n;
-      cyl_height =
+      cyl_height = relative_text_width *
 	cylinder_context->const_data.cyl_height *
-	((float) utils_context->screen.width) /
-	((float) utils_context->screen.height);
+	((float) utils_context->video_mode.width) /
+	((float) utils_context->video_mode.height);
       y =
 	_mod_gl_menu_cylinder_get_cylinder_y (utils_context, cylinder_context,
 					      i, n);
+      dt =
+	mod_gl_utils_timer_uptime (utils_context) %
+	cylinder_context->const_data.oscil_period;
       dy =
 	(cylinder_context->const_data.oscil_range1 / n) * sin (2.0f * M_PI *
-							       (((((float)
-								   mod_gl_utils_get_ticks
-								   (utils_context)))
-								 /
+							       ((dt /
 								 ((float)
-								  cylinder_context->const_data.oscil_period))
+								  cylinder_context->
+								  const_data.
+								  oscil_period))
 								+
 								(((float) i) /
 								 ((float)
@@ -163,3 +166,55 @@ _mod_gl_menu_cylinder_draw_sphere (mod_gl_utils_context_t * utils_context,
       lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create quadric"));
     }
 }
+
+void
+_mod_gl_menu_cylinder_draw_fixed_cylinder (mod_gl_utils_context_t *
+					   utils_context,
+					   _mod_gl_menu_cylinder_context_t *
+					   cylinder_context, GLenum mode,
+					   float offset, float radius,
+					   float cyl_height,
+					   float cyl_height_offset,
+					   float rotate)
+{
+  GLUquadricObj *cyl;
+
+  cyl = gluNewQuadric ();
+  if (cyl != NULL)
+    {
+      int slices;
+      int stacks;
+
+      if (mode == GL_RENDER)
+	{
+	  gluQuadricTexture (cyl, GL_TRUE);
+	}
+
+      gluQuadricTexture (cyl, GL_TRUE);
+
+      slices = cylinder_context->const_data.slices_min;
+      stacks = cylinder_context->const_data.stacks;
+
+      glMatrixMode (GL_MODELVIEW);
+      glPushMatrix ();
+      glLoadIdentity ();
+      glTranslatef (cyl_height_offset - cyl_height / 2.0f, 0.0f, -1.0f);
+      glRotatef (90.0f, 0.0f, 1.0f, 0.0f);
+      glTranslatef (0.0f, offset, 0.0f);
+
+      glTranslatef (-0.0f, 0.0f, cyl_height / 2.0f);
+      glRotatef (rotate, 1.0f, 0.0f, 0.0f);
+      glTranslatef (0.0f, 0.0f, -cyl_height / 2.0f);
+
+      gluCylinder (cyl, radius, radius, cyl_height, slices, stacks);
+
+      glMatrixMode (GL_MODELVIEW);
+      glPopMatrix ();
+
+      gluDeleteQuadric (cyl);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create quadric"));
+    }
+}
