@@ -36,7 +36,7 @@ typedef struct _mod_gl_menu_cylinder_const_data_s
   int stacks;
   float oscil_range1;
   int oscil_period;
-  float rotate_offset;
+  float texture_offset;
   int nb_spheres;
   float sphere_radius1;
   float sphere_between1;
@@ -46,6 +46,11 @@ typedef struct _mod_gl_menu_cylinder_const_data_s
   float progress_offset;
   float progress_radius;
   float progress_cyl_height;
+  float esc_offset;
+  float esc_radius;
+  float esc_cyl_height;
+  float esc_cyl_height_offset;
+  float esc_rotate;
 }
 _mod_gl_menu_cylinder_const_data_t;
 
@@ -68,13 +73,18 @@ _mod_gl_menu_cylinder_center_on_menuitem (mod_gl_utils_context_t *
 /*
  * In display.c
  */
-extern void _mod_gl_menu_cylinder_display (mod_gl_utils_context_t *
-					   utils_context,
-					   _mod_gl_menu_cylinder_context_t *
-					   cylinder_context,
-					   lw6gui_look_t * look,
-					   lw6gui_menu_t * menu,
-					   float progress);
+extern void _mod_gl_menu_cylinder_display_menu (mod_gl_utils_context_t *
+						utils_context,
+						_mod_gl_menu_cylinder_context_t
+						* cylinder_context,
+						lw6gui_look_t * look,
+						lw6gui_menu_t * menu);
+extern void _mod_gl_menu_cylinder_display_progress (mod_gl_utils_context_t *
+						    utils_context,
+						    _mod_gl_menu_cylinder_context_t
+						    * cylinder_context,
+						    lw6gui_look_t * look,
+						    float progress);
 
 /*
  * In data.c
@@ -101,13 +111,24 @@ extern void _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t *
 						 _mod_gl_menu_cylinder_context_t
 						 * cylinder_context,
 						 GLenum mode, int i, int n,
-						 float ratio);
+						 float relative_text_width);
 extern void _mod_gl_menu_cylinder_draw_sphere (mod_gl_utils_context_t *
 					       utils_context,
 					       _mod_gl_menu_cylinder_context_t
 					       * cylinder_context,
 					       GLenum mode, int i, int n,
 					       int sphere_i, int nb_spheres);
+extern void _mod_gl_menu_cylinder_draw_fixed_cylinder (mod_gl_utils_context_t
+						       * utils_context,
+						       _mod_gl_menu_cylinder_context_t
+						       * cylinder_context,
+						       GLenum mode,
+						       float offset,
+						       float radius,
+						       float cyl_height,
+						       float
+						       cyl_height_offset,
+						       float rotate);
 
 /*
  * In pick.c
@@ -116,7 +137,7 @@ extern void
 _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
 				 _mod_gl_menu_cylinder_context_t *
 				 cylinder_context, lw6gui_look_t * look,
-				 int *position, int *scroll,
+				 int *position, int *scroll, int *esc,
 				 lw6gui_menu_t * menu, int screen_x,
 				 int screen_y);
 
