@@ -34,15 +34,43 @@
 #define NAME_DEFAULT -1
 #define NAME_PREV -2
 #define NAME_NEXT -3
+#define NAME_ESC -4
 
 static void
 draw_button_shape (mod_gl_utils_context_t * utils_context,
 		   _mod_gl_menu_cylinder_context_t * cylinder_context,
-		   int i, int n, int name)
+		   int i, int n, float relative_text_width, int name)
 {
   glLoadName (name);
-  _mod_gl_menu_cylinder_draw_cylinder (utils_context, cylinder_context,
-				       GL_SELECT, i, n, 1.0f);
+  if (i >= 0)
+    {
+      _mod_gl_menu_cylinder_draw_cylinder (utils_context, cylinder_context,
+					   GL_SELECT, i, n,
+					   relative_text_width);
+    }
+  else
+    {
+      _mod_gl_menu_cylinder_draw_fixed_cylinder (utils_context,
+						 cylinder_context, GL_SELECT,
+						 cylinder_context->const_data.
+						 esc_offset,
+						 cylinder_context->const_data.
+						 esc_radius,
+						 cylinder_context->const_data.
+						 esc_cyl_height *
+						 ((float) utils_context->
+						  video_mode.width) /
+						 ((float) utils_context->
+						  video_mode.height),
+						 cylinder_context->const_data.
+						 esc_cyl_height_offset *
+						 ((float) utils_context->
+						  video_mode.width) /
+						 ((float) utils_context->
+						  video_mode.height),
+						 cylinder_context->const_data.
+						 esc_rotate);
+    }
 }
 
 static void
@@ -60,9 +88,6 @@ draw_spheres_shape (mod_gl_utils_context_t * utils_context,
 					 GL_SELECT, i, n, sphere_i,
 					 nb_spheres);
     }
-  // we also draw the cylinder, lazy pick...
-  _mod_gl_menu_cylinder_draw_cylinder (utils_context, cylinder_context,
-				       GL_SELECT, i, n, 1.0f);
 }
 
 static int
@@ -100,7 +125,7 @@ void
 _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
 				 _mod_gl_menu_cylinder_context_t *
 				 cylinder_context, lw6gui_look_t * look,
-				 int *position, int *scroll,
+				 int *position, int *scroll, int *esc,
 				 lw6gui_menu_t * menu, int screen_x,
 				 int screen_y)
 {
@@ -109,6 +134,8 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
   lw6gui_menuitem_t *menuitem;
   GLuint select_buffer[SELECT_BUFFER_SIZE];
   GLint select_hits;
+  SDL_Surface *button_surface = NULL;
+  float relative_text_width = 1.0f;
 
   lw6gui_menu_update_display_range (menu,
 				    cylinder_context->
@@ -127,18 +154,60 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
       draw_spheres_shape (utils_context, cylinder_context, 0, n,
 			  cylinder_context->const_data.nb_spheres, NAME_PREV);
     }
-  for (i = 0; i < menu->nb_items_displayed; ++i)
-    {
-      menuitem = menu->items[i + menu->first_item_displayed];
-      draw_button_shape (utils_context,
-			 cylinder_context,
-			 i + 1, n, i + menu->first_item_displayed);
-    }
   if (menu->first_item_displayed + menu->nb_items_displayed < menu->nb_items)
     {
       draw_spheres_shape (utils_context, cylinder_context, n - 1, n,
 			  cylinder_context->const_data.nb_spheres, NAME_NEXT);
     }
+  for (i = 0; i < menu->nb_items_displayed; ++i)
+    {
+      menuitem = menu->items[i + menu->first_item_displayed];
+      button_surface =
+	mod_gl_utils_get_button_from_menucache (utils_context, look,
+						menuitem);
+      if (button_surface)
+	{
+	  /*
+	   * If button_surface doesn't exist, well, we won't die,
+	   * we just suppose the button is very large. It practise
+	   * it shouldn't happen for we've drawn them just before.
+	   */
+	  relative_text_width =
+	    ((float) button_surface->w) /
+	    ((float) MOD_GL_UTILS_MENU_TEXTURE_W);
+	}
+      else
+	{
+	  relative_text_width = 1.0f;
+	}
+      draw_button_shape (utils_context,
+			 cylinder_context,
+			 i + 1, n, relative_text_width,
+			 i + menu->first_item_displayed);
+    }
+  if (menu->esc_item->enabled)
+    {
+      button_surface =
+	mod_gl_utils_get_button_from_menucache (utils_context, look,
+						menu->esc_item);
+      if (button_surface)
+	{
+	  /*
+	   * If button_surface doesn't exist, well, we won't die,
+	   * we just suppose the button is very large. It practise
+	   * it shouldn't happen for we've drawn them just before.
+	   */
+	  relative_text_width =
+	    ((float) button_surface->w) /
+	    ((float) MOD_GL_UTILS_MENU_TEXTURE_W);
+	}
+      else
+	{
+	  relative_text_width = 1.0f;
+	}
+      draw_button_shape (utils_context, cylinder_context, -1, n,
+			 relative_text_width, NAME_ESC);
+    }
 
   select_hits = glRenderMode (GL_RENDER);
   ret = process_select_hits (select_hits, select_buffer, screen_x, screen_y);
@@ -146,28 +215,23 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
   switch (ret)
     {
     case NAME_PREV:
+      (*position) = -1;
       (*scroll) = -1;
-      (*position) = NAME_DEFAULT;
+      (*esc) = 0;
       break;
     case NAME_NEXT:
+      (*position) = -1;
       (*scroll) = +1;
-      (*position) = NAME_DEFAULT;
+      (*esc) = 0;
+      break;
+    case NAME_ESC:
+      (*position) = -1;
+      (*scroll) = 0;
+      (*esc) = 1;
       break;
     default:
       (*position) = ret;
       (*scroll) = 0;
+      (*esc) = 0;
     }
 }
-
-void
-mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
-				void *cylinder_context, lw6gui_look_t * look,
-				int *position,
-				int *scroll, lw6gui_menu_t * menu,
-				int screen_x, int screen_y)
-{
-  _mod_gl_menu_cylinder_pick_item (utils_context,
-				   (_mod_gl_menu_cylinder_context_t *)
-				   cylinder_context, look, position, scroll,
-				   menu, screen_x, screen_y);
-}
