@@ -42,51 +42,6 @@ prepare_view (mod_gl_utils_context_t * utils_context,
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
 }
 
-static void
-draw_cylinder (mod_gl_utils_context_t * utils_context,
-	       _mod_gl_menu_cylinder_context_t * cylinder_context)
-{
-  GLUquadricObj *cyl;
-
-  cyl = gluNewQuadric ();
-  if (cyl != NULL)
-    {
-      float radius;
-      float cyl_height;
-      int slices;
-      int stacks;
-      float y;
-
-      gluQuadricTexture (cyl, GL_TRUE);
-
-      radius = cylinder_context->const_data.progress_radius;
-      cyl_height =
-	cylinder_context->const_data.progress_cyl_height *
-	((float) utils_context->screen.width) /
-	((float) utils_context->screen.height);
-      y = cylinder_context->const_data.progress_offset;
-      slices = cylinder_context->const_data.slices_min;
-      stacks = cylinder_context->const_data.stacks;
-
-      glMatrixMode (GL_MODELVIEW);
-      glPushMatrix ();
-      glLoadIdentity ();
-      glTranslatef (-cyl_height / 2.0f, 0.0f, -1.0f);
-      glRotatef (90.0f, 0.0f, 1.0f, 0.0f);
-      glTranslatef (0.0f, y, 0.0f);
-      gluCylinder (cyl, radius, radius, cyl_height, slices, stacks);
-
-      glMatrixMode (GL_MODELVIEW);
-      glPopMatrix ();
-
-      gluDeleteQuadric (cyl);
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create quadric"));
-    }
-}
-
 static void
 draw_cylinder_with_color (mod_gl_utils_context_t * utils_context,
 			  _mod_gl_menu_cylinder_context_t *
@@ -102,6 +57,9 @@ draw_cylinder_with_color (mod_gl_utils_context_t * utils_context,
   SDL_Surface *surface = NULL;
   GLuint texture;
   int limit;
+  float offset;
+  float radius;
+  float cyl_height;
 
   done = look->style.menu_color_default.fg;
   todo = look->style.menu_color_default.bg;
@@ -124,7 +82,7 @@ draw_cylinder_with_color (mod_gl_utils_context_t * utils_context,
       mod_gl_utils_draw_rectfill (surface, limit, 0,
 				  MOD_GL_UTILS_MENU_TEXTURE_W - 1,
 				  MOD_GL_UTILS_MENU_TEXTURE_H - 1, i_todo);
-      texture = mod_gl_utils_surface2texture (utils_context, surface);
+      texture = mod_gl_utils_surface2texture (utils_context, surface, 0);
       if (texture)
 	{
 	  glEnable (GL_TEXTURE_2D);
@@ -136,11 +94,23 @@ draw_cylinder_with_color (mod_gl_utils_context_t * utils_context,
 	  glLoadIdentity ();
 	  glScalef (1.0f, -1.0f, 1.0f);
 	  glTranslatef (0.0f,
-			-0.25f + cylinder_context->const_data.rotate_offset,
+			-0.25f + cylinder_context->const_data.texture_offset,
 			0.0f);
 	  glRotatef (-90.0f, 0.0f, 0.0f, 1.0f);
 
-	  draw_cylinder (utils_context, cylinder_context);
+	  offset = cylinder_context->const_data.progress_offset;
+	  radius = cylinder_context->const_data.progress_radius;
+	  cyl_height =
+	    cylinder_context->const_data.progress_cyl_height *
+	    ((float) utils_context->video_mode.width) /
+	    ((float) utils_context->video_mode.height);
+
+	  _mod_gl_menu_cylinder_draw_fixed_cylinder (utils_context,
+						     cylinder_context,
+						     GL_RENDER, offset,
+						     radius, cyl_height,
+						     0.0f, 0.0f);
+
 	  glMatrixMode (GL_TEXTURE);
 	  glPopMatrix ();
 	  mod_gl_utils_schedule_delete_texture (utils_context, texture);
