@@ -34,33 +34,20 @@ extern mod_gl_menu_backend_t
   * mod_gl_menu_cylinder_create_backend (mod_gl_utils_context_t *
 					 utils_context);
 
-/*
- * In center.c
- */
-extern void mod_gl_menu_cylinder_center (mod_gl_utils_context_t *
-					 utils_context,
-					 void *cylinder_context,
-					 lw6gui_look_t * look,
-					 lw6gui_menu_t * menu, int position);
-
 /*
  * In display.c
  */
-extern void mod_gl_menu_cylinder_display (mod_gl_utils_context_t *
-					  utils_context, void *menu_context,
-					  lw6gui_look_t * look,
-					  lw6gui_menu_t * menu,
-					  float progress);
+extern void mod_gl_menu_cylinder_display_menu (mod_gl_utils_context_t *
+					       utils_context,
+					       void *menu_context,
+					       lw6gui_look_t * look,
+					       lw6gui_menu_t * menu);
 
-/*
- * In pick.c
- */
-extern void mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t *
-					    utils_context, void *menu_context,
-					    lw6gui_look_t * look,
-					    int *position, int *scroll,
-					    lw6gui_menu_t * menu,
-					    int screen_x, int screen_y);
+extern void mod_gl_menu_cylinder_display_progress (mod_gl_utils_context_t *
+						   utils_context,
+						   void *menu_context,
+						   lw6gui_look_t * look,
+						   float progress);
 
 /*
  * In setup.c
@@ -70,25 +57,4 @@ extern void *mod_gl_menu_cylinder_init (mod_gl_utils_context_t *
 extern void mod_gl_menu_cylinder_quit (mod_gl_utils_context_t * utils_context,
 				       void *menu_context);
 
-/*
- * In pick.c
- */
-extern int mod_gl_menu_cylinder_warp_mouse_on_menuitem (mod_gl_utils_context_t
-							* utils_context,
-							void *menu_context,
-							lw6gui_look_t * look,
-							lw6gui_menu_t * menu,
-							int position);
-
-/*
- * In warp.c
- */
-extern int mod_gl_menu_cylinder_warp_mouse_on_menuitem (mod_gl_utils_context_t
-							* utils_context,
-							void
-							*cylinder_context,
-							lw6gui_look_t * look,
-							lw6gui_menu_t * menu,
-							int position);
-
 #endif
