@@ -64,14 +64,14 @@ mod_gl_menu_quit (mod_gl_utils_context_t * utils_context,
 }
 
 void
-mod_gl_menu_display (mod_gl_utils_context_t * utils_context,
-		     mod_gl_menu_backend_t * backend, lw6gui_look_t * look,
-		     lw6gui_menu_t * menu, float progress)
+mod_gl_menu_display_menu (mod_gl_utils_context_t * utils_context,
+			  mod_gl_menu_backend_t * backend,
+			  lw6gui_look_t * look, lw6gui_menu_t * menu)
 {
-  if (backend->display)
+  if (backend->display_menu)
     {
-      backend->display (utils_context, backend->menu_context, look, menu,
-			progress);
+      backend->display_menu (utils_context, backend->menu_context, look,
+			     menu);
     }
   else
     {
@@ -80,54 +80,14 @@ mod_gl_menu_display (mod_gl_utils_context_t * utils_context,
 }
 
 void
-mod_gl_menu_pick_item (mod_gl_utils_context_t * utils_context,
-		       mod_gl_menu_backend_t * backend, lw6gui_look_t * look,
-		       int *position,
-		       int *scroll, lw6gui_menu_t * menu, int screen_x,
-		       int screen_y)
+mod_gl_menu_display_progress (mod_gl_utils_context_t * utils_context,
+			      mod_gl_menu_backend_t * backend,
+			      lw6gui_look_t * look, float progress)
 {
-  if (backend->pick_item)
+  if (backend->display_progress)
     {
-      backend->pick_item (utils_context, backend->menu_context, look,
-			  position, scroll, menu, screen_x, screen_y);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-}
-
-int
-mod_gl_menu_warp_mouse_on_menuitem (mod_gl_utils_context_t * utils_context,
-				    mod_gl_menu_backend_t * backend,
-				    lw6gui_look_t * look,
-				    lw6gui_menu_t * menu, int position)
-{
-  int ret = 0;
-
-  if (backend->warp_mouse_on_menuitem)
-    {
-      ret =
-	backend->warp_mouse_on_menuitem (utils_context, backend->menu_context,
-					 look, menu, position);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  return ret;
-}
-
-void
-mod_gl_menu_center (mod_gl_utils_context_t * utils_context,
-		    mod_gl_menu_backend_t * backend,
-		    lw6gui_look_t * look, lw6gui_menu_t * menu, int position)
-{
-  if (backend->center)
-    {
-      backend->center (utils_context, backend->menu_context,
-		       look, menu, position);
+      backend->display_progress (utils_context, backend->menu_context, look,
+				 progress);
     }
   else
     {
