@@ -37,18 +37,12 @@ typedef struct mod_gl_menu_backend_s
 
   void *(*init) (mod_gl_utils_context_t * utils_context);
   void (*quit) (mod_gl_utils_context_t * utils_context, void *menu_context);
-  void (*display) (mod_gl_utils_context_t * utils_context, void *menu_context,
-		   lw6gui_look_t * look, lw6gui_menu_t * menu,
-		   float progress);
-  void (*pick_item) (mod_gl_utils_context_t * utils_context,
-		     void *menu_context, lw6gui_look_t * look, int *position,
-		     int *scroll, lw6gui_menu_t * menu, int screen_x,
-		     int screen_y);
-  int (*warp_mouse_on_menuitem) (mod_gl_utils_context_t * utils_context,
-				 void *menu_context, lw6gui_look_t * look,
-				 lw6gui_menu_t * menu, int position);
-  void (*center) (mod_gl_utils_context_t * utils_context, void *menu_context,
-		  lw6gui_look_t * look, lw6gui_menu_t * menu, int position);
+  void (*display_menu) (mod_gl_utils_context_t * utils_context,
+			void *menu_context, lw6gui_look_t * look,
+			lw6gui_menu_t * menu);
+  void (*display_progress) (mod_gl_utils_context_t * utils_context,
+			    void *menu_context, lw6gui_look_t * look,
+			    float progress);
 }
 mod_gl_menu_backend_t;
 
@@ -59,25 +53,15 @@ extern int mod_gl_menu_init (mod_gl_utils_context_t * utils_context,
 			     mod_gl_menu_backend_t * backend);
 extern void mod_gl_menu_quit (mod_gl_utils_context_t * utils_context,
 			      mod_gl_menu_backend_t * backend);
-extern void mod_gl_menu_display (mod_gl_utils_context_t * utils_context,
-				 mod_gl_menu_backend_t * backend,
-				 lw6gui_look_t * look, lw6gui_menu_t * menu,
-				 float progress);
-extern void mod_gl_menu_pick_item (mod_gl_utils_context_t * utils_context,
-				   mod_gl_menu_backend_t * backend,
-				   lw6gui_look_t * look, int *position,
-				   int *scroll, lw6gui_menu_t * menu,
-				   int screen_x, int screen_y);
-extern int mod_gl_menu_warp_mouse_on_menuitem (mod_gl_utils_context_t *
-					       utils_context,
-					       mod_gl_menu_backend_t *
-					       backend, lw6gui_look_t * look,
-					       lw6gui_menu_t * menu,
-					       int position);
-extern void mod_gl_menu_center (mod_gl_utils_context_t * utils_context,
-				mod_gl_menu_backend_t * backend,
-				lw6gui_look_t * look, lw6gui_menu_t * menu,
-				int position);
+extern void mod_gl_menu_display_menu (mod_gl_utils_context_t * utils_context,
+				      mod_gl_menu_backend_t * backend,
+				      lw6gui_look_t * look,
+				      lw6gui_menu_t * menu);
+extern void mod_gl_menu_display_progress (mod_gl_utils_context_t *
+					  utils_context,
+					  mod_gl_menu_backend_t * backend,
+					  lw6gui_look_t * look,
+					  float progress);
 
 /*
  * In backend.c
