@@ -26,7 +26,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 SDL_Color
 mod_gl_utils_color_8_to_sdl (lw6sys_color_8_t color_8)
@@ -117,6 +116,21 @@ mod_gl_utils_update_team_color_map (mod_gl_utils_team_color_map_t *
     }
 }
 
+int
+mod_gl_utils_team_color_map_is_same (mod_gl_utils_team_color_map_t
+				     * team_color_map_a,
+				     mod_gl_utils_team_color_map_t *
+				     team_color_map_b)
+{
+  int ret = 0;
+
+  ret =
+    !memcmp (team_color_map_a, team_color_map_b,
+	     sizeof (mod_gl_utils_team_color_map_t));
+
+  return ret;
+}
+
 void
 mod_gl_utils_force_color32_alpha (Uint32 * color, float alpha)
 {
@@ -124,3 +138,17 @@ mod_gl_utils_force_color32_alpha (Uint32 * color, float alpha)
 
   ptr[3] = (unsigned char) (alpha * 255.0f);
 }
+
+Uint32
+mod_gl_utils_get_shaded_color_for_fighter_f (mod_gl_utils_context_t *
+					     utils_context, int team_id,
+					     float health)
+{
+  Uint32 ret;
+  float f;
+
+  f = health * (float) MOD_GL_SHADES_FOR_FIGHTERS_SCALE;
+  ret = utils_context->team_color_map.team_colors[team_id][(int) f];
+
+  return ret;
+}
