@@ -29,7 +29,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 #define FONT_FILE "utils/font/FreeSansBold.ttf"
 
@@ -49,6 +48,12 @@ mod_gl_utils_load_image (mod_gl_utils_context_t * utils_context,
     {
       lw6sys_log (LW6SYS_LOG_INFO, _("loading image \"%s\""), image_file);
       ret = IMG_Load (image_file);
+      if (!ret)
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("SDL_image error \"%s\" while loading image \"%s\""),
+		      IMG_GetError (), image_file);
+	}
       LW6SYS_FREE (image_file);
     }
 
@@ -78,47 +83,6 @@ mod_gl_utils_unload_image (mod_gl_utils_context_t * utils_context,
   mod_gl_utils_delete_surface (utils_context, image);
 }
 
-/*
- * Dummy wrapper to handle cast & errors.
- */
-GLuint
-mod_gl_utils_load_texture (mod_gl_utils_context_t * utils_context,
-			   SDL_Surface * surface)
-{
-  GLuint ret = 0;
-
-  ret = mod_gl_utils_surface2texture (utils_context, surface);
-
-  if (!ret)
-    {
-      lw6sys_log (LW6SYS_LOG_ERROR, _("unable to load texture"));
-    }
-
-  return ret;
-}
-
-/*
- * Dummy wrapper to handle cast & errors.
- */
-void
-mod_gl_utils_unload_texture (mod_gl_utils_context_t * utils_context,
-			     int texture)
-{
-  if (texture != 0)
-    {
-      mod_gl_utils_delete_texture (utils_context, texture);
-    }
-  else
-    {
-      /*
-       * Not sure wether 0 is actually an invalid texture id,
-       * in doubt we issue a warning, if it ever shows up,
-       * will be time to decide wether to disable this check or not.
-       */
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to delete NULL texture"));
-    }
-}
-
 /*
  * Dummy wrapper to handle cast & errors.
  */
@@ -162,7 +126,7 @@ unload_font (TTF_Font * font)
  * Loads fonts
  */
 int
-_mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
+mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
 {
   int ret = 0;
 
@@ -200,7 +164,7 @@ _mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
  * Unload fonts, free memory
  */
 void
-_mod_gl_utils_unload_fonts (mod_gl_utils_context_t * utils_context)
+mod_gl_utils_unload_fonts (mod_gl_utils_context_t * utils_context)
 {
   unload_font (utils_context->font_data.system);
   unload_font (utils_context->font_data.cursor);
@@ -221,8 +185,7 @@ mod_gl_utils_load_data (mod_gl_utils_context_t * utils_context)
 
   ret =
     ((utils_context->texture_data.to_delete = lw6sys_list_new (NULL)) != NULL)
-    && _mod_gl_utils_load_consts (utils_context)
-    && _mod_gl_utils_load_fonts (utils_context);
+    && mod_gl_utils_load_fonts (utils_context);
 
   look = lw6gui_look_new (NULL);
   if (look)
@@ -256,11 +219,9 @@ mod_gl_utils_unload_data (mod_gl_utils_context_t * utils_context)
   memset (&utils_context->texture_data, 0,
 	  sizeof (mod_gl_utils_texture_data_t));
 
-  _mod_gl_utils_unload_fonts (utils_context);
+  mod_gl_utils_unload_fonts (utils_context);
 
   mod_gl_utils_texture_1x1_clear (utils_context);
-
-  _mod_gl_utils_unload_consts (utils_context);
 }
 
 void
