@@ -24,11 +24,10 @@
 #include "config.h"
 #endif
 
-#include <GL/glu.h>
+//#include <GL/glu.h>
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 static void
 get_text_wh (TTF_Font * font, char *text, int *width, int *height)
@@ -83,6 +82,32 @@ mod_gl_utils_get_system_text_height (mod_gl_utils_context_t * context,
   return get_text_height (context->font_data.system, text);
 }
 
+SDL_Surface *
+mod_gl_utils_blended_text_surface (mod_gl_utils_context_t * context,
+				   TTF_Font * font, SDL_Color color,
+				   char *text)
+{
+  SDL_Surface *ret = NULL;
+  char *utf8 = NULL;
+
+  utf8 = lw6sys_locale_to_utf8 (text);
+  if (utf8 != NULL)
+    {
+      ret = TTF_RenderUTF8_Blended (font, utf8, color);
+      if (ret)
+	{
+	  context->surface_counter.new_counter++;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("TTF_RenderUTF8_Blended failed"));
+	}
+      LW6SYS_FREE (utf8);
+    }
+
+  return ret;
+}
+
 /*
  * Helper internal func
  */
@@ -92,53 +117,28 @@ draw_text (mod_gl_utils_context_t * context,
 {
   SDL_Surface *text_surface;
   GLuint text_texture;
-  char *utf8;
   int ret = 0;
 
-  utf8 = lw6sys_locale_to_utf8 (text);
-  if (utf8 != NULL)
+  text_surface =
+    mod_gl_utils_blended_text_surface (context, font, color, text);
+  if (text_surface != NULL)
     {
-      text_surface = TTF_RenderUTF8_Blended (font, utf8, color);
-      if (text_surface != NULL)
+      text_texture = mod_gl_utils_surface2texture (context, text_surface, 0);
+      if (text_texture)
 	{
-	  context->surface_counter.new_counter++;
-	  text_texture = mod_gl_utils_surface2texture (context, text_surface);
-	  if (text_texture)
-	    {
-	      glEnable (GL_TEXTURE_2D);
-	      glColor3f (1.0f, 1.0f, 1.0f);
-	      glBindTexture (GL_TEXTURE_2D, text_texture);
+	  glEnable (GL_TEXTURE_2D);
+	  glColor3f (1.0f, 1.0f, 1.0f);
+	  mod_gl_utils_display_texture_full (context, text_texture, x, y,
+					     text_surface->w + x,
+					     text_surface->h + y,
+					     text_surface->w,
+					     text_surface->h);
 
-	      GLdouble x1 = (GLdouble) x;
-	      GLdouble y1 = (GLdouble) y;
-	      GLdouble x2 = (GLdouble) text_surface->w + x;
-	      GLdouble y2 = (GLdouble) text_surface->h + y;
-	      GLdouble texw = mod_gl_utils_texture_scale (text_surface->w);
-	      GLdouble texh = mod_gl_utils_texture_scale (text_surface->h);
+	  ret = 1;
 
-	      glBegin (GL_QUADS);
-	      glTexCoord2d (0.0f, 0.0f);
-	      glVertex3f (x1, y1, 0.0f);	// top left
-	      glTexCoord2d (texw, 0.0f);
-	      glVertex3f (x2, y1, 0.0f);	// top right
-	      glTexCoord2d (texw, texh);
-	      glVertex3f (x2, y2, 0.0f);	// bottom right
-	      glTexCoord2d (0.0f, texh);
-	      glVertex3f (x1, y2, 0.0f);	// bottom left
-	      glEnd ();
-	      glPopMatrix ();
-
-	      ret = 1;
-
-	      mod_gl_utils_schedule_delete_texture (context, text_texture);
-	    }
-	  mod_gl_utils_delete_surface (context, text_surface);
+	  mod_gl_utils_schedule_delete_texture (context, text_texture);
 	}
-      else
-	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("TTF_RenderUTF8_Blended failed"));
-	}
-      LW6SYS_FREE (utf8);
+      mod_gl_utils_delete_surface (context, text_surface);
     }
 
   if (!ret)
@@ -216,7 +216,7 @@ mod_gl_utils_draw_system_text_top_right (mod_gl_utils_context_t * context,
 
   mod_gl_utils_set_render_mode_2d_blend (context);
 
-  x = context->screen.width;
+  x = context->video_mode.width;
   y = 0;
   while (*text_list)
     {
@@ -257,7 +257,7 @@ mod_gl_utils_draw_system_text_bottom_left (mod_gl_utils_context_t * context,
       list_end++;
     }
 
-  y = context->screen.height;
+  y = context->video_mode.height;
   tmp_list = list_end;
   while (tmp_list != text_list)
     {
@@ -298,8 +298,8 @@ mod_gl_utils_draw_system_text_bottom_right (mod_gl_utils_context_t * context,
       list_end++;
     }
 
-  x = context->screen.width;
-  y = context->screen.height;
+  x = context->video_mode.width;
+  y = context->video_mode.height;
   tmp_list = list_end;
   while (tmp_list != text_list)
     {
