@@ -26,7 +26,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 /*
  * This is where the game map with actual information "there are
@@ -39,48 +38,91 @@ update_game_surface (mod_gl_utils_context_t * utils_context,
 		     lw6gui_look_t * look, int x0, int y0, int w, int h)
 {
   int x, y, z, x1, y1, d;
+  int safe_x, safe_y;
   int fighter_id, hidden;
   lw6ker_fighter_t *fighter;
   Uint32 color;
   float hidden_layer_alpha;
+  int team_color;
+  lw6map_rules_t *rules;
+  lw6sys_whd_t *shape;
+  int bytes_per_pixel;
 
   hidden_layer_alpha = look->style.hidden_layer_alpha;
   x1 = x0 + w;
   y1 = y0 + h;
-  d = game_state->map_state.shape.d;
+  shape = &(game_state->map_state.shape);
+  d = shape->d;
+  rules = &(game_state->game_struct->rules);
+  bytes_per_pixel = surface->format->BytesPerPixel;
   for (x = x0; x < x1; ++x)
     {
       for (y = y0; y < y1; ++y)
 	{
 	  fighter_id = -1;
 	  hidden = 0;
+	  safe_x = x;
+	  safe_y = y;
+	  lw6map_coords_fix_xy (rules, shape, &safe_x, &safe_y);
 	  for (z = 0; z < d && fighter_id < 0; ++z)
 	    {
 	      fighter_id =
 		lw6ker_map_state_get_fighter_id (&(game_state->map_state),
-						 x, y, z);
-	      if (fighter_id < 0)
+						 safe_x, safe_y, z);
+	      /*
+	       * It's important to test d>1 else a call
+	       * to get_zone_id is done when it's not needed,
+	       * and this function does cost CPU. When d==1 hidden
+	       * just makes no sense.
+	       */
+	      if (d > 1 && fighter_id < 0)
 		{
 		  hidden =
 		    (lw6ker_map_struct_get_zone_id
-		     (game_state->map_state.map_struct, x, y, z) < 0);
+		     (game_state->map_state.map_struct, safe_x, safe_y,
+		      z) < 0);
 		}
 	    }
 	  if (fighter_id >= 0)
 	    {
 	      fighter = &(game_state->map_state.armies.fighters[fighter_id]);
-	      color = mod_gl_utils_get_shaded_color_for_fighter
-		(utils_context, fighter->team_color, fighter->health);
-	      if (hidden)
+	      team_color = fighter->team_color;
+	      if (team_color >= 0)
 		{
-		  mod_gl_utils_force_color32_alpha (&color,
-						    hidden_layer_alpha);
+		  /*
+		   * We need to cache & check team_color for in dirty read
+		   * mode, team_color could be negative even if fighter was
+		   * reported active just before.
+		   */
+		  color = mod_gl_utils_get_shaded_color_for_fighter
+		    (utils_context, team_color, fighter->health);
+		  if (hidden)
+		    {
+		      mod_gl_utils_force_color32_alpha (&color,
+							hidden_layer_alpha);
+		    }
+		}
+	      if (bytes_per_pixel == 4)
+		{
+		  mod_gl_utils_putpixel_4_bytes_per_pixel (surface, x - x0,
+							   y - y0, color);
+		}
+	      else
+		{
+		  mod_gl_utils_putpixel (surface, x - x0, y - y0, color);
 		}
-	      mod_gl_utils_putpixel (surface, x - x0, y - y0, color);
 	    }
 	  else
 	    {
-	      mod_gl_utils_putpixel (surface, x - x0, y - y0, 0);
+	      if (bytes_per_pixel == 4)
+		{
+		  mod_gl_utils_putpixel_4_bytes_per_pixel (surface, x - x0,
+							   y - y0, 0);
+		}
+	      else
+		{
+		  mod_gl_utils_putpixel (surface, x - x0, y - y0, 0);
+		}
 	    }
 	}
     }
@@ -93,8 +135,6 @@ mod_gl_utils_update_game_texture (mod_gl_utils_context_t * utils_context,
 				  lw6ker_game_state_t * game_state,
 				  lw6gui_look_t * look)
 {
-  mod_gl_utils_update_team_color_map (&(utils_context->team_color_map),
-				      &(look->style));
   update_game_surface (utils_context, surface, game_state, look,
 		       0, 0, game_state->map_state.shape.w,
 		       game_state->map_state.shape.h);
@@ -105,7 +145,8 @@ mod_gl_utils_update_game_texture (mod_gl_utils_context_t * utils_context,
    * be created each time: it's always the same size and represents
    * pretty much the same thing/layer -> where fighters are!
    */
-  mod_gl_utils_texture_update (utils_context, texture, surface);
+  mod_gl_utils_texture_update (utils_context, texture, surface,
+			       look->style.pixelize);
 }
 
 void
@@ -130,9 +171,6 @@ mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
       utils_context->last_action.game_texture_array_update_rounds =
 	game_state->rounds;
 
-      mod_gl_utils_update_team_color_map (&(utils_context->team_color_map),
-					  &(look->style));
-
       for (n_y = 0; n_y < surface_array->layout.n_h; ++n_y)
 	{
 	  for (n_x = 0; n_x < surface_array->layout.n_w; ++n_x)
@@ -152,7 +190,7 @@ mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
        * Now transform surfaces into textures.
        */
       mod_gl_utils_texture_array_update (utils_context, texture_array,
-					 surface_array);
+					 surface_array, look->style.pixelize);
     }
   else
     {
