@@ -28,7 +28,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 void
 mod_gl_utils_display_log (mod_gl_utils_context_t * context,
@@ -46,11 +45,11 @@ mod_gl_display_log (void *context, lw6gui_look_t * look, char **log_list)
 
 void
 mod_gl_utils_display_fps (mod_gl_utils_context_t * context,
-			  lw6gui_look_t * look, int fps)
+			  lw6gui_look_t * look, float fps)
 {
   char *list_fps[2];
 
-  list_fps[0] = lw6sys_itoa (fps);
+  list_fps[0] = lw6sys_itoa ((int) fps);
   list_fps[1] = NULL;
 
   if (list_fps[0])
@@ -61,7 +60,33 @@ mod_gl_utils_display_fps (mod_gl_utils_context_t * context,
 }
 
 void
-mod_gl_display_fps (void *context, lw6gui_look_t * look, int fps)
+mod_gl_display_fps (void *context, lw6gui_look_t * look, float fps)
 {
   mod_gl_utils_display_fps ((mod_gl_utils_context_t *) context, look, fps);
 }
+
+void
+mod_gl_utils_display_rps (mod_gl_utils_context_t * context,
+			  lw6gui_look_t * look, float rps)
+{
+  char *list_rps[3];
+
+  if (rps >= 0.1f)
+    {
+      list_rps[0] = " ";
+      list_rps[1] = lw6sys_new_sprintf ("%0.1f", rps);
+      list_rps[2] = NULL;
+
+      if (list_rps[0])
+	{
+	  mod_gl_utils_draw_system_text_top_right (context, look, list_rps);
+	  LW6SYS_FREE (list_rps[1]);
+	}
+    }
+}
+
+void
+mod_gl_display_rps (void *context, lw6gui_look_t * look, float rps)
+{
+  mod_gl_utils_display_rps ((mod_gl_utils_context_t *) context, look, rps);
+}
