@@ -26,24 +26,23 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 /*
  * Setup main light (top left).
  */
 void
-mod_gl_utils_main_light (mod_gl_utils_context_t * context)
+mod_gl_utils_main_light (mod_gl_utils_context_t * utils_context)
 {
-  GLfloat mainlight_specular[4] = { 1.0f, 1.0f, 1.0f, 1.0 };
+  GLfloat mainlight_specular[4] = { 1.0f, 1.0f, 1.0f, 1.0f };
   GLfloat mainlight_position[4] = { 1.0f, 1.0f, 1.0f, 0.0f };
 
-  mainlight_specular[0] = context->const_data.mainlight_r;
-  mainlight_specular[1] = context->const_data.mainlight_g;
-  mainlight_specular[2] = context->const_data.mainlight_b;
-  mainlight_specular[3] = context->const_data.mainlight_a;
-  mainlight_position[0] = context->const_data.mainlight_x;
-  mainlight_position[1] = context->const_data.mainlight_y;
-  mainlight_position[2] = context->const_data.mainlight_z;
+  mainlight_specular[0] = utils_context->const_data.mainlight_r;
+  mainlight_specular[1] = utils_context->const_data.mainlight_g;
+  mainlight_specular[2] = utils_context->const_data.mainlight_b;
+  mainlight_specular[3] = utils_context->const_data.mainlight_a;
+  mainlight_position[0] = utils_context->const_data.mainlight_x;
+  mainlight_position[1] = utils_context->const_data.mainlight_y;
+  mainlight_position[2] = utils_context->const_data.mainlight_z;
 
   glEnable (GL_LIGHTING);
   glLightfv (GL_LIGHT0, GL_POSITION, mainlight_position);
