@@ -26,7 +26,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 int
 mod_gl_utils_rect_array_init (mod_gl_utils_context_t *
@@ -36,13 +35,15 @@ mod_gl_utils_rect_array_init (mod_gl_utils_context_t *
 {
   int ret = 0;
   int n_w, n_h, n_x, n_y;
+  int tile_spacing;
 
   tile_size = mod_gl_utils_power_of_two_le (tile_size);
   tile_size = lw6sys_min (tile_size, utils_context->caps.max_texture_size);
-  tile_size = lw6sys_max (tile_size, 1);
+  tile_size = lw6sys_max (tile_size, 3);
+  tile_spacing = tile_size - 2;
 
-  n_w = ((w - 1) / tile_size) + 1;
-  n_h = ((h - 1) / tile_size) + 1;
+  n_w = ((w - 1) / tile_spacing) + 1;
+  n_h = ((h - 1) / tile_spacing) + 1;
 
   rect_array->n_w = n_w;
   rect_array->n_h = n_h;
@@ -50,25 +51,27 @@ mod_gl_utils_rect_array_init (mod_gl_utils_context_t *
   rect_array->y0 = (int *) LW6SYS_CALLOC (n_h * sizeof (int));
   rect_array->w = (int *) LW6SYS_CALLOC (n_w * sizeof (int));
   rect_array->h = (int *) LW6SYS_CALLOC (n_h * sizeof (int));
+  rect_array->screen_x = (float *) LW6SYS_CALLOC ((n_w + 1) * sizeof (float));
+  rect_array->screen_y = (float *) LW6SYS_CALLOC ((n_h + 1) * sizeof (float));
 
   if (rect_array->x0 && rect_array->y0 && rect_array->w && rect_array->h
-      && n_w > 0 && n_h > 0)
+      && rect_array->screen_x && rect_array->screen_y && n_w > 0 && n_h > 0)
     {
-      rect_array->x0[0] = 0;
+      rect_array->x0[0] = -1;
       for (n_x = 0; n_x < n_w - 1; ++n_x)
 	{
 	  rect_array->w[n_x] = tile_size;
-	  rect_array->x0[n_x + 1] = rect_array->x0[n_x] + tile_size;
+	  rect_array->x0[n_x + 1] = rect_array->x0[n_x] + tile_spacing;
 	}
-      rect_array->w[n_w - 1] = w - rect_array->x0[n_w - 1];
+      rect_array->w[n_w - 1] = w + 1 - rect_array->x0[n_w - 1];
 
-      rect_array->y0[0] = 0;
+      rect_array->y0[0] = -1;
       for (n_y = 0; n_y < n_h - 1; ++n_y)
 	{
 	  rect_array->h[n_y] = tile_size;
-	  rect_array->y0[n_y + 1] = rect_array->y0[n_y] + tile_size;
+	  rect_array->y0[n_y + 1] = rect_array->y0[n_y] + tile_spacing;
 	}
-      rect_array->h[n_h - 1] = h - rect_array->y0[n_h - 1];
+      rect_array->h[n_h - 1] = h + 1 - rect_array->y0[n_h - 1];
 
       if (rect_array->w[n_w - 1] > 0 && rect_array->w[n_w - 1] <= tile_size &&
 	  rect_array->h[n_h - 1] > 0 && rect_array->h[n_h - 1] <= tile_size)
@@ -113,5 +116,13 @@ mod_gl_utils_rect_array_clear (mod_gl_utils_context_t *
     {
       LW6SYS_FREE (rect_array->h);
     }
+  if (rect_array->screen_x)
+    {
+      LW6SYS_FREE (rect_array->screen_x);
+    }
+  if (rect_array->screen_y)
+    {
+      LW6SYS_FREE (rect_array->screen_y);
+    }
   memset (rect_array, 0, sizeof (mod_gl_utils_rect_array_t));
 }
