@@ -26,7 +26,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 #define PICK_WIDTH 3.0f
 #define PICK_HEIGHT 3.0f
@@ -48,10 +47,11 @@ mod_gl_utils_prepare_buffer (mod_gl_utils_context_t * utils_context,
   lw6sys_color_f_t bg_color;
 
   mod_gl_utils_sync_viewport (utils_context);
-
   lw6sys_color_8_to_f (&bg_color, look->style.background_color_root.bg);
   glClearColor (bg_color.r, bg_color.g, bg_color.b, bg_color.a);
   glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+  mod_gl_utils_update_team_color_map (&(utils_context->team_color_map),
+				      &(look->style));
 }
 
 void
@@ -67,7 +67,11 @@ mod_gl_prepare_buffer (void *utils_context, lw6gui_look_t * look)
 void
 mod_gl_utils_swap_buffers (mod_gl_utils_context_t * utils_context)
 {
-  glFinish ();
+  /*
+   * glFinish suspected to be a performance killer, and anyways
+   * SwapBuffers should call it.
+   */
+  //glFinish ();
   SDL_GL_SwapBuffers ();
   mod_gl_utils_optimize_texturecache (utils_context);
   mod_gl_utils_delete_scheduled_textures (utils_context);
@@ -89,8 +93,8 @@ mod_gl_utils_set_render_mode_2d (mod_gl_utils_context_t * utils_context)
       glLoadIdentity ();
 
       gluOrtho2D (0.0f,		// left
-		  (GLfloat) utils_context->screen.width,	// right
-		  (GLfloat) utils_context->screen.height,	// bottom
+		  (GLfloat) utils_context->video_mode.width,	// right
+		  (GLfloat) utils_context->video_mode.height,	// bottom
 		  0.0f);	// top
 
       glDisable (GL_DEPTH_TEST);
@@ -112,8 +116,8 @@ mod_gl_utils_set_render_mode_2d_blend (mod_gl_utils_context_t * utils_context)
       glLoadIdentity ();
 
       gluOrtho2D (0.0f,		// left
-		  (GLfloat) utils_context->screen.width,	// right
-		  (GLfloat) utils_context->screen.height,	// bottom
+		  (GLfloat) utils_context->video_mode.width,	// right
+		  (GLfloat) utils_context->video_mode.height,	// bottom
 		  0.0f);	// top
 
       glDisable (GL_DEPTH_TEST);
@@ -135,8 +139,8 @@ mod_gl_utils_set_render_mode_3d_map (mod_gl_utils_context_t * utils_context)
       glMatrixMode (GL_PROJECTION);
       glLoadIdentity ();
       gluPerspective (utils_context->const_data.persp_fovy,
-		      ((float) utils_context->screen.width) /
-		      ((float) utils_context->screen.height),
+		      ((float) utils_context->video_mode.width) /
+		      ((float) utils_context->video_mode.height),
 		      utils_context->const_data.persp_znear,
 		      utils_context->const_data.persp_zfar);
       glEnable (GL_DEPTH_TEST);
@@ -158,14 +162,14 @@ mod_gl_utils_set_render_mode_3d_menu (mod_gl_utils_context_t * utils_context)
       glMatrixMode (GL_PROJECTION);
       glLoadIdentity ();
       gluPerspective (utils_context->const_data.persp_fovy,
-		      ((float) utils_context->screen.width) /
-		      ((float) utils_context->screen.height),
+		      ((float) utils_context->video_mode.width) /
+		      ((float) utils_context->video_mode.height),
 		      utils_context->const_data.persp_znear,
 		      utils_context->const_data.persp_zfar);
       glEnable (GL_DEPTH_TEST);
       glEnable (GL_DEPTH);
-      glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-      glEnable (GL_BLEND);
+      //glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+      glDisable (GL_BLEND);
       mod_gl_utils_main_light (utils_context);
 
       utils_context->render_mode = MOD_GL_UTILS_RENDER_3D_MENU;
@@ -188,8 +192,8 @@ mod_gl_utils_set_render_mode_3d_pick (mod_gl_utils_context_t * utils_context,
       gluPickMatrix (x, viewport[3] - y, PICK_WIDTH, PICK_HEIGHT, viewport);
 
       gluPerspective (utils_context->const_data.persp_fovy,
-		      ((float) utils_context->screen.width) /
-		      ((float) utils_context->screen.height),
+		      ((float) utils_context->video_mode.width) /
+		      ((float) utils_context->video_mode.height),
 		      utils_context->const_data.persp_znear,
 		      utils_context->const_data.persp_zfar);
       glDisable (GL_DEPTH_TEST);
@@ -200,26 +204,3 @@ mod_gl_utils_set_render_mode_3d_pick (mod_gl_utils_context_t * utils_context,
       utils_context->render_mode = MOD_GL_UTILS_RENDER_3D_PICK;
     }
 }
-
-void
-mod_gl_utils_set_render_mode_3d_warp (mod_gl_utils_context_t * utils_context)
-{
-  basic_cleanup ();
-  if (utils_context->render_mode != MOD_GL_UTILS_RENDER_3D_WARP)
-    {
-      glMatrixMode (GL_PROJECTION);
-      glLoadIdentity ();
-
-      gluPerspective (utils_context->const_data.persp_fovy,
-		      ((float) utils_context->screen.width) /
-		      ((float) utils_context->screen.height),
-		      utils_context->const_data.persp_znear,
-		      utils_context->const_data.persp_zfar);
-      glDisable (GL_DEPTH_TEST);
-      glDisable (GL_DEPTH);
-      glDisable (GL_BLEND);
-      glDisable (GL_LIGHTING);
-
-      utils_context->render_mode = MOD_GL_UTILS_RENDER_3D_WARP;
-    }
-}
