@@ -26,7 +26,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 int
 mod_gl_utils_surface_array_init (mod_gl_utils_context_t *
@@ -102,6 +101,8 @@ mod_gl_utils_surface_array_init_from_surface (mod_gl_utils_context_t *
   SDL_Surface *sub_surface;
   SDL_Rect area;
   SDL_Rect sub_area;
+  SDL_Rect border_area;
+  SDL_Rect border_sub_area;
 
   if (mod_gl_utils_surface_array_init
       (utils_context, surface_array, surface->w, surface->h, tile_size))
@@ -130,6 +131,54 @@ mod_gl_utils_surface_array_init_from_surface (mod_gl_utils_context_t *
 		  SDL_SetAlpha (sub_surface, 0, SDL_ALPHA_OPAQUE);
 		  mod_gl_utils_clear_surface (sub_surface);
 		  SDL_BlitSurface (surface, &area, sub_surface, &sub_area);
+		  if (area.x == -1)
+		    {
+		      border_area = area;
+		      border_area.x = 0;
+		      border_area.w = 1;
+		      border_sub_area = sub_area;
+		      border_sub_area.w = 1;
+		      SDL_BlitSurface (surface, &border_area, sub_surface,
+				       &border_sub_area);
+		    }
+		  if (area.y == -1)
+		    {
+		      border_area = area;
+		      border_area.y = 0;
+		      border_area.h = 1;
+		      border_sub_area = sub_area;
+		      border_sub_area.h = 1;
+		      SDL_BlitSurface (surface, &border_area, sub_surface,
+				       &border_sub_area);
+		    }
+		  if (area.x + area.w == surface->w + 1)
+		    {
+		      border_area = area;
+		      border_area.x = surface->w - 1;
+		      border_area.w = 1;
+		      border_sub_area = sub_area;
+		      border_sub_area.x = sub_area.w - 1;
+		      border_sub_area.w = 1;
+		    }
+		  if (area.y + area.h == surface->h + 1)
+		    {
+		      border_area = area;
+		      border_area.y = surface->h - 1;
+		      border_area.h = 1;
+		      border_sub_area = sub_area;
+		      border_sub_area.y = sub_area.h - 1;
+		      border_sub_area.h = 1;
+		    }
+		  if (area.x < -1 || area.y < -1
+		      || area.x + area.w > surface->w + 1
+		      || area.y + area.h > surface->h + 1)
+		    {
+		      lw6sys_log (LW6SYS_LOG_WARNING,
+				  _
+				  ("unsupported ayout area.x=%d area.y=%d area.w=%d area.h=%d surface->w=%d surface->h=%d"),
+				  area.x, area.y, area.w, area.h, surface->w,
+				  surface->h);
+		    }
 		}
 	      else
 		{
