@@ -26,7 +26,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 /*
  * A bunch of code here has been ripped from SDL examples,
@@ -74,8 +73,9 @@ mod_gl_utils_texture_scale (int size)
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
-		      SDL_Surface * surface, int x, int y, int w, int h)
+_surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
+		       SDL_Surface * surface, int x, int y, int w, int h,
+		       int mipmap)
 {
   GLuint texture = 0;
 
@@ -114,14 +114,14 @@ surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
     }
 
   /* Copy the surface into the GL texture image */
-  src_area.x = 0;
-  src_area.y = 0;
-  src_area.w = surface->w;
-  src_area.h = surface->h;
-  dst_area.x = x;
-  dst_area.y = y;
-  dst_area.w = surface->w - x;
-  dst_area.h = surface->h - y;
+  src_area.x = x;
+  src_area.y = y;
+  src_area.w = surface->w - x;
+  src_area.h = surface->h - y;
+  dst_area.x = 0;
+  dst_area.y = 0;
+  dst_area.w = surface->w;
+  dst_area.h = surface->h;
   SDL_BlitSurface (surface, &src_area, image, &dst_area);
 
   /* Restore the alpha blending attributes */
@@ -132,18 +132,38 @@ surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
 
   /* Create an OpenGL texture for the image */
   glGenTextures (1, &texture);
-  glBindTexture (GL_TEXTURE_2D, texture);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
-  glTexImage2D (GL_TEXTURE_2D,
-		0,
-		GL_RGBA, w, h, 0, GL_RGBA, GL_UNSIGNED_BYTE, image->pixels);
+  if (texture)
+    {
+      glBindTexture (GL_TEXTURE_2D, texture);
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
+      if (mipmap)
+	{
+	  gluBuild2DMipmaps (GL_TEXTURE_2D,
+			     4, w, h, GL_RGBA, GL_UNSIGNED_BYTE,
+			     image->pixels);
+	}
+      else
+	{
+	  glTexImage2D (GL_TEXTURE_2D,
+			0,
+			GL_RGBA, w, h, 0, GL_RGBA, GL_UNSIGNED_BYTE,
+			image->pixels);
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("glGenTextures failed"));
+    }
 
-  if (glIsTexture (texture))
+  if (texture && glIsTexture (texture))
     {
       gfx_context->texture_counter.new_counter++;
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("new texture %d (%dx%d mipmap=%d)"), (int) texture, w, h,
+		  mipmap);
     }
   else
     {
@@ -160,17 +180,18 @@ surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-surface2texture_wh (mod_gl_utils_context_t * gfx_context,
-		    SDL_Surface * surface, int w, int h)
+_surface2texture_wh (mod_gl_utils_context_t * gfx_context,
+		     SDL_Surface * surface, int w, int h, int mipmap)
 {
-  return surface2texture_xywh (gfx_context, surface, 0, 0, w, h);
+  return _surface2texture_xywh (gfx_context, surface, 0, 0, w, h, mipmap);
 }
 
 /*
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-surface2texture (mod_gl_utils_context_t * gfx_context, SDL_Surface * surface)
+_surface2texture (mod_gl_utils_context_t * gfx_context, SDL_Surface * surface,
+		  int mipmap)
 {
   int w, h;
 
@@ -178,7 +199,7 @@ surface2texture (mod_gl_utils_context_t * gfx_context, SDL_Surface * surface)
   w = mod_gl_utils_power_of_two_ge (surface->w);
   h = mod_gl_utils_power_of_two_ge (surface->h);
 
-  return surface2texture_wh (gfx_context, surface, w, h);
+  return _surface2texture_wh (gfx_context, surface, w, h, mipmap);
 }
 
 /*
@@ -187,11 +208,11 @@ surface2texture (mod_gl_utils_context_t * gfx_context, SDL_Surface * surface)
 GLuint
 mod_gl_utils_surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
 				   SDL_Surface * surface, int x, int y, int w,
-				   int h)
+				   int h, int mipmap)
 {
   GLuint texture;
 
-  texture = surface2texture_xywh (gfx_context, surface, x, y, w, h);
+  texture = _surface2texture_xywh (gfx_context, surface, x, y, w, h, mipmap);
 
   return (int) texture;
 }
@@ -201,11 +222,12 @@ mod_gl_utils_surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
  */
 GLuint
 mod_gl_utils_surface2texture_wh (mod_gl_utils_context_t * gfx_context,
-				 SDL_Surface * surface, int w, int h)
+				 SDL_Surface * surface, int w, int h,
+				 int mipmap)
 {
   GLuint texture;
 
-  texture = surface2texture_wh (gfx_context, surface, w, h);
+  texture = _surface2texture_wh (gfx_context, surface, w, h, mipmap);
 
   return (int) texture;
 }
@@ -215,11 +237,11 @@ mod_gl_utils_surface2texture_wh (mod_gl_utils_context_t * gfx_context,
  */
 GLuint
 mod_gl_utils_surface2texture (mod_gl_utils_context_t * gfx_context,
-			      SDL_Surface * surface)
+			      SDL_Surface * surface, int mipmap)
 {
   GLuint texture;
 
-  texture = surface2texture (gfx_context, surface);
+  texture = _surface2texture (gfx_context, surface, mipmap);
 
   return (int) texture;
 }
@@ -228,8 +250,8 @@ mod_gl_utils_surface2texture (mod_gl_utils_context_t * gfx_context,
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-map2texture_xywh (mod_gl_utils_context_t * gfx_context,
-		  lw6map_level_t * level, int x, int y, int w, int h)
+_map2texture_xywh (mod_gl_utils_context_t * gfx_context,
+		   lw6map_level_t * level, int x, int y, int w, int h)
 {
   GLuint texture = 0;
   SDL_Surface *image;
@@ -252,20 +274,31 @@ map2texture_xywh (mod_gl_utils_context_t * gfx_context,
     {
       /* Create an OpenGL texture for the image */
       glGenTextures (1, &texture);
-      glBindTexture (GL_TEXTURE_2D, texture);
-      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-      glTexImage2D (GL_TEXTURE_2D,
-		    0,
-		    GL_RGBA, w, h, 0, GL_RGBA, GL_UNSIGNED_BYTE,
-		    image->pixels);
+      if (texture)
+	{
+	  glBindTexture (GL_TEXTURE_2D, texture);
+	  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+	  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+	  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S,
+			   GL_CLAMP_TO_EDGE);
+	  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T,
+			   GL_CLAMP_TO_EDGE);
+	  glTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, w, h, 0, GL_RGBA,
+			GL_UNSIGNED_BYTE, image->pixels);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("glGenTextures failed"));
+	}
 
       mod_gl_utils_delete_surface (gfx_context, image);	/* No longer needed */
     }
 
-  if (glIsTexture (texture))
+  if (texture && glIsTexture (texture))
     {
       gfx_context->texture_counter.new_counter++;
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("new map texture %d (%dx%d)"), (int) texture, w, h);
     }
   else
     {
@@ -277,14 +310,14 @@ map2texture_xywh (mod_gl_utils_context_t * gfx_context,
 }
 
 static GLuint
-map2texture_wh (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level,
-		int w, int h)
+_map2texture_wh (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level,
+		 int w, int h)
 {
-  return map2texture_xywh (gfx_context, level, 0, 0, w, h);
+  return _map2texture_xywh (gfx_context, level, 0, 0, w, h);
 }
 
 static GLuint
-map2texture (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level)
+_map2texture (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level)
 {
   int w, h;
 
@@ -292,7 +325,7 @@ map2texture (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level)
   w = mod_gl_utils_power_of_two_ge (level->texture.w);
   h = mod_gl_utils_power_of_two_ge (level->texture.h);
 
-  return map2texture_wh (gfx_context, level, w, h);
+  return _map2texture_wh (gfx_context, level, w, h);
 }
 
 GLuint
@@ -302,7 +335,7 @@ mod_gl_utils_map2texture_xywh (mod_gl_utils_context_t * gfx_context,
 {
   GLuint texture;
 
-  texture = map2texture_xywh (gfx_context, level, x, y, w, h);
+  texture = _map2texture_xywh (gfx_context, level, x, y, w, h);
 
   return (int) texture;
 }
@@ -313,7 +346,7 @@ mod_gl_utils_map2texture_wh (mod_gl_utils_context_t * gfx_context,
 {
   GLuint texture;
 
-  texture = map2texture_wh (gfx_context, level, w, h);
+  texture = _map2texture_wh (gfx_context, level, w, h);
 
   return (int) texture;
 }
@@ -324,7 +357,7 @@ mod_gl_utils_map2texture (mod_gl_utils_context_t * gfx_context,
 {
   GLuint texture;
 
-  texture = map2texture (gfx_context, level);
+  texture = _map2texture (gfx_context, level);
 
   return (int) texture;
 }
@@ -342,15 +375,26 @@ void
 mod_gl_utils_delete_texture (mod_gl_utils_context_t * gfx_context,
 			     GLuint texture)
 {
-  if (glIsTexture ((GLuint) texture))
+  if (texture)
     {
       gfx_context->texture_counter.delete_counter++;
       glDeleteTextures (1, (GLuint *) & texture);
+      if (glIsTexture ((GLuint) texture))
+	{
+	  lw6sys_log (LW6SYS_LOG_DEBUG,
+		      _("delete texture %d"), (int) texture);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_DEBUG,
+		      _
+		      ("trying to delete texture %d, but glIsTexture returns false"),
+		      (int) texture);
+	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  "trying to delete texture, but it isn't a texture");
+      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to delete NULL texture"));
     }
 }
 
@@ -399,17 +443,37 @@ mod_gl_utils_delete_scheduled_textures (mod_gl_utils_context_t * gfx_context)
 void
 mod_gl_utils_texture_update (mod_gl_utils_context_t *
 			     utils_context,
-			     GLuint texture, SDL_Surface * surface)
+			     GLuint texture, SDL_Surface * surface,
+			     int pixelize)
 {
   /*
    * Note that texture and surface need be the same size, else KABOUM!
    * Usually, one should create the bitmap and the texture with
-   * surface2texture then use this function afterwards on the same
+   * _surface2texture then use this function afterwards on the same
    * objects. Safer. Typical use is displaying armies/fighters.
    */
   glBindTexture (GL_TEXTURE_2D, texture);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-  glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, surface->w, surface->h, GL_RGBA,
-		   GL_UNSIGNED_BYTE, surface->pixels);
+  if (pixelize)
+    {
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
+    }
+  else
+    {
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+    }
+  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
+  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
+  if (glIsTexture (texture))
+    {
+      glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, surface->w, surface->h,
+		       GL_RGBA, GL_UNSIGNED_BYTE, surface->pixels);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("%d isn't a texture, can't call glTexSubImage2D"),
+		  texture);
+    }
 }
