@@ -26,7 +26,6 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 GLuint
 mod_gl_utils_texture_1x1_color2texture (mod_gl_utils_context_t *
@@ -42,7 +41,7 @@ mod_gl_utils_texture_1x1_color2texture (mod_gl_utils_context_t *
     {
       color = mod_gl_utils_color_8_to_sdl (color_8);
       mod_gl_utils_clear_surface_with_color (surface, color);
-      texture = mod_gl_utils_surface2texture (utils_context, surface);
+      texture = mod_gl_utils_surface2texture (utils_context, surface, 0);
       mod_gl_utils_delete_surface (utils_context, surface);
     }
 
@@ -88,38 +87,40 @@ mod_gl_utils_texture_1x1_update (mod_gl_utils_context_t * utils_context,
 void
 mod_gl_utils_texture_1x1_clear (mod_gl_utils_context_t * utils_context)
 {
-  if (glIsTexture (utils_context->textures_1x1.menu_fg))
+  if (utils_context->textures_1x1.menu_fg)
     {
       mod_gl_utils_delete_texture (utils_context,
 				   utils_context->textures_1x1.menu_fg);
     }
-  if (glIsTexture (utils_context->textures_1x1.menu_bg))
+  if (utils_context->textures_1x1.menu_bg)
     {
       mod_gl_utils_delete_texture (utils_context,
 				   utils_context->textures_1x1.menu_bg);
     }
-  if (glIsTexture (utils_context->textures_1x1.menu_fg_disabled))
+  if (utils_context->textures_1x1.menu_fg_disabled)
     {
       mod_gl_utils_delete_texture (utils_context,
 				   utils_context->
 				   textures_1x1.menu_fg_disabled);
     }
-  if (glIsTexture (utils_context->textures_1x1.menu_bg_disabled))
+  if (utils_context->textures_1x1.menu_bg_disabled)
     {
       mod_gl_utils_delete_texture (utils_context,
 				   utils_context->
 				   textures_1x1.menu_bg_disabled);
     }
-  if (glIsTexture (utils_context->textures_1x1.menu_fg_selected))
+  if (utils_context->textures_1x1.menu_fg_selected)
     {
       mod_gl_utils_delete_texture (utils_context,
 				   utils_context->
 				   textures_1x1.menu_fg_selected);
     }
-  if (glIsTexture (utils_context->textures_1x1.menu_bg_selected))
+  if (utils_context->textures_1x1.menu_bg_selected)
     {
       mod_gl_utils_delete_texture (utils_context,
 				   utils_context->
 				   textures_1x1.menu_bg_selected);
     }
+  memset (&(utils_context->textures_1x1), 0,
+	  sizeof (mod_gl_utils_texture_1x1_t));
 }
