@@ -26,13 +26,12 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
 int
 mod_gl_utils_texture_array_init (mod_gl_utils_context_t *
 				 utils_context,
 				 mod_gl_utils_texture_array_t * texture_array,
-				 int w, int h, int tile_size)
+				 int w, int h, int tile_size, int mipmap)
 {
   int ret = 0;
   int n_x, n_y;
@@ -62,7 +61,8 @@ mod_gl_utils_texture_array_init (mod_gl_utils_context_t *
 		  if (surface)
 		    {
 		      texture =
-			mod_gl_utils_surface2texture (utils_context, surface);
+			mod_gl_utils_surface2texture (utils_context, surface,
+						      mipmap);
 		      if (texture)
 			{
 			  mod_gl_utils_set_texture_array_texture
@@ -108,7 +108,7 @@ mod_gl_utils_texture_array_update (mod_gl_utils_context_t *
 				   mod_gl_utils_texture_array_t *
 				   texture_array,
 				   mod_gl_utils_surface_array_t *
-				   surface_array)
+				   surface_array, int pixelize)
 {
   int n_x, n_y;
 
@@ -123,7 +123,8 @@ mod_gl_utils_texture_array_update (mod_gl_utils_context_t *
 					   mod_gl_utils_get_texture_array_texture
 					   (texture_array, n_x, n_y),
 					   mod_gl_utils_get_surface_array_surface
-					   (surface_array, n_x, n_y));
+					   (surface_array, n_x, n_y),
+					   pixelize);
 	    }
 	}
     }
