@@ -26,42 +26,22 @@
 
 #include "../../gfx.h"
 #include "gl-utils.h"
-#include "gl-utils-internal.h"
 
-/*
- * Sets an offset so that time allways start at zero and is
- * library independant.
- */
 void
-mod_gl_utils_timer_init (mod_gl_utils_context_t * utils_context, int ticks)
+mod_gl_utils_timer_update (mod_gl_utils_context_t * utils_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _("init timer t0=%d"), ticks);
-
-  utils_context->timer_data.ticks_offset = ticks - SDL_GetTicks ();
+  lw6sys_timer_update (&(utils_context->timer.timestamp),
+		       &(utils_context->timer.uptime));
 }
 
-/*
- * Dummy wrapper arround SDL func.
- */
-void
-mod_gl_utils_delay (mod_gl_utils_context_t * utils_context, int ms)
+int64_t
+mod_gl_utils_timer_timestamp (mod_gl_utils_context_t * utils_context)
 {
-  SDL_Delay (ms);
+  return utils_context->timer.timestamp;
 }
 
-/*
-  void
-  mod_gl_delay (void *context, int ms)
-  {
-  mod_gl_utils_delay ((mod_gl_utils_context_t *) context, ms);
-  }
-*/
-
-/*
- * Dummy wrapper arround SDL func.
- */
-int
-mod_gl_utils_get_ticks (mod_gl_utils_context_t * utils_context)
+int64_t
+mod_gl_utils_timer_uptime (mod_gl_utils_context_t * utils_context)
 {
-  return SDL_GetTicks () + utils_context->timer_data.ticks_offset;
+  return utils_context->timer.uptime;
 }
