@@ -25,10 +25,10 @@
 
 #include "../../gfx.h"
 
-#include <SDL/SDL.h>
-#include <SDL/SDL_opengl.h>
-#include <SDL/SDL_image.h>
-#include <SDL/SDL_ttf.h>
+#include <SDL.h>
+#include <SDL_opengl.h>
+#include <SDL_image.h>
+#include <SDL_ttf.h>
 
 #ifndef GL_CLAMP_TO_EDGE
 #define GL_CLAMP_TO_EDGE GL_CLAMP
@@ -37,23 +37,6 @@
 #define MOD_GL_UTILS_MENU_TEXTURE_W 512
 #define MOD_GL_UTILS_MENU_TEXTURE_H 128
 
-/*
- * Internal event buffer. One might wonder why we recode
- * some stuff which could be handled by SDL directly.
- * Answer: we need to do some basic processing before
- * sending the info to guile/scheme. For instance we
- * want key strokes to arrive with all the keycode/scancode/label
- * to be sent. We might also wish to send virtual key events
- * such as "mouse up" or "joy up".
- */
-#define MOD_GL_UTILS_KEYPRESS_BUFFER_SIZE 256
-
-/*
- * Size of the buffer we use to keep track of which key is pressed
- * or not. The index in this array is a keysym, not an ascii code.
- */
-#define MOD_GL_UTILS_KEYPRESS_STATE_SIZE 512
-
 /*
  * We keep 64 menu bitmaps in memory, to avoid redrawing them
  * at each display frame.
@@ -81,9 +64,6 @@
  */
 #define MOD_GL_SHADES_FOR_FIGHTERS_SCALE 64
 
-#define MOD_GL_NB_JOYSTICKS 4
-#define MOD_GL_NB_JOYSTICK_BUTTONS 6
-
 typedef struct mod_gl_utils_path_s
 {
   char *data_dir;
@@ -100,18 +80,10 @@ mod_gl_utils_mem_counter_t;
 typedef struct mod_gl_utils_caps_s
 {
   GLint max_texture_size;
+  int bpp;
 }
 mod_gl_utils_caps_t;
 
-typedef struct mod_gl_utils_screen_s
-{
-  int width;
-  int height;
-  int bpp;
-  int fullscreen;
-}
-mod_gl_utils_screen_t;
-
 typedef enum mod_gl_utils_render_mode_e
 {
   MOD_GL_UTILS_RENDER_NONE = 0,
@@ -119,8 +91,7 @@ typedef enum mod_gl_utils_render_mode_e
   MOD_GL_UTILS_RENDER_2D_BLEND = 2,
   MOD_GL_UTILS_RENDER_3D_MAP = 3,
   MOD_GL_UTILS_RENDER_3D_MENU = 4,
-  MOD_GL_UTILS_RENDER_3D_PICK = 5,
-  MOD_GL_UTILS_RENDER_3D_WARP = 6
+  MOD_GL_UTILS_RENDER_3D_PICK = 5
 }
 mod_gl_utils_render_mode_t;
 
@@ -132,6 +103,8 @@ typedef struct mod_gl_utils_rect_array_s
   int *y0;
   int *w;
   int *h;
+  float *screen_x;
+  float *screen_y;
 }
 mod_gl_utils_rect_array_t;
 
@@ -149,61 +122,6 @@ typedef struct mod_gl_utils_texture_array_s
 }
 mod_gl_utils_texture_array_t;
 
-typedef struct mod_gl_utils_keyboard_state_s
-{
-  lw6gui_keypress_t keypress_buffer[MOD_GL_UTILS_KEYPRESS_BUFFER_SIZE];
-  int keypress_current;
-  int keypress_queue;
-  int keypress_state[MOD_GL_UTILS_KEYPRESS_STATE_SIZE];
-}
-mod_gl_utils_keyboard_state_t;
-
-typedef struct mod_gl_utils_button_state_s
-{
-  int pressed;
-  int queue;
-  int last_press;
-  int last_repeat;
-}
-mod_gl_utils_button_state_t;
-
-typedef struct mod_gl_utils_mouse_state_s
-{
-  int x;
-  int y;
-  int moved;
-  mod_gl_utils_button_state_t button_left;
-  mod_gl_utils_button_state_t button_right;
-  mod_gl_utils_button_state_t wheel_up;
-  mod_gl_utils_button_state_t wheel_down;
-}
-mod_gl_utils_mouse_state_t;
-
-typedef struct mod_gl_utils_joystick_state_s
-{
-  mod_gl_utils_button_state_t up;
-  mod_gl_utils_button_state_t down;
-  mod_gl_utils_button_state_t left;
-  mod_gl_utils_button_state_t right;
-  mod_gl_utils_button_state_t buttons[MOD_GL_NB_JOYSTICK_BUTTONS];
-  SDL_Joystick *sdl_joystick;
-}
-mod_gl_utils_joystick_state_t;
-
-typedef struct mod_gl_utils_joysticks_state_s
-{
-  int supported;
-  int driver_nb_joysticks;
-  mod_gl_utils_joystick_state_t joystick_state[MOD_GL_NB_JOYSTICKS];
-}
-mod_gl_utils_joysticks_state_t;
-
-typedef struct mod_gl_utils_quit_state_s
-{
-  int quit;
-}
-mod_gl_utils_quit_state_t;
-
 typedef struct mod_gl_utils_texture_data_s
 {
   lw6sys_list_t *to_delete;
@@ -254,16 +172,11 @@ mod_gl_utils_texturecache_array_t;
 
 typedef struct mod_gl_utils_const_data_s
 {
-  /*
-   * Set by the hud module
-   */
-  float viewport_x;
-  float viewport_y;
-  float viewport_w;
-  float viewport_h;
   /*
    * Set by the utils module itself
    */
+  float warp_x;
+  float warp_y;
   float mode_sleep;
   float quit_sleep;
   float persp_fovy;
@@ -285,10 +198,46 @@ typedef struct mod_gl_utils_const_data_s
   float mainlight_x;
   float mainlight_y;
   float mainlight_z;
-  int joystick_limit_up;
-  int joystick_limit_down;
-  int joystick_limit_left;
-  int joystick_limit_right;
+  int keysym1_up;
+  int keysym2_up;
+  int keysym3_up;
+  int keysym4_up;
+  int keysym1_down;
+  int keysym2_down;
+  int keysym3_down;
+  int keysym4_down;
+  int keysym1_left;
+  int keysym2_left;
+  int keysym3_left;
+  int keysym4_left;
+  int keysym1_right;
+  int keysym2_right;
+  int keysym3_right;
+  int keysym4_right;
+  int keysym1_enter;
+  int keysym2_enter;
+  int keysym1_esc;
+  int keysym2_esc;
+  int keysym1_pgup;
+  int keysym2_pgup;
+  int keysym1_pgdown;
+  int keysym2_pgdown;
+  int keysym_quit;
+  int joystick_limit;
+  int joystick1_index;
+  int joystick1_button_a_index;
+  int joystick1_button_b_index;
+  int joystick1_button_c_index;
+  int joystick1_button_d_index;
+  int joystick2_index;
+  int joystick2_button_a_index;
+  int joystick2_button_b_index;
+  int joystick2_button_c_index;
+  int joystick2_button_d_index;
+  int joystick_all_buttons;
+  int smoother_global_zoom_duration;
+  int smoother_center_duration;
+  int smoother_drawable_duration;
 }
 mod_gl_utils_const_data_t;
 
@@ -314,12 +263,6 @@ typedef struct mod_gl_utils_team_color_map_s
 }
 mod_gl_utils_team_color_map_t;
 
-typedef struct mod_gl_utils_timer_data_s
-{
-  int ticks_offset;
-}
-mod_gl_utils_timer_data_t;
-
 typedef struct mod_gl_utils_last_action_s
 {
   int game_texture_array_update_id;
@@ -327,36 +270,71 @@ typedef struct mod_gl_utils_last_action_s
 }
 mod_gl_utils_last_action_t;
 
-typedef struct mod_gl_utils_repeat_settings_s
+typedef struct mod_gl_utils_joysticks_info_s
 {
-  int delay;
-  int interval;
+  int supported;
+  int driver_nb_joysticks;
+  SDL_Joystick *sdl_joysticks[LW6GUI_NB_JOYSTICKS];
 }
-mod_gl_utils_repeat_settings_t;
+mod_gl_utils_joysticks_info_t;
+
+typedef struct mod_gl_utils_mouse_state_s
+{
+  int shown;
+}
+mod_gl_utils_mouse_state_t;
+
+typedef struct mod_gl_utils_timer_s
+{
+  int64_t timestamp;
+  int64_t uptime;
+}
+mod_gl_utils_timer_t;
+
+typedef struct _mod_gl_utils_smoothers_s
+{
+  lw6gui_smoother_t global_zoom;
+  lw6gui_smoother_t center_x;
+  lw6gui_smoother_t center_y;
+  lw6gui_smoother_t drawable_x1;
+  lw6gui_smoother_t drawable_y1;
+  lw6gui_smoother_t drawable_x2;
+  lw6gui_smoother_t drawable_y2;
+}
+_mod_gl_utils_smoothers_t;
+
+typedef struct _mod_gl_utils_smoothed_s
+{
+  float global_zoom;
+  float center_x;
+  float center_y;
+  lw6gui_zone_t drawable;
+}
+_mod_gl_utils_smoothed_t;
 
 typedef struct mod_gl_utils_context_s
 {
-  void (*resize_callback) (int width, int height, int fullscreen);
+  lw6gui_resize_callback_func_t resize_callback;
   mod_gl_utils_path_t path;
   mod_gl_utils_mem_counter_t surface_counter;
   mod_gl_utils_mem_counter_t texture_counter;
   mod_gl_utils_caps_t caps;
-  mod_gl_utils_screen_t screen;
+  lw6gui_video_mode_t video_mode;
   mod_gl_utils_render_mode_t render_mode;
   mod_gl_utils_texture_data_t texture_data;
   mod_gl_utils_font_data_t font_data;
-  mod_gl_utils_keyboard_state_t keyboard_state;
-  mod_gl_utils_mouse_state_t mouse_state;
-  mod_gl_utils_joysticks_state_t joysticks_state;
-  mod_gl_utils_quit_state_t quit_state;
   mod_gl_utils_const_data_t const_data;
   mod_gl_utils_texture_1x1_t textures_1x1;
   mod_gl_utils_menucache_array_t menucache_array;
   mod_gl_utils_texturecache_array_t texturecache_array;
   mod_gl_utils_team_color_map_t team_color_map;
-  mod_gl_utils_timer_data_t timer_data;
   mod_gl_utils_last_action_t last_action;
-  mod_gl_utils_repeat_settings_t repeat_settings;
+  mod_gl_utils_joysticks_info_t joysticks_info;
+  mod_gl_utils_mouse_state_t mouse_state;
+  mod_gl_utils_timer_t timer;
+  lw6gui_input_t input;
+  _mod_gl_utils_smoothers_t smoothers;
+  _mod_gl_utils_smoothed_t smoothed;
 }
 mod_gl_utils_context_t;
 
@@ -368,7 +346,15 @@ extern SDL_Color mod_gl_utils_color_f_to_sdl (lw6sys_color_f_t * color_f);
 extern void mod_gl_utils_update_team_color_map (mod_gl_utils_team_color_map_t
 						* team_color_map,
 						lw6map_style_t * map_style);
+extern int mod_gl_utils_team_color_map_is_same (mod_gl_utils_team_color_map_t
+						* team_color_map_a,
+						mod_gl_utils_team_color_map_t
+						* team_color_map_b);
 extern void mod_gl_utils_force_color32_alpha (Uint32 * color, float alpha);
+extern Uint32
+mod_gl_utils_get_shaded_color_for_fighter_f (mod_gl_utils_context_t *
+					     utils_context, int team_id,
+					     float health);
 inline static Uint32
 mod_gl_utils_get_shaded_color_for_fighter (mod_gl_utils_context_t *
 					   utils_context, int team_id,
@@ -385,26 +371,67 @@ extern SDL_Surface *mod_gl_utils_colorize_image (mod_gl_utils_context_t *
 						 utils_context,
 						 SDL_Surface * image,
 						 lw6map_color_couple_t *
-						 color);
+						 color, int has_alpha);
+
+/*
+ * In consts.c
+ */
+extern int mod_gl_utils_load_consts (mod_gl_utils_context_t * context);
+extern void mod_gl_utils_unload_consts (mod_gl_utils_context_t * context);
 
 /*
  * In data.c
  */
+extern int mod_gl_utils_load_fonts (mod_gl_utils_context_t * context);
+extern void mod_gl_utils_unload_fonts (mod_gl_utils_context_t * context);
+
 extern SDL_Surface *mod_gl_utils_load_image (mod_gl_utils_context_t *
 					     utils_context, char *filename);
 extern void mod_gl_utils_unload_image (mod_gl_utils_context_t * utils_context,
 				       SDL_Surface * image);
-extern GLuint mod_gl_utils_load_texture (mod_gl_utils_context_t *
-					 utils_context,
-					 SDL_Surface * surface);
-extern void mod_gl_utils_unload_texture (mod_gl_utils_context_t *
-					 utils_context, int texture);
 extern int mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context);
 extern void mod_gl_utils_unload_fonts (mod_gl_utils_context_t *
 				       utils_context);
 extern int mod_gl_utils_load_data (mod_gl_utils_context_t * utils_context);
 extern void mod_gl_utils_unload_data (mod_gl_utils_context_t * utils_context);
 
+/*
+ * In debug.c
+ */
+extern void mod_gl_utils_display_zones (mod_gl_utils_context_t *
+					utils_context, lw6gui_look_t * look,
+					lw6ker_game_struct_t * game_struct);
+extern void mod_gl_utils_display_gradient (mod_gl_utils_context_t *
+					   utils_context,
+					   lw6gui_look_t * look,
+					   lw6ker_game_state_t * game_state,
+					   int team_id, int layer_id);
+
+/*
+ * In display.c
+ */
+extern void mod_gl_utils_display_texture_full (mod_gl_utils_context_t *
+					       utils_context, GLuint texture,
+					       float x1, float y1, float x2,
+					       float y2, int texture_w,
+					       int texture_h);
+extern void mod_gl_utils_display_texture (mod_gl_utils_context_t *
+					  utils_context, GLuint texture,
+					  float x1, float y1, float x2,
+					  float y2, float texture_x1,
+					  float texture_y1, float texture_x2,
+					  float texture_y2);
+extern void mod_gl_utils_display_texture_with_filter (mod_gl_utils_context_t *
+						      utils_context,
+						      GLuint texture,
+						      float x1, float y1,
+						      float x2, float y2,
+						      float texture_x1,
+						      float texture_y1,
+						      float texture_x2,
+						      float texture_y2,
+						      int pixelize);
+
 /*
  * In draw.c
  */
@@ -414,64 +441,8 @@ extern void mod_gl_utils_draw_rectfill (SDL_Surface * surface, int x1, int y1,
 /*
  * In event.c
  */
-extern int mod_gl_utils_poll_key (mod_gl_utils_context_t * utils_context,
-				  lw6gui_keypress_t * keypress);
-extern int mod_gl_utils_is_key_esc (mod_gl_utils_context_t * utils_context,
-				    int keysym);
-extern int mod_gl_utils_is_key_enter (mod_gl_utils_context_t * utils_context,
-				      int keysym);
-extern int mod_gl_utils_is_key_up (mod_gl_utils_context_t * utils_context,
-				   int keysym);
-extern int mod_gl_utils_is_key_down (mod_gl_utils_context_t * utils_context,
-				     int keysym);
-extern int mod_gl_utils_is_key_left (mod_gl_utils_context_t * utils_context,
-				     int keysym);
-extern int mod_gl_utils_is_key_right (mod_gl_utils_context_t * utils_context,
-				      int keysym);
-extern int mod_gl_utils_poll_quit (mod_gl_utils_context_t * utils_context);
-extern void mod_gl_utils_send_quit (mod_gl_utils_context_t * utils_context);
-extern int mod_gl_utils_get_key_state (mod_gl_utils_context_t * utils_context,
-				       int keysym);
-extern void mod_gl_utils_get_default_keys_state (mod_gl_utils_context_t *
-						 utils_context, int *up,
-						 int *down, int *left,
-						 int *right, int *esc,
-						 int *enter);
-extern int mod_gl_utils_poll_mouse_move (mod_gl_utils_context_t *
-					 utils_context, int *x, int *y);
-extern int mod_gl_utils_poll_mouse_button_left (mod_gl_utils_context_t *
-						utils_context);
-extern int mod_gl_utils_poll_mouse_button_right (mod_gl_utils_context_t *
+extern lw6gui_input_t *mod_gl_utils_pump_events (mod_gl_utils_context_t *
 						 utils_context);
-extern int mod_gl_utils_poll_mouse_wheel_up (mod_gl_utils_context_t *
-					     utils_context);
-extern int mod_gl_utils_poll_mouse_wheel_down (mod_gl_utils_context_t *
-					       utils_context);
-extern void mod_gl_utils_get_mouse_state (mod_gl_utils_context_t *
-					  utils_context, int *x, int *y,
-					  int *button_left,
-					  int *button_right);
-extern int mod_gl_utils_warp_mouse (mod_gl_utils_context_t *
-				    utils_context, int x, int y);
-extern void mod_gl_utils_show_mouse (mod_gl_utils_context_t * utils_context,
-				     int state);
-extern int mod_gl_utils_poll_joystick_up (mod_gl_utils_context_t *
-					  utils_context, int i);
-extern int mod_gl_utils_poll_joystick_down (mod_gl_utils_context_t *
-					    utils_context, int i);
-extern int mod_gl_utils_poll_joystick_left (mod_gl_utils_context_t *
-					    utils_context, int i);
-extern int mod_gl_utils_poll_joystick_right (mod_gl_utils_context_t *
-					     utils_context, int i);
-extern int mod_gl_utils_poll_joystick_button (mod_gl_utils_context_t *
-					      utils_context, int i, int b);
-extern void mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
-					     utils_context, int *x, int *y,
-					     int *button_a, int *button_b,
-					     int i, int b1, int b2);
-extern int mod_gl_utils_set_key_repeat (mod_gl_utils_context_t *
-					utils_context, int key_repeat_delay,
-					int key_repeat_interval);
 
 /*
  * In font.c
@@ -480,6 +451,11 @@ extern int mod_gl_utils_get_system_text_width (mod_gl_utils_context_t *
 					       utils_context, char *text);
 extern int mod_gl_utils_get_system_text_height (mod_gl_utils_context_t *
 						utils_context, char *text);
+extern SDL_Surface *mod_gl_utils_blended_text_surface (mod_gl_utils_context_t
+						       * context,
+						       TTF_Font * font,
+						       SDL_Color color,
+						       char *text);
 extern void mod_gl_utils_draw_system_text (mod_gl_utils_context_t *
 					   utils_context,
 					   lw6gui_look_t * look, char *text,
@@ -537,42 +513,23 @@ extern SDL_Surface
 extern void mod_gl_utils_display_log (mod_gl_utils_context_t * utils_context,
 				      lw6gui_look_t * look, char **log_list);
 extern void mod_gl_utils_display_fps (mod_gl_utils_context_t * utils_context,
-				      lw6gui_look_t * look, int fps);
+				      lw6gui_look_t * look, float fps);
+extern void mod_gl_utils_display_rps (mod_gl_utils_context_t * utils_context,
+				      lw6gui_look_t * look, float rps);
 
 /*
  * In joystick.c
  */
-extern int mod_gl_utils_joystick_init (mod_gl_utils_joysticks_state_t *
-				       joysticks_state);
-extern void mod_gl_utils_joystick_quit (mod_gl_utils_joysticks_state_t *
-					joysticks_state);
+extern int mod_gl_utils_joystick_init (mod_gl_utils_joysticks_info_t *
+				       joysticks_info);
+extern void mod_gl_utils_joystick_quit (mod_gl_utils_joysticks_info_t *
+					joysticks_info);
 
 /*
  * In light.c
  */
 extern void mod_gl_utils_main_light (mod_gl_utils_context_t * utils_context);
 
-/*
- * In mode.c
- */
-extern int mod_gl_utils_set_video_mode (mod_gl_utils_context_t *
-					utils_context, int width, int height,
-					int fullscreen,
-					void (*resize_callback) (int width,
-								 int height,
-								 int
-								 fullscreen));
-extern int mod_gl_utils_resize_video_mode (mod_gl_utils_context_t *
-					   utils_context, int width,
-					   int height);
-extern int mod_gl_utils_get_video_mode (mod_gl_utils_context_t *
-					utils_context, int *width,
-					int *height, int *fullscreen);
-extern int mod_gl_utils_sync_viewport (mod_gl_utils_context_t *
-				       utils_context);
-extern int mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context,
-				   int force);
-
 /*
  * In menucache.c
  */
@@ -589,6 +546,33 @@ extern SDL_Surface
 extern void mod_gl_utils_clear_menucache (mod_gl_utils_context_t *
 					  utils_context);
 
+/*
+ * In mode.c
+ */
+extern int mod_gl_utils_set_video_mode (mod_gl_utils_context_t *
+					utils_context,
+					lw6gui_video_mode_t * video_mode);
+extern int mod_gl_utils_resize_video_mode (mod_gl_utils_context_t *
+					   utils_context,
+					   lw6gui_video_mode_t * video_mode);
+extern int mod_gl_utils_get_video_mode (mod_gl_utils_context_t *
+					utils_context,
+					lw6gui_video_mode_t * video_mode);
+extern int mod_gl_utils_sync_viewport (mod_gl_utils_context_t *
+				       utils_context);
+extern int mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context,
+				   int force);
+extern int mod_gl_utils_set_resize_callback (mod_gl_utils_context_t *
+					     utils_context,
+					     lw6gui_resize_callback_func_t
+					     resize_callback);
+
+/*
+ * In mouse.c
+ */
+extern void mod_gl_utils_show_mouse (mod_gl_utils_context_t * utils_context,
+				     int state, int force);
+
 /*
  * In path.c
  */
@@ -602,6 +586,13 @@ extern void mod_gl_utils_path_quit (mod_gl_utils_context_t * utils_context);
 extern Uint32 mod_gl_utils_getpixel (SDL_Surface * surface, int x, int y);
 extern void mod_gl_utils_putpixel (SDL_Surface * surface, int x, int y,
 				   Uint32 pixel);
+static inline void
+mod_gl_utils_putpixel_4_bytes_per_pixel (SDL_Surface * surface, int x, int y,
+					 Uint32 pixel)
+{
+  *((Uint32 *) ((Uint8 *) surface->pixels + (y * surface->pitch) +
+		(x << 2))) = pixel;
+}
 
 /*
  * In rectarray.c
@@ -634,43 +625,29 @@ extern void mod_gl_utils_set_render_mode_3d_menu (mod_gl_utils_context_t *
 extern void mod_gl_utils_set_render_mode_3d_pick (mod_gl_utils_context_t *
 						  utils_context, int x,
 						  int y);
-extern void mod_gl_utils_set_render_mode_3d_warp (mod_gl_utils_context_t *
-						  utils_context);
 
 /*
  * In resolution.c
  */
-extern void mod_gl_utils_get_low_resolution (mod_gl_utils_context_t *
-					     utils_context, int *width,
-					     int *height);
-extern void mod_gl_utils_get_standard_resolution (mod_gl_utils_context_t *
-						  utils_context, int *width,
-						  int *height);
-extern void mod_gl_utils_get_high_resolution (mod_gl_utils_context_t *
-					      utils_context, int *width,
-					      int *height);
+extern int mod_gl_utils_get_fullscreen_modes (mod_gl_utils_context_t *
+					      utils_context,
+					      lw6gui_fullscreen_modes_t *
+					      modes);
 extern void mod_gl_utils_find_closest_resolution (mod_gl_utils_context_t *
 						  utils_context,
 						  int *closest_width,
 						  int *closest_height,
 						  int wished_width,
 						  int wished_height);
-
 /*
- * In setup.c
+ * In smoothers.c
  */
-extern mod_gl_utils_context_t *mod_gl_utils_init ();
-extern int mod_gl_utils_set_video_mode (mod_gl_utils_context_t *
-					utils_context, int width, int height,
-					int fullscreen,
-					void (*resize_callback) (int width,
-								 int height,
-								 int
-								 fullscreen));
-extern int mod_gl_utils_resize_video_mode (mod_gl_utils_context_t *
-					   utils_context, int width,
-					   int height);
-extern void mod_gl_utils_quit (mod_gl_utils_context_t * utils_context);
+extern void mod_gl_utils_smoothers_init (mod_gl_utils_context_t *
+					 utils_context);
+extern void mod_gl_utils_smoothers_reset_drawable (mod_gl_utils_context_t *
+						   utils_context);
+extern void mod_gl_utils_smoothers_update (mod_gl_utils_context_t *
+					   utils_context);
 
 /*
  * In surface.c
@@ -745,14 +722,16 @@ extern float mod_gl_utils_texture_scale (int size);
 extern GLuint mod_gl_utils_surface2texture_xywh (mod_gl_utils_context_t *
 						 utils_context,
 						 SDL_Surface * surface, int x,
-						 int y, int w, int h);
+						 int y, int w, int h,
+						 int mipmap);
 extern GLuint mod_gl_utils_surface2texture_wh (mod_gl_utils_context_t *
 					       utils_context,
 					       SDL_Surface * surface, int w,
-					       int h);
+					       int h, int mipmap);
 extern GLuint mod_gl_utils_surface2texture (mod_gl_utils_context_t *
 					    utils_context,
-					    SDL_Surface * surface);
+					    SDL_Surface * surface,
+					    int mipmap);
 extern GLuint mod_gl_utils_map2texture_xywh (mod_gl_utils_context_t *
 					     utils_context,
 					     lw6map_level_t * level, int x,
@@ -773,7 +752,7 @@ extern void mod_gl_utils_delete_scheduled_textures (mod_gl_utils_context_t *
 						    utils_context);
 extern void mod_gl_utils_texture_update (mod_gl_utils_context_t *
 					 utils_context, GLuint texture,
-					 SDL_Surface * surface);
+					 SDL_Surface * surface, int pixelize);
 
 /*
  * In texture1x1.c
@@ -795,13 +774,13 @@ extern int mod_gl_utils_texture_array_init (mod_gl_utils_context_t *
 					    utils_context,
 					    mod_gl_utils_texture_array_t *
 					    texture_array, int w, int h,
-					    int tile_size);
+					    int tile_size, int mipmap);
 extern void mod_gl_utils_texture_array_update (mod_gl_utils_context_t *
 					       utils_context,
 					       mod_gl_utils_texture_array_t *
 					       texture_array,
 					       mod_gl_utils_surface_array_t *
-					       surface_array);
+					       surface_array, int pixelize);
 extern void mod_gl_utils_texture_array_clear (mod_gl_utils_context_t *
 					      utils_context,
 					      mod_gl_utils_texture_array_t *
@@ -867,34 +846,18 @@ extern void mod_gl_utils_clear_texturecache (mod_gl_utils_context_t *
 /*
  * In timer.c
  */
-extern void mod_gl_utils_timer_init (mod_gl_utils_context_t * utils_context,
-				     int ticks);
-extern void mod_gl_utils_delay (mod_gl_utils_context_t * utils_context,
-				int ms);
-extern int mod_gl_utils_get_ticks (mod_gl_utils_context_t * utils_context);
+extern void mod_gl_utils_timer_update (mod_gl_utils_context_t *
+				       utils_context);
+extern int64_t mod_gl_utils_timer_timestamp (mod_gl_utils_context_t *
+					     utils_context);
+extern int64_t mod_gl_utils_timer_uptime (mod_gl_utils_context_t *
+					  utils_context);
 
 /*
  * In viewport.c
  */
-extern void mod_gl_utils_viewport_calc_view_area (mod_gl_utils_context_t *
-						  utils_context, int *view_x1,
-						  int *view_y1, int *view_x2,
-						  int *view_y2);
-extern void mod_gl_utils_viewport_calc_map_area (mod_gl_utils_context_t *
-						 utils_context, float *map_x1,
-						 float *map_y1, float *map_x2,
-						 float *map_y2,
-						 int main_cursor_x,
-						 int main_cursor_y,
-						 int shape_w, int shape_h,
-						 lw6gui_look_t * look);
-extern void mod_gl_utils_viewport_calc_map_pos (mod_gl_utils_context_t *
-						utils_context, float *map_x,
-						float *map_y, int pos_x,
-						int pos_y, int main_cursor_x,
-						int main_cursor_y,
-						int shape_w, int shape_h,
-						lw6gui_look_t * look);
+extern void mod_gl_utils_viewport_drawable_max (mod_gl_utils_context_t *
+						utils_context);
 
 /*
  * In zones.c
