@@ -40,9 +40,8 @@ mod_gl_view_flat_create_backend (mod_gl_utils_context_t * utils_context)
       memset (backend, 0, sizeof (mod_gl_view_backend_t));
 
       backend->display_preview = mod_gl_view_flat_display_preview;
-      backend->display_zones = mod_gl_view_flat_display_zones;
-      backend->display_gradient = mod_gl_view_flat_display_gradient;
-      backend->display_game = mod_gl_view_flat_display_game;
+      backend->display_map = mod_gl_view_flat_display_map;
+      backend->display_fighters = mod_gl_view_flat_display_fighters;
       backend->display_cursors = mod_gl_view_flat_display_cursors;
       backend->init = mod_gl_view_flat_init;
       backend->quit = mod_gl_view_flat_quit;
