@@ -24,7 +24,7 @@
 #include "config.h"
 #endif
 
-#include <GL/glu.h>
+//#include <GL/glu.h>
 #include <math.h>
 
 #include "../../../gfx.h"
@@ -122,7 +122,8 @@ cursor_texture (mod_gl_utils_context_t * utils_context, int w, int h,
 					 lw6sys_color_8_to_i (tmp_color));
 		}
 	    }
-	  ret = mod_gl_utils_surface2texture (utils_context, cursor_surface);
+	  ret =
+	    mod_gl_utils_surface2texture (utils_context, cursor_surface, 0);
 	  mod_gl_utils_delete_surface (utils_context, cursor_surface);
 	}
       mod_gl_utils_delete_surface (utils_context, text_surface);
