@@ -42,8 +42,12 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 
   if (!strcmp (element, "int"))
     {
+      lw6cfg_read_xml_int (key, value, "scroll-min-offset",
+			   &const_data->scroll_min_offset);
       lw6cfg_read_xml_int (key, value, "cursor-blink-period",
 			   &const_data->cursor_blink_period);
+      lw6cfg_read_xml_int (key, value, "cursor-heartbeat-period",
+			   &const_data->cursor_heartbeat_period);
       lw6cfg_read_xml_int (key, value, "cursor-texture-size",
 			   &const_data->cursor_texture_size);
       lw6cfg_read_xml_int (key, value, "cursor-border-width",
@@ -58,8 +62,12 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 
   if (!strcmp (element, "float"))
     {
-      lw6cfg_read_xml_float (key, value, "cursor-size",
-			     &const_data->cursor_size);
+      lw6cfg_read_xml_float (key, value, "cursor-size-min",
+			     &const_data->cursor_size_min);
+      lw6cfg_read_xml_float (key, value, "cursor-size-max",
+			     &const_data->cursor_size_max);
+      lw6cfg_read_xml_float (key, value, "scroll-limit",
+			     &const_data->scroll_limit);
     }
 }
 
