@@ -35,7 +35,7 @@ _mod_gl_view_flat_game_context_map_t;
 
 typedef struct _mod_gl_view_flat_game_context_armies_s
 {
-  int game_state_id;
+  int game_struct_id;
   lw6ker_game_state_t *game_state;
   mod_gl_utils_surface_array_t armies_surface_array;
   mod_gl_utils_texture_array_t armies_texture_array;
@@ -68,8 +68,12 @@ _mod_gl_view_flat_cursors_context_t;
 
 typedef struct _mod_gl_view_flat_const_data_s
 {
-  float cursor_size;
+  float cursor_size_min;
+  float cursor_size_max;
+  float scroll_limit;
+  int scroll_min_offset;
   int cursor_blink_period;
+  int cursor_heartbeat_period;
   int cursor_texture_size;
   int cursor_border_width;
   int cursor_blur_width;
@@ -78,11 +82,25 @@ typedef struct _mod_gl_view_flat_const_data_s
 }
 _mod_gl_view_flat_const_data_t;
 
+/*
+typedef struct _mod_gl_view_flat_smoothers_s
+{
+  //float last_zoom;
+  //int last_center_x;
+  //int last_center_y;
+  lw6gui_smoother_t center_x;
+  lw6gui_smoother_t center_y;
+}
+_mod_gl_view_flat_smoothers_t;
+*/
+
 typedef struct _mod_gl_view_flat_context_s
 {
   _mod_gl_view_flat_game_context_t game_context;
   _mod_gl_view_flat_cursors_context_t cursors_context;
   _mod_gl_view_flat_const_data_t const_data;
+  //_mod_gl_view_flat_smoother_t smoothers;
+  lw6gui_viewport_t viewport;
 }
 _mod_gl_view_flat_context_t;
 
@@ -153,30 +171,23 @@ extern void _mod_gl_view_flat_display_preview (mod_gl_utils_context_t *
 					       flat_context,
 					       lw6gui_look_t * look,
 					       lw6map_level_t * level);
-extern void _mod_gl_view_flat_display_zones (mod_gl_utils_context_t *
-					     utils_context,
-					     _mod_gl_view_flat_context_t *
-					     flat_context,
-					     lw6gui_look_t * look,
-					     lw6map_level_t * level,
-					     lw6ker_map_struct_t *
-					     map_struct);
-extern void _mod_gl_view_flat_display_gradient (mod_gl_utils_context_t *
+extern void _mod_gl_view_flat_display_map (mod_gl_utils_context_t *
+					   utils_context,
+					   _mod_gl_view_flat_context_t *
+					   flat_context,
+					   lw6gui_look_t * look,
+					   lw6ker_game_state_t * game_state,
+					   lw6gui_main_cursor_t *
+					   main_cursor);
+extern void _mod_gl_view_flat_display_fighters (mod_gl_utils_context_t *
 						utils_context,
 						_mod_gl_view_flat_context_t *
 						flat_context,
 						lw6gui_look_t * look,
-						lw6map_level_t * level,
-						lw6ker_map_state_t *
-						map_state, int team_id,
-						int layer_id);
-extern void _mod_gl_view_flat_display_game (mod_gl_utils_context_t *
-					    utils_context,
-					    _mod_gl_view_flat_context_t *
-					    flat_context,
-					    lw6gui_look_t * look,
-					    lw6ker_game_state_t * game_state,
-					    u_int16_t main_cursor_id);
+						lw6ker_game_state_t *
+						game_state,
+						lw6gui_main_cursor_t *
+						main_cursor);
 extern void _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
 					       utils_context,
 					       _mod_gl_view_flat_context_t *
@@ -184,7 +195,8 @@ extern void _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
 					       lw6gui_look_t * look,
 					       lw6ker_game_state_t *
 					       game_state,
-					       u_int16_t main_cursor_id);
+					       lw6gui_main_cursor_t *
+					       main_cursor);
 
 /*
  * In gamecontext.c
@@ -205,6 +217,7 @@ extern int _mod_gl_view_flat_game_context_init_map (mod_gl_utils_context_t *
 						    * flat_context,
 						    _mod_gl_view_flat_game_context_map_t
 						    * game_context_map,
+						    lw6gui_look_t * look,
 						    lw6map_level_t * level);
 extern int _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t
 						       * utils_context,
@@ -250,6 +263,7 @@ extern int _mod_gl_view_flat_game_context_update_map (mod_gl_utils_context_t *
 						      * flat_context,
 						      _mod_gl_view_flat_game_context_map_t
 						      * game_context_map,
+						      lw6gui_look_t * look,
 						      lw6map_level_t * level);
 extern int
 _mod_gl_view_flat_game_context_update_armies (mod_gl_utils_context_t *
@@ -271,4 +285,24 @@ extern void _mod_gl_view_flat_quit (mod_gl_utils_context_t * utils_context,
 				    _mod_gl_view_flat_context_t *
 				    flat_context);
 
+/*
+ * in viewport.c
+ */
+extern void _mod_gl_view_flat_viewport_update_preview (mod_gl_utils_context_t
+						       * utils_context,
+						       _mod_gl_view_flat_context_t
+						       * flat_context,
+						       lw6gui_look_t * look,
+						       lw6map_level_t *
+						       level);
+extern void _mod_gl_view_flat_viewport_update (mod_gl_utils_context_t *
+					       utils_context,
+					       _mod_gl_view_flat_context_t *
+					       flat_context,
+					       lw6gui_look_t * look,
+					       lw6ker_game_state_t *
+					       game_state,
+					       lw6gui_main_cursor_t *
+					       main_cursor);
+
 #endif
