@@ -80,16 +80,16 @@ mod_gl_view_display_preview (mod_gl_utils_context_t * utils_context,
 }
 
 void
-mod_gl_view_display_zones (mod_gl_utils_context_t * utils_context,
-			   mod_gl_view_backend_t * backend,
-			   lw6gui_look_t * look,
-			   lw6map_level_t * level,
-			   lw6ker_map_struct_t * map_struct)
+mod_gl_view_display_map (mod_gl_utils_context_t * utils_context,
+			 mod_gl_view_backend_t * backend,
+			 lw6gui_look_t * look,
+			 lw6ker_game_state_t * game_state,
+			 lw6gui_main_cursor_t * main_cursor)
 {
-  if (backend->display_zones)
+  if (backend->display_map)
     {
-      backend->display_zones (utils_context, backend->view_context, look,
-			      level, map_struct);
+      backend->display_map (utils_context, backend->view_context, look,
+			    game_state, main_cursor);
     }
   else
     {
@@ -98,35 +98,16 @@ mod_gl_view_display_zones (mod_gl_utils_context_t * utils_context,
 }
 
 void
-mod_gl_view_display_gradient (mod_gl_utils_context_t * utils_context,
+mod_gl_view_display_fighters (mod_gl_utils_context_t * utils_context,
 			      mod_gl_view_backend_t * backend,
 			      lw6gui_look_t * look,
-			      lw6map_level_t * level,
-			      lw6ker_map_state_t * map_state, int team_id,
-			      int layer_id)
+			      lw6ker_game_state_t * game_state,
+			      lw6gui_main_cursor_t * main_cursor)
 {
-  if (backend->display_gradient)
+  if (backend->display_fighters)
     {
-      backend->display_gradient (utils_context, backend->view_context, look,
-				 level, map_state, team_id, layer_id);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-}
-
-void
-mod_gl_view_display_game (mod_gl_utils_context_t * utils_context,
-			  mod_gl_view_backend_t * backend,
-			  lw6gui_look_t * look,
-			  lw6ker_game_state_t * game_state,
-			  u_int16_t main_cursor_id)
-{
-  if (backend->display_game)
-    {
-      backend->display_game (utils_context, backend->view_context, look,
-			     game_state, main_cursor_id);
+      backend->display_fighters (utils_context, backend->view_context, look,
+				 game_state, main_cursor);
     }
   else
     {
@@ -139,12 +120,12 @@ mod_gl_view_display_cursors (mod_gl_utils_context_t * utils_context,
 			     mod_gl_view_backend_t * backend,
 			     lw6gui_look_t * look,
 			     lw6ker_game_state_t * game_state,
-			     u_int16_t main_cursor_id)
+			     lw6gui_main_cursor_t * main_cursor)
 {
-  if (backend->display_game)
+  if (backend->display_cursors)
     {
       backend->display_cursors (utils_context, backend->view_context, look,
-				game_state, main_cursor_id);
+				game_state, main_cursor);
     }
   else
     {
