@@ -41,23 +41,18 @@ typedef struct mod_gl_view_backend_s
   void (*display_preview) (mod_gl_utils_context_t * utils_context,
 			   void *view_context, lw6gui_look_t * look,
 			   lw6map_level_t * level);
-  void (*display_zones) (mod_gl_utils_context_t * utils_context,
-			 void *view_context, lw6gui_look_t * look,
-			 lw6map_level_t * level,
-			 lw6ker_map_struct_t * map_struct);
-  void (*display_gradient) (mod_gl_utils_context_t * utils_context,
+  void (*display_map) (mod_gl_utils_context_t * utils_context,
+		       void *view_context, lw6gui_look_t * look,
+		       lw6ker_game_state_t * game_state,
+		       lw6gui_main_cursor_t * main_cursor);
+  void (*display_fighters) (mod_gl_utils_context_t * utils_context,
 			    void *view_context, lw6gui_look_t * look,
-			    lw6map_level_t * level,
-			    lw6ker_map_state_t * map_state, int team_id,
-			    int layer_id);
-  void (*display_game) (mod_gl_utils_context_t * utils_context,
-			void *view_context, lw6gui_look_t * look,
-			lw6ker_game_state_t * game_state,
-			u_int16_t main_cursor_id);
+			    lw6ker_game_state_t * game_state,
+			    lw6gui_main_cursor_t * main_cursor);
   void (*display_cursors) (mod_gl_utils_context_t * utils_context,
 			   void *view_context, lw6gui_look_t * look,
 			   lw6ker_game_state_t * game_state,
-			   u_int16_t main_cursor_id);
+			   lw6gui_main_cursor_t * main_cursor);
 }
 mod_gl_view_backend_t;
 
@@ -73,29 +68,23 @@ extern void mod_gl_view_display_preview (mod_gl_utils_context_t *
 					 mod_gl_view_backend_t * backend,
 					 lw6gui_look_t * look,
 					 lw6map_level_t * level);
-extern void mod_gl_view_display_zones (mod_gl_utils_context_t * utils_context,
-				       mod_gl_view_backend_t * backend,
-				       lw6gui_look_t * look,
-				       lw6map_level_t * level,
-				       lw6ker_map_struct_t * map_struct);
-extern void mod_gl_view_display_gradient (mod_gl_utils_context_t *
+extern void mod_gl_view_display_map (mod_gl_utils_context_t * utils_context,
+				     mod_gl_view_backend_t * backend,
+				     lw6gui_look_t * look,
+				     lw6ker_game_state_t * game_state,
+				     lw6gui_main_cursor_t * main_cursor);
+extern void mod_gl_view_display_fighters (mod_gl_utils_context_t *
 					  utils_context,
 					  mod_gl_view_backend_t * backend,
 					  lw6gui_look_t * look,
-					  lw6map_level_t * level,
-					  lw6ker_map_state_t * map_state,
-					  int team_id, int layer_id);
-extern void mod_gl_view_display_game (mod_gl_utils_context_t * utils_context,
-				      mod_gl_view_backend_t * backend,
-				      lw6gui_look_t * look,
-				      lw6ker_game_state_t * game_state,
-				      u_int16_t main_cursor_id);
+					  lw6ker_game_state_t * game_state,
+					  lw6gui_main_cursor_t * main_cursor);
 extern void mod_gl_view_display_cursors (mod_gl_utils_context_t *
 					 utils_context,
 					 mod_gl_view_backend_t * backend,
 					 lw6gui_look_t * look,
 					 lw6ker_game_state_t * game_state,
-					 u_int16_t main_cursor_id);
+					 lw6gui_main_cursor_t * main_cursor);
 
 /*
  * In backend.c
