@@ -40,27 +40,32 @@ typedef struct _mod_gl_context_s
 }
 _mod_gl_context_t;
 
+/*
+ * In repr.c
+ */
+extern char *_mod_gl_repr (_mod_gl_context_t * gl_context, u_int32_t id);
+
 /*
  * In setup.c
  */
-extern _mod_gl_context_t *_mod_gl_init (int argc, char *argv[], int width,
-					int height, int fullscreen,
-					void (*resize_callback) (int width,
-								 int height,
-								 int
-								 fullscreen),
-					int ticks, int key_repeat_delay,
-					int key_repeat_interval);
-extern void _mod_gl_quit (_mod_gl_context_t * gfx_context);
-extern int _mod_gl_set_backends (_mod_gl_context_t * gfx_context,
+extern _mod_gl_context_t *_mod_gl_init (int argc, char *argv[],
+					lw6gui_video_mode_t * video_mode,
+					lw6gui_resize_callback_func_t
+					resize_callback);
+extern void _mod_gl_quit (_mod_gl_context_t * gl_context);
+extern int _mod_gl_set_backends (_mod_gl_context_t * gl_context,
 				 lw6gui_look_t * look);
-extern int _mod_gl_set_background_backend (_mod_gl_context_t * gfx_context,
+extern void _mod_gl_clear_background_backend (_mod_gl_context_t * gl_context);
+extern void _mod_gl_clear_hud_backend (_mod_gl_context_t * gl_context);
+extern void _mod_gl_clear_menu_backend (_mod_gl_context_t * gl_context);
+extern void _mod_gl_clear_view_backend (_mod_gl_context_t * gl_context);
+extern int _mod_gl_set_background_backend (_mod_gl_context_t * gl_context,
 					   char *background_style);
-extern int _mod_gl_set_hud_backend (_mod_gl_context_t * gfx_context,
+extern int _mod_gl_set_hud_backend (_mod_gl_context_t * gl_context,
 				    char *hud_style);
-extern int _mod_gl_set_menu_backend (_mod_gl_context_t * gfx_context,
+extern int _mod_gl_set_menu_backend (_mod_gl_context_t * gl_context,
 				     char *menu_style);
-extern int _mod_gl_set_view_backend (_mod_gl_context_t * gfx_context,
+extern int _mod_gl_set_view_backend (_mod_gl_context_t * gl_context,
 				     char *view_style);
 
 #endif
