@@ -24,12 +24,31 @@
 #include "config.h"
 #endif
 
-#include <string.h>
-
 #include "gui.h"
 
 #define DEFAULT_DYNAMIC_ZOOM 1.0f
 
+static void
+_fix_zoom (lw6gui_look_t * look)
+{
+  if (look->dynamic_zoom <= 0.0f)
+    {
+      look->dynamic_zoom = 1.0f;
+    }
+  if (look->style.zoom <= 0.0f)
+    {
+      look->style.zoom = LW6MAP_STYLE_DEFAULT_ZOOM;
+    }
+  if (look->dynamic_zoom * look->style.zoom > look->style.zoom_max)
+    {
+      look->dynamic_zoom = look->style.zoom_max / look->style.zoom;
+    }
+  if (look->dynamic_zoom * look->style.zoom < look->style.zoom_min)
+    {
+      look->dynamic_zoom = look->style.zoom_min / look->style.zoom;
+    }
+}
+
 /*
  * This is used to stamp maps as they are created.
  * Note that there's no race condition due to the fact that this
@@ -120,33 +139,11 @@ lw6gui_look_set (lw6gui_look_t * look, char *key, char *value)
 {
   int ret = 0;
 
-  if (strcmp (key, "focus-id"))
-    {
-      look->focus_id = lw6sys_atoi (value);
-      if (look->focus_id >= 0 || look->focus_id < LW6MAP_MAX_NB_CURSORS)
-	{
-	  ret = 1;
-	}
-      else
-	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("incorrect focus_id %d"),
-		      look->focus_id);
-	  look->focus_id = 0;
-	}
-    }
-  else if (strcmp (key, "dynamic-zoom"))
+  if (!strcmp (key, "dynamic-zoom"))
     {
       look->dynamic_zoom = lw6sys_atof (value);
-      if (look->dynamic_zoom > 0.0f)
-	{
-	  ret = 1;
-	}
-      else
-	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("incorrect dynamic_zoom %f"),
-		      look->dynamic_zoom);
-	  look->dynamic_zoom = DEFAULT_DYNAMIC_ZOOM;
-	}
+      _fix_zoom (look);
+      ret = 1;
     }
   else
     {
@@ -161,11 +158,7 @@ lw6gui_look_get (lw6gui_look_t * look, char *key)
 {
   char *ret = NULL;
 
-  if (strcmp (key, "focus-id"))
-    {
-      ret = lw6sys_itoa (look->focus_id);
-    }
-  else if (strcmp (key, "dynamic-zoom"))
+  if (!strcmp (key, "dynamic-zoom"))
     {
       ret = lw6sys_ftoa (look->dynamic_zoom);
     }
@@ -176,3 +169,106 @@ lw6gui_look_get (lw6gui_look_t * look, char *key)
 
   return ret;
 }
+
+int
+lw6gui_look_is_same (lw6gui_look_t * look_a, lw6gui_look_t * look_b)
+{
+  int ret = 1;
+
+  if (((!look_a) && look_b) || (look_a && (!look_b)))
+    {
+      ret = 0;
+    }
+  if (look_a && look_b)
+    {
+      ret = ret && look_a->dynamic_zoom == look_b->dynamic_zoom;
+      ret = ret && lw6map_style_is_same (&look_a->style, &look_b->style);
+    }
+
+  return ret;
+}
+
+lw6gui_look_t *
+lw6gui_look_dup (lw6gui_look_t * look)
+{
+  lw6gui_look_t *ret = NULL;
+
+  if (look)
+    {
+      ret = lw6gui_look_new (&(look->style));
+    }
+  else
+    {
+      ret = lw6gui_look_new (NULL);
+    }
+  if (ret)
+    {
+      ret->dynamic_zoom = look->dynamic_zoom;
+    }
+
+  return ret;
+}
+
+void
+lw6gui_look_fix (lw6gui_look_t * look)
+{
+  _fix_zoom (look);
+}
+
+int
+lw6gui_look_zoom_in (lw6gui_look_t * look, float zoom_step)
+{
+  int ret = 0;
+  float old_zoom = look->dynamic_zoom;
+
+  if (zoom_step > 1.0f)
+    {
+      look->dynamic_zoom *= zoom_step;
+      if (look->dynamic_zoom >= 1.0 / zoom_step && look->dynamic_zoom < 1.0f)
+	{
+	  /*
+	   * Sticky behavior
+	   */
+	  look->dynamic_zoom = 1.0f;
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("zoom_step=%f, should be >1.0"),
+		  zoom_step);
+    }
+  _fix_zoom (look);
+
+  ret = (old_zoom != look->dynamic_zoom);
+
+  return ret;
+}
+
+int
+lw6gui_look_zoom_out (lw6gui_look_t * look, float zoom_step)
+{
+  int ret = 0;
+  float old_zoom = look->dynamic_zoom;
+
+  if (zoom_step > 1.0f)
+    {
+      look->dynamic_zoom /= zoom_step;
+      /*
+       * Sticky behavior
+       */
+      if (look->dynamic_zoom <= zoom_step && look->dynamic_zoom > 1.0f)
+	{
+	  look->dynamic_zoom = 1.0f;
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("zoom_step=%f, should be >1.0"),
+		  zoom_step);
+    }
+  _fix_zoom (look);
+
+  ret = (old_zoom != look->dynamic_zoom);
+
+  return ret;
+}
