@@ -40,6 +40,8 @@ static u_int32_t seq_id = 0;
  *
  * @title: the string to be displayed, what the user sees. Can be freed after
  *   the call is done, function will make a copy internally.
+ * @esc: the label to be displayed in the ESC button
+ * @enable_esc: wether to enable the escape button.
  *
  * Constructs a new menu object. Note that you can always call other
  * functions to modify it afterwards.
@@ -47,7 +49,7 @@ static u_int32_t seq_id = 0;
  * Return value: a pointer to the newly allocated object.
  */
 lw6gui_menu_t *
-lw6gui_menu_new (char *title)
+lw6gui_menu_new (char *title, char *esc, int enable_esc)
 {
   lw6gui_menu_t *menu = NULL;
 
@@ -57,10 +59,20 @@ lw6gui_menu_new (char *title)
       menu->title = lw6sys_str_copy (title);
       if (menu->title)
 	{
-	  menu->id = 0;
-	  while (!menu->id)
+	  menu->esc_item = lw6gui_menuitem_new (esc, 0, enable_esc, 0, 0);
+	  if (menu->esc_item)
 	    {
-	      menu->id = ++seq_id;
+	      menu->id = 0;
+	      while (!menu->id)
+		{
+		  menu->id = ++seq_id;
+		}
+	    }
+	  else
+	    {
+	      LW6SYS_FREE (menu->title);
+	      LW6SYS_FREE (menu);
+	      menu = NULL;
 	    }
 	}
       else
@@ -99,6 +111,10 @@ lw6gui_menu_free (lw6gui_menu_t * menu)
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("menu with NULL title"));
 	}
 
+      if (menu->esc_item)
+	{
+	  lw6gui_menuitem_free (menu->esc_item);
+	}
       if (menu->items)
 	{
 	  for (i = 0; i < menu->nb_items; ++i)
@@ -234,6 +250,7 @@ lw6gui_menu_get_item (lw6gui_menu_t * menu, int position)
  *
  * @menu: the menu we want to modify
  * @position: the position of the item we want to select
+ * @allow_scroll: wether scrolling should be allowed when displaying it
  * @now: the current time, as a timestamp.
  *
  * Selects the item at the given position. Use this function to be sure
@@ -243,7 +260,8 @@ lw6gui_menu_get_item (lw6gui_menu_t * menu, int position)
  * Return value: 1 if success, 0 if failure (out of range).
  */
 int
-lw6gui_menu_select (lw6gui_menu_t * menu, int position, int now)
+lw6gui_menu_select (lw6gui_menu_t * menu, int position, int allow_scroll,
+		    int64_t now)
 {
   int ret = 0;
   int i = 0;
@@ -255,14 +273,7 @@ lw6gui_menu_select (lw6gui_menu_t * menu, int position, int now)
 	  menu->selected_item = position;
 	  for (i = 0; i < menu->nb_items; ++i)
 	    {
-	      if (i == position)
-		{
-		  lw6gui_menuitem_select (menu->items[i], now);
-		}
-	      else
-		{
-		  lw6gui_menuitem_unselect (menu->items[i], now);
-		}
+	      lw6gui_menuitem_select (menu->items[i], (i == position), now);
 	    }
 	  ret = 1;
 	}
@@ -273,10 +284,47 @@ lw6gui_menu_select (lw6gui_menu_t * menu, int position, int now)
 		      menu->nb_items);
 	}
     }
+  menu->allow_scroll = allow_scroll;
 
   return ret;
 }
 
+/**
+ * lw6gui_menu_select_esc
+ *
+ * @menu: the menu we want to modify
+ * @state: 1 to select, 0 to unselect
+ * @now: the current time, as a timestamp.
+ *
+ * Selects the escape item, this does not affect other items, it's mostly.
+ * to handle eye candy.
+ *
+ * Return value: none.
+ */
+void
+lw6gui_menu_select_esc (lw6gui_menu_t * menu, int state, int64_t now)
+{
+  lw6gui_menuitem_select (menu->esc_item, state, now);
+}
+
+/**
+ * lw6gui_menu_enable_esc
+ *
+ * @menu: the menu we want to modify
+ * @state: 1 to enable, 0 to disable
+ * @now: the current time, as a timestamp.
+ *
+ * Enables the escape item, this does not affect other items, it's mostly.
+ * to handle eye candy.
+ *
+ * Return value: none.
+ */
+void
+lw6gui_menu_enable_esc (lw6gui_menu_t * menu, int state, int64_t now)
+{
+  lw6gui_menuitem_enable (menu->esc_item, state, now);
+}
+
 /**
  * lw6gui_menu_scroll_up
  *
@@ -365,7 +413,7 @@ lw6gui_menu_center (lw6gui_menu_t * menu, int position,
  */
 int
 lw6gui_menu_insert (lw6gui_menu_t * menu, lw6gui_menuitem_t * menuitem,
-		    int position, int now)
+		    int position, int64_t now)
 {
   int ret = 0;
   int i;
@@ -390,7 +438,7 @@ lw6gui_menu_insert (lw6gui_menu_t * menu, lw6gui_menuitem_t * menuitem,
 	      menu->items[position] = menuitem;
 	      if (menu->selected_item >= position)
 		{
-		  lw6gui_menu_select (menu, menu->selected_item + 1, now);
+		  lw6gui_menu_select (menu, menu->selected_item + 1, 0, now);
 		}
 	      ret = 1;
 	    }
@@ -404,7 +452,7 @@ lw6gui_menu_insert (lw6gui_menu_t * menu, lw6gui_menuitem_t * menuitem,
 	    {
 	      menu->nb_items = 1;
 	      menu->items[0] = menuitem;
-	      lw6gui_menu_select (menu, 0, now);
+	      lw6gui_menu_select (menu, 0, 0, now);
 	      ret = 1;
 	    }
 	}
@@ -436,7 +484,7 @@ lw6gui_menu_insert (lw6gui_menu_t * menu, lw6gui_menuitem_t * menuitem,
  */
 int
 lw6gui_menu_append (lw6gui_menu_t * menu, lw6gui_menuitem_t * menuitem,
-		    int now)
+		    int64_t now)
 {
   int ret = 0;
 
@@ -457,7 +505,7 @@ lw6gui_menu_append (lw6gui_menu_t * menu, lw6gui_menuitem_t * menuitem,
  * Return value: 1 if success, 0 if failure (out of range).
  */
 int
-lw6gui_menu_remove (lw6gui_menu_t * menu, int position, int now)
+lw6gui_menu_remove (lw6gui_menu_t * menu, int position, int64_t now)
 {
   int ret = 0;
   int i;
@@ -476,22 +524,22 @@ lw6gui_menu_remove (lw6gui_menu_t * menu, int position, int now)
 	    {
 	      if (menu->selected_item > 0)
 		{
-		  lw6gui_menu_select (menu, menu->selected_item - 1, now);
+		  lw6gui_menu_select (menu, menu->selected_item - 1, 0, now);
 		}
 	      else
 		{
-		  lw6gui_menu_select (menu, menu->selected_item, now);
+		  lw6gui_menu_select (menu, menu->selected_item, 0, now);
 		}
 	    }
 	  else
 	    {
 	      if (position < menu->nb_items)
 		{
-		  lw6gui_menu_select (menu, position, now);
+		  lw6gui_menu_select (menu, position, 0, now);
 		}
 	      else
 		{
-		  lw6gui_menu_select (menu, menu->nb_items - 1, now);
+		  lw6gui_menu_select (menu, menu->nb_items - 1, 0, now);
 		}
 	    }
 	}
@@ -517,7 +565,7 @@ lw6gui_menu_remove (lw6gui_menu_t * menu, int position, int now)
 }
 
 /**
- * lw6gui_update_display_range
+ * lw6gui_menu_update_display_range
  *
  * @menu: the menu concerned
  * @max_displayed_items: the maximum number of items to display at once
@@ -537,6 +585,12 @@ lw6gui_menu_update_display_range (lw6gui_menu_t * menu,
 {
   if (menu->nb_items > max_displayed_items)
     {
+      if (menu->allow_scroll)
+	{
+	  menu->first_item_displayed =
+	    menu->selected_item - menu->order_of_selected_on_display;
+	}
+
       /*
        * Here there are more items in the menu than the max
        * displayable number. 
@@ -570,6 +624,8 @@ lw6gui_menu_update_display_range (lw6gui_menu_t * menu,
       menu->first_item_displayed = 0;
       menu->nb_items_displayed = menu->nb_items;
     }
+  menu->order_of_selected_on_display =
+    menu->selected_item - menu->first_item_displayed;
 }
 
 /**
@@ -601,7 +657,7 @@ lw6gui_menu_update_display_range (lw6gui_menu_t * menu,
 int
 lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label, int value,
 			       int enabled, int selected,
-			       int colored, int position, int now)
+			       int colored, int position, int64_t now)
 {
   int ret = 0;
   lw6gui_menuitem_t *menuitem;
@@ -613,7 +669,7 @@ lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label, int value,
 	{
 	  if (selected)
 	    {
-	      lw6gui_menu_select (menu, position, now);
+	      lw6gui_menu_select (menu, position, 0, now);
 	    }
 	  ret = menuitem->id;
 	}
@@ -644,7 +700,7 @@ lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label, int value,
 int
 lw6gui_menu_append_for_id_use (lw6gui_menu_t * menu, char *label, int value,
 			       int enabled, int selected,
-			       int colored, int now)
+			       int colored, int64_t now)
 {
   int ret = 0;
 
@@ -695,7 +751,8 @@ get_position_using_id (lw6gui_menu_t * menu, int id)
  * Return value: 1 if success, 0 if failure (out of range).
  */
 int
-lw6gui_menu_remove_using_id (lw6gui_menu_t * menu, int menuitem_id, int now)
+lw6gui_menu_remove_using_id (lw6gui_menu_t * menu, int menuitem_id,
+			     int64_t now)
 {
   int ret = 0;
   int position;
@@ -729,7 +786,7 @@ lw6gui_menu_remove_using_id (lw6gui_menu_t * menu, int menuitem_id, int now)
 void
 lw6gui_menu_sync_using_id (lw6gui_menu_t * menu, int menuitem_id, char *label,
 			   int value, int enabled, int selected, int colored,
-			   int now)
+			   int64_t now)
 {
   int position;
   lw6gui_menuitem_t *menuitem;
@@ -745,9 +802,211 @@ lw6gui_menu_sync_using_id (lw6gui_menu_t * menu, int menuitem_id, char *label,
 	  menuitem->enabled = enabled;
 	  if (selected)
 	    {
-	      lw6gui_menu_select (menu, position, now);
+	      lw6gui_menu_select (menu, position, 0, now);
 	    }
 	  menuitem->colored = colored;
 	}
     }
 }
+
+/**
+ * lw6gui_menu_is_same
+ *
+ * @menu_a: first item to compare
+ * @menu_b: second item to compare
+ *
+ * Compares two menus.
+ *
+ * Return value: 1 if they are the same, 0 if not
+ */
+int
+lw6gui_menu_is_same (lw6gui_menu_t * menu_a, lw6gui_menu_t * menu_b)
+{
+  int ret = 1;
+  int i;
+
+  if (((!menu_a) && menu_b) || (menu_a && (!menu_b)))
+    {
+      ret = 0;
+    }
+  if (menu_a && menu_b)
+    {
+      ret = ret && !strcmp (menu_a->title, menu_b->title);
+      ret = ret && menu_a->nb_items == menu_b->nb_items;
+      ret = ret
+	&& lw6gui_menuitem_is_same (menu_a->esc_item, menu_b->esc_item);
+      for (i = 0; ret && i < lw6sys_min (menu_a->nb_items, menu_b->nb_items);
+	   ++i)
+	{
+	  if (i < menu_a->nb_items && i < menu_b->nb_items
+	      && !lw6gui_menuitem_is_same (menu_a->items[i],
+					   menu_b->items[i]))
+	    {
+	      ret = 0;
+	    }
+	}
+      ret = ret && menu_a->selected_item == menu_b->selected_item;
+      ret = ret
+	&& menu_a->first_item_displayed == menu_b->first_item_displayed;
+      ret = ret && menu_a->nb_items_displayed == menu_b->nb_items_displayed;
+      ret = ret
+	&& menu_a->order_of_selected_on_display ==
+	menu_b->order_of_selected_on_display;
+      ret = ret && menu_a->allow_scroll == menu_b->allow_scroll;
+    }
+
+  return ret;
+}
+
+/**
+ * lw6gui_menu_dup
+ *
+ * @menu: the menu to duplicate
+ *
+ * Duplicates a menu structure.
+ *
+ * Return value: a pointer to the new menu.
+ */
+lw6gui_menu_t *
+lw6gui_menu_dup (lw6gui_menu_t * menu)
+{
+  lw6gui_menu_t *ret = NULL;
+  lw6gui_menuitem_t *item = NULL;
+  int i;
+
+  if (menu)
+    {
+      ret =
+	lw6gui_menu_new (menu->title, menu->esc_item->label,
+			 menu->esc_item->enabled);
+      if (ret)
+	{
+	  lw6gui_menuitem_sync (ret->esc_item, menu->esc_item);
+	  for (i = 0; i < menu->nb_items; ++i)
+	    {
+	      item = lw6gui_menuitem_dup (menu->items[i]);
+	      if (item)
+		{
+		  lw6gui_menu_append (ret, item, item->last_change);
+		}
+	    }
+	  if (ret->nb_items == menu->nb_items)
+	    {
+	      for (i = 0; i < menu->nb_items; ++i)
+		{
+		  ret->items[i]->selected = menu->items[i]->selected;
+		}
+	    }
+	  else
+	    {
+	      lw6gui_menu_free (ret);
+	      ret = NULL;
+	    }
+	}
+    }
+
+  if (ret)
+    {
+      ret->selected_item = menu->selected_item;
+      ret->first_item_displayed = menu->first_item_displayed;
+      ret->nb_items_displayed = menu->nb_items_displayed;
+      ret->order_of_selected_on_display = menu->order_of_selected_on_display;
+      ret->allow_scroll = menu->allow_scroll;
+    }
+
+  return ret;
+}
+
+/**
+ * lw6gui_menu_sync
+ *
+ * @dst: the target menu
+ * @src: the source menu
+ *
+ * Synchronizes two menus, this supposes that they represent the same menu, but
+ * simply in a different state. This function does not really copy src to dst, it 
+ * has a special behavior, indeed everything is copied from src to dst, except
+ * the @first_item_displayed and @nb_items_displayed which are taken from dst
+ * and copied to src. This is because in practise, those values are updated
+ * in the display loop/thread, which is the one which uses the target. This is
+ * not very orthodox, but should work.
+ *
+ * Return value: 1 if success, 0 if failure
+ */
+int
+lw6gui_menu_sync (lw6gui_menu_t * dst, lw6gui_menu_t * src)
+{
+  int ret = 0;
+  int i, d;
+  lw6gui_menuitem_t *item = NULL;
+
+  if (dst && src)
+    {
+      if (strcmp (dst->title, src->title))
+	{
+	  lw6gui_menu_set_title (dst, src->title);
+	}
+      d = dst->nb_items - src->nb_items;
+      if (d > 0)
+	{
+	  for (i = 0; i < d; ++i)
+	    {
+	      /*
+	       * We remove the first item, it might not be perfect but
+	       * we don't care, items will be synchronized later
+	       */
+	      lw6gui_menu_remove (dst, 0, 0);
+	    }
+	}
+      if (d < 0)
+	{
+	  for (i = 0; i < -d; ++i)
+	    {
+	      /*
+	       * We add any item, we just don't care, synchronisation
+	       * of items will fix things.
+	       */
+	      item = lw6gui_menuitem_dup (src->items[i]);
+	      if (item)
+		{
+		  lw6gui_menu_append (dst, item, 0);
+		}
+	    }
+	}
+
+      lw6gui_menuitem_sync (dst->esc_item, src->esc_item);
+      if (dst->nb_items == src->nb_items)
+	{
+	  for (i = 0; i < src->nb_items; ++i)
+	    {
+	      lw6gui_menuitem_sync (dst->items[i], src->items[i]);
+	    }
+	  dst->selected_item = src->selected_item;
+	  /*
+	   * Note the src <-> dst inversion for the following values
+	   */
+	  src->first_item_displayed = dst->first_item_displayed;
+	  src->nb_items_displayed = dst->nb_items_displayed;
+	  src->order_of_selected_on_display =
+	    dst->order_of_selected_on_display;
+	  /*
+	   * The rest is "normal", copied from src to dst
+	   */
+	  dst->allow_scroll = src->allow_scroll;
+	  ret = 1;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _
+		      ("unable to sync menus, dst has %d items while src has %d items"),
+		      dst->nb_items, src->nb_items);
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("menus are not syncable"));
+    }
+
+  return ret;
+}
