@@ -187,7 +187,8 @@ lw6gui_menuitem_repr (lw6gui_menuitem_t * menuitem)
  * Return value: none
  */
 void
-lw6gui_menuitem_set_label (lw6gui_menuitem_t * menuitem, char *label, int now)
+lw6gui_menuitem_set_label (lw6gui_menuitem_t * menuitem, char *label,
+			   int64_t now)
 {
   if (strcmp (label, menuitem->label))
     {
@@ -218,7 +219,8 @@ lw6gui_menuitem_set_label (lw6gui_menuitem_t * menuitem, char *label, int now)
  * Return value: none
  */
 void
-lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem, int value, int now)
+lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem, int value,
+			   int64_t now)
 {
   if (value != menuitem->value)
     {
@@ -231,9 +233,10 @@ lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem, int value, int now)
  * lw6gui_menuitem_select
  *
  * @menuitem: a pointer to the menuitem.
+ * @state: 1 to select, 0 to unselect
  * @now: the current time, as a timestamp.
  * 
- * Switches the menuitem to selected state. Use this function, don't try
+ * Switches the menuitem to (un)selected state. Use this function, don't try
  * to modify the struct members directly. The idea is to have
  * the @last_select parameter up to date.
  * It can be later used for eye-candy effects.
@@ -241,35 +244,60 @@ lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem, int value, int now)
  * Return value: none
  */
 void
-lw6gui_menuitem_select (lw6gui_menuitem_t * menuitem, int now)
+lw6gui_menuitem_select (lw6gui_menuitem_t * menuitem, int state, int64_t now)
 {
-  if (!(menuitem->selected))
+  if (state && !(menuitem->selected))
     {
       menuitem->selected = 1;
       menuitem->last_select = now;
     }
+  if ((!state) && menuitem->selected)
+    {
+      menuitem->selected = 0;
+      menuitem->last_unselect = now;
+    }
 }
 
 /**
- * lw6gui_menuitem_select
+ * lw6gui_menuitem_enable
  *
  * @menuitem: a pointer to the menuitem.
+ * @state: 1 to enable, 0 to disable
  * @now: the current time, as a timestamp.
  * 
- * Switches the menuitem to unselected state. Use this function, don't try
+ * Switches the menuitem to enabled/disabled state. Use this function, don't try
  * to modify the struct members directly. The idea is to have
- * the @last_unselect parameter up to date.
+ * the @last_select parameter up to date.
  * It can be later used for eye-candy effects.
  *
  * Return value: none
  */
 void
-lw6gui_menuitem_unselect (lw6gui_menuitem_t * menuitem, int now)
+lw6gui_menuitem_enable (lw6gui_menuitem_t * menuitem, int state, int64_t now)
 {
-  if (menuitem->selected)
+  if (state && (!menuitem->enabled))
     {
-      menuitem->selected = 0;
-      menuitem->last_unselect = now;
+      menuitem->enabled = 1;
+      if (menuitem->selected)
+	{
+	  menuitem->last_select = now;
+	}
+      else
+	{
+	  menuitem->last_unselect = now;
+	}
+    }
+  if ((!state) && menuitem->enabled)
+    {
+      menuitem->enabled = 0;
+      if (menuitem->selected)
+	{
+	  menuitem->last_select = now;
+	}
+      else
+	{
+	  menuitem->last_unselect = now;
+	}
     }
 }
 
@@ -297,3 +325,108 @@ lw6gui_menuitem_checksum (lw6gui_menuitem_t * menuitem, lw6gui_look_t * look)
 
   return ret;
 }
+
+/**
+ * lw6gui_menuitem_is_same
+ *
+ * @menuitem_a: first item to compare
+ * @menuitem_b: second item to compare
+ *
+ * Compares two menuitems.
+ *
+ * Return value: 1 if they are the same, 0 if not
+ */
+int
+lw6gui_menuitem_is_same (lw6gui_menuitem_t * menuitem_a,
+			 lw6gui_menuitem_t * menuitem_b)
+{
+  int ret = 1;
+
+  if (((!menuitem_a) && menuitem_b) || (menuitem_a && (!menuitem_b)))
+    {
+      ret = 0;
+    }
+  if (menuitem_a && menuitem_b)
+    {
+      ret = ret && !strcmp (menuitem_a->label, menuitem_b->label);
+      ret = ret && menuitem_a->value == menuitem_b->value;
+      ret = ret && menuitem_a->enabled == menuitem_b->enabled;
+      ret = ret && menuitem_a->selected == menuitem_b->selected;
+      ret = ret && menuitem_a->colored == menuitem_b->colored;
+      ret = ret && menuitem_a->last_change == menuitem_b->last_change;
+      ret = ret && menuitem_a->last_select == menuitem_b->last_select;
+      ret = ret && menuitem_a->last_unselect == menuitem_b->last_unselect;
+    }
+
+  return ret;
+}
+
+/**
+ * lw6gui_menuitem_dup
+ *
+ * @menuitem: the menuitem to duplicate
+ *
+ * The menuitem to duplicate.
+ *
+ * Return value: a pointer to the duplicted menuitem.
+ */
+lw6gui_menuitem_t *
+lw6gui_menuitem_dup (lw6gui_menuitem_t * menuitem)
+{
+  lw6gui_menuitem_t *ret = NULL;
+
+  if (menuitem)
+    {
+      ret =
+	lw6gui_menuitem_new (menuitem->label, menuitem->value,
+			     menuitem->enabled, menuitem->selected,
+			     menuitem->colored);
+      if (ret)
+	{
+	  ret->last_change = menuitem->last_change;
+	  ret->last_select = menuitem->last_select;
+	  ret->last_unselect = menuitem->last_unselect;
+	}
+    }
+
+  return ret;
+}
+
+/**
+ * lw6gui_menuitem_sync
+ *
+ * @dst: the target menuitem
+ * @src: the source menuitem
+ *
+ * Synchronizes two menuitems, this supposes that they represent the same item, but
+ * simply in a different state. 
+ *
+ * Return value: 1 if success, 0 if failure
+ */
+int
+lw6gui_menuitem_sync (lw6gui_menuitem_t * dst, lw6gui_menuitem_t * src)
+{
+  int ret = 0;
+
+  if (dst && src)
+    {
+      if (strcmp (dst->label, src->label))
+	{
+	  lw6gui_menuitem_set_label (dst, src->label, src->last_change);
+	}
+      dst->value = src->value;
+      dst->enabled = src->enabled;
+      dst->selected = src->selected;
+      dst->colored = src->colored;
+      dst->last_change = src->last_change;
+      dst->last_select = src->last_select;
+      dst->last_unselect = src->last_unselect;
+      ret = 1;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("menuitems are not syncable"));
+    }
+
+  return ret;
+}
