@@ -30,6 +30,9 @@ typedef struct _lw6hlp_reference_entry_s
   lw6hlp_type_t type;
   char *key;
   char *about;
+  char *default_value;
+  int min_value;
+  int max_value;
 } _lw6hlp_reference_entry_t;
 
 extern _lw6hlp_reference_entry_t *_lw6hlp_reference_get_entry (char *key);
