@@ -35,8 +35,6 @@ update_quick (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_COPYRIGHT);
   lw6sys_list_push_back (list, LW6DEF_VERSION);
   lw6sys_list_push_back (list, LW6DEF_TEST);
-  lw6sys_list_push_back (list, LW6DEF_PEDIGREE);
-  lw6sys_list_push_back (list, LW6DEF_RESET);
   lw6sys_list_push_back (list, LW6DEF_DEFAULTS);
   lw6sys_list_push_back (list, LW6DEF_LIST);
   lw6sys_list_push_back (list, LW6DEF_ABOUT);
@@ -122,8 +120,10 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TARGET_CPU);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENDIANNESS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_POINTER_SIZE);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_X86);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TARGET_OS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MS_WINDOWS);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MAC_OS_X);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TOP_SRCDIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_PREFIX);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_DATADIR);
@@ -139,7 +139,11 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_OPTIMIZE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_ALLINONE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_FULLSTATIC);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_PARANOID);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_GPROF);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_INSTRUMENT);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_PROFILER);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_GCOV);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_VALGRIND);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_USER_DIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_CONFIG_FILE);
@@ -254,24 +258,22 @@ static int
 update_input (lw6sys_list_t ** list)
 {
   lw6sys_list_push_back (list, LW6DEF_MOUSE_SENSITIVITY);
-  lw6sys_list_push_back (list, LW6DEF_JOYSTICK_SENSITIVITY);
-  lw6sys_list_push_back (list, LW6DEF_KEYBOARD_SENSITIVITY);
-  lw6sys_list_push_back (list, LW6DEF_MAX_JOYSTICK_CURSOR_SPEED);
-  lw6sys_list_push_back (list, LW6DEF_MAX_KEYBOARD_CURSOR_SPEED);
-  lw6sys_list_push_back (list, LW6DEF_KEY_REPEAT_DELAY);
-  lw6sys_list_push_back (list, LW6DEF_KEY_REPEAT_INTERVAL);
-  lw6sys_list_push_back (list, LW6DEF_JOYSTICK1_INDEX);
-  lw6sys_list_push_back (list, LW6DEF_JOYSTICK1_BUTTON_A);
-  lw6sys_list_push_back (list, LW6DEF_JOYSTICK1_BUTTON_B);
-  lw6sys_list_push_back (list, LW6DEF_JOYSTICK2_INDEX);
-  lw6sys_list_push_back (list, LW6DEF_JOYSTICK2_BUTTON_A);
-  lw6sys_list_push_back (list, LW6DEF_JOYSTICK2_BUTTON_B);
+  lw6sys_list_push_back (list, LW6DEF_CURSOR_SENSITIVITY);
+  lw6sys_list_push_back (list, LW6DEF_MAX_CURSOR_SPEED);
+  lw6sys_list_push_back (list, LW6DEF_REPEAT_DELAY);
+  lw6sys_list_push_back (list, LW6DEF_REPEAT_INTERVAL);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_UP);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_DOWN);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_LEFT);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_RIGHT);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_ESC);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_ENTER);
+  lw6sys_list_push_back (list, LW6DEF_CUSTOM_PGUP);
+  lw6sys_list_push_back (list, LW6DEF_CUSTOM_PGDOWN);
+  lw6sys_list_push_back (list, LW6DEF_CLICK_TO_FOCUS);
+  lw6sys_list_push_back (list, LW6DEF_USE_ESC_BUTTON);
+  lw6sys_list_push_back (list, LW6DEF_ZOOM_STEP);
+  lw6sys_list_push_back (list, LW6DEF_ZOOM_STICK_DELAY);
 
   return ((*list) != NULL);
 }
@@ -296,7 +298,6 @@ update_graphics (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_WIDTH);
   lw6sys_list_push_back (list, LW6DEF_HEIGHT);
   lw6sys_list_push_back (list, LW6DEF_FULLSCREEN);
-  lw6sys_list_push_back (list, LW6DEF_PRESET_RESOLUTION);
   lw6sys_list_push_back (list, LW6DEF_GFX_BACKEND);
   lw6sys_list_push_back (list, LW6DEF_WINDOWED_MODE_LIMIT);
 
@@ -501,6 +502,10 @@ update_map_style (lw6sys_list_t ** list)
 {
   lw6sys_list_push_back (list, LW6DEF_KEEP_RATIO);
   lw6sys_list_push_back (list, LW6DEF_ZOOM);
+  lw6sys_list_push_back (list, LW6DEF_ZOOM_MIN);
+  lw6sys_list_push_back (list, LW6DEF_ZOOM_MAX);
+  lw6sys_list_push_back (list, LW6DEF_X_WRAP);
+  lw6sys_list_push_back (list, LW6DEF_Y_WRAP);
   lw6sys_list_push_back (list, LW6DEF_BACKGROUND_STYLE);
   lw6sys_list_push_back (list, LW6DEF_HUD_STYLE);
   lw6sys_list_push_back (list, LW6DEF_MENU_STYLE);
@@ -510,6 +515,7 @@ update_map_style (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_CURSOR_SIZE);
   lw6sys_list_push_back (list, LW6DEF_HIDDEN_LAYER_ALPHA);
   lw6sys_list_push_back (list, LW6DEF_COLORIZE);
+  lw6sys_list_push_back (list, LW6DEF_PIXELIZE);
   lw6sys_list_push_back (list, LW6DEF_COLOR_BASE_BG);
   lw6sys_list_push_back (list, LW6DEF_COLOR_BASE_FG);
   lw6sys_list_push_back (list, LW6DEF_COLOR_ALTERNATE_BG);
@@ -605,20 +611,35 @@ lw6hlp_list_hooks ()
 static int
 update_tuning (lw6sys_list_t ** list)
 {
+  lw6sys_list_push_back (list, LW6DEF_PEDIGREE);
   lw6sys_list_push_back (list, LW6DEF_TARGET);
   lw6sys_list_push_back (list, LW6DEF_AUDIT);
   lw6sys_list_push_back (list, LW6DEF_MODULES);
+  lw6sys_list_push_back (list, LW6DEF_RESET);
   lw6sys_list_push_back (list, LW6DEF_LOG_LEVEL);
-  lw6sys_list_push_back (list, LW6DEF_FRAMES_PER_SEC);
+  lw6sys_list_push_back (list, LW6DEF_TARGET_FPS);
   lw6sys_list_push_back (list, LW6DEF_IO_PER_SEC);
   lw6sys_list_push_back (list, LW6DEF_COMMANDS_PER_SEC);
-  lw6sys_list_push_back (list, LW6DEF_CHECKPOINT_PERIOD);
   lw6sys_list_push_back (list, LW6DEF_LOADER_SLEEP);
-  lw6sys_list_push_back (list, LW6DEF_PILOT_SLEEP);
   lw6sys_list_push_back (list, LW6DEF_PILOT_LAG);
   lw6sys_list_push_back (list, LW6DEF_MEMORY_BAZOOKA_SIZE);
   lw6sys_list_push_back (list, LW6DEF_MEMORY_BAZOOKA_ERASER);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_SPLASH);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_BACKGROUND);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_PREVIEW);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_MAP);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_FIGHTERS);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_CURSORS);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_HUD);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_SCORE);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_MENU);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_PROGRESS);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_LOG);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_FPS);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_RPS);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_MOUSE);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_DEBUG_ZONES);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_DEBUG_GRADIENT);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_CONSOLE);
   lw6sys_list_push_back (list, LW6DEF_SERVER);
   lw6sys_list_push_back (list, LW6DEF_QUICK_START);
@@ -626,6 +647,11 @@ update_tuning (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_BENCH);
   lw6sys_list_push_back (list, LW6DEF_BOT_SPEED);
   lw6sys_list_push_back (list, LW6DEF_BOT_IQ);
+  lw6sys_list_push_back (list, LW6DEF_DEBUG_TEAM_ID);
+  lw6sys_list_push_back (list, LW6DEF_DEBUG_LAYER_ID);
+  lw6sys_list_push_back (list, LW6DEF_LOG_TIMEOUT);
+  lw6sys_list_push_back (list, LW6DEF_GFX_CPU_USAGE);
+  lw6sys_list_push_back (list, LW6DEF_DIRTY_READ);
 
   return ((*list) != NULL);
 }
@@ -653,6 +679,8 @@ update_aliases (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_COPYLEFT);
   lw6sys_list_push_back (list, LW6DEF_COPY);
   lw6sys_list_push_back (list, "c");
+  lw6sys_list_push_back (list, LW6DEF_CFLAGS);
+  lw6sys_list_push_back (list, LW6DEF_LDFLAGS);
 
   return ((*list) != NULL);
 }
