@@ -57,7 +57,7 @@ print_content_callback (void *func_data, void *data)
   entry = (char *) data;
   if (entry)
     {
-      about = lw6hlp_about (&type, entry);
+      about = lw6hlp_about (&type, NULL, NULL, NULL, entry);
       if (lw6hlp_match (entry, LW6DEF_ABOUT))
 	{
 	  /*
