@@ -39,15 +39,35 @@ test_about ()
 
   {
     char *help_string = NULL;
+    lw6hlp_type_t type;
+    char *default_value;
+    int min_value;
+    int max_value;
 
     if (!lw6hlp_is_documented (TEST_KEYWORD))
       {
 	ret = 0;
       }
 
-    help_string = lw6hlp_about (NULL, TEST_KEYWORD);
+    help_string = lw6hlp_about (NULL, NULL, NULL, NULL, TEST_KEYWORD);
     lw6sys_log (LW6SYS_LOG_NOTICE, _("help for \"%s\" is \"%s\""),
 		TEST_KEYWORD, help_string);
+    type = lw6hlp_get_type (TEST_KEYWORD);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("type for \"%s\" is \"%d\""),
+		TEST_KEYWORD, (int) type);
+    default_value = lw6hlp_get_default_value (TEST_KEYWORD);
+    if (default_value)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("default value for \"%s\" is \"%s\""), TEST_KEYWORD,
+		    default_value);
+      }
+    min_value = lw6hlp_get_min_value (TEST_KEYWORD);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("min value for \"%s\" is \"%d\""),
+		TEST_KEYWORD, min_value);
+    max_value = lw6hlp_get_max_value (TEST_KEYWORD);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("max value for \"%s\" is \"%d\""),
+		TEST_KEYWORD, max_value);
   }
 
   LW6SYS_TEST_FUNCTION_END;
