@@ -44,8 +44,12 @@ lw6hlp_type_t;
 
 /* hlp-about.c */
 extern int lw6hlp_is_documented (char *keyword);
-extern char *lw6hlp_about (lw6hlp_type_t * type, char *keyword);
+extern char *lw6hlp_about (lw6hlp_type_t * type, char **default_value,
+			   int *min_value, int *max_value, char *keyword);
 extern lw6hlp_type_t lw6hlp_get_type (char *keyword);
+extern char *lw6hlp_get_default_value (char *keyword);
+extern int lw6hlp_get_min_value (char *keyword);
+extern int lw6hlp_get_max_value (char *keyword);
 
 /* hlp-keyword.c */
 extern int lw6hlp_match (char *keyword1, char *keyword2);
