@@ -84,6 +84,7 @@ _lw6ker_armies_sync (lw6ker_armies_t * dst, lw6ker_armies_t * src)
       for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
 	  dst->fighters_per_team[i] = src->fighters_per_team[i];
+	  dst->frags[i] = src->frags[i];
 	}
       memcpy (dst->fighters, src->fighters,
 	      src->max_fighters * sizeof (lw6ker_fighter_t));
@@ -110,6 +111,7 @@ _lw6ker_armies_update_checksum (lw6ker_armies_t * armies,
   for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
       lw6sys_checksum_update_int32 (checksum, armies->fighters_per_team[i]);
+      lw6sys_checksum_update_int32 (checksum, armies->frags[i]);
     }
   for (i = 0; i < armies->max_fighters; ++i)
     {
