@@ -135,7 +135,7 @@ _lw6ker_cursor_update_apply_pos (lw6ker_cursor_t * cursor,
   if (map_struct)
     {
       lw6ker_map_struct_find_free_slot_near (map_struct, &(cursor->apply_pos),
-					     cursor->pos);
+					     (cursor->pos));
     }
   else
     {
