@@ -140,6 +140,34 @@ lw6ker_game_state_repr (lw6ker_game_state_t * game_state)
   return ret;
 }
 
+int
+lw6ker_game_state_can_sync (lw6ker_game_state_t * dst,
+			    lw6ker_game_state_t * src)
+{
+  int ret = 0;
+
+  /*
+   * Sanity check, this function is designed to copy game states
+   * which correspond to the same game struct. Any other use is
+   * useless in LW6 context.
+   */
+  if (dst && src && dst->game_struct && src->game_struct)
+    {
+      if (dst == src)
+	{
+	  ret = 1;
+	}
+      else
+	{
+	  ret =
+	    _lw6ker_map_struct_lazy_compare (&(dst->game_struct->map_struct),
+					     &(src->game_struct->map_struct));
+	}
+    }
+
+  return ret;
+}
+
 /*
  * Fundamental function, used to carbon copy a game state to another,
  * this is intensively used to keep too tracks of the game state, one
@@ -158,7 +186,7 @@ lw6ker_game_state_sync (lw6ker_game_state_t * dst, lw6ker_game_state_t * src)
    * which correspond to the same game struct. Any other use is
    * useless in LW6 context.
    */
-  if (dst && src && dst->game_struct && src->game_struct)
+  if (lw6ker_game_state_can_sync (dst, src))
     {
       if (dst == src)
 	{
@@ -175,9 +203,15 @@ lw6ker_game_state_sync (lw6ker_game_state_t * dst, lw6ker_game_state_t * src)
 	  ret = _lw6ker_map_state_sync (&dst->map_state, &src->map_state);
 	  memcpy (&(dst->server_array), &(src->server_array),
 		  sizeof (lw6ker_server_array_t));
+	  memcpy (&(dst->global_history), &(src->global_history),
+		  sizeof (lw6ker_history_t));
+	  memcpy (&(dst->latest_history), &(src->latest_history),
+		  sizeof (lw6ker_history_t));
 	  dst->moves = src->moves;
 	  dst->spreads = src->spreads;
 	  dst->rounds = src->rounds;
+	  dst->max_reached_teams = src->max_reached_teams;
+	  dst->over = src->over;
 	}
     }
   else
@@ -191,16 +225,17 @@ lw6ker_game_state_sync (lw6ker_game_state_t * dst, lw6ker_game_state_t * src)
 }
 
 lw6ker_game_state_t *
-lw6ker_game_state_dup (lw6ker_game_state_t * game_state)
+lw6ker_game_state_dup (lw6ker_game_state_t * game_state,
+		       lw6sys_progress_t * progress)
 {
   lw6ker_game_state_t *ret;
 
-  ret = lw6ker_game_state_new (game_state->game_struct, NULL);
+  ret = lw6ker_game_state_new (game_state->game_struct, progress);
   if (ret)
     {
       if (lw6ker_game_state_sync (ret, game_state))
 	{
-	  //ok
+	  // ok
 	}
       else
 	{
@@ -235,9 +270,13 @@ _lw6ker_game_state_update_checksum (lw6ker_game_state_t *
   _lw6ker_map_state_update_checksum (&(game_state->map_state), checksum);
   _lw6ker_server_array_update_checksum (&(game_state->server_array),
 					checksum);
+  _lw6ker_history_update_checksum (&(game_state->global_history), checksum);
+  _lw6ker_history_update_checksum (&(game_state->latest_history), checksum);
   lw6sys_checksum_update_int32 (checksum, game_state->moves);
   lw6sys_checksum_update_int32 (checksum, game_state->spreads);
   lw6sys_checksum_update_int32 (checksum, game_state->rounds);
+  lw6sys_checksum_update_int32 (checksum, game_state->max_reached_teams);
+  lw6sys_checksum_update_int32 (checksum, game_state->over);
 }
 
 u_int32_t
@@ -551,8 +590,7 @@ lw6ker_game_state_set_cursor (lw6ker_game_state_t * game_state,
 }
 
 int
-lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
-			    u_int64_t server_id, int team_color)
+_lw6ker_game_state_add_team (lw6ker_game_state_t * game_state, int team_color)
 {
   int ret = 0;
   int32_t i;
@@ -576,6 +614,7 @@ lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
 				   &(game_state->map_state.shape), rules);
       desired_center.x = x;
       desired_center.y = y;
+      desired_center.z = 0;
 
       nb_fighters =
 	lw6ker_per100_2 (game_state->map_state.map_struct->room_for_armies,
@@ -608,8 +647,9 @@ lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
 						     (total_fighters_to_remove
 						      *
 						      game_state->
-						      map_state.armies.fighters_per_team
-						      [i]) / total_fighters);
+						      map_state.armies.
+						      fighters_per_team[i]) /
+						     total_fighters);
 	    }
 	  /*
 	   * Note that this value has probably changed since we last
@@ -622,7 +662,9 @@ lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
 	  lw6ker_map_state_remove_fighters (&(game_state->map_state),
 					    total_fighters_to_remove);
 	}
-
+      /*
+       * Do add people.
+       */
       lw6ker_map_state_populate_team (&game_state->map_state, team_color,
 				      nb_fighters, desired_center, rules);
       ret = 1;
@@ -637,8 +679,32 @@ lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
 }
 
 int
-lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
-			       u_int64_t server_id, int team_color)
+lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
+			    u_int64_t server_id, int team_color)
+{
+  int ret = 0;
+
+  if (check_server_id (game_state, server_id))
+    {
+      ret = _lw6ker_game_state_add_team (game_state, team_color);
+      if (ret)
+	{
+	  /*
+	   * Set frags to 0. If we're in a network game and someone
+	   * re-uses a color, we don't want these frags to count.
+	   * Note that the other function _lw6ker_game_state_add_team
+	   * does *not* touch the frag count.
+	   */
+	  game_state->map_state.armies.frags[team_color] = 0;
+	}
+    }
+
+  return ret;
+}
+
+int
+_lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
+				int team_color)
 {
   int ret = 0;
 
@@ -707,13 +773,12 @@ lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
 						      (game_state->map_state),
 						      i, team_color,
 						      (game_state->
-						       map_state.armies.fighters_per_team
-						       [i] *
+						       map_state.armies.
+						       fighters_per_team[i] *
 						       total_fighters_to_distribute)
 						      / new_active_fighters,
-						      &
-						      (game_state->game_struct->
-						       rules));
+						      &(game_state->
+							game_struct->rules));
 		}
 	    }
 	  /*
@@ -731,10 +796,12 @@ lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
 		  if (game_state->map_state.teams[i].active)
 		    {
 		      lw6ker_map_state_redistribute_team (&
-							  (game_state->map_state),
-							  i, team_color, 1,
-							  &
-							  (game_state->game_struct->rules));
+							  (game_state->
+							   map_state), i,
+							  team_color, 1,
+							  &(game_state->
+							    game_struct->
+							    rules));
 		    }
 		}
 	    }
@@ -748,6 +815,20 @@ lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
   return ret;
 }
 
+int
+lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
+			       u_int64_t server_id, int team_color)
+{
+  int ret = 0;
+
+  if (check_server_id (game_state, server_id))
+    {
+      ret = _lw6ker_game_state_remove_team (game_state, team_color);
+    }
+
+  return ret;
+}
+
 int
 lw6ker_game_state_team_exists (lw6ker_game_state_t * game_state,
 			       int team_color)
@@ -827,32 +908,136 @@ void
 lw6ker_game_state_do_spread (lw6ker_game_state_t *
 			     game_state, u_int32_t team_mask)
 {
-  // todo: use team_mask
-  lw6ker_map_state_spread_gradient (&(game_state->map_state),
-				    &(game_state->game_struct->rules),
-				    game_state->game_struct->
-				    rules.spreads_per_round, team_mask);
+  if (!game_state->over)
+    {
+      lw6ker_map_state_spread_gradient (&(game_state->map_state),
+					&(game_state->game_struct->rules),
+					game_state->game_struct->
+					rules.spreads_per_round, team_mask);
+    }
 }
 
 void
 lw6ker_game_state_do_move (lw6ker_game_state_t *
 			   game_state, u_int32_t team_mask)
 {
-  // todo: use team_mask
-  lw6ker_map_state_move_fighters (&(game_state->map_state),
-				  lw6sys_checksum_int32 (game_state->rounds) %
-				  LW6KER_NB_PARITIES,
-				  &(game_state->game_struct->rules),
-				  game_state->game_struct->
-				  rules.moves_per_round, team_mask);
+  if (!game_state->over)
+    {
+      lw6ker_map_state_move_fighters (&(game_state->map_state),
+				      lw6sys_checksum_int32 (game_state->
+							     rounds) %
+				      LW6KER_NB_PARITIES,
+				      &(game_state->game_struct->rules),
+				      game_state->game_struct->rules.
+				      moves_per_round, team_mask);
+    }
 }
 
 void
 lw6ker_game_state_finish_round (lw6ker_game_state_t * game_state)
 {
-  game_state->moves += game_state->game_struct->rules.moves_per_round;
-  game_state->spreads += game_state->game_struct->rules.spreads_per_round;
-  game_state->rounds++;
+  int total_rounds;
+  int nb_teams;
+  int team_color;
+  int32_t nb_cursors = 0;
+  int32_t nb_fighters = 0;
+  int32_t nb_fighters_to_delete = 0;
+  int i;
+
+  total_rounds = lw6ker_game_state_get_total_rounds (game_state);
+  nb_teams = lw6ker_game_state_get_nb_teams (game_state);
+
+  game_state->max_reached_teams =
+    lw6sys_max (game_state->max_reached_teams, nb_teams);
+
+  for (team_color = 0; team_color < LW6MAP_MAX_NB_TEAMS; ++team_color)
+    {
+      lw6ker_game_state_get_team_info (game_state, team_color, &nb_cursors,
+				       &nb_fighters);
+      if (nb_cursors == 0)
+	{
+	  /*
+	   * This should be a rare case, how come there are no cursors for a team?
+	   * Still, with an alliance system, it could theorically happen.
+	   */
+	  lw6sys_log (LW6SYS_LOG_DEBUG,
+		      _("no cursors for team %d, removing it"), team_color);
+	  _lw6ker_game_state_remove_team (game_state, team_color);
+	}
+      else
+	{
+	  if (nb_fighters == 0)
+	    {
+	      _lw6ker_game_state_remove_team (game_state, team_color);
+	      if (game_state->game_struct->rules.respawn_team)
+		{
+		  /*
+		   * We don't delete more than half of the fighters but still,
+		   * we do need to delete some.
+		   */
+		  nb_fighters_to_delete =
+		    lw6sys_min (lw6ker_per100_2
+				(game_state->map_state.map_struct->
+				 room_for_armies,
+				 game_state->game_struct->rules.
+				 single_army_size),
+				lw6ker_game_state_get_nb_active_fighters
+				(game_state) / 2);
+		  lw6ker_map_state_remove_fighters (&(game_state->map_state),
+						    nb_fighters_to_delete);
+		  /*
+		   * Cancelling then adding will have the effect to repopulate the team
+		   */
+		  _lw6ker_game_state_add_team (game_state, team_color);
+		  game_state->map_state.armies.frags[team_color]--;
+		}
+	      else
+		{
+		  /*
+		   * OK this is hell we do it manually but high-level functions
+		   * all require a server-id...
+		   */
+		  for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
+		    {
+		      if (game_state->map_state.cursor_array.cursors[i].
+			  team_color == team_color)
+			{
+			  lw6ker_cursor_disable (&
+						 (game_state->map_state.
+						  cursor_array.cursors[i]));
+			  game_state->map_state.cursor_array.nb_cursors--;
+			}
+		    }
+		}
+	    }
+	}
+    }
+
+  // First good reason to finish : time up
+  if (game_state->rounds >= total_rounds)
+    {
+      game_state->over = 1;
+    }
+
+  // Second good reason to finish : in classical mode, only one left
+  if ((!game_state->game_struct->rules.respawn_team) &&
+      (nb_teams <= 1) && (game_state->max_reached_teams >= 2))
+    {
+      game_state->over = 1;
+    }
+
+  if (!game_state->over)
+    {
+      _lw6ker_history_set (&(game_state->global_history),
+			   &(game_state->map_state.armies),
+			   (game_state->rounds * LW6KER_HISTORY_SIZE) /
+			   total_rounds);
+      _lw6ker_history_add (&(game_state->latest_history),
+			   &(game_state->map_state.armies));
+      game_state->moves += game_state->game_struct->rules.moves_per_round;
+      game_state->spreads += game_state->game_struct->rules.spreads_per_round;
+      game_state->rounds++;
+    }
 }
 
 /*
@@ -865,11 +1050,16 @@ lw6ker_game_state_finish_round (lw6ker_game_state_t * game_state)
 void
 lw6ker_game_state_do_round (lw6ker_game_state_t * game_state)
 {
+  /*
+   * No joke about the implementation, here one really must
+   * call do_spread do_move and finish_round and do nothing
+   * else. This is because code elsewhere (especially in pil)
+   * might assume that those 3 functions are equivalent to
+   * do_round when they fiddle zith threads and team_mask.
+   */
   lw6ker_game_state_do_spread (game_state, LW6KER_TEAM_MASK_ALL);
   lw6ker_game_state_do_move (game_state, LW6KER_TEAM_MASK_ALL);
-  game_state->moves += game_state->game_struct->rules.moves_per_round;
-  game_state->spreads += game_state->game_struct->rules.spreads_per_round;
-  game_state->rounds++;
+  lw6ker_game_state_finish_round (game_state);
 }
 
 u_int32_t
@@ -890,8 +1080,71 @@ lw6ker_game_state_get_rounds (lw6ker_game_state_t * game_state)
   return (game_state->rounds);
 }
 
+u_int32_t
+lw6ker_game_state_get_total_rounds (lw6ker_game_state_t * game_state)
+{
+  return (game_state->game_struct->rules.rounds_per_sec *
+	  game_state->game_struct->rules.total_time);
+}
+
+int
+lw6ker_game_state_is_over (lw6ker_game_state_t * game_state)
+{
+  return game_state->over ? 1 : 0;
+}
+
 int32_t
 lw6ker_game_state_get_nb_active_fighters (lw6ker_game_state_t * game_state)
 {
   return (game_state->map_state.armies.active_fighters);
 }
+
+int32_t
+lw6ker_game_state_get_time_elapsed (lw6ker_game_state_t * game_state)
+{
+  int32_t ret = 0;
+  u_int32_t rounds = 0;
+
+  rounds = lw6ker_game_state_get_rounds (game_state);
+  ret = rounds / (u_int32_t) game_state->game_struct->rules.rounds_per_sec;
+
+  return ret;
+}
+
+int32_t
+lw6ker_game_state_get_time_left (lw6ker_game_state_t * game_state)
+{
+  int32_t ret = 0;
+
+  ret =
+    game_state->game_struct->rules.total_time -
+    lw6ker_game_state_get_time_elapsed (game_state);
+
+  return ret;
+}
+
+int32_t
+lw6ker_game_state_get_global_history (lw6ker_game_state_t * game_state, int i,
+				      int team_id)
+{
+  return _lw6ker_history_get (&(game_state->global_history), i, team_id);
+}
+
+int32_t
+lw6ker_game_state_get_latest_history (lw6ker_game_state_t * game_state, int i,
+				      int team_id)
+{
+  return _lw6ker_history_get (&(game_state->latest_history), i, team_id);
+}
+
+int32_t
+lw6ker_game_state_get_global_history_max (lw6ker_game_state_t * game_state)
+{
+  return _lw6ker_history_get_max (&(game_state->global_history));
+}
+
+int32_t
+lw6ker_game_state_get_latest_history_max (lw6ker_game_state_t * game_state)
+{
+  return _lw6ker_history_get_max (&(game_state->latest_history));
+}
