@@ -116,38 +116,48 @@ lw6ker_game_struct_repr (lw6ker_game_struct_t * game_struct)
 }
 
 lw6ker_game_struct_t *
-lw6ker_game_struct_dup (lw6ker_game_struct_t * game_struct)
+lw6ker_game_struct_dup (lw6ker_game_struct_t * game_struct,
+			lw6sys_progress_t * progress)
 {
   lw6ker_game_struct_t *ret = NULL;
 
+  lw6sys_progress_begin (progress);
+
   ret =
     (lw6ker_game_struct_t *) LW6SYS_CALLOC (sizeof (lw6ker_game_struct_t));
 
   if (ret)
     {
+      memcpy (ret, game_struct, sizeof (lw6ker_game_struct_t));
+      lw6sys_progress_update (progress, 0, 6, 1);
+      /*
+       * Set id after the memcpy, else will be overwritten
+       */
       ret->id = 0;
       while (!ret->id)
 	{
 	  ret->id = ++seq_id;
 	}
-      ret->level = game_struct->level;
-      memcpy (ret, game_struct, sizeof (lw6ker_game_struct_t));
       ret->map_struct.zones =
 	(lw6ker_zone_struct_t *) LW6SYS_MALLOC (sizeof (lw6ker_zone_struct_t)
 						* ret->map_struct.nb_zones);
+      lw6sys_progress_update (progress, 0, 6, 2);
       if (ret->map_struct.zones)
 	{
 	  memcpy (ret->map_struct.zones, game_struct->map_struct.zones,
 		  sizeof (lw6ker_zone_struct_t) * ret->map_struct.nb_zones);
 	}
+      lw6sys_progress_update (progress, 0, 6, 3);
       ret->map_struct.slots =
 	(lw6ker_slot_struct_t *) LW6SYS_MALLOC (sizeof (lw6ker_slot_struct_t)
 						* ret->map_struct.nb_slots);
+      lw6sys_progress_update (progress, 0, 6, 4);
       if (ret->map_struct.slots)
 	{
 	  memcpy (ret->map_struct.slots, game_struct->map_struct.slots,
 		  sizeof (lw6ker_slot_struct_t) * ret->map_struct.nb_slots);
 	}
+      lw6sys_progress_update (progress, 0, 6, 5);
       if ((!ret->map_struct.zones) || (!ret->map_struct.slots))
 	{
 	  if (ret->map_struct.zones)
@@ -178,6 +188,9 @@ lw6ker_game_struct_dup (lw6ker_game_struct_t * game_struct)
 	}
     }
 
+  lw6sys_progress_end (progress);
+
+
   return ret;
 }
 
