@@ -42,6 +42,7 @@ _lw6ker_map_state_init (lw6ker_map_state_t * map_state,
 
   map_state->map_struct = map_struct;
   map_state->shape = map_struct->shape;
+  map_state->shape_surface = map_struct->shape_surface;
 
   ret = 1;
 
@@ -113,6 +114,7 @@ _lw6ker_map_state_sync (lw6ker_map_state_t * dst, lw6ker_map_state_t * src)
       int i;
 
       dst->shape = src->shape;
+      dst->shape_surface = src->shape_surface;
       ret = _lw6ker_armies_sync (&(dst->armies), &(src->armies));
       dst->max_nb_teams = src->max_nb_teams;
       for (i = 0; i < src->max_nb_teams; ++i)
@@ -146,6 +148,7 @@ _lw6ker_map_state_update_checksum (lw6ker_map_state_t * map_state,
    * game_struct_update_checksum.
    */
   lw6sys_checksum_update_whd (checksum, &(map_state->shape));
+  lw6sys_checksum_update_int32 (checksum, map_state->shape_surface);
   _lw6ker_armies_update_checksum (&(map_state->armies), checksum);
   lw6sys_checksum_update_int32 (checksum, map_state->max_nb_teams);
   for (i = 0; i < map_state->max_nb_teams; ++i)
@@ -598,66 +601,14 @@ lw6ker_map_state_spread_gradient (lw6ker_map_state_t * map_state,
 	    {
 	      for (j = 0; j < nb_spreads; ++j)
 		{
-		  lw6ker_team_spread_gradient (&(map_state->teams[i]),
-					       map_state->shape.d == 1);
+		  _lw6ker_spread_update_gradient (&(map_state->teams[i]),
+						  map_state->shape.d == 1);
 		}
 	    }
 	}
     }
 }
 
-int
-_lw6ker_map_state_is_slot_free (lw6ker_map_state_t * map_state,
-				int32_t x, int32_t y, int32_t z)
-{
-  return (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y, z) >= 0
-	  && lw6ker_map_state_get_fighter_id (map_state, x, y, z) < 0);
-}
-
-int
-_lw6ker_map_state_is_enemy_there (lw6ker_map_state_t * map_state,
-				  int32_t team_color,
-				  int32_t x, int32_t y, int32_t z)
-{
-  int ret = 0;
-
-  if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y, z) >= 0)
-    {
-      int32_t enemy_id;
-
-      enemy_id = lw6ker_map_state_get_fighter_id (map_state, x, y, z);
-      if (enemy_id >= 0)
-	{
-	  ret =
-	    (map_state->armies.fighters[enemy_id].team_color != team_color);
-	}
-    }
-
-  return ret;
-}
-
-int
-_lw6ker_map_state_is_ally_there (lw6ker_map_state_t * map_state,
-				 int32_t team_color,
-				 int32_t x, int32_t y, int32_t z)
-{
-  int ret = 0;
-
-  if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y, z) >= 0)
-    {
-      int32_t ally_id;
-
-      ally_id = lw6ker_map_state_get_fighter_id (map_state, x, y, z);
-      if (ally_id >= 0)
-	{
-	  ret =
-	    (map_state->armies.fighters[ally_id].team_color == team_color);
-	}
-    }
-
-  return ret;
-}
-
 int
 _lw6ker_map_state_get_nb_teams (lw6ker_map_state_t * map_state)
 {
@@ -675,325 +626,33 @@ _lw6ker_map_state_get_nb_teams (lw6ker_map_state_t * map_state)
   return ret;
 }
 
-static int32_t
-find_straight_dir (int from_x, int from_y, lw6sys_xyz_t to, int parity)
-{
-  int32_t ret;
-  int32_t straight_dir = 0;
-
-  if (to.y < from_y)
-    {
-      straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_UP;
-    }
-  if (to.x > from_x)
-    {
-      straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_RIGHT;
-    }
-  if (to.y > from_y)
-    {
-      straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_DOWN;
-    }
-  if (to.x < from_x)
-    {
-      straight_dir = straight_dir | _LW6KER_STRAIGHT_DIR_LEFT;
-    }
-
-  ret = _LW6KER_TABLES_STRAIGHT_DIRS[parity][straight_dir];
-
-  return ret;
-}
-
-/*
- * Higher potential = closer to the cursor
- */
-static int32_t
-find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
-	       int parity)
-{
-  int32_t ret = fighter->last_direction;
-  int32_t zone_id =
-    lw6ker_map_struct_get_zone_id (map_state->map_struct, fighter->pos.x,
-				   fighter->pos.y, fighter->pos.z);
-  lw6ker_zone_state_t *zone_states =
-    map_state->teams[fighter->team_color].gradient;
-
-  if (zone_id >= 0)
-    {
-      if (zone_states[zone_id].direction_to_cursor >= 0)
-	{
-	  /*
-	   * OK, it was cached...
-	   */
-	  ret = zone_states[zone_id].direction_to_cursor;
-	}
-      else
-	{
-	  /*
-	   * Nothing in cache, we calculate it
-	   */
-	  int32_t i;
-	  lw6ker_zone_struct_t *zone_structs = map_state->map_struct->zones;
-	  int32_t neighbour_zone_id;
-	  lw6ker_zone_struct_t *fighter_zone_struct;
-	  fighter_zone_struct = &(zone_structs[zone_id]);
-	  int32_t best_potential = zone_states[zone_id].potential;
-
-	  ret = -1;
-
-	  if (parity)
-	    {
-	      for (i = 0; i < LW6KER_NB_DIRS; ++i)
-		{
-		  neighbour_zone_id = fighter_zone_struct->link[i];
-		  if (neighbour_zone_id >= 0)
-		    {
-		      if (zone_states[neighbour_zone_id].potential >
-			  best_potential)
-			{
-			  best_potential =
-			    zone_states[neighbour_zone_id].potential;
-			  ret = i;
-			}
-		    }
-		}
-	    }
-	  else
-	    {
-	      for (i = LW6KER_NB_DIRS - 1; i >= 0; --i)
-		{
-		  neighbour_zone_id = fighter_zone_struct->link[i];
-		  if (neighbour_zone_id >= 0)
-		    {
-		      if (zone_states[neighbour_zone_id].potential >
-			  best_potential)
-			{
-			  best_potential =
-			    zone_states[neighbour_zone_id].potential;
-			  ret = i;
-			}
-		    }
-		}
-	    }
-
-	  if (ret < 0)
-	    {
-	      /*
-	       * Now, in most cases, if we can't find an adjacent square
-	       * which is closer, it just means we are in the square
-	       * where the cursor is. So we go straight to it.
-	       * Fortunately this information is cached in
-	       * closest_cursor_pos.
-	       */
-	      ret =
-		find_straight_dir (fighter->pos.x, fighter->pos.y,
-				   zone_states[zone_id].closest_cursor_pos,
-				   parity);
-	    }
-
-	  if (ret < 0)
-	    {
-	      /*
-	       * this can happen, for find_straight_dir is very likely
-	       * to return -1
-	       */
-	      ret = fighter->last_direction;
-	    }
-	}
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("fighter with incorrect zone_id=%d (pos=%d,%d,%d)"),
-		  zone_id, (int) fighter->pos.x, (int) fighter->pos.y,
-		  (int) fighter->pos.z);
-    }
-
-  return ret;
-}
-
-static void
-polarity_func (lw6map_rules_t * rules, lw6sys_whd_t * shape, int32_t * x,
-	       int32_t * y, int32_t * z, int32_t move_dir)
-{
-  (*x) = (*x) + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  (*y) = (*y) + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-  (*z) = (*z) + _LW6KER_TABLES_MOVE_Z_OFFSET[move_dir];
-  /*
-   * next line is need to stay within map boundaries,
-   * it will also handle polarity information
-   */
-  lw6map_coords_fix_xy (rules, shape, x, y);
-  lw6map_coords_fix_z (rules, shape, z);
-}
-
-/*
- * Probably the most time greedy function of the algorithm, and
- * one of the hardest one to optimize. It simply moves all the
- * fighters on the battlefield, once the gradient has been calculated.
- *
- * It's the direct equivalent of move_fighters in src/fighter.c
- * in Liquid War 5.
- */
 void
 lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
 				int parity, lw6map_rules_t * rules,
 				int32_t nb_moves, u_int32_t team_mask)
 {
-  int i, j, k;
-  lw6ker_armies_t *armies = &(map_state->armies);
-  int32_t active_fighters = armies->active_fighters;
-  lw6ker_fighter_t *fighter = NULL;
-  int32_t x, y, z;
-  int32_t best_dir, test_dir;
-  int32_t fighter_team_color, fighter_x, fighter_y, fighter_z;
-  int32_t loop_init, loop_step;
-  int done_with_fighter;
-  int32_t fighter_attack;
-  int32_t fighter_defense;
-  int32_t fighter_new_health;
-  int32_t fighter_regenerate;
-  int32_t side_attack_factor;
-  int32_t side_defense_factor;
-  int32_t nb_move_tries;
-  int32_t nb_attack_tries;
-  int32_t nb_defense_tries;
-  int32_t vertical_move;
-  int32_t fighter_side_attack;
-  int32_t fighter_side_defense;
-  lw6sys_whd_t shape;
-  int d;
+  _lw6ker_move_context_t context;
+  int move_i = 0;
 
-  fighter_attack = rules->fighter_attack;
-  fighter_defense = rules->fighter_defense;
-  fighter_new_health = rules->fighter_new_health;
-  fighter_regenerate = rules->fighter_regenerate;
-  side_attack_factor = rules->side_attack_factor;
-  side_defense_factor = rules->side_defense_factor;
-  nb_move_tries = rules->nb_move_tries;
-  nb_attack_tries = rules->nb_attack_tries;
-  nb_defense_tries = rules->nb_defense_tries;
-  vertical_move = rules->vertical_move;
-  fighter_side_attack = lw6ker_percent (fighter_attack, side_attack_factor);
-  fighter_side_defense =
-    lw6sys_max (fighter_regenerate,
-		lw6ker_percent (fighter_defense, side_defense_factor));
-  shape = map_state->shape;
-  d = shape.d;
+  memset (&context, 0, sizeof (_lw6ker_move_context_t));
 
-  for (k = 0; k < nb_moves; ++k)
+  context.parity = parity;
+  context.team_mask = team_mask;
+  context.map_state = map_state;
+  context.rules = *rules;
+  context.armies = &(map_state->armies);
+  context.active_fighters = context.armies->active_fighters;
+  context.fighter_side_attack =
+    lw6ker_percent (rules->fighter_attack, rules->side_attack_factor);
+  context.fighter_side_defense =
+    lw6sys_max (rules->fighter_regenerate,
+		lw6ker_percent (rules->fighter_defense,
+				rules->side_defense_factor));
+  context.shape = map_state->shape;
+
+  for (move_i = 0; move_i < nb_moves; ++move_i)
     {
-      loop_init = parity ? active_fighters - 1 : 0;
-      loop_step = parity ? -1 : 1;
-      for (i = loop_init; i >= 0 && i < active_fighters; i += loop_step)
-	{
-	  done_with_fighter = 0;
-	  fighter = &(map_state->armies.fighters[i]);
-	  fighter_team_color = fighter->team_color;
-	  if (lw6ker_team_mask_is_concerned (fighter_team_color, team_mask))
-	    {
-	      fighter_x = fighter->pos.x;
-	      fighter_y = fighter->pos.y;
-	      fighter_z = fighter->pos.z;
-
-	      best_dir = find_best_dir (map_state, fighter, parity);
-	      // we assume best_dir is equal to something valid now
-
-	      for (j = 0; j < nb_move_tries; ++j)
-		{
-		  test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
-		  x = fighter_x;
-		  y = fighter_y;
-		  z = fighter_z;
-		  polarity_func (rules, &shape, &x, &y, &z, test_dir);
-		  if (_lw6ker_map_state_is_slot_free (map_state, x, y, z))
-		    {
-		      done_with_fighter = 1;
-		      _lw6ker_fighter_move (fighter, i, x, y, z, map_state);
-		      _lw6ker_fighter_regenerate (fighter,
-						  fighter_regenerate);
-		      break;
-		    }
-		  if (d > 1)
-		    {
-		      if (j + 1 == vertical_move)
-			{
-			  z = fighter_z - 1;
-			  lw6map_coords_fix_z (rules, &shape, &z);
-			  if (_lw6ker_map_state_is_slot_free
-			      (map_state, fighter_x, fighter_y, z))
-			    {
-			      _lw6ker_fighter_move (fighter, i, fighter_x,
-						    fighter_y, z, map_state);
-			      _lw6ker_fighter_regenerate (fighter,
-							  fighter_regenerate);
-			      break;
-			    }
-			  z = fighter_z + 1;
-			  lw6map_coords_fix_z (rules, &shape, &z);
-			  if (_lw6ker_map_state_is_slot_free
-			      (map_state, fighter_x, fighter_y, z))
-			    {
-			      _lw6ker_fighter_move (fighter, i, fighter_x,
-						    fighter_y, z, map_state);
-			      _lw6ker_fighter_regenerate (fighter,
-							  fighter_regenerate);
-			      break;
-			    }
-			}
-		    }
-		}
-
-	      if (!done_with_fighter)
-		{
-		  for (j = 0; j < nb_attack_tries; ++j)
-		    {
-		      test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
-		      x = fighter_x;
-		      y = fighter_y;
-		      polarity_func (rules, &shape, &x, &y, &z, test_dir);
-		      if (_lw6ker_map_state_is_enemy_there
-			  (map_state, fighter_team_color, x, y, z))
-			{
-			  done_with_fighter = 1;
-			  _lw6ker_fighter_attack (fighter,
-						  x, y, z, map_state,
-						  j ==
-						  0 ? fighter_attack :
-						  fighter_side_attack,
-						  fighter_new_health);
-			  break;
-			}
-		    }
-		}
-
-	      if (!done_with_fighter)
-		{
-		  for (j = 0; j < nb_defense_tries; ++j)
-		    {
-		      test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
-		      x = fighter_x;
-		      y = fighter_y;
-		      z = fighter_z;
-		      polarity_func (rules, &shape, &x, &y, &z, test_dir);
-		      if (_lw6ker_map_state_is_ally_there
-			  (map_state, fighter_team_color, x, y, z))
-			{
-			  done_with_fighter = 1;
-			  _lw6ker_fighter_defend (fighter,
-						  x, y, z, map_state,
-						  j ==
-						  0 ? fighter_defense :
-						  fighter_side_defense);
-			  break;
-			}
-		    }
-		}
-	      if (!done_with_fighter)
-		{
-		  _lw6ker_fighter_regenerate (fighter, fighter_regenerate);
-		}
-	    }
-	}
+      _lw6ker_move_update_fighters_universal (&context);
     }
 }
 
