@@ -67,6 +67,7 @@ _lw6ker_map_struct_update_checksum (lw6ker_map_struct_t *
   int i;
 
   lw6sys_checksum_update_whd (checksum, &(map_struct->shape));
+  lw6sys_checksum_update_int32 (checksum, map_struct->shape_surface);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_zones);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_slots);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_usable_slots);
@@ -100,6 +101,7 @@ _lw6ker_map_struct_lazy_compare (lw6ker_map_struct_t *
 	  ret = (map_struct_a->shape.w == map_struct_b->shape.w) &&
 	    (map_struct_a->shape.h == map_struct_b->shape.h) &&
 	    (map_struct_a->shape.d == map_struct_b->shape.d) &&
+	    (map_struct_a->shape_surface == map_struct_b->shape_surface) &&
 	    (map_struct_a->nb_zones == map_struct_b->nb_zones) &&
 	    (map_struct_a->nb_slots == map_struct_b->nb_slots) &&
 	    (map_struct_a->nb_usable_slots == map_struct_b->nb_usable_slots)
@@ -575,7 +577,8 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
 	}
     }
 
-  map_struct->shape = draft_zones->shape;;
+  map_struct->shape = draft_zones->shape;
+  map_struct->shape_surface = w * h;
   map_struct->nb_slots = w * h * d;
   map_struct->nb_zones = nb_zones;
   map_struct->max_zone_size = draft_zones->max_zone_size;
@@ -711,12 +714,12 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
 float
 _lw6ker_map_struct_get_compression (lw6ker_map_struct_t * map_struct)
 {
-  float ret;
+  float ret = 0.0f;
 
-  ret =
-    ((float) map_struct->nb_zones) /
-    ((float)
-     (map_struct->shape.w * map_struct->shape.h * map_struct->shape.d));
+  if (map_struct->nb_slots > 0)
+    {
+      ret = ((float) map_struct->nb_zones) / ((float) (map_struct->nb_slots));
+    }
 
   return ret;
 }
@@ -821,44 +824,48 @@ lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t * map_struct,
 {
   int found = 0;
 
-  there->x = there->y = 0;
+  there->x = there->y = there->z = 0;
 
-  if (lw6ker_map_struct_get_zone_id (map_struct, here.x, here.y, here.z) >= 0)
+  if (lw6sys_shape_check_pos (&(map_struct->shape), &here))
     {
-      *there = here;
-      found = 1;
-    }
-  else
-    {
-      int32_t angle, radius;
-      int32_t max_radius, max_angle;
-      int32_t x, y, z;
-
-      max_radius = map_struct->shape.w + map_struct->shape.h;	// +, not *
-      for (radius = 0; radius < max_radius && !found; ++radius)
+      if (lw6ker_map_struct_get_zone_id (map_struct, here.x, here.y, here.z)
+	  >= 0)
 	{
-	  max_angle = radius * M_PI * 2;
-	  for (angle = 0; angle < max_angle && !found; ++angle)
+	  *there = here;
+	  found = 1;
+	}
+      else
+	{
+	  int32_t angle, radius;
+	  int32_t max_radius, max_angle;
+	  lw6sys_xyz_t test;
+
+	  max_radius = map_struct->shape.w + map_struct->shape.h;	// +, not *
+	  for (radius = 0; radius < max_radius && !found; ++radius)
 	    {
-	      x =
-		here.x +
-		(lw6ker_cos ((angle * LW6KER_TRIGO_2PI) / max_angle) *
-		 radius) / LW6KER_TRIGO_RADIUS;
-	      y =
-		here.y -
-		(lw6ker_sin ((angle * LW6KER_TRIGO_2PI) / max_angle) *
-		 radius) / LW6KER_TRIGO_RADIUS;
-	      if (x >= 0 && x < map_struct->shape.w && y >= 0
-		  && y < map_struct->shape.h)
+	      max_angle = radius * M_PI * 2;
+	      for (angle = 0; angle < max_angle && !found; ++angle)
 		{
-		  for (z = 0; z < map_struct->shape.d; ++z)
+		  test.x =
+		    here.x +
+		    (lw6ker_cos ((angle * LW6KER_TRIGO_2PI) / max_angle) *
+		     radius) / LW6KER_TRIGO_RADIUS;
+		  test.y =
+		    here.y -
+		    (lw6ker_sin ((angle * LW6KER_TRIGO_2PI) / max_angle) *
+		     radius) / LW6KER_TRIGO_RADIUS;
+		  test.z = 0;
+		  if (lw6sys_shape_check_pos (&map_struct->shape, &test))
 		    {
-		      if (lw6ker_map_struct_get_zone_id (map_struct, x, y, z)
-			  >= 0)
+		      for (test.z = 0; test.z < map_struct->shape.d; ++test.z)
 			{
-			  found = 1;
-			  there->x = x;
-			  there->y = y;
+			  if (lw6ker_map_struct_get_zone_id
+			      (map_struct, test.x, test.y, test.z) >= 0)
+			    {
+			      found = 1;
+			      there->x = test.x;
+			      there->y = test.y;
+			    }
 			}
 		    }
 		}
@@ -878,7 +885,7 @@ lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct)
 {
   int ret = 1;
   int x, y, z, w, h, d;
-  int nb_zones, nb_slots;
+  int shape_surface, nb_zones, nb_slots;
   int zone_id;
   int i, j;
   int z1, z2;
@@ -886,9 +893,18 @@ lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct)
   w = map_struct->shape.w;
   h = map_struct->shape.h;
   d = map_struct->shape.d;
+  shape_surface = map_struct->shape_surface;
   nb_zones = map_struct->nb_zones;
   nb_slots = map_struct->nb_slots;
 
+  if (shape_surface != w * h)
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("inconsistent shape_surface=%d shape=%dx%d"),
+		  shape_surface, w, h);
+      ret = 0;
+    }
+
   if (nb_slots != w * h * d)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
