@@ -30,10 +30,10 @@
 #define TEST_MAP_HEIGHT 24
 #define TEST_MAP_NB_LAYERS 5
 #define TEST_NB_ROUNDS 100
-#define TEST_GAME_STRUCT_CHECKSUM 0x44df6790
-#define TEST_GAME_STATE_CHECKSUM 0x64970de0
-#define TEST_GAME_STATE_POPULATE_CHECKSUM 0x75400075
-#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0x2c1bf492
+#define TEST_GAME_STRUCT_CHECKSUM 0xf65ea4db
+#define TEST_GAME_STATE_CHECKSUM 0xe077bc23
+#define TEST_GAME_STATE_POPULATE_CHECKSUM 0x98aca3a9
+#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0xab604ac9
 #define TEST_SERVER_ID 0x1234123412341234LL
 #define TEST_CURSOR1_ID 0x1234
 #define TEST_CURSOR2_ID 0x2345
@@ -42,6 +42,7 @@
 #define TEST_COLOR2 LW6MAP_TEAM_COLOR_GREEN
 #define TEST_COLOR3 LW6MAP_TEAM_COLOR_BLUE
 #define TEST_TEAM_MASK_SEED 123
+#define TEST_HISTORY_TEAM 0
 
 static void
 print_game_struct_repr (lw6ker_game_struct_t * game_struct)
@@ -76,6 +77,9 @@ print_game_state_repr (lw6ker_game_state_t * game_state)
       fflush (stdout);
       LW6SYS_FREE (capture);
     }
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("time_elapsed=%d time_left=%d"),
+	      lw6ker_game_state_get_time_elapsed (game_state),
+	      lw6ker_game_state_get_time_left (game_state));
 }
 
 static int
@@ -91,7 +95,8 @@ test_struct ()
 
     ret = 0;
     level =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -128,7 +133,8 @@ test_state ()
 
     ret = 0;
     level =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -138,6 +144,8 @@ test_state ()
 	    game_state = lw6ker_game_state_new (game_struct, NULL);
 	    if (game_state)
 	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("is_over returns %d"),
+			    lw6ker_game_state_is_over (game_state));
 		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
@@ -173,7 +181,8 @@ test_population ()
     ret = 0;
 
     level =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -227,13 +236,18 @@ test_algorithm ()
     lw6map_level_t *level;
     lw6ker_game_struct_t *game_struct;
     lw6ker_game_state_t *game_state;
+    lw6ker_score_array_t score_array;
     int checksum;
     int i;
     int cursor_x, cursor_y;
+    u_int64_t server_id = 0;
+    char letter = ' ';
+    int team_color = -1;
 
     ret = 0;
     level =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -264,6 +278,15 @@ test_algorithm ()
 		lw6ker_game_state_set_cursor (game_state, TEST_SERVER_ID,
 					      TEST_CURSOR3_ID, cursor_x,
 					      cursor_y);
+		lw6ker_game_state_get_cursor_info (game_state,
+						   TEST_CURSOR1_ID,
+						   &server_id, &letter,
+						   &team_color, &cursor_x,
+						   &cursor_y);
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("cursor %x letter='%c' color=%d x=%d y=%d"),
+			    TEST_CURSOR1_ID, letter, team_color, cursor_x,
+			    cursor_y);
 		for (i = 0; i < TEST_NB_ROUNDS; ++i)
 		  {
 		    lw6ker_game_state_do_round (game_state);
@@ -272,6 +295,38 @@ test_algorithm ()
 				game_state->rounds,
 				lw6ker_game_state_checksum (game_state));
 		  }
+		lw6ker_score_array_update (&score_array, game_state);
+		for (i = 0; i < score_array.nb_scores; ++i)
+		  {
+		    if (score_array.scores[i].fighters_absolute > 0)
+		      {
+			lw6sys_log (LW6SYS_LOG_NOTICE,
+				    _
+				    ("order=%d team_color=%d score=%d%%"),
+				    i, score_array.scores[i].team_color,
+				    score_array.scores[i].fighters_percent);
+		      }
+		  }
+		for (i = 0;
+		     i < lw6sys_min (LW6KER_HISTORY_SIZE,
+				     lw6ker_game_state_get_rounds
+				     (game_state)); ++i)
+		  {
+		    lw6sys_log (LW6SYS_LOG_NOTICE,
+				_
+				("history entry %d for team %d is global=%d latest=%d"),
+				i, TEST_HISTORY_TEAM,
+				lw6ker_game_state_get_global_history
+				(game_state, i, TEST_HISTORY_TEAM),
+				lw6ker_game_state_get_latest_history
+				(game_state, i, TEST_HISTORY_TEAM));
+		  }
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("max history entry global=%d latest=%d"),
+			    lw6ker_game_state_get_global_history_max
+			    (game_state),
+			    lw6ker_game_state_get_latest_history_max
+			    (game_state));
 		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
@@ -292,6 +347,57 @@ test_algorithm ()
   return ret;
 }
 
+static int
+test_dup ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6map_level_t *level;
+    lw6ker_game_struct_t *game_struct;
+    lw6ker_game_state_t *game_state;
+    lw6ker_game_struct_t *game_struct2;
+    lw6ker_game_state_t *game_state2;
+
+    ret = 0;
+    level =
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
+    if (level)
+      {
+	game_struct = lw6ker_game_struct_new (level, NULL);
+	if (game_struct)
+	  {
+	    print_game_struct_repr (game_struct);
+	    game_struct2 = lw6ker_game_struct_dup (game_struct, NULL);
+	    lw6ker_game_struct_free (game_struct);
+	    game_struct = NULL;
+	    print_game_struct_repr (game_struct2);
+	    game_state = lw6ker_game_state_new (game_struct2, NULL);
+	    if (game_state)
+	      {
+		print_game_state_repr (game_state);
+		game_state2 = lw6ker_game_state_dup (game_state, NULL);
+		lw6ker_game_state_free (game_state);
+		game_state = NULL;
+		print_game_state_repr (game_state2);
+		lw6ker_game_state_free (game_state2);
+		game_state2 = NULL;
+		ret = 1;
+	      }
+	    lw6ker_game_struct_free (game_struct2);
+	    game_struct2 = NULL;
+	  }
+	lw6map_free (level);
+	level = NULL;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static int
 test_team_mask ()
 {
@@ -344,7 +450,7 @@ lw6ker_test ()
     }
 
   ret = test_team_mask () && test_struct () && test_state ()
-    && test_population () && test_algorithm ();
+    && test_population () && test_algorithm () && test_dup ();
 
   return ret;
 }
