@@ -60,6 +60,8 @@
 #define LW6KER_TEAM_MASK_PINK 0x200
 #define LW6KER_TEAM_MASK_ALL 0x3ff
 
+#define LW6KER_HISTORY_SIZE 512
+
 #include "ker-trigo.h"
 
 typedef struct lw6ker_zone_struct_s
@@ -94,6 +96,7 @@ lw6ker_slot_struct_t;
 typedef struct lw6ker_map_struct_s
 {
   lw6sys_whd_t shape;
+  int32_t shape_surface;
   int32_t nb_zones;
   int32_t nb_slots;
   int32_t nb_usable_slots;
@@ -164,6 +167,30 @@ typedef struct lw6ker_cursor_array_s
 }
 lw6ker_cursor_array_t;
 
+typedef struct lw6ker_score_s
+{
+  int team_color;
+  int fighters_percent;
+  int fighters_absolute;
+  float fighters_ratio;		// one of the rare float in lw6ker, only for eye candy 
+  int frags;
+}
+lw6ker_score_t;
+
+typedef struct lw6ker_score_array_s
+{
+  int active_fighters;
+  int nb_scores;
+  lw6ker_score_t scores[LW6MAP_NB_TEAM_COLORS];
+}
+lw6ker_score_array_t;
+
+typedef struct lw6ker_history_s
+{
+  int nb_entries;
+  int nb_fighters[LW6KER_HISTORY_SIZE][LW6MAP_MAX_NB_TEAMS];
+} lw6ker_history_t;
+
 typedef struct lw6ker_server_s
 {
   u_int64_t server_id;
@@ -213,6 +240,7 @@ typedef struct lw6ker_armies_s
    * game refreh, to display the information on the screen.
    */
   int32_t fighters_per_team[LW6MAP_MAX_NB_TEAMS];
+  int32_t frags[LW6MAP_MAX_NB_TEAMS];
   /*
    * The actual data, a pointer to all the fighters in the map.
    * It's more convenient to access them this way, instead of
@@ -230,6 +258,7 @@ typedef struct lw6ker_map_state_s
 {
   lw6ker_map_struct_t *map_struct;
   lw6sys_whd_t shape;		// redundant but convenient
+  int32_t shape_surface;
   lw6ker_armies_t armies;
   int32_t max_nb_teams;
   lw6ker_team_t teams[LW6MAP_MAX_NB_TEAMS];
@@ -251,9 +280,13 @@ typedef struct lw6ker_game_state_s
   lw6ker_game_struct_t *game_struct;
   lw6ker_map_state_t map_state;
   lw6ker_server_array_t server_array;
+  lw6ker_history_t global_history;
+  lw6ker_history_t latest_history;
   u_int32_t moves;
   u_int32_t spreads;
   u_int32_t rounds;
+  int max_reached_teams;
+  int over;
 }
 lw6ker_game_state_t;
 
@@ -322,10 +355,14 @@ extern void lw6ker_game_state_point_to (lw6ker_game_state_t * game_state,
 extern int lw6ker_game_state_memory_footprint (lw6ker_game_state_t *
 					       game_state);
 extern char *lw6ker_game_state_repr (lw6ker_game_state_t * game_state);
+extern int lw6ker_game_state_can_sync (lw6ker_game_state_t * dst,
+				       lw6ker_game_state_t * src);
 extern int lw6ker_game_state_sync (lw6ker_game_state_t * dst,
 				   lw6ker_game_state_t * src);
 extern lw6ker_game_state_t *lw6ker_game_state_dup (lw6ker_game_state_t *
-						   game_state);
+						   game_state,
+						   lw6sys_progress_t *
+						   progress);
 extern u_int32_t lw6ker_game_state_checksum (lw6ker_game_state_t *
 					     game_state);
 extern int lw6ker_game_state_register_server (lw6ker_game_state_t *
@@ -380,8 +417,25 @@ extern u_int32_t lw6ker_game_state_get_spreads (lw6ker_game_state_t *
 						game_state);
 extern u_int32_t lw6ker_game_state_get_rounds (lw6ker_game_state_t *
 					       game_state);
+extern u_int32_t lw6ker_game_state_get_total_rounds (lw6ker_game_state_t *
+						     game_state);
+extern int lw6ker_game_state_is_over (lw6ker_game_state_t * game_state);
 extern int32_t lw6ker_game_state_get_nb_active_fighters (lw6ker_game_state_t *
 							 game_state);
+extern int32_t lw6ker_game_state_get_time_elapsed (lw6ker_game_state_t *
+						   game_state);
+extern int32_t lw6ker_game_state_get_time_left (lw6ker_game_state_t *
+						game_state);
+extern int32_t lw6ker_game_state_get_global_history (lw6ker_game_state_t *
+						     game_state, int i,
+						     int team_id);
+extern int32_t lw6ker_game_state_get_latest_history (lw6ker_game_state_t *
+						     game_state, int i,
+						     int team_id);
+extern int32_t lw6ker_game_state_get_global_history_max (lw6ker_game_state_t *
+							 game_state);
+extern int32_t lw6ker_game_state_get_latest_history_max (lw6ker_game_state_t *
+							 game_state);
 
 /*
  * In gamestruct.c
@@ -396,10 +450,13 @@ extern int lw6ker_game_struct_memory_footprint (lw6ker_game_struct_t *
 						game_struct);
 extern char *lw6ker_game_struct_repr (lw6ker_game_struct_t * game_struct);
 extern lw6ker_game_struct_t *lw6ker_game_struct_dup (lw6ker_game_struct_t *
-						     game_struct);
+						     game_struct,
+						     lw6sys_progress_t *
+						     progress);
 extern u_int32_t lw6ker_game_struct_checksum (lw6ker_game_struct_t *
 					      game_struct);
 
+
 /*
  * in mapstate.c
  */
@@ -407,8 +464,7 @@ static inline int
 lw6ker_map_state_slot_index (lw6ker_map_state_t * map_state, int32_t x,
 			     int32_t y, int32_t z)
 {
-  return (map_state->shape.w * map_state->shape.h * z +
-	  map_state->shape.w * y + x);
+  return (map_state->shape_surface * z + map_state->shape.w * y + x);
 }
 
 extern int lw6ker_map_state_get_free_team_color (lw6ker_map_state_t *
@@ -438,17 +494,16 @@ lw6ker_map_state_set_fighter_id (lw6ker_map_state_t * map_state,
 				 int32_t x,
 				 int32_t y, int32_t z, int32_t fighter_id)
 {
-  map_state->
-    slots[lw6ker_map_state_slot_index (map_state, x, y, z)].fighter_id =
-    fighter_id;
+  map_state->slots[lw6ker_map_state_slot_index (map_state, x, y, z)].
+    fighter_id = fighter_id;
 };
 
 static inline int32_t
 lw6ker_map_state_get_fighter_id (lw6ker_map_state_t * map_state,
 				 int32_t x, int32_t y, int32_t z)
 {
-  return (map_state->
-	  slots[lw6ker_map_state_slot_index (map_state, x, y, z)].fighter_id);
+  return (map_state->slots[lw6ker_map_state_slot_index (map_state, x, y, z)].
+	  fighter_id);
 };
 
 extern lw6ker_fighter_t *lw6ker_map_state_get_fighter_safe (lw6ker_map_state_t
@@ -492,8 +547,7 @@ static inline int
 lw6ker_map_struct_slot_index (lw6ker_map_struct_t * map_struct, int32_t x,
 			      int32_t y, int32_t z)
 {
-  return (map_struct->shape.w * map_struct->shape.h * z +
-	  map_struct->shape.w * y + x);
+  return (map_struct->shape_surface * z + map_struct->shape.w * y + x);
 }
 
 static inline void
@@ -501,9 +555,8 @@ lw6ker_map_struct_set_zone_id (lw6ker_map_struct_t * map_struct,
 			       int32_t x, int32_t y, int32_t z,
 			       int32_t zone_id)
 {
-  map_struct->
-    slots[lw6ker_map_struct_slot_index (map_struct, x, y, z)].zone_id =
-    zone_id;
+  map_struct->slots[lw6ker_map_struct_slot_index (map_struct, x, y, z)].
+    zone_id = zone_id;
 };
 
 static inline int32_t
@@ -520,6 +573,12 @@ extern void lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t *
 						   lw6sys_xyz_t here);
 extern int lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct);
 
+/*
+ * in scorearrqy.c
+ */
+extern int lw6ker_score_array_update (lw6ker_score_array_t * score_array,
+				      lw6ker_game_state_t * game_state);
+
 /*
  * in server.c
  */
@@ -548,8 +607,6 @@ extern int lw6ker_server_array_sanity_check (lw6ker_server_array_t *
  */
 extern void lw6ker_team_activate (lw6ker_team_t * team, lw6sys_xyz_t pos);
 extern void lw6ker_team_unactivate (lw6ker_team_t * team);
-extern void lw6ker_team_spread_gradient (lw6ker_team_t * team,
-					 int skip_vertical);
 extern void lw6ker_team_normalize_pot (lw6ker_team_t * team,
 				       lw6map_rules_t * rules);
 
