@@ -104,11 +104,16 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
       if (use.use_texture)
 	{
 	  lw6ldr_auto_colors (&level->param.style, &hints);
-	  ok = ok
-	    && lw6ldr_texture_read (&level->texture, dirname,
-				    &(level->param), &hints, use.use_texture,
-				    display_w, display_h, &ratio,
-				    &texture_exists, &progress_texture);
+	  /*
+	   * Note that this will return 0 only on errors, if there's just
+	   * no texture (texture.jpg) file then it will return true but
+	   * texture_exists will contain 0.
+	   */
+	  ok = ok && lw6ldr_texture_read (&level->texture, dirname,
+					  &(level->param), &hints,
+					  use.use_texture, display_w,
+					  display_h, &ratio, &texture_exists,
+					  &progress_texture);
 	}
       ok = ok
 	&& lw6ldr_body_read (&level->body, dirname, &(level->param), &hints,
@@ -129,6 +134,7 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
 	    }
 	}
       lw6ldr_auto_colors (&level->param.style, &hints);
+      level->texture.has_alpha = lw6map_texture_has_alpha (&(level->texture));
     }
 
   if (!ok)
