@@ -144,7 +144,7 @@ rules_update_callback (void *func_data, void *data)
 
   if (lw6sys_assoc_has_key (update_data->values, key))
     {
-      about = lw6hlp_about (&type, key);
+      about = lw6hlp_about (&type, NULL, NULL, NULL, key);
       value = lw6sys_assoc_get (update_data->values, key);
       element = lw6cfg_xml_element (type);
       read_callback (update_data->rules, element, key, value);
