@@ -115,7 +115,7 @@ lw6ldr_style_set (lw6map_style_t * style, char *key, char *value)
   char *element = NULL;
   lw6hlp_type_t type = LW6HLP_TYPE_VOID;
 
-  about = lw6hlp_about (&type, key);
+  about = lw6hlp_about (&type, NULL, NULL, NULL, key);
   element = lw6cfg_xml_element (type);
   if (about && element)
     {
