@@ -78,7 +78,7 @@ check_map_with_absolute_path (char *absolute_path)
 		{
 		  if (strcmp (hexa_level1, hexa_level2) == 0)
 		    {
-		      level3 = lw6map_dup (level2);
+		      level3 = lw6map_dup (level2, NULL);
 		      if (level3)
 			{
 			  repr = lw6map_repr (level3);
