@@ -300,5 +300,14 @@ lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
       *ratio = 1.0f;
     }
 
+  if ((*texture_exists) == 0)
+    {
+      /*
+       * If there's no texture, we just return 1 (ok) for now, the code will
+       * apply a texture later, with lw6map_texture_from_body for instance.
+       */
+      ret = 1;
+    }
+
   return ret;
 }
