@@ -33,9 +33,9 @@
 #define LW6LDR_HINTS_DEFAULT_MAX_MAP_WIDTH 1600
 #define LW6LDR_HINTS_DEFAULT_MIN_MAP_HEIGHT 30
 #define LW6LDR_HINTS_DEFAULT_MAX_MAP_HEIGHT 1200
-#define LW6LDR_HINTS_DEFAULT_MIN_MAP_SURFACE 4800	// 80x60
-#define LW6LDR_HINTS_DEFAULT_MAX_MAP_SURFACE 480000	// 800x600
-#define LW6LDR_HINTS_DEFAULT_FIGHTER_SCALE 4.0f
+#define LW6LDR_HINTS_DEFAULT_MIN_MAP_SURFACE 4800
+#define LW6LDR_HINTS_DEFAULT_MAX_MAP_SURFACE 480000
+#define LW6LDR_HINTS_DEFAULT_FIGHTER_SCALE 4.0
 #define LW6LDR_HINTS_DEFAULT_GUESS_COLORS 1
 #define LW6LDR_HINTS_DEFAULT_BACKGROUND_COLOR_AUTO 1
 #define LW6LDR_HINTS_DEFAULT_HUD_COLOR_AUTO 1
