@@ -27,7 +27,7 @@
  * This is the main Liquid War 6 header file.
  */
 
-#define LW6_VERSION "0.0.6beta"
+#define LW6_VERSION "0.0.7beta"
 
 #include <pthread.h>
 #include <libguile.h>
@@ -44,6 +44,7 @@
 #include "tsk/tsk.h"
 #include "gui/gui.h"
 #include "gfx/gfx.h"
+#include "dsp/dsp.h"
 #include "snd/snd.h"
 #include "img/img.h"
 #include "pil/pil.h"
@@ -54,6 +55,8 @@
 
 typedef struct lw6_smob_types_s
 {
+  scm_t_bits dsp;
+  scm_t_bits snd;
   scm_t_bits map;
   scm_t_bits menu;
   scm_t_bits game_struct;
@@ -65,6 +68,22 @@ typedef struct lw6_smob_types_s
 }
 lw6_smob_types_t;
 
+typedef struct lw6_dsp_smob_s
+{
+  lw6dsp_backend_t *c_dsp;
+  SCM level;
+  SCM game_struct;
+  SCM game_state;
+  SCM pilot;
+}
+lw6_dsp_smob_t;
+
+typedef struct lw6_snd_smob_s
+{
+  lw6snd_backend_t *c_snd;
+}
+lw6_snd_smob_t;
+
 typedef struct lw6_map_smob_s
 {
   lw6map_level_t *c_map;
@@ -101,6 +120,7 @@ typedef struct lw6_bot_smob_s
 {
   lw6bot_backend_t *c_bot;
   SCM game_state;
+  SCM pilot;
 }
 lw6_bot_smob_t;
 
@@ -120,11 +140,7 @@ typedef struct lw6_global_s
 {
   pthread_mutex_t mutex;
   void *cfg_context;
-  lw6gfx_backend_t *gfx_backend;
-  lw6snd_backend_t *snd_backend;
   int cfg_initialized;
-  int gfx_initialized;
-  int snd_initialized;
   int cns_initialized;
   int net_initialized;
   int start_time;
@@ -132,6 +148,8 @@ typedef struct lw6_global_s
   char **argv;
   float progress;
   lw6_smob_types_t smob_types;
+  lw6sys_assoc_t *dsp_smobs;
+  lw6sys_assoc_t *snd_smobs;
   lw6sys_assoc_t *map_smobs;
   lw6sys_assoc_t *menu_smobs;
   lw6sys_assoc_t *game_struct_smobs;
@@ -151,16 +169,18 @@ lw6_global_t;
 
 extern lw6_global_t lw6_global;
 extern int lw6_init_global (int argc, char *argv[]);
-extern void lw6_quit_global ();
+extern void lw6_quit_global_1 ();
+extern void lw6_quit_global_2 ();
 
 /*
  * Functions in callback.c
  */
-extern void lw6_resize_callback (int width, int height, int fullscreen);
+extern void lw6_resize_callback (lw6gui_video_mode_t * video_mode);
 
 /*
  * Functions in control.c
  */
+extern void lw6_release ();
 extern void lw6_exit ();
 
 /*
@@ -217,6 +237,12 @@ extern void lw6_print_goodbye ();
 /*
  * Functions in smobs.c
  */
+extern SCM lw6_make_scm_dsp (lw6dsp_backend_t * c_dsp);
+extern lw6dsp_backend_t *lw6_scm_to_dsp (SCM dsp);
+extern void lw6_free_dsp_smob (lw6_dsp_smob_t * dsp_smob);
+extern SCM lw6_make_scm_snd (lw6snd_backend_t * c_snd);
+extern lw6snd_backend_t *lw6_scm_to_snd (SCM snd);
+extern void lw6_free_snd_smob (lw6_snd_smob_t * snd_smob);
 extern SCM lw6_make_scm_map (lw6map_level_t * c_map);
 extern lw6map_level_t *lw6_scm_to_map (SCM map);
 extern void lw6_free_map_smob (lw6_map_smob_t * map_smob);
@@ -236,7 +262,8 @@ extern void lw6_free_game_state_smob (lw6_game_state_smob_t *
 extern SCM lw6_make_scm_pilot (lw6pil_pilot_t * c_pilot);
 extern lw6pil_pilot_t *lw6_scm_to_pilot (SCM pilot);
 extern void lw6_free_pilot_smob (lw6_pilot_smob_t * pilot_smob);
-extern SCM lw6_make_scm_bot (lw6bot_backend_t * c_bot, SCM game_state);
+extern SCM lw6_make_scm_bot (lw6bot_backend_t * c_bot, SCM game_state,
+			     SCM pilot);
 extern lw6bot_backend_t *lw6_scm_to_bot (SCM bot);
 extern void lw6_free_bot_smob (lw6_bot_smob_t * bot_smob);
 extern SCM lw6_make_scm_look (lw6gui_look_t * c_look);
