@@ -37,13 +37,15 @@
  * like a thumb isn't a bad thing.
  */
 void
-lw6_resize_callback (int width, int height, int fullscreen)
+lw6_resize_callback (lw6gui_video_mode_t * video_mode)
 {
   if (lw6_global.cfg_context)
     {
-      lw6cfg_set_option_int (lw6_global.cfg_context, LW6DEF_WIDTH, width);
-      lw6cfg_set_option_int (lw6_global.cfg_context, LW6DEF_HEIGHT, height);
+      lw6cfg_set_option_int (lw6_global.cfg_context, LW6DEF_WIDTH,
+			     video_mode->width);
+      lw6cfg_set_option_int (lw6_global.cfg_context, LW6DEF_HEIGHT,
+			     video_mode->height);
       lw6cfg_set_option_bool (lw6_global.cfg_context, LW6DEF_FULLSCREEN,
-			      fullscreen);
+			      video_mode->fullscreen);
     }
 }
