@@ -61,6 +61,10 @@ lw6_init_global (int argc, char *argv[])
   LW6_MUTEX_LOCK;
 
   ret =
+    ((lw6_global.dsp_smobs =
+      lw6sys_assoc_new ((void (*)(void *)) lw6_free_dsp_smob)) != NULL) &&
+    ((lw6_global.snd_smobs =
+      lw6sys_assoc_new ((void (*)(void *)) lw6_free_snd_smob)) != NULL) &&
     ((lw6_global.map_smobs =
       lw6sys_assoc_new ((void (*)(void *)) lw6_free_map_smob)) != NULL) &&
     ((lw6_global.menu_smobs =
@@ -100,36 +104,6 @@ quit_cfg ()
   lw6_global.cfg_initialized = 0;
 }
 
-static void
-quit_gfx ()
-{
-  if (lw6_global.gfx_backend != NULL)
-    {
-      if (lw6_global.gfx_initialized)
-	{
-	  lw6gfx_quit (lw6_global.gfx_backend);
-	}
-      lw6gfx_destroy_backend (lw6_global.gfx_backend);
-    }
-  lw6_global.gfx_backend = NULL;
-  lw6_global.gfx_initialized = 0;
-}
-
-static void
-quit_snd ()
-{
-  if (lw6_global.snd_backend != NULL)
-    {
-      if (lw6_global.snd_initialized)
-	{
-	  lw6snd_quit (lw6_global.snd_backend);
-	}
-      lw6snd_destroy_backend (lw6_global.snd_backend);
-    }
-  lw6_global.snd_backend = NULL;
-  lw6_global.snd_initialized = 0;
-}
-
 static void
 quit_cns ()
 {
@@ -151,36 +125,50 @@ quit_net ()
 }
 
 void
-lw6_quit_global ()
+lw6_quit_global_1 ()
+{
+  lw6sys_log (LW6SYS_LOG_INFO, _("free global ressources"));
+
+  quit_cns ();
+  quit_net ();
+  quit_cfg ();
+}
+
+void
+lw6_quit_global_2 ()
 {
-  /*
-   * First, we free libraries. Note that this is normally
-   * done in scripts, but... in some cases (especially when
-   * a script is wrecked and/or crashes) it's not done.
-   * In that case we do it manually, sort of double security.
-   */
   lw6sys_log (LW6SYS_LOG_INFO, _("final garbage collection"));
 
   LW6_MUTEX_LOCK;
 
+  /*
+   * Should the Guile GC be perfect, not one single object
+   * would be freed here.
+   */
   lw6sys_assoc_free (lw6_global.loader_smobs);
+  lw6_global.loader_smobs = NULL;
   lw6sys_assoc_free (lw6_global.look_smobs);
+  lw6_global.look_smobs = NULL;
   lw6sys_assoc_free (lw6_global.bot_smobs);
+  lw6_global.bot_smobs = NULL;
   lw6sys_assoc_free (lw6_global.pilot_smobs);
+  lw6_global.pilot_smobs = NULL;
   lw6sys_assoc_free (lw6_global.game_state_smobs);
+  lw6_global.game_state_smobs = NULL;
   lw6sys_assoc_free (lw6_global.game_struct_smobs);
+  lw6_global.game_struct_smobs = NULL;
   lw6sys_assoc_free (lw6_global.menu_smobs);
+  lw6_global.menu_smobs = NULL;
   lw6sys_assoc_free (lw6_global.map_smobs);
+  lw6_global.map_smobs = NULL;
+  lw6sys_assoc_free (lw6_global.snd_smobs);
+  lw6_global.snd_smobs = NULL;
+  lw6sys_assoc_free (lw6_global.dsp_smobs);
+  lw6_global.dsp_smobs = NULL;
 
   LW6_MUTEX_UNLOCK;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _("quit everything"));
-
-  quit_cns ();
-  quit_snd ();
-  quit_gfx ();
-  quit_net ();
-  quit_cfg ();
-
   pthread_mutex_destroy (&lw6_global.mutex);
+
+  memset (&lw6_global, 0, sizeof (lw6_global_t));
 }
