@@ -32,7 +32,7 @@
 #define GUILE_LOAD_PATH_SUFFIX "guile"
 
 static void
-fix_guile_load_path (int argc, char *argv[])
+_fix_guile_load_path (int argc, char *argv[])
 {
   char *run_dir = NULL;
   char *guile_dir = NULL;
@@ -92,12 +92,29 @@ guile_main (void *data)
     }
 
   scm_gc ();
-
-  lw6_quit_global ();
+  /*
+   * It's important to call lw6_quit_global_1 only now, for in vthread
+   * mode we need the possible dsp/gfx module cleanup to be in the
+   * same thread than the caller (SDL limitation on Mac OS X).
+   */
+  lw6_quit_global_1 ();
 
   return NULL;
 }
 
+static void
+_run (void *data)
+{
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("main run data=%p"), data);
+  scm_with_guile (guile_main, NULL);
+}
+
+static void
+_end (void *data)
+{
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("main end data=%p"), data);
+}
+
 /**
  * lw6_main:
  * 
@@ -165,12 +182,31 @@ lw6_main (int argc, char *argv[])
 		  lw6sys_build_get_target_os (),
 		  lw6sys_build_get_target_cpu ());
       lw6_print_hello (argc, argv);
+
       if (lw6_init_global (argc, argv))
 	{
 #ifdef LW6_MS_WINDOWS
-	  fix_guile_load_path (argc, argv);
+	  _fix_guile_load_path (argc, argv);
 #endif
-	  scm_with_guile (guile_main, NULL);
+
+#ifdef LW6_MAC_OS_X
+	  if (!lw6sys_vthread_run (_run, _end, NULL))
+	    {
+	      ret = 0;
+	    }
+#else
+	  _run (NULL);
+	  _end (NULL);
+#endif
+
+	  /*
+	   * It's important to call lw6_quit_global_2 only now, when Guile
+	   * is finished, otherwise Guile might call the destructors
+	   * afterwards, when globals are zeroed. This way it works, the
+	   * destructors (even for "chained" objects like game_struct)
+	   * do not need to access SCM objects.
+	   */
+	  lw6_quit_global_2 ();
 	}
 
       lw6_print_goodbye ();
