@@ -126,9 +126,9 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	    && lw6cns_test ()
 	    && lw6hlp_test () && lw6cfg_test () && lw6ldr_test ()
 	    && lw6tsk_test () && lw6gui_test () && lw6gfx_test ()
-	    && lw6snd_test () && lw6img_test () && lw6pil_test ()
-	    && lw6net_test () && lw6cli_test () && lw6srv_test ()
-	    && lw6p2p_test () && lw6_test ();
+	    && lw6dsp_test () && lw6snd_test () && lw6img_test ()
+	    && lw6pil_test () && lw6net_test () && lw6cli_test ()
+	    && lw6srv_test () && lw6p2p_test () && lw6_test ();
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match (LW6DEF_BENCH, argv[i]))
@@ -346,12 +346,14 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_gcc_version ());
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_CFLAGS, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_CFLAGS, argv[i])
+	       || lw6sys_arg_match (LW6DEF_CFLAGS, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_cflags ());
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_LDFLAGS, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_LDFLAGS, argv[i])
+	       || lw6sys_arg_match (LW6DEF_LDFLAGS, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_ldflags ());
 	  (*run_game) = 0;
@@ -386,6 +388,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%d\n", lw6sys_build_get_pointer_size ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_X86, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_is_x86 ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_TARGET_OS, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_target_os ());
@@ -396,6 +403,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%d\n", lw6sys_build_is_ms_windows ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_MAC_OS_X, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_is_mac_os_x ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_TOP_SRCDIR, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_top_srcdir ());
@@ -473,11 +485,32 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_enable_fullstatic ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_PARANOID, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_paranoid ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_GPROF, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_enable_gprof ());
 	  (*run_game) = 0;
 	}
+      else
+	if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_INSTRUMENT, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_instrument ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_PROFILER, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_profiler ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_GCOV, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_gcov ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_VALGRIND, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_enable_valgrind ());
