@@ -136,8 +136,10 @@ lw6_print_target ()
   printf ("target-cpu: %s\n", lw6sys_build_get_target_cpu ());
   printf ("endianness: %s\n", lw6sys_build_get_endianness ());
   printf ("pointer-size: %d\n", lw6sys_build_get_pointer_size ());
+  printf ("x86: %d\n", lw6sys_build_is_x86 ());
   printf ("target-os: %s\n", lw6sys_build_get_target_os ());
   printf ("ms-windows: %d\n", lw6sys_build_is_ms_windows ());
+  printf ("mac-os-x: %d\n", lw6sys_build_is_mac_os_x ());
   fflush (stdout);
 }
 
@@ -329,7 +331,10 @@ lw6_print_modules ()
   printf ("enable-optimize: %s\n", lw6sys_build_get_enable_optimize ());
   printf ("enable-allinone: %s\n", lw6sys_build_get_enable_allinone ());
   printf ("enable-fullstatic: %s\n", lw6sys_build_get_enable_fullstatic ());
+  printf ("enable-paranoid: %s\n", lw6sys_build_get_enable_paranoid ());
   printf ("enable-gprof: %s\n", lw6sys_build_get_enable_gprof ());
+  printf ("enable-instrument: %s\n", lw6sys_build_get_enable_instrument ());
+  printf ("enable-profiler: %s\n", lw6sys_build_get_enable_profiler ());
   printf ("enable-gcov: %s\n", lw6sys_build_get_enable_gcov ());
   printf ("enable-valgrind: %s\n", lw6sys_build_get_enable_valgrind ());
 
@@ -575,12 +580,17 @@ lw6_print_about (char *keyword)
 {
   char *doc_str = NULL;
   lw6hlp_type_t type = LW6HLP_TYPE_VOID;
+  char *default_value = NULL;
+  int min_value = 0;
+  int max_value = 0;
   char *type_str = NULL;
-  char *type_str2 = NULL;
+  char *tmp = NULL;
+  int values_set = 0;
 
   doc_str =
-    lw6sys_str_reformat (lw6hlp_about (&type, keyword),
-			 LW6SYS_REFORMAT_DEFAULT_PREFIX,
+    lw6sys_str_reformat (lw6hlp_about
+			 (&type, &default_value, &min_value, &max_value,
+			  keyword), LW6SYS_REFORMAT_DEFAULT_PREFIX,
 			 LW6SYS_REFORMAT_DEFAULT_NB_COLUMNS);
   if (doc_str)
     {
@@ -607,13 +617,44 @@ lw6_print_about (char *keyword)
 	}
       if (type_str && type != LW6HLP_TYPE_VOID)
 	{
-	  type_str2 = lw6sys_new_sprintf (_("Type: %s."), type_str);
-	  if (type_str2)
+	  tmp = lw6sys_new_sprintf (_("Type: %s."), type_str);
+	  if (tmp)
 	    {
-	      printf ("%s\n\n", type_str2);
-	      LW6SYS_FREE (type_str2);
+	      printf ("%s\n\n", tmp);
+	      LW6SYS_FREE (tmp);
 	    }
 	}
+      if (default_value)
+	{
+	  tmp = lw6sys_new_sprintf (_("Default value: %s."), default_value);
+	  if (tmp)
+	    {
+	      values_set = 1;
+	      printf ("%s\n", tmp);
+	      LW6SYS_FREE (tmp);
+	    }
+	}
+      if (min_value != 0 || max_value != 0)
+	{
+	  tmp = lw6sys_new_sprintf (_("Min value: %d."), min_value);
+	  if (tmp)
+	    {
+	      values_set = 1;
+	      printf ("%s\n", tmp);
+	      LW6SYS_FREE (tmp);
+	    }
+	  tmp = lw6sys_new_sprintf (_("Max value: %d."), max_value);
+	  if (tmp)
+	    {
+	      values_set = 1;
+	      printf ("%s\n", tmp);
+	      LW6SYS_FREE (tmp);
+	    }
+	}
+      if (values_set)
+	{
+	  printf ("\n");
+	}
       printf ("%s", doc_str);
       fflush (stdout);
       LW6SYS_FREE (doc_str);
