@@ -26,6 +26,8 @@
 
 #include "liquidwar6.h"
 
+#define SMOB_TYPE_DSP "lw6dsp-backend"
+#define SMOB_TYPE_SND "lw6snd-backend"
 #define SMOB_TYPE_MAP "lw6map-level"
 #define SMOB_TYPE_MENU "lw6gui-menu"
 #define SMOB_TYPE_GAME_STRUCT "lw6ker-game-struct"
@@ -45,6 +47,267 @@ smob_id (char *type, int id)
   return ret;
 }
 
+/*
+ * Display smob
+ */
+static SCM
+mark_dsp (SCM dsp)
+{
+  lw6_dsp_smob_t *dsp_smob = (lw6_dsp_smob_t *) SCM_SMOB_DATA (dsp);
+
+  scm_gc_mark (dsp_smob->level);
+  scm_gc_mark (dsp_smob->game_struct);
+  scm_gc_mark (dsp_smob->game_state);
+  scm_gc_mark (dsp_smob->pilot);
+
+  return SCM_BOOL_F;
+}
+
+static size_t
+free_dsp (SCM dsp)
+{
+  char *id = NULL;
+  lw6_dsp_smob_t *dsp_smob = (lw6_dsp_smob_t *) SCM_SMOB_DATA (dsp);
+
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect dsp smob"));
+  id = smob_id (SMOB_TYPE_DSP, dsp_smob->c_dsp->id);
+  if (id)
+    {
+      if (lw6_global.dsp_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free dsp smob \"%s\""), id);
+	  lw6sys_assoc_unset (lw6_global.dsp_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free dsp smob \"%s\" but assoc is NULL"),
+		      id);
+	}
+      LW6SYS_FREE (id);
+    }
+
+  LW6_MUTEX_UNLOCK;
+
+  return 0;
+}
+
+static int
+print_dsp (SCM dsp, SCM port, scm_print_state * pstate)
+{
+  lw6dsp_backend_t *c_dsp = lw6_scm_to_dsp (dsp);
+  char *repr = NULL;
+
+  repr = lw6dsp_repr (c_dsp);
+
+  scm_puts ("#<" SMOB_TYPE_DSP " ", port);
+  if (repr)
+    {
+      scm_display (scm_makfrom0str (repr), port);
+      LW6SYS_FREE (repr);
+    }
+  scm_puts (">", port);
+
+  return 1;
+}
+
+// c_dsp is supposed to have been initialized with lw6dsp_init()
+SCM
+lw6_make_scm_dsp (lw6dsp_backend_t * c_dsp)
+{
+  char *repr = NULL;
+  char *id = NULL;
+  lw6_dsp_smob_t *dsp_smob = NULL;
+
+  scm_gc ();
+
+  dsp_smob = (lw6_dsp_smob_t *) LW6SYS_CALLOC (sizeof (lw6_dsp_smob_t));
+  if (dsp_smob)
+    {
+      dsp_smob->c_dsp = c_dsp;
+      dsp_smob->level = SCM_BOOL_F;	// initialized later with update
+      dsp_smob->game_struct = SCM_BOOL_F;	// initialized later with update
+      dsp_smob->game_state = SCM_BOOL_F;	// initialized later with update
+      dsp_smob->pilot = SCM_BOOL_F;	// initialized later with update
+      id = smob_id (SMOB_TYPE_DSP, c_dsp->id);
+      if (id)
+	{
+	  repr = lw6dsp_repr (c_dsp);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating dsp smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.dsp_smobs, id, (void *) dsp_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to create dsp smob, expect trouble"));
+    }
+
+  SCM_RETURN_NEWSMOB (lw6_global.smob_types.dsp, dsp_smob);
+}
+
+lw6dsp_backend_t *
+lw6_scm_to_dsp (SCM dsp)
+{
+  lw6dsp_backend_t *c_dsp;
+
+  c_dsp = ((lw6_dsp_smob_t *) SCM_SMOB_DATA (dsp))->c_dsp;
+
+  return c_dsp;
+}
+
+void
+lw6_free_dsp_smob (lw6_dsp_smob_t * dsp_smob)
+{
+  char *repr = NULL;
+
+  repr = lw6dsp_repr (dsp_smob->c_dsp);
+  if (repr)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("freeing dsp smob \"%s\""), repr);
+      LW6SYS_FREE (repr);
+    }
+
+  lw6dsp_quit (dsp_smob->c_dsp);
+  lw6dsp_destroy_backend (dsp_smob->c_dsp);
+  LW6SYS_FREE (dsp_smob);
+}
+
+/*
+ * Sound smob
+ */
+static SCM
+mark_snd (SCM snd)
+{
+  return SCM_BOOL_F;
+}
+
+static size_t
+free_snd (SCM snd)
+{
+  char *id = NULL;
+  lw6_snd_smob_t *snd_smob = (lw6_snd_smob_t *) SCM_SMOB_DATA (snd);
+
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect snd smob"));
+  id = smob_id (SMOB_TYPE_SND, snd_smob->c_snd->id);
+  if (id)
+    {
+      if (lw6_global.snd_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free snd smob \"%s\""), id);
+	  lw6sys_assoc_unset (lw6_global.snd_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free snd smob \"%s\" but assoc is NULL"),
+		      id);
+	}
+      LW6SYS_FREE (id);
+    }
+
+  LW6_MUTEX_UNLOCK;
+
+  return 0;
+}
+
+static int
+print_snd (SCM snd, SCM port, scm_print_state * pstate)
+{
+  lw6snd_backend_t *c_snd = lw6_scm_to_snd (snd);
+  char *repr = NULL;
+
+  repr = lw6snd_repr (c_snd);
+
+  scm_puts ("#<" SMOB_TYPE_SND " ", port);
+  if (repr)
+    {
+      scm_display (scm_makfrom0str (repr), port);
+      LW6SYS_FREE (repr);
+    }
+  scm_puts (">", port);
+
+  return 1;
+}
+
+// c_snd is supposed to have been initialized with lw6snd_init()
+SCM
+lw6_make_scm_snd (lw6snd_backend_t * c_snd)
+{
+  char *repr = NULL;
+  char *id = NULL;
+  lw6_snd_smob_t *snd_smob = NULL;
+
+  scm_gc ();
+
+  snd_smob = (lw6_snd_smob_t *) LW6SYS_CALLOC (sizeof (lw6_snd_smob_t));
+  if (snd_smob)
+    {
+      snd_smob->c_snd = c_snd;
+      id = smob_id (SMOB_TYPE_SND, c_snd->id);
+      if (id)
+	{
+	  repr = lw6snd_repr (c_snd);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating snd smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.snd_smobs, id, (void *) snd_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to create snd smob, expect trouble"));
+    }
+
+  SCM_RETURN_NEWSMOB (lw6_global.smob_types.snd, snd_smob);
+}
+
+lw6snd_backend_t *
+lw6_scm_to_snd (SCM snd)
+{
+  lw6snd_backend_t *c_snd;
+
+  c_snd = ((lw6_snd_smob_t *) SCM_SMOB_DATA (snd))->c_snd;
+
+  return c_snd;
+}
+
+void
+lw6_free_snd_smob (lw6_snd_smob_t * snd_smob)
+{
+  char *repr = NULL;
+
+  repr = lw6snd_repr (snd_smob->c_snd);
+  if (repr)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("freeing snd smob \"%s\""), repr);
+      LW6SYS_FREE (repr);
+    }
+
+  lw6snd_quit (snd_smob->c_snd);
+  lw6snd_destroy_backend (snd_smob->c_snd);
+  LW6SYS_FREE (snd_smob);
+}
+
 /*
  * Map smob
  */
@@ -60,16 +323,28 @@ free_map (SCM map)
   char *id = NULL;
   lw6_map_smob_t *map_smob = (lw6_map_smob_t *) SCM_SMOB_DATA (map);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect map smob"));
   id = smob_id (SMOB_TYPE_MAP, map_smob->c_map->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.map_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.map_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free map smob \"%s\""), id);
+	  lw6sys_assoc_unset (lw6_global.map_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free map smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -180,16 +455,29 @@ free_menu (SCM menu)
   char *id = NULL;
   lw6_menu_smob_t *menu_smob = (lw6_menu_smob_t *) SCM_SMOB_DATA (menu);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect menu smob"));
   id = smob_id (SMOB_TYPE_MENU, menu_smob->c_menu->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.menu_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.menu_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free menu smob \"%s\""),
+		      id);
+	  lw6sys_assoc_unset (lw6_global.menu_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free menu smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -298,16 +586,30 @@ free_game_struct (SCM game_struct)
   lw6_game_struct_smob_t *game_struct_smob =
     (lw6_game_struct_smob_t *) SCM_SMOB_DATA (game_struct);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect game struct smob"));
   id = smob_id (SMOB_TYPE_GAME_STRUCT, game_struct_smob->c_game_struct->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.game_struct_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.game_struct_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _("request free game struct smob \"%s\""), id);
+	  lw6sys_assoc_unset (lw6_global.game_struct_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _
+		      ("request free game struct smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -421,16 +723,30 @@ free_game_state (SCM game_state)
   lw6_game_state_smob_t *game_state_smob =
     (lw6_game_state_smob_t *) SCM_SMOB_DATA (game_state);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect game state smob"));
   id = smob_id (SMOB_TYPE_GAME_STATE, game_state_smob->c_game_state->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.game_state_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.game_state_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _("request free game state smob \"%s\""), id);
+	  lw6sys_assoc_unset (lw6_global.game_state_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _
+		      ("request free game state smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -536,16 +852,29 @@ free_pilot (SCM pilot)
   char *id = NULL;
   lw6_pilot_smob_t *pilot_smob = (lw6_pilot_smob_t *) SCM_SMOB_DATA (pilot);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect pilot smob"));
   id = smob_id (SMOB_TYPE_PILOT, pilot_smob->c_pilot->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.pilot_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.pilot_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free pilot smob \"%s\""),
+		      id);
+	  lw6sys_assoc_unset (lw6_global.pilot_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free pilot smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -642,6 +971,7 @@ mark_bot (SCM bot)
   lw6_bot_smob_t *bot_smob = (lw6_bot_smob_t *) SCM_SMOB_DATA (bot);
 
   scm_gc_mark (bot_smob->game_state);
+  scm_gc_mark (bot_smob->pilot);
 
   return SCM_BOOL_F;
 }
@@ -652,16 +982,28 @@ free_bot (SCM bot)
   char *id = NULL;
   lw6_bot_smob_t *bot_smob = (lw6_bot_smob_t *) SCM_SMOB_DATA (bot);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect bot smob"));
   id = smob_id (SMOB_TYPE_BOT, bot_smob->c_bot->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.bot_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.bot_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free bot smob \"%s\""), id);
+	  lw6sys_assoc_unset (lw6_global.bot_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free bot smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -686,7 +1028,7 @@ print_bot (SCM bot, SCM port, scm_print_state * pstate)
 
 // c_bot is supposed to have been initialized with lw6bot_init()
 SCM
-lw6_make_scm_bot (lw6bot_backend_t * c_bot, SCM game_state)
+lw6_make_scm_bot (lw6bot_backend_t * c_bot, SCM game_state, SCM pilot)
 {
   char *repr = NULL;
   char *id = NULL;
@@ -699,6 +1041,7 @@ lw6_make_scm_bot (lw6bot_backend_t * c_bot, SCM game_state)
     {
       bot_smob->c_bot = c_bot;
       bot_smob->game_state = game_state;
+      bot_smob->pilot = pilot;
       id = smob_id (SMOB_TYPE_BOT, c_bot->id);
       if (id)
 	{
@@ -766,16 +1109,29 @@ free_look (SCM look)
   char *id = NULL;
   lw6_look_smob_t *look_smob = (lw6_look_smob_t *) SCM_SMOB_DATA (look);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect look smob"));
   id = smob_id (SMOB_TYPE_LOOK, look_smob->c_look->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.look_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.look_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free look smob \"%s\""),
+		      id);
+	  lw6sys_assoc_unset (lw6_global.look_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free look smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -879,16 +1235,29 @@ free_loader (SCM loader)
   lw6_loader_smob_t *loader_smob =
     (lw6_loader_smob_t *) SCM_SMOB_DATA (loader);
 
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect loader smob"));
   id = smob_id (SMOB_TYPE_LOADER, loader_smob->c_loader->id);
   if (id)
     {
-      LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.loader_smobs, id);
-      LW6_MUTEX_UNLOCK;
-
+      if (lw6_global.loader_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free loader smob \"%s\""),
+		      id);
+	  lw6sys_assoc_unset (lw6_global.loader_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free loader smob \"%s\" but assoc is NULL"),
+		      id);
+	}
       LW6SYS_FREE (id);
     }
 
+  LW6_MUTEX_UNLOCK;
+
   return 0;
 }
 
@@ -985,6 +1354,18 @@ lw6_register_smobs ()
 {
   int ret = 1;
 
+  lw6_global.smob_types.dsp =
+    scm_make_smob_type (SMOB_TYPE_DSP, sizeof (lw6_dsp_smob_t));
+  scm_set_smob_mark (lw6_global.smob_types.dsp, mark_dsp);
+  scm_set_smob_free (lw6_global.smob_types.dsp, free_dsp);
+  scm_set_smob_print (lw6_global.smob_types.dsp, print_dsp);
+
+  lw6_global.smob_types.snd =
+    scm_make_smob_type (SMOB_TYPE_SND, sizeof (lw6_snd_smob_t));
+  scm_set_smob_mark (lw6_global.smob_types.snd, mark_snd);
+  scm_set_smob_free (lw6_global.smob_types.snd, free_snd);
+  scm_set_smob_print (lw6_global.smob_types.snd, print_snd);
+
   lw6_global.smob_types.map =
     scm_make_smob_type (SMOB_TYPE_MAP, sizeof (lw6_map_smob_t));
   scm_set_smob_mark (lw6_global.smob_types.map, mark_map);
