@@ -61,7 +61,8 @@ int
 lw6map_color_is_same (lw6map_color_couple_t * color1,
 		      lw6map_color_couple_t * color2)
 {
-  return memcmp (color1, color2, sizeof (lw6map_color_couple_t)) ? 0 : 1;
+  return lw6sys_color_is_same (color1->fg, color2->fg)
+    && lw6sys_color_is_same (color1->bg, color2->bg);
 }
 
 /**
