@@ -32,6 +32,7 @@
  * lw6map_dup:
  *
  * @source: the map to copy
+ * @progress: to show advancement
  *
  * Performs a deep copy of the map, all elements are newly allocated
  * and source can safely be destroyed after it's been duplicated.
@@ -39,12 +40,17 @@
  * Return value: a newly allocated map, may be NULL.
  */
 lw6map_level_t *
-lw6map_dup (lw6map_level_t * source)
+lw6map_dup (lw6map_level_t * source, lw6sys_progress_t * progress)
 {
   lw6map_level_t *ret = NULL;
   int size = 0;
   u_int32_t id;
   int layer = 0;
+  int progress_i = 0;
+  int progress_n = 1;
+
+  lw6sys_progress_begin (progress);
+  progress_n = source->body.shape.d + 2;
 
   ret = lw6map_new ();
   if (ret)
@@ -55,7 +61,6 @@ lw6map_dup (lw6map_level_t * source)
 
       memset (&(ret->param), 0, sizeof (lw6map_param_t));
       lw6map_param_copy (&(ret->param), &(source->param));
-
       if (source->metadata.title)
 	{
 	  ret->metadata.title = lw6sys_str_copy (source->metadata.title);
@@ -64,6 +69,7 @@ lw6map_dup (lw6map_level_t * source)
 	{
 	  ret->metadata.readme = lw6sys_str_copy (source->metadata.readme);
 	}
+      lw6sys_progress_update (progress, 0, progress_n, ++progress_i);
       for (layer = 0; layer < ret->body.shape.d; ++layer)
 	{
 	  size =
@@ -74,6 +80,7 @@ lw6map_dup (lw6map_level_t * source)
 	    {
 	      memcpy (ret->body.layers[layer].data,
 		      source->body.layers[layer].data, size);
+	      lw6sys_progress_update (progress, 0, progress_n, ++progress_i);
 	    }
 	  else
 	    {
@@ -90,6 +97,7 @@ lw6map_dup (lw6map_level_t * source)
 	  if (ret->texture.data)
 	    {
 	      memcpy (ret->texture.data, source->texture.data, size);
+	      lw6sys_progress_update (progress, 0, progress_n, ++progress_i);
 	    }
 	  else
 	    {
@@ -98,6 +106,7 @@ lw6map_dup (lw6map_level_t * source)
 	    }
 	}
     }
+  lw6sys_progress_end (progress);
 
   return ret;
 }
