@@ -69,6 +69,8 @@ push_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
   int ret = 1;
   int layer;
 
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer, body->checksum);
   ret = ret && lw6sys_hexa_serializer_push_whd (hexa_serializer, body->shape);
   for (layer = 0; layer < body->shape.d && ret; ++layer)
     {
@@ -89,6 +91,9 @@ push_texture (lw6sys_hexa_serializer_t * hexa_serializer,
     && lw6sys_hexa_serializer_push_int32 (hexa_serializer, texture->w);
   ret = ret
     && lw6sys_hexa_serializer_push_int32 (hexa_serializer, texture->h);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  texture->has_alpha);
   for (y = 0; y < texture->h && ret; ++y)
     {
       for (x = 0; x < texture->w && ret; ++x)
@@ -136,6 +141,18 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
 					  param->style.keep_ratio);
   ret = ret
     && lw6sys_hexa_serializer_push_float (hexa_serializer, param->style.zoom);
+  ret = ret
+    && lw6sys_hexa_serializer_push_float (hexa_serializer,
+					  param->style.zoom_min);
+  ret = ret
+    && lw6sys_hexa_serializer_push_float (hexa_serializer,
+					  param->style.zoom_max);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  param->style.x_wrap);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  param->style.y_wrap);
   ret = ret
     && lw6sys_hexa_serializer_push_str (hexa_serializer,
 					param->style.background_style);
@@ -157,6 +174,9 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
   ret = ret
     && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
 					  param->style.colorize);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  param->style.pixelize);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
 					  param->style.color_base.bg);
@@ -205,20 +225,20 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
 					  param->style.menu_color_default.fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.
-					  menu_color_selected.bg);
+					  param->style.menu_color_selected.
+					  bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.
-					  menu_color_selected.fg);
+					  param->style.menu_color_selected.
+					  fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.
-					  menu_color_disabled.bg);
+					  param->style.menu_color_disabled.
+					  bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.
-					  menu_color_disabled.fg);
+					  param->style.menu_color_disabled.
+					  fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
 					  param->style.view_color_cursor.bg);
@@ -343,6 +363,8 @@ pop_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
   int ret = 1;
   int layer;
 
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &(body->checksum));
   ret = ret
     && lw6sys_hexa_serializer_pop_whd (hexa_serializer, &(body->shape));
   if (lw6sys_shape_check_min_max_whd
@@ -377,10 +399,11 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &(texture->w));
   ret = ret
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &(texture->h));
-  if (texture->w >= LW6MAP_MIN_SIDE
-      && texture->w <= LW6MAP_MAX_SIDE
-      && texture->h >= LW6MAP_MIN_SIDE
-      && texture->h <= LW6MAP_MAX_SIDE
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(texture->has_alpha));
+  if (texture->w >= LW6MAP_MIN_SIDE && texture->w <= LW6MAP_MAX_SIDE
+      && texture->h >= LW6MAP_MIN_SIDE && texture->h <= LW6MAP_MAX_SIDE
       && texture->w * texture->h >= LW6MAP_MIN_SURFACE
       && texture->w * texture->h <= LW6MAP_MAX_SURFACE)
     {
@@ -453,6 +476,18 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
   ret = ret
     && lw6sys_hexa_serializer_pop_float (hexa_serializer,
 					 &(param->style.zoom));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_float (hexa_serializer,
+					 &(param->style.zoom_min));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_float (hexa_serializer,
+					 &(param->style.zoom_max));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(param->style.x_wrap));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(param->style.y_wrap));
   ret = ret
     && lw6sys_hexa_serializer_pop_str (hexa_serializer,
 				       &(param->style.background_style));
@@ -474,6 +509,9 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
   ret = ret
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
 					 &(param->style.colorize));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(param->style.pixelize));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
 					 &(param->style.color_base.bg));
