@@ -67,20 +67,36 @@ lw6map_new ()
 }
 
 /**
- * lw6map_defaults
+ * lw6map_builtin_whd
  *
- * @nb_layers: the number of layers of the map
- * @w: the width of the map
- * @h: the height of the map
- *
- * Creates a map, set to defaults. This is usefull mostly for testing,
- * it will just create a dull rectangle plain and uninteresting map,
- * however it's a quick way to have a working object and test stuff on it.
+ * Creates a map, set to defaults. This is usefull mostly for testing.
+ * This builtin map has walls, paths, it's playable.
  *
  * Return value: a newly allocated map. 
  */
 lw6map_level_t *
-lw6map_defaults (int nb_layers, int w, int h)
+lw6map_builtin_defaults ()
+{
+  return lw6map_builtin_whd (LW6MAP_BUILTIN_DEFAULT_WIDTH,
+			     LW6MAP_BUILTIN_DEFAULT_HEIGHT,
+			     LW6MAP_BUILTIN_DEFAULT_DEPTH);
+}
+
+/**
+ * lw6map_builtin_whd
+ *
+ * @w: the width of the map
+ * @h: the height of the map
+ * @d: the depth (number of layers) of the map
+ *
+ * Creates a map, set to defaults. This is usefull mostly for testing.
+ * This one, unlike @lw6map_builtin_defaults  will let you give a width,
+ * height and a depth.
+ *
+ * Return value: a newly allocated map. 
+ */
+lw6map_level_t *
+lw6map_builtin_whd (int w, int h, int d)
 {
   lw6map_level_t *level = NULL;
   lw6map_color_couple_t color;
@@ -97,7 +113,7 @@ lw6map_defaults (int nb_layers, int w, int h)
 	  level->id = ++seq_id;
 	}
 
-      lw6map_body_defaults (&level->body, nb_layers, w, h);
+      lw6map_body_builtin_whd (&level->body, w, h, d);
       lw6map_texture_from_body (&level->texture, &level->body, &color);
       lw6map_param_defaults (&level->param);
       lw6map_metadata_defaults (&level->metadata);
@@ -207,3 +223,46 @@ lw6map_repr (lw6map_level_t * level)
 
   return ret;
 }
+
+/**
+ * lw6map_is_same
+ *
+ * @level_a: the first level to compare
+ * @level_b: the other level to compare
+ *
+ * Compares two level structs, the idea is to compare the content, not
+ * only the pointers and level ids.
+ *
+ * Return value: 1 if they're the same, 0 if not.
+ */
+int
+lw6map_is_same (lw6map_level_t * level_a, lw6map_level_t * level_b)
+{
+  int ret = 1;
+
+  if (((!level_a) && level_b) || (level_a && (!level_b)))
+    {
+      ret = 0;
+    }
+  if (level_a && level_b)
+    {
+      /*
+       * We don't compare the whole map (performance...) but assume if 
+       * the metadata is the same, all the parameters are the same,
+       * the shape is the same, and the body checksum is the same ->
+       * it's the same map
+       */
+      ret = ret
+	&& lw6map_metadata_is_same (&(level_a->metadata),
+				    &(level_b->metadata));
+      ret = ret
+	&& lw6sys_shape_is_same (&(level_a->body.shape),
+				 &(level_b->body.shape));
+      ret = ret
+	&& lw6map_param_is_same (&(level_a->param), &(level_b->param));
+
+      ret = ret && (level_a->body.checksum == level_b->body.checksum);
+    }
+
+  return ret;
+}
