@@ -120,3 +120,14 @@ lw6map_param_set (lw6map_param_t * param, char *key, char *value)
 
   return ret;
 }
+
+int
+lw6map_param_is_same (lw6map_param_t * param_a, lw6map_param_t * param_b)
+{
+  int ret = 1;
+
+  ret = ret && lw6map_rules_is_same (&(param_a->rules), &(param_b->rules));
+  ret = ret && lw6map_style_is_same (&(param_a->style), &(param_b->style));
+
+  return ret;
+}
