@@ -697,3 +697,13 @@ lw6map_rules_clear (lw6map_rules_t * rules)
       memset (rules, 0, sizeof (lw6map_rules_t));
     }
 }
+
+int
+lw6map_rules_is_same (lw6map_rules_t * rules_a, lw6map_rules_t * rules_b)
+{
+  int ret = 1;
+
+  ret = !memcmp ((char *) rules_a, (char *) rules_b, sizeof (lw6map_rules_t));
+
+  return ret;
+}
