@@ -28,6 +28,12 @@
 
 #include "map.h"
 
+void
+lw6map_style_zero (lw6map_style_t * style)
+{
+  memset (style, 0, sizeof (lw6map_style_t));
+}
+
 void
 lw6map_style_defaults (lw6map_style_t * style)
 {
@@ -35,6 +41,10 @@ lw6map_style_defaults (lw6map_style_t * style)
 
   style->keep_ratio = LW6MAP_STYLE_DEFAULT_KEEP_RATIO;
   style->zoom = LW6MAP_STYLE_DEFAULT_ZOOM;
+  style->zoom_min = LW6MAP_STYLE_DEFAULT_ZOOM_MIN;
+  style->zoom_max = LW6MAP_STYLE_DEFAULT_ZOOM_MAX;
+  style->x_wrap = LW6MAP_STYLE_DEFAULT_X_WRAP;
+  style->y_wrap = LW6MAP_STYLE_DEFAULT_Y_WRAP;
   style->background_style =
     lw6sys_str_copy (LW6MAP_STYLE_DEFAULT_BACKGROUND_STYLE);
   style->hud_style = lw6sys_str_copy (LW6MAP_STYLE_DEFAULT_HUD_STYLE);
@@ -45,6 +55,7 @@ lw6map_style_defaults (lw6map_style_t * style)
   style->cursor_size = LW6MAP_STYLE_DEFAULT_CURSOR_SIZE;
   style->hidden_layer_alpha = LW6MAP_STYLE_DEFAULT_HIDDEN_LAYER_ALPHA;
   style->colorize = LW6MAP_STYLE_DEFAULT_COLORIZE;
+  style->pixelize = LW6MAP_STYLE_DEFAULT_PIXELIZE;
   style->color_base.bg =
     lw6sys_color_a_to_8 (LW6MAP_STYLE_DEFAULT_COLOR_BASE_BG);
   style->color_base.fg =
@@ -146,7 +157,7 @@ lw6map_style_clear (lw6map_style_t * style)
 	  LW6SYS_FREE (style->view_style);
 	}
 
-      memset (style, 0, sizeof (lw6map_style_t));
+      lw6map_style_zero (style);
     }
 }
 
@@ -195,6 +206,22 @@ lw6map_style_set (lw6map_style_t * style, char *key, char *value)
 	{
 	  style->zoom = lw6sys_atof (value);
 	}
+      else if (!strcmp (LW6DEF_ZOOM_MIN, formatted_key))
+	{
+	  style->zoom_min = lw6sys_atof (value);
+	}
+      else if (!strcmp (LW6DEF_ZOOM_MAX, formatted_key))
+	{
+	  style->zoom_max = lw6sys_atof (value);
+	}
+      else if (!strcmp (LW6DEF_X_WRAP, formatted_key))
+	{
+	  style->x_wrap = lw6sys_atob (value);
+	}
+      else if (!strcmp (LW6DEF_Y_WRAP, formatted_key))
+	{
+	  style->y_wrap = lw6sys_atob (value);
+	}
       else if (!strcmp (LW6DEF_BACKGROUND_STYLE, formatted_key))
 	{
 	  if (style->background_style)
@@ -247,6 +274,10 @@ lw6map_style_set (lw6map_style_t * style, char *key, char *value)
 	{
 	  style->colorize = lw6sys_atob (value);
 	}
+      else if (!strcmp (LW6DEF_PIXELIZE, formatted_key))
+	{
+	  style->pixelize = lw6sys_atob (value);
+	}
       else if (!strcmp (LW6DEF_COLOR_BASE_BG, formatted_key))
 	{
 	  style->color_base.bg = lw6sys_color_a_to_8 (value);
@@ -424,6 +455,22 @@ lw6map_style_get (lw6map_style_t * style, char *key)
 	{
 	  ret = lw6sys_ftoa (style->zoom);
 	}
+      else if (!strcmp (LW6DEF_ZOOM_MIN, formatted_key))
+	{
+	  ret = lw6sys_ftoa (style->zoom_min);
+	}
+      else if (!strcmp (LW6DEF_ZOOM_MAX, formatted_key))
+	{
+	  ret = lw6sys_ftoa (style->zoom_max);
+	}
+      else if (!strcmp (LW6DEF_X_WRAP, formatted_key))
+	{
+	  ret = lw6sys_btoa (style->x_wrap);
+	}
+      else if (!strcmp (LW6DEF_Y_WRAP, formatted_key))
+	{
+	  ret = lw6sys_btoa (style->y_wrap);
+	}
       else if (!strcmp (LW6DEF_BACKGROUND_STYLE, formatted_key))
 	{
 	  ret = lw6sys_str_copy (style->background_style);
@@ -460,6 +507,10 @@ lw6map_style_get (lw6map_style_t * style, char *key)
 	{
 	  ret = lw6sys_btoa (style->colorize);
 	}
+      else if (!strcmp (LW6DEF_PIXELIZE, formatted_key))
+	{
+	  ret = lw6sys_btoa (style->pixelize);
+	}
       else if (!strcmp (LW6DEF_COLOR_BASE_BG, formatted_key))
 	{
 	  ret = lw6sys_color_8_to_a (style->color_base.bg);
@@ -641,3 +692,71 @@ lw6map_style_get_default (char *key)
 
   return ret;
 }
+
+int
+lw6map_style_is_same (lw6map_style_t * style_a, lw6map_style_t * style_b)
+{
+  int ret = 1;
+  int i;
+
+  ret = ret && style_a->keep_ratio == style_b->keep_ratio;
+  ret = ret && style_a->zoom == style_b->zoom;
+  ret = ret && style_a->zoom_min == style_b->zoom_min;
+  ret = ret && style_a->zoom_max == style_b->zoom_max;
+  ret = ret && style_a->x_wrap == style_b->x_wrap;
+  ret = ret && style_a->y_wrap == style_b->y_wrap;
+  ret = ret
+    && lw6sys_str_is_same (style_a->background_style,
+			   style_b->background_style);
+  ret = ret && lw6sys_str_is_same (style_a->hud_style, style_b->hud_style);
+  ret = ret && lw6sys_str_is_same (style_a->menu_style, style_b->menu_style);
+  ret = ret && lw6sys_str_is_same (style_a->view_style, style_b->view_style);
+  ret = ret && style_a->animation_density == style_b->animation_density;
+  ret = ret && style_a->animation_speed == style_b->animation_speed;
+  ret = ret && style_a->cursor_size == style_b->cursor_size;
+  ret = ret && style_a->hidden_layer_alpha == style_b->hidden_layer_alpha;
+  ret = ret && style_a->colorize == style_b->colorize;
+  ret = ret && style_a->pixelize == style_b->pixelize;
+  ret = ret
+    && lw6map_color_is_same (&style_a->color_base, &style_b->color_base);
+  ret = ret
+    && lw6map_color_is_same (&style_a->color_alternate,
+			     &style_b->color_alternate);
+  ret = ret
+    && lw6map_color_is_same (&style_a->background_color_root,
+			     &style_b->background_color_root);
+  ret = ret
+    && lw6map_color_is_same (&style_a->background_color_stuff,
+			     &style_b->background_color_stuff);
+  ret = ret
+    && lw6map_color_is_same (&style_a->hud_color_frame,
+			     &style_b->hud_color_frame);
+  ret = ret
+    && lw6map_color_is_same (&style_a->hud_color_text,
+			     &style_b->hud_color_text);
+  ret = ret
+    && lw6map_color_is_same (&style_a->menu_color_default,
+			     &style_b->menu_color_default);
+  ret = ret
+    && lw6map_color_is_same (&style_a->menu_color_selected,
+			     &style_b->menu_color_selected);
+  ret = ret
+    && lw6map_color_is_same (&style_a->menu_color_disabled,
+			     &style_b->menu_color_disabled);
+  ret = ret
+    && lw6map_color_is_same (&style_a->view_color_cursor,
+			     &style_b->view_color_cursor);
+  ret = ret
+    && lw6map_color_is_same (&style_a->view_color_map,
+			     &style_b->view_color_map);
+  ret = ret
+    && lw6map_color_is_same (&style_a->system_color, &style_b->system_color);
+  for (i = 0; i < LW6MAP_NB_TEAM_COLORS; ++i)
+    {
+      ret = ret
+	&& lw6sys_color_is_same (style_a->team_colors[i],
+				 style_b->team_colors[i]);
+    }
+
+  return ret;
+}
