@@ -33,7 +33,7 @@
 #define TEST_MAP_HEIGHT 6
 #define TEST_RULES_KEY LW6DEF_TOTAL_TIME
 #define TEST_RULES_VALUE 3600
-#define TEST_RULES_CHECKSUM 0x3c5fbb06
+#define TEST_RULES_CHECKSUM 0xef80939f
 #define TEST_STYLE_KEY LW6DEF_ZOOM
 #define TEST_STYLE_VALUE "1.0"
 #define TEST_COORDS_NB 5
@@ -180,9 +180,9 @@ test_defaults ()
   {
     lw6map_level_t *level = NULL;
     char *repr = NULL;
+    int has_alpha = 0;
 
-    level =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+    level = lw6map_builtin_defaults ();
     if (level)
       {
 	repr = lw6map_repr (level);
@@ -190,6 +190,8 @@ test_defaults ()
 	  {
 	    lw6sys_log (LW6SYS_LOG_NOTICE,
 			_("default map \"%s\" constructed"), repr);
+	    has_alpha = lw6map_texture_has_alpha (&(level->texture));
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("has_alpha=%d"), has_alpha);
 	    LW6SYS_FREE (repr);
 	  }
 	else
@@ -224,13 +226,14 @@ test_dup ()
     char *repr2 = NULL;
 
     level1 =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
     if (level1)
       {
 	repr1 = lw6map_repr (level1);
 	if (repr1)
 	  {
-	    level2 = lw6map_dup (level1);
+	    level2 = lw6map_dup (level1, NULL);
 	    if (level2)
 	      {
 		repr2 = lw6map_repr (level2);
@@ -239,6 +242,16 @@ test_dup ()
 		    lw6sys_log (LW6SYS_LOG_NOTICE,
 				_("map \"%s\" copied to \"%s\""), repr1,
 				repr2);
+		    if (lw6map_is_same (level1, level2))
+		      {
+			lw6sys_log (LW6SYS_LOG_NOTICE,
+				    _("map \"%s\" and \"%s\" are the same"),
+				    repr1, repr2);
+		      }
+		    else
+		      {
+			ret = 0;
+		      }
 		    LW6SYS_FREE (repr2);
 		  }
 		else
@@ -285,7 +298,8 @@ test_hexa ()
     char *hexa_check = NULL;
 
     level =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
     if (level)
       {
 	repr = lw6map_repr (level);
@@ -427,6 +441,13 @@ test_style ()
 	  }
 	else
 	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("can't find style key \"%s\""), TEST_STYLE_KEY);
+	    ret = 0;
+	  }
+	if (!lw6map_style_is_same (style, style))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING, _("map style comparison failed"));
 	    ret = 0;
 	  }
 	lw6map_style_clear (style);
