@@ -124,3 +124,30 @@ lw6map_texture_get_with_body_coord (lw6map_level_t * level, int body_x,
 
   return ret;
 }
+
+int
+lw6map_texture_has_alpha (lw6map_texture_t * texture)
+{
+  int ret = 0;
+  int x = 0;
+  int y = 0;
+  lw6sys_color_8_t color;
+
+  if (texture->data)
+    {
+      for (y = 0; y < texture->h; ++y)
+	{
+	  for (x = 0; x < texture->w; ++x)
+	    {
+	      color = lw6map_texture_get (texture, x, y);
+	      if (color.a < 255)
+		{
+		  ret = 1;
+		}
+	    }
+	}
+      texture->has_alpha = ret;
+    }
+
+  return ret;
+}
