@@ -34,9 +34,12 @@
 /*
  * All static rules default/min/max
  */
-#define LW6MAP_RULES_DEFAULT_TOTAL_TIME 900	// 15 minutes
-#define LW6MAP_RULES_MIN_TOTAL_TIME 10	// 10 seconds
-#define LW6MAP_RULES_MAX_TOTAL_TIME 864000	// 10 days
+// 15 minutes
+#define LW6MAP_RULES_DEFAULT_TOTAL_TIME 900
+// 10 seconds
+#define LW6MAP_RULES_MIN_TOTAL_TIME 10
+// 10 days
+#define LW6MAP_RULES_MAX_TOTAL_TIME 864000
 
 #define LW6MAP_RULES_DEFAULT_RESPAWN_TEAM 1
 #define LW6MAP_RULES_MIN_RESPAWN_TEAM 0
@@ -50,7 +53,7 @@
 #define LW6MAP_RULES_MIN_SPREADS_PER_ROUND 1
 #define LW6MAP_RULES_MAX_SPREADS_PER_ROUND 12
 
-#define LW6MAP_RULES_DEFAULT_ROUNDS_PER_SEC 25
+#define LW6MAP_RULES_DEFAULT_ROUNDS_PER_SEC 50
 #define LW6MAP_RULES_MIN_ROUNDS_PER_SEC 1
 #define LW6MAP_RULES_MAX_ROUNDS_PER_SEC 100
 
@@ -70,11 +73,13 @@
 #define LW6MAP_RULES_MIN_FIGHTER_REGENERATE 0
 #define LW6MAP_RULES_MAX_FIGHTER_REGENERATE LW6MAP_MAX_FIGHTER_HEALTH
 
-#define LW6MAP_RULES_DEFAULT_SIDE_ATTACK_FACTOR 20	// 20%
+// 20%
+#define LW6MAP_RULES_DEFAULT_SIDE_ATTACK_FACTOR 20
 #define LW6MAP_RULES_MIN_SIDE_ATTACK_FACTOR 0
 #define LW6MAP_RULES_MAX_SIDE_ATTACK_FACTOR 100
 
-#define LW6MAP_RULES_DEFAULT_SIDE_DEFENSE_FACTOR 20	// 20%
+// 20%
+#define LW6MAP_RULES_DEFAULT_SIDE_DEFENSE_FACTOR 20
 #define LW6MAP_RULES_MIN_SIDE_DEFENSE_FACTOR 0
 #define LW6MAP_RULES_MAX_SIDE_DEFENSE_FACTOR 100
 
@@ -94,13 +99,19 @@
 #define LW6MAP_RULES_MIN_VERTICAL_MOVE 0
 #define LW6MAP_RULES_MAX_VERTICAL_MOVE LW6MAP_MAX_NB_DIR_TRIES
 
-#define LW6MAP_RULES_DEFAULT_SINGLE_ARMY_SIZE 30	// 9%
-#define LW6MAP_RULES_MIN_SINGLE_ARMY_SIZE 1	// 0.01%
-#define LW6MAP_RULES_MAX_SINGLE_ARMY_SIZE 95	// 90%
+// 9%
+#define LW6MAP_RULES_DEFAULT_SINGLE_ARMY_SIZE 30
+// 0.01%
+#define LW6MAP_RULES_MIN_SINGLE_ARMY_SIZE 1
+// 90%
+#define LW6MAP_RULES_MAX_SINGLE_ARMY_SIZE 95
 
-#define LW6MAP_RULES_DEFAULT_TOTAL_ARMIES_SIZE 60	// 36%
-#define LW6MAP_RULES_MIN_TOTAL_ARMIES_SIZE 1	// 0.01%
-#define LW6MAP_RULES_MAX_TOTAL_ARMIES_SIZE 95	// 90%
+// 36%
+#define LW6MAP_RULES_DEFAULT_TOTAL_ARMIES_SIZE 60
+// 0.01%
+#define LW6MAP_RULES_MIN_TOTAL_ARMIES_SIZE 1
+// 90%
+#define LW6MAP_RULES_MAX_TOTAL_ARMIES_SIZE 95
 
 #define LW6MAP_RULES_DEFAULT_MAX_NB_TEAMS LW6MAP_MAX_NB_TEAMS
 #define LW6MAP_RULES_MIN_MAX_NB_TEAMS 2
@@ -110,7 +121,8 @@
 #define LW6MAP_RULES_MIN_MAX_NB_CURSORS 2
 #define LW6MAP_RULES_MAX_MAX_NB_CURSORS LW6MAP_MAX_NB_CURSORS
 
-#define LW6MAP_RULES_DEFAULT_MAX_NB_SERVERS LW6MAP_MAX_NB_TEAMS	// 10, not 26
+// 10, not 26
+#define LW6MAP_RULES_DEFAULT_MAX_NB_SERVERS LW6MAP_MAX_NB_TEAMS
 #define LW6MAP_RULES_MIN_MAX_NB_SERVERS 2
 #define LW6MAP_RULES_MAX_MAX_NB_SERVERS LW6MAP_MAX_NB_SERVERS
 
@@ -309,14 +321,20 @@ typedef struct lw6map_rules_s
 extern char *LW6MAP_RULES_LIST[];
 
 #define LW6MAP_MIN_SIDE 3
-#define LW6MAP_MAX_SIDE 8000	// serious limit here, must be < 8191
+// serious limit here, must be < 8191
+#define LW6MAP_MAX_SIDE 8000
 #define LW6MAP_MIN_SURFACE 12
 #define LW6MAP_MAX_SURFACE 48000000
 
-#define LW6MAP_MAX_DEPTH 7	// can't be too high for perf issues
+// can't be too high for perf issues
+#define LW6MAP_MAX_DEPTH 7
 
 #define LW6MAP_STYLE_DEFAULT_KEEP_RATIO 1
 #define LW6MAP_STYLE_DEFAULT_ZOOM 1.0f
+#define LW6MAP_STYLE_DEFAULT_ZOOM_MIN 0.3f
+#define LW6MAP_STYLE_DEFAULT_ZOOM_MAX 30.0f
+#define LW6MAP_STYLE_DEFAULT_X_WRAP 1
+#define LW6MAP_STYLE_DEFAULT_Y_WRAP 1
 #define LW6MAP_STYLE_DEFAULT_BACKGROUND_STYLE "bubbles"
 #define LW6MAP_STYLE_DEFAULT_HUD_STYLE "floating"
 #define LW6MAP_STYLE_DEFAULT_MENU_STYLE "cylinder"
@@ -326,6 +344,7 @@ extern char *LW6MAP_RULES_LIST[];
 #define LW6MAP_STYLE_DEFAULT_CURSOR_SIZE 1.0f
 #define LW6MAP_STYLE_DEFAULT_HIDDEN_LAYER_ALPHA 0.1f
 #define LW6MAP_STYLE_DEFAULT_COLORIZE 1
+#define LW6MAP_STYLE_DEFAULT_PIXELIZE 0
 #define LW6MAP_STYLE_DEFAULT_COLOR_BASE_BG "#000"
 #define LW6MAP_STYLE_DEFAULT_COLOR_BASE_FG "#ccc"
 #define LW6MAP_STYLE_DEFAULT_COLOR_ALTERNATE_BG "#333"
@@ -373,6 +392,11 @@ extern char *LW6MAP_RULES_LIST[];
 #define LW6MAP_TEAM_COLOR_KEY_PINK "pink"
 
 #define LW6MAP_NB_TEAM_COLORS LW6MAP_MAX_NB_TEAMS
+
+#define LW6MAP_BUILTIN_DEFAULT_WIDTH 256
+#define LW6MAP_BUILTIN_DEFAULT_HEIGHT 128
+#define LW6MAP_BUILTIN_DEFAULT_DEPTH 1
+
 typedef enum lw6map_team_color_e
 { LW6MAP_TEAM_COLOR_INVALID = -1, LW6MAP_TEAM_COLOR_RED =
     0, LW6MAP_TEAM_COLOR_GREEN = 1, LW6MAP_TEAM_COLOR_BLUE =
@@ -381,38 +405,50 @@ typedef enum lw6map_team_color_e
     6, LW6MAP_TEAM_COLOR_LIGHTBLUE = 7, LW6MAP_TEAM_COLOR_PURPLE =
     8, LW6MAP_TEAM_COLOR_PINK = 9
 } lw6map_team_color_t;
+
 typedef struct lw6map_metadata_s
 {
   char *title;
   char *readme;
 } lw6map_metadata_t;
+
 typedef struct lw6map_layer_s
 {
   lw6sys_whd_t shape;
   u_int8_t *data;
 } lw6map_layer_t;
+
 typedef struct lw6map_body_s
 {
+  int checksum;
   lw6sys_whd_t shape;
   lw6map_layer_t layers[LW6MAP_MAX_DEPTH];
 } lw6map_body_t;
+
 typedef struct lw6map_color_couple_s
 {
   lw6sys_color_8_t fg;
   lw6sys_color_8_t bg;
 } lw6map_color_couple_t;
+
 typedef struct lw6map_texture_s
 {
   int w;
   int h;
+  int has_alpha;
   lw6sys_color_8_t *data;
   lw6map_color_couple_t guessed_color_base;
   lw6map_color_couple_t guessed_color_alternate;
 } lw6map_texture_t;
+
 typedef struct lw6map_style_s
 {
   int keep_ratio;		// boolean
   float zoom;
+  float zoom_min;
+  float zoom_max;
+  int x_wrap;
+  int y_wrap;
   char *background_style;
   char *hud_style;
   char *menu_style;
@@ -422,6 +458,7 @@ typedef struct lw6map_style_s
   float cursor_size;
   float hidden_layer_alpha;
   int colorize;
+  int pixelize;
   lw6map_color_couple_t color_base;
   lw6map_color_couple_t color_alternate;
   lw6map_color_couple_t background_color_root;
@@ -436,11 +473,13 @@ typedef struct lw6map_style_s
   lw6map_color_couple_t system_color;
   lw6sys_color_8_t team_colors[LW6MAP_NB_TEAM_COLORS];
 } lw6map_style_t;
+
 typedef struct lw6map_param_s
 {
   lw6map_rules_t rules;
   lw6map_style_t style;
 } lw6map_param_t;
+
 typedef struct lw6map_level_s
 {
   u_int32_t id;
@@ -483,8 +522,9 @@ lw6map_texture_set (lw6map_texture_t * texture, int x, int y,
 		    lw6sys_color_8_t value)
 {
   texture->data[y * texture->w + x] = value;
-} static inline lw6sys_color_8_t
+}
 
+static inline lw6sys_color_8_t
 lw6map_texture_get (lw6map_texture_t * texture, int x, int y)
 {
   return texture->data[y * texture->w + x];
@@ -505,11 +545,14 @@ extern void lw6map_coords_fix_z (lw6map_rules_t * rules, lw6sys_whd_t * shape,
 				 int *z);
 
 /* map-dup.c */
-extern lw6map_level_t *lw6map_dup (lw6map_level_t * source);
+extern lw6map_level_t *lw6map_dup (lw6map_level_t * source,
+				   lw6sys_progress_t * progress);
 
 /* map-body.c */
-extern void lw6map_body_defaults (lw6map_body_t * body, int w, int h, int d);
+extern void lw6map_body_builtin_whd (lw6map_body_t * body, int w, int h,
+				     int d);
 extern void lw6map_body_clear (lw6map_body_t * body);
+extern void lw6map_body_fix_checksum (lw6map_body_t * body);
 extern int lw6map_body_check_and_fix_holes (lw6map_body_t * body,
 					    lw6map_rules_t * rules);
 extern int lw6map_body_coord_from_texture (lw6map_level_t * level,
@@ -525,21 +568,26 @@ extern char *lw6map_to_hexa (lw6map_level_t * level);
 extern lw6map_level_t *lw6map_from_hexa (char *hexa);
 
 /* map-layer.c */
-extern void lw6map_layer_defaults (lw6map_layer_t * layer, int w, int h);
+extern void lw6map_layer_builtin_whd (lw6map_layer_t * layer, int w, int h);
 extern void lw6map_layer_clear (lw6map_layer_t * layer);
 
 /* map-level.c */
 extern lw6map_level_t *lw6map_new ();
-extern lw6map_level_t *lw6map_defaults (int w, int h, int d);
+extern lw6map_level_t *lw6map_builtin_defaults ();
+extern lw6map_level_t *lw6map_builtin_whd (int w, int h, int d);
 extern void lw6map_free (lw6map_level_t * level);
 extern int lw6map_memory_footprint (lw6map_level_t * level);
 extern char *lw6map_repr (lw6map_level_t * level);
+extern int lw6map_is_same (lw6map_level_t * level_a,
+			   lw6map_level_t * level_b);
 
 /*
  * In metadata.c
  */
 extern void lw6map_metadata_defaults (lw6map_metadata_t * metadata);
 extern void lw6map_metadata_clear (lw6map_metadata_t * metadata);
+extern int lw6map_metadata_is_same (lw6map_metadata_t * metadata_a,
+				    lw6map_metadata_t * metadata_b);
 
 /*
  * In rules.c
@@ -558,22 +606,29 @@ extern int lw6map_rules_get_bool (lw6map_rules_t * rules, char *key);
 extern int lw6map_rules_set_bool (lw6map_rules_t * rules, char *key,
 				  int value);
 extern void lw6map_rules_clear (lw6map_rules_t * rules);
+extern int lw6map_rules_is_same (lw6map_rules_t * rules_a,
+				 lw6map_rules_t * rules_b);
 
 // map-param.c
 extern void lw6map_param_defaults (lw6map_param_t * param);
 extern void lw6map_param_clear (lw6map_param_t * param);
 extern void lw6map_param_copy (lw6map_param_t * dst, lw6map_param_t * src);
 extern int lw6map_param_set (lw6map_param_t * param, char *key, char *value);
+extern int lw6map_param_is_same (lw6map_param_t * param_a,
+				 lw6map_param_t * param_b);
 
 /*
  * In style.c
  */
+extern void lw6map_style_zero (lw6map_style_t * style);
 extern void lw6map_style_defaults (lw6map_style_t * style);
 extern void lw6map_style_clear (lw6map_style_t * style);
 extern void lw6map_style_copy (lw6map_style_t * dst, lw6map_style_t * src);
 extern int lw6map_style_set (lw6map_style_t * style, char *key, char *value);
 extern char *lw6map_style_get (lw6map_style_t * style, char *key);
 extern char *lw6map_style_get_default (char *key);
+extern int lw6map_style_is_same (lw6map_style_t * style_a,
+				 lw6map_style_t * style_b);
 
 /*
  * In test.c
@@ -594,5 +649,6 @@ extern lw6sys_color_8_t lw6map_texture_get_with_body_coord (lw6map_level_t *
 extern int lw6map_texture_from_body (lw6map_texture_t * texture,
 				     lw6map_body_t * body,
 				     lw6map_color_couple_t * color);
+extern int lw6map_texture_has_alpha (lw6map_texture_t * texture);
 
 #endif /*  */
