@@ -75,7 +75,8 @@ _lw6net_const_init (int argc, char *argv[])
 	    lw6cfg_read_key_value_xml_file (const_file, read_callback,
 					    (void *)
 					    &
-					    (_lw6net_global_context->const_data));
+					    (_lw6net_global_context->
+					     const_data));
 
 	  LW6SYS_FREE (const_file);
 	}
