@@ -130,9 +130,7 @@ _lw6net_thread_vacuum ()
 		    lw6sys_assoc_get (_lw6net_global_context->threads, key);
 		  if (handler)
 		    {
-		      if ((lw6sys_thread_get_flag (handler) &
-			   _LW6NET_FLAG_VACUUM)
-			  && lw6sys_thread_is_callback_done (handler))
+		      if (lw6sys_thread_is_callback_done (handler))
 			{
 			  /*
 			   * This will call "join" automatically.
