@@ -27,13 +27,10 @@
 #include "pil.h"
 #include "pil-internal.h"
 
-#define BENCH_DURATION 10
-#define BENCH_MAP_WIDTH 400
-#define BENCH_MAP_HEIGHT 300
-#define BENCH_MAP_NB_LAYERS 1
+#define BENCH_DURATION 10000L
 #define DUMMY_INIT 0.0f
 #define DUMMY_INC 0.000001f
-#define BENCH_WORKER_SLEEP 0.001f
+#define NOP_LOOP 100000
 
 static char *bench_init_commands[] = {
   "1 1234abcd1234abcd REGISTER",
@@ -56,11 +53,22 @@ static char *bench_init_commands[] = {
 #define BENCH_NOP_COMMAND "%d 1234abcd1234abcd NOP"
 #define BENCH_ANTICIPATION_DELTA LW6MAP_RULES_DEFAULT_ROUNDS_PER_SEC
 
+void
+_lw6pil_bench_dummy_nop (float *dummy)
+{
+  int i;
+
+  for (i = 0; i < NOP_LOOP; ++i)
+    {
+      (*dummy) += DUMMY_INC;
+    }
+}
+
 static void
 do_bench (lw6pil_pilot_t * pilot, float *value)
 {
-  int64_t start_time = 0;
-  int64_t current_time = 0;
+  int64_t start_time = 0L;
+  int64_t current_time = 0L;
   float dummy = DUMMY_INIT;
   char **command;
   int last_round = -BENCH_ANTICIPATION_DELTA;
@@ -93,20 +101,11 @@ do_bench (lw6pil_pilot_t * pilot, float *value)
     }
   lw6pil_pilot_commit (pilot);
 
-  // align on an exact timestamp change
-  do
-    {
-      lw6sys_sleep (BENCH_WORKER_SLEEP);
-      dummy += DUMMY_INC;
-    }
-  while (lw6sys_timestamp () < start_time + 1);
-
   computed_reference_begin = pilot->reference.computed_rounds;
   computed_draft_begin = pilot->draft.computed_rounds;
 
   lw6sys_log (LW6SYS_LOG_INFO, _("stress start dummy=%f"), dummy);
-  while ((current_time =
-	  lw6sys_timestamp ()) < start_time + 1 + BENCH_DURATION)
+  while ((current_time = lw6sys_timestamp ()) < start_time + BENCH_DURATION)
     {
       current_round = lw6pil_pilot_get_reference_current_round (pilot);
       if (current_round - BENCH_ANTICIPATION_DELTA >= last_round)
@@ -125,7 +124,7 @@ do_bench (lw6pil_pilot_t * pilot, float *value)
 	  lw6pil_pilot_commit (pilot);
 	  last_round = current_round;
 	}
-      dummy += DUMMY_INC;
+      _lw6pil_bench_dummy_nop (&dummy);
     }
   lw6sys_log (LW6SYS_LOG_INFO, _("stress stop dummy=%f"), dummy);
 
@@ -156,8 +155,8 @@ do_bench (lw6pil_pilot_t * pilot, float *value)
 	      computed_reference_delta, computed_draft_delta);
 
   (*value) =
-    ((float) (computed_reference_delta + computed_draft_delta))
-    / (2.0f * BENCH_DURATION);
+    (((float) (computed_reference_delta + computed_draft_delta)) *
+     LW6SYS_TICKS_PER_SEC) / (2.0f * BENCH_DURATION);
 
 }
 
@@ -182,8 +181,7 @@ lw6pil_bench (float *bench_result)
   lw6pil_pilot_t *pilot = NULL;
   float value;
 
-  level =
-    lw6map_defaults (BENCH_MAP_WIDTH, BENCH_MAP_HEIGHT, BENCH_MAP_NB_LAYERS);
+  level = lw6map_builtin_defaults ();
   if (level)
     {
       level->param.rules.total_time = LW6MAP_RULES_MAX_TOTAL_TIME;
@@ -193,7 +191,7 @@ lw6pil_bench (float *bench_result)
 	  game_state = lw6ker_game_state_new (game_struct, NULL);
 	  if (game_state)
 	    {
-	      pilot = lw6pil_pilot_new (game_state, BENCH_WORKER_SLEEP, 0);
+	      pilot = lw6pil_pilot_new (game_state, 0, NULL);
 	      if (pilot)
 		{
 		  /*
