@@ -32,8 +32,12 @@
 static int
 is_spc (char c)
 {
-  //return ((c==' ') || (c<32) || (c>127));
-  return (c <= 32 || c > 127);
+  /*
+   * Because c is of type char, comparing it to 32 is enough, it will
+   * also trap chars > 127 (accents & the rest), in fact we just want
+   * to ignore those, and use strict ASCII.
+   */
+  return (((signed char) c) <= 32);
 }
 
 static void
