@@ -43,7 +43,7 @@ _lw6pil_compute_thread_func (lw6pil_worker_t * worker)
       commands = NULL;
       command = NULL;
 
-      lw6sys_mutex_lock (worker->commands_mutex);
+      lw6sys_spinlock_lock (worker->commands_spinlock);
       if (worker->commands && !lw6sys_list_is_empty (worker->commands))
 	{
 	  commands = worker->commands;
@@ -54,7 +54,7 @@ _lw6pil_compute_thread_func (lw6pil_worker_t * worker)
 	      lw6sys_log (LW6SYS_LOG_WARNING, _("worker->commands is NULL"));
 	    }
 	}
-      lw6sys_mutex_unlock (worker->commands_mutex);
+      lw6sys_spinlock_unlock (worker->commands_spinlock);
 
       if (commands)
 	{
@@ -83,7 +83,7 @@ _lw6pil_compute_thread_func (lw6pil_worker_t * worker)
 		      spread_thread =
 			lw6sys_thread_create ((lw6sys_thread_callback_func_t)
 					      _lw6pil_spread_thread_func,
-					      NULL, (void *) &spread_data, 0);
+					      NULL, (void *) &spread_data);
 		      lw6ker_game_state_do_move (worker->game_state,
 						 team_mask_even);
 		      if (spread_thread)
@@ -103,7 +103,7 @@ _lw6pil_compute_thread_func (lw6pil_worker_t * worker)
 		      spread_thread =
 			lw6sys_thread_create ((lw6sys_thread_callback_func_t)
 					      _lw6pil_spread_thread_func,
-					      NULL, (void *) &spread_data, 0);
+					      NULL, (void *) &spread_data);
 		      lw6ker_game_state_do_move (worker->game_state,
 						 team_mask_odd);
 		      if (spread_thread)
@@ -124,15 +124,22 @@ _lw6pil_compute_thread_func (lw6pil_worker_t * worker)
 		      lw6ker_game_state_do_round (worker->game_state);
 		    }
 		  worker->current_round++;
-		  if (worker->current_round !=
-		      lw6ker_game_state_get_rounds (worker->game_state))
+		  if (lw6ker_game_state_is_over (worker->game_state))
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _
-				  ("possible race condition, worker and game_state do not report the same round number (%d vs %d)"),
-				  worker->current_round,
-				  lw6ker_game_state_get_rounds
-				  (worker->game_state));
+		      worker->over = 1;
+		    }
+		  else
+		    {
+		      if (worker->current_round !=
+			  lw6ker_game_state_get_rounds (worker->game_state))
+			{
+			  lw6sys_log (LW6SYS_LOG_WARNING,
+				      _
+				      ("possible race condition, worker and game_state do not report the same round number (%d vs %d)"),
+				      worker->current_round,
+				      lw6ker_game_state_get_rounds
+				      (worker->game_state));
+			}
 		    }
 		  worker->computed_rounds++;
 		  lw6sys_mutex_unlock (worker->compute_mutex);
@@ -162,7 +169,7 @@ _lw6pil_compute_thread_func (lw6pil_worker_t * worker)
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG, _("worker idle"));
-	  lw6sys_sleep (worker->sleep);
+	  lw6sys_idle ();
 	}
     }
 }
