@@ -31,6 +31,9 @@ typedef struct _lw6pil_spread_data_s
   u_int32_t team_mask;
 } _lw6pil_spread_data_t;
 
+/* pil-bench.c */
+extern void _lw6pil_bench_dummy_nop (float *dummy);
+
 /* pil-command.c */
 extern int _lw6pil_command_sort_callback (lw6sys_list_t ** list_a,
 					  lw6sys_list_t ** list_b);
@@ -45,7 +48,7 @@ extern void _lw6pil_spread_thread_func (_lw6pil_spread_data_t * spread_data);
 /* pil-worker.c */
 extern int _lw6pil_worker_init (lw6pil_worker_t * worker,
 				lw6ker_game_state_t * game_state,
-				float sleep);
+				lw6sys_progress_t * progress);
 extern int _lw6pil_worker_quit (lw6pil_worker_t * worker);
 
 #endif
