@@ -41,8 +41,8 @@ static u_int32_t seq_id = 0;
  * lw6pil_pilot_new
  *
  * @game_state: the game state we're going to work on
- * @sleep: sleep latency, in seconds, typically very low (0.002)
- * @ticks: the current ticks (1000 ticks per sec, used to calibrate)
+ * @timestamp: the current ticks (1000 ticks per sec, used to calibrate)
+ * @progress: object used to show the advancement of the process
  *
  * Initializes a 'pilot' object, this object is responsible for
  * interpreting messages, transform them into low-level 'ker' module
@@ -51,10 +51,20 @@ static u_int32_t seq_id = 0;
  * Return value: a working pilot object. May be NULL on memory failure.
  */
 lw6pil_pilot_t *
-lw6pil_pilot_new (lw6ker_game_state_t * game_state, float sleep, int ticks)
+lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t timestamp,
+		  lw6sys_progress_t * progress)
 {
   lw6pil_pilot_t *ret = NULL;
   int ok = 0;
+  lw6sys_progress_t progress_level;
+  lw6sys_progress_t progress_game_struct;
+  lw6sys_progress_t progress_game_state;
+  lw6sys_progress_t progress_reference;
+  lw6sys_progress_t progress_draft;
+
+  lw6sys_progress_split5 (&progress_level, &progress_game_struct,
+			  &progress_game_state, &progress_reference,
+			  &progress_draft, progress);
 
   ret = (lw6pil_pilot_t *) LW6SYS_CALLOC (sizeof (lw6pil_pilot_t));
   if (ret)
@@ -66,7 +76,7 @@ lw6pil_pilot_new (lw6ker_game_state_t * game_state, float sleep, int ticks)
 	}
       ret->last_commit_round = -1;
       ret->last_sync_draft_from_reference = -1;
-      lw6pil_pilot_calibrate (ret, ticks,
+      lw6pil_pilot_calibrate (ret, timestamp,
 			      lw6ker_game_state_get_rounds (game_state));
 
       ret->replay =
@@ -79,17 +89,21 @@ lw6pil_pilot_new (lw6ker_game_state_t * game_state, float sleep, int ticks)
 	      ret->unverified_queue = lw6sys_list_new (lw6sys_free_callback);
 	      if (ret->unverified_queue)
 		{
-		  ret->level = lw6map_dup (game_state->game_struct->level);
+		  ret->level =
+		    lw6map_dup (game_state->game_struct->level,
+				&progress_level);
 		  if (ret->level)
 		    {
 		      ret->game_struct =
-			lw6ker_game_struct_dup (game_state->game_struct);
+			lw6ker_game_struct_dup (game_state->game_struct,
+						&progress_game_struct);
 		      if (ret->game_struct)
 			{
 			  if (ret->level)
 			    {
 			      ret->backup =
-				lw6ker_game_state_dup (game_state);
+				lw6ker_game_state_dup (game_state,
+						       &progress_game_state);
 			      if (ret->backup)
 				{
 				  /*
@@ -102,12 +116,15 @@ lw6pil_pilot_new (lw6ker_game_state_t * game_state, float sleep, int ticks)
 				  lw6ker_game_struct_point_to
 				    (ret->game_struct, ret->level);
 				  lw6ker_game_state_point_to (ret->backup,
-							      ret->game_struct);
+							      ret->
+							      game_struct);
 				  if (_lw6pil_worker_init
-				      (&(ret->reference), ret->backup, sleep))
+				      (&(ret->reference), ret->backup,
+				       &progress_reference))
 				    {
 				      if (_lw6pil_worker_init
-					  (&(ret->draft), ret->backup, sleep))
+					  (&(ret->draft), ret->backup,
+					   &progress_draft))
 					{
 					  ok = 1;
 					}
@@ -266,7 +283,7 @@ commit_reference (lw6pil_pilot_t * pilot)
    */
   if (!lw6sys_list_is_empty (pilot->verified_queue))
     {
-      lw6sys_mutex_lock (pilot->reference.commands_mutex);
+      lw6sys_spinlock_lock (pilot->reference.commands_spinlock);
       while (pilot->verified_queue
 	     && (command_text =
 		 lw6sys_list_pop_front (&(pilot->verified_queue))) != NULL)
@@ -293,7 +310,7 @@ commit_reference (lw6pil_pilot_t * pilot)
 		      _("verified_queue should be NULL, but isn't"));
 	}
       pilot->verified_queue = lw6sys_list_new (lw6sys_free_callback);
-      lw6sys_mutex_unlock (pilot->reference.commands_mutex);
+      lw6sys_spinlock_unlock (pilot->reference.commands_spinlock);
       if (min_round >= 0)
 	{
 	  if (min_round <= pilot->last_commit_round)
@@ -366,7 +383,7 @@ commit_draft (lw6pil_pilot_t * pilot)
 	{
 	  sync_draft_from_reference (pilot);
 
-	  lw6sys_mutex_lock (pilot->draft.commands_mutex);
+	  lw6sys_spinlock_lock (pilot->draft.commands_spinlock);
 	  replay = lw6sys_list_new ((lw6sys_free_func_t) lw6pil_command_free);
 	  if (replay)
 	    {
@@ -401,7 +418,7 @@ commit_draft (lw6pil_pilot_t * pilot)
 	      pilot->replay = replay;
 	      replay = NULL;
 	    }
-	  lw6sys_mutex_unlock (pilot->draft.commands_mutex);
+	  lw6sys_spinlock_unlock (pilot->draft.commands_spinlock);
 	}
     }
 
@@ -450,6 +467,30 @@ lw6pil_pilot_make_backup (lw6pil_pilot_t * pilot)
   return ret;
 }
 
+/**
+ * lw6pil_pilot_can_sync
+ *
+ * @target: the target game_state we would sync on
+ * @pilot: the object to perform the backup on
+ *
+ * Tests wether sync functions are callable with a given game state.
+ * It verifies if the internal game_state and the target look the same.
+ *
+ * Return value: 1 if sync functions can be called, 0 if not.
+ */
+int
+lw6pil_pilot_can_sync (lw6ker_game_state_t * target, lw6pil_pilot_t * pilot)
+{
+  int ret = 1;
+
+  ret = ret && lw6ker_game_state_can_sync (target, pilot->backup);
+  ret = ret
+    && lw6ker_game_state_can_sync (target, pilot->reference.game_state);
+  ret = ret && lw6ker_game_state_can_sync (target, pilot->draft.game_state);
+
+  return ret;
+}
+
 /**
  * lw6pil_pilot_sync_from_backup
  *
@@ -511,20 +552,24 @@ lw6pil_pilot_sync_from_reference (lw6ker_game_state_t * target,
  *
  * @target: the game_state structure which will get the informations.
  * @pilot: the object to get informations from.
+ * @dirty_read: wether to allow dirty read or not
  *
  * Gets the informations from the pilot object, not being worried about
  * game consistency, this one will just return the latest version available.
  * It might even be in an inconsistent state, the position could reflect
  * a position which will never exist. Still, the data returned will not
- * correspond to a half-spread or half-moved game_state. The data has at
- * least some basic consistency and getting this does require some mutex
- * lock, however wait time should be fairly small (max. a round).
+ * correspond to a half-spread or half-moved game_state if dirty_read
+ * is set to 0. In this case the data has at least some basic consistency 
+ * and getting this does require some mutex lock, however wait time should 
+ * be fairly small (max. a round). But, in a general manner, this function
+ * is only used for display, and we do not care much if there's a small
+ * glitch, we prefer fast & smooth display.
  *
  * Return value: 1 if OK, 0 if not.
  */
 int
 lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
-			      lw6pil_pilot_t * pilot)
+			      lw6pil_pilot_t * pilot, int dirty_read)
 {
   int ret = 0;
   int draft_rounds;
@@ -535,8 +580,11 @@ lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
 
   if (lw6pil_pilot_get_max_round (pilot) > current_round)
     {
-      lw6sys_mutex_lock (pilot->draft.compute_mutex);
-      lw6sys_mutex_lock (pilot->reference.compute_mutex);
+      if (dirty_read == LW6PIL_DIRTY_READ_NEVER)
+	{
+	  lw6sys_mutex_lock (pilot->draft.compute_mutex);
+	  lw6sys_mutex_lock (pilot->reference.compute_mutex);
+	}
       if (lw6pil_pilot_get_max_round (pilot) > current_round)
 	{
 	  draft_rounds =
@@ -562,9 +610,11 @@ lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
 	{
 	  ret = 1;
 	}
-
-      lw6sys_mutex_unlock (pilot->reference.compute_mutex);
-      lw6sys_mutex_unlock (pilot->draft.compute_mutex);
+      if (dirty_read == LW6PIL_DIRTY_READ_NEVER)
+	{
+	  lw6sys_mutex_unlock (pilot->reference.compute_mutex);
+	  lw6sys_mutex_unlock (pilot->draft.compute_mutex);
+	}
     }
   else
     {
@@ -574,6 +624,44 @@ lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
   return ret;
 }
 
+/**
+ * lw6pil_pilot_dirty_read
+ *
+ * @pilot: the object to get informations from.
+ *
+ * Returns a direct access to the most up-to-date game_state, without
+ * locking anything whatsoever. This is clearly to implement a dirty read
+ * mode as the name of the function suggests.
+ *
+ * Return value: 1 if OK, 0 if not.
+ */
+lw6ker_game_state_t *
+lw6pil_pilot_dirty_read (lw6pil_pilot_t * pilot)
+{
+  lw6ker_game_state_t *ret = NULL;
+  int draft_rounds = 0;
+  int reference_rounds = 0;
+
+  draft_rounds = lw6ker_game_state_get_rounds (pilot->draft.game_state);
+  reference_rounds =
+    lw6ker_game_state_get_rounds (pilot->reference.game_state);
+  if (draft_rounds > reference_rounds)
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("dirty read using draft round=%d/%d"),
+		  draft_rounds, reference_rounds);
+      ret = pilot->draft.game_state;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("dirty read using reference round=%d/%d"),
+		  reference_rounds, draft_rounds);
+      ret = pilot->reference.game_state;
+    }
+
+  return ret;
+}
+
 /**
  * lw6pil_pilot_repr
  *
@@ -613,7 +701,7 @@ lw6pil_pilot_repr (lw6pil_pilot_t * pilot)
  * lw6pil_pilot_calibrate
  *
  * @pilot: the object to calibrate
- * @ticks: the current ticks setting (1000 ticks per second)
+ * @timestamp: the current ticks setting (1000 ticks per second)
  * @round: the round expected to be returned with this ticks value
  *
  * Calibrates the pilot, that is, initializes it so that subsequent calls
@@ -622,9 +710,9 @@ lw6pil_pilot_repr (lw6pil_pilot_t * pilot)
  * Return value: none.
  */
 void
-lw6pil_pilot_calibrate (lw6pil_pilot_t * pilot, int ticks, int round)
+lw6pil_pilot_calibrate (lw6pil_pilot_t * pilot, int64_t timestamp, int round)
 {
-  pilot->calibrate_ticks = ticks;
+  pilot->calibrate_ticks = timestamp;
   pilot->calibrate_round = round;
 }
 
@@ -666,7 +754,7 @@ lw6pil_pilot_slow_down (lw6pil_pilot_t * pilot, int round_dec)
  * lw6pil_pilot_get_next_round
  *
  * @pilot: the object to query
- * @ticks: the current ticks setting (1000 ticks per second)
+ * @timestamp: the current ticks setting (1000 ticks per second)
  *
  * Returns the round one should use to generate new events/commands
  * at a given time (given in ticks).
@@ -674,14 +762,14 @@ lw6pil_pilot_slow_down (lw6pil_pilot_t * pilot, int round_dec)
  * Return value: none.
  */
 int
-lw6pil_pilot_get_next_round (lw6pil_pilot_t * pilot, int ticks)
+lw6pil_pilot_get_next_round (lw6pil_pilot_t * pilot, int64_t timestamp)
 {
   int ret = 0;
   int64_t delta;
 
-  delta = ticks - pilot->calibrate_ticks;
+  delta = timestamp - pilot->calibrate_ticks;
   delta *= (int64_t) pilot->backup->game_struct->rules.rounds_per_sec;
-  delta /= 1000;
+  delta /= LW6SYS_TICKS_PER_SEC;
   ret = pilot->calibrate_round + (int) delta;
 
   return ret;
@@ -774,3 +862,22 @@ lw6pil_pilot_get_max_round (lw6pil_pilot_t * pilot)
 
   return ret;
 }
+
+/**
+ * lw6pil_pilot_is_over
+ *
+ * @pilot: the object to query
+ *
+ * Tells wether the game is over or not.
+ *
+ * Return value: 1 if over, 0 if not
+ */
+int
+lw6pil_pilot_is_over (lw6pil_pilot_t * pilot)
+{
+  int ret = 0;
+
+  ret = pilot->reference.over ? 1 : 0;
+
+  return ret;
+}
