@@ -30,13 +30,13 @@
 #define TEST_MAP_WIDTH 45
 #define TEST_MAP_HEIGHT 15
 #define TEST_MAP_NB_LAYERS 7
-#define TEST_WORKER_SLEEP 0.02f
 #define TEST_CYCLE 0.5f
 #define TEST_NB_PILOTS 3
 #define TEST_SYNC_COMMAND_I 10
 #define TEST_BACKUP_ROUND 70
-#define TEST_BACKUP_CHECKSUM 0x0cf2d466
-#define TEST_CALIBRATE_TICKS 12345
+#define TEST_BACKUP_CHECKSUM 0xcdbb7f42
+#define TEST_CALIBRATE_TICKS1 12345
+#define TEST_CALIBRATE_TICKS2 23456
 #define TEST_COORDS_NB 5
 #define TEST_COORDS_W 100
 #define TEST_COORDS_H 50
@@ -264,7 +264,8 @@ test_pilot ()
     u_int32_t checksum = 0;
 
     level =
-      lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			  TEST_MAP_NB_LAYERS);
     if (level)
       {
 	/*
@@ -278,7 +279,7 @@ test_pilot ()
 	    game_state = lw6ker_game_state_new (game_struct, NULL);
 	    if (game_state)
 	      {
-		pilot = lw6pil_pilot_new (game_state, TEST_WORKER_SLEEP, 0);
+		pilot = lw6pil_pilot_new (game_state, 0, NULL);
 		if (pilot)
 		  {
 		    repr = lw6pil_pilot_repr (pilot);
@@ -318,6 +319,10 @@ test_pilot ()
 
 			    if (i == TEST_SYNC_COMMAND_I)
 			      {
+				lw6sys_log (LW6SYS_LOG_NOTICE,
+					    _("can_sync: %d"),
+					    lw6pil_pilot_can_sync (game_state,
+								   pilot));
 				lw6pil_pilot_sync_from_reference (game_state,
 								  pilot);
 				print_game_state (game_state, _("reference"));
@@ -348,11 +353,13 @@ test_pilot ()
 				    checksum =
 				      lw6ker_game_state_checksum (game_state);
 				  }
+				print_game_state (lw6pil_pilot_dirty_read
+						  (pilot), _("dirty read"));
 			      }
 			    else
 			      {
 				lw6pil_pilot_sync_from_draft (game_state,
-							      pilot);
+							      pilot, i % 2);
 				print_game_state (game_state, _("draft"));
 			      }
 			  }
@@ -372,10 +379,19 @@ test_pilot ()
 			lw6sys_sleep (TEST_CYCLE);
 
 			lw6sys_log (LW6SYS_LOG_NOTICE,
-				    _("next_round for ticks %d is %d"),
-				    TEST_CALIBRATE_TICKS,
+				    _("next_round for ticks %"
+				      LW6SYS_PRINTF_LL "d is %d"),
+				    (int64_t) TEST_CALIBRATE_TICKS1,
+				    (int64_t)
 				    lw6pil_pilot_get_next_round (pilot,
-								 TEST_CALIBRATE_TICKS));
+								 TEST_CALIBRATE_TICKS1));
+			lw6sys_log (LW6SYS_LOG_NOTICE,
+				    _("next_round for ticks %"
+				      LW6SYS_PRINTF_LL "d is %d"),
+				    (int64_t) TEST_CALIBRATE_TICKS2,
+				    (int64_t)
+				    lw6pil_pilot_get_next_round (pilot,
+								 TEST_CALIBRATE_TICKS2));
 			lw6sys_log (LW6SYS_LOG_NOTICE,
 				    _("last_commit_round=%d"),
 				    lw6pil_pilot_get_last_commit_round
