@@ -29,25 +29,25 @@
 
 int
 _lw6pil_worker_init (lw6pil_worker_t * worker,
-		     lw6ker_game_state_t * game_state, float sleep)
+		     lw6ker_game_state_t * game_state,
+		     lw6sys_progress_t * progress)
 {
   int ret = 0;
 
   memset (worker, 0, sizeof (lw6pil_worker_t));
   worker->run = 1;
-  worker->sleep = sleep;
   worker->target_round = lw6ker_game_state_get_rounds (game_state);
   worker->current_round = worker->current_round;
   worker->computed_rounds = 0;
-  worker->game_state = lw6ker_game_state_dup (game_state);
+  worker->game_state = lw6ker_game_state_dup (game_state, progress);
   if (worker->game_state)
     {
       worker->commands =
 	lw6sys_list_new ((lw6sys_free_func_t) lw6pil_command_free);
       if (worker->commands)
 	{
-	  worker->commands_mutex = lw6sys_mutex_create ();
-	  if (worker->commands_mutex)
+	  worker->commands_spinlock = lw6sys_spinlock_create ();
+	  if (worker->commands_spinlock)
 	    {
 	      worker->compute_mutex = lw6sys_mutex_create ();
 	      if (worker->compute_mutex)
@@ -60,7 +60,7 @@ _lw6pil_worker_init (lw6pil_worker_t * worker,
 					      _lw6pil_compute_thread_func,
 					      (lw6sys_thread_callback_func_t)
 					      _lw6pil_compute_thread_join,
-					      (void *) worker, 0);
+					      (void *) worker);
 		      if (worker->compute_thread)
 			{
 			  ret = 1;
@@ -89,9 +89,9 @@ _lw6pil_worker_quit (lw6pil_worker_t * worker)
     {
       lw6sys_thread_join (worker->compute_thread);
     }
-  if (worker->commands_mutex)
+  if (worker->commands_spinlock)
     {
-      lw6sys_mutex_destroy (worker->commands_mutex);
+      lw6sys_spinlock_destroy (worker->commands_spinlock);
     }
   if (worker->compute_mutex)
     {
