@@ -35,6 +35,10 @@
 #define LW6PIL_COMMAND_TEXT_REMOVE "REMOVE"
 #define LW6PIL_COMMAND_TEXT_UNREGISTER "UNREGISTER"
 
+#define LW6PIL_DIRTY_READ_NEVER 0
+#define LW6PIL_DIRTY_READ_SYNC_ONLY 1
+#define LW6PIL_DIRTY_READ_ALWAYS 2
+
 typedef enum lw6pil_command_code_e
 {
   LW6PIL_COMMAND_CODE_INVALID = 0,
@@ -83,14 +87,14 @@ typedef struct lw6pil_command_s
 typedef struct lw6pil_worker_s
 {
   int run;
-  float sleep;
   int current_round;
   int target_round;
   int computed_rounds;
+  int over;
   void *compute_thread;
   void *global_mutex;
   void *compute_mutex;
-  void *commands_mutex;
+  void *commands_spinlock;
   lw6ker_game_state_t *game_state;
   lw6sys_list_t *commands;
 } lw6pil_worker_t;
@@ -98,7 +102,7 @@ typedef struct lw6pil_worker_s
 typedef struct lw6pil_pilot_s
 {
   u_int32_t id;
-  int calibrate_ticks;
+  int64_t calibrate_ticks;
   int calibrate_round;
   lw6map_level_t *level;
   lw6ker_game_struct_t *game_struct;
@@ -131,28 +135,35 @@ extern void lw6pil_coords_fix (lw6map_rules_t * rules, lw6sys_whd_t * shape,
 
 /* pil-pilot.c */
 extern lw6pil_pilot_t *lw6pil_pilot_new (lw6ker_game_state_t * game_state,
-					 float sleep, int ticks);
+					 int64_t timestamp,
+					 lw6sys_progress_t * progress);
 extern void lw6pil_pilot_free (lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_send_command (lw6pil_pilot_t * pilot,
 				      char *command_text, int verified);
 extern int lw6pil_pilot_commit (lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_make_backup (lw6pil_pilot_t * pilot);
+extern int lw6pil_pilot_can_sync (lw6ker_game_state_t * target,
+				  lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_sync_from_backup (lw6ker_game_state_t * target,
 					  lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_sync_from_reference (lw6ker_game_state_t * target,
 					     lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
-					 lw6pil_pilot_t * pilot);
+					 lw6pil_pilot_t * pilot,
+					 int dirty_read);
+extern lw6ker_game_state_t *lw6pil_pilot_dirty_read (lw6pil_pilot_t * pilot);
 extern char *lw6pil_pilot_repr (lw6pil_pilot_t * pilot);
-extern void lw6pil_pilot_calibrate (lw6pil_pilot_t * pilot, int ticks,
+extern void lw6pil_pilot_calibrate (lw6pil_pilot_t * pilot, int64_t timestamp,
 				    int round);
 extern void lw6pil_pilot_speed_up (lw6pil_pilot_t * pilot, int round_inc);
 extern void lw6pil_pilot_slow_down (lw6pil_pilot_t * pilot, int round_dec);
-extern int lw6pil_pilot_get_next_round (lw6pil_pilot_t * pilot, int ticks);
+extern int lw6pil_pilot_get_next_round (lw6pil_pilot_t * pilot,
+					int64_t timestamp);
 extern int lw6pil_pilot_get_last_commit_round (lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_get_reference_target_round (lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_get_reference_current_round (lw6pil_pilot_t * pilot);
 extern int lw6pil_pilot_get_max_round (lw6pil_pilot_t * pilot);
+extern int lw6pil_pilot_is_over (lw6pil_pilot_t * pilot);
 
 /* pil-test.c */
 extern int lw6pil_test ();
