@@ -105,6 +105,21 @@ _quit (void *snd_context)
     }
 }
 
+static char *
+_repr (void *snd_context, u_int32_t id)
+{
+  char *ret = NULL;
+  _mod_csound_context_t *mod_csound_context =
+    (_mod_csound_context_t *) snd_context;
+
+  if (mod_csound_context)
+    {
+      ret = _mod_csound_repr (mod_csound_context, id);
+    }
+
+  return ret;
+}
+
 lw6sys_module_pedigree_t *
 mod_csound_get_pedigree ()
 {
@@ -148,6 +163,7 @@ mod_csound_create_backend ()
       backend->set_sound_volume = _set_sound_volume;
       backend->set_music_volume = _set_music_volume;
       backend->quit = _quit;
+      backend->repr = _repr;
     }
 
   return backend;
