@@ -64,6 +64,12 @@ extern int _mod_csound_path_init (_mod_csound_context_t *
 				  csound_context, int argc, char *argv[]);
 extern void _mod_csound_path_quit (_mod_csound_context_t * csound_context);
 
+/*
+ * In repr.c
+ */
+extern char *_mod_csound_repr (_mod_csound_context_t * csound_context,
+			       u_int32_t id);
+
 /*
  * In setup.c
  */
