@@ -101,6 +101,20 @@ _quit (void *snd_context)
     }
 }
 
+static char *
+_repr (void *snd_context, u_int32_t id)
+{
+  char *ret = NULL;
+  _mod_ogg_context_t *mod_ogg_context = (_mod_ogg_context_t *) snd_context;
+
+  if (mod_ogg_context)
+    {
+      ret = _mod_ogg_repr (mod_ogg_context, id);
+    }
+
+  return ret;
+}
+
 lw6sys_module_pedigree_t *
 mod_ogg_get_pedigree ()
 {
@@ -144,6 +158,7 @@ mod_ogg_create_backend ()
       backend->set_sound_volume = _set_sound_volume;
       backend->set_music_volume = _set_music_volume;
       backend->quit = _quit;
+      backend->repr = _repr;
     }
 
   return backend;
