@@ -92,6 +92,11 @@ extern int _mod_ogg_path_init (_mod_ogg_context_t * ogg_context,
 			       int argc, char *argv[]);
 extern void _mod_ogg_path_quit (_mod_ogg_context_t * ogg_context);
 
+/*
+ * In repr.c
+ */
+extern char *_mod_ogg_repr (_mod_ogg_context_t * gfx_context, u_int32_t id);
+
 /*
  * In setup.c
  */
