@@ -33,6 +33,7 @@ _mod_ogg_init (int argc, char *argv[], float sound_volume, float music_volume)
   _mod_ogg_context_t *snd_context = NULL;
   int sdl_ok = 1;
   int ok = 0;
+  SDL_version version;
 
   lw6sys_log (LW6SYS_LOG_INFO,
 	      _("ogg init volume=%01.2f/%01.2f"), sound_volume, music_volume);
@@ -43,15 +44,30 @@ _mod_ogg_init (int argc, char *argv[], float sound_volume, float music_volume)
     {
       if (_mod_ogg_path_init (snd_context, argc, argv))
 	{
+	  memset (&version, 0, sizeof (SDL_version));
+	  SDL_VERSION (&version);
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _("SDL header version when compiled %u.%u.%u"),
+		      version.major, version.minor, version.patch);
+	  version = *SDL_Linked_Version ();
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _("SDL linked version now at runtime %u.%u.%u"),
+		      version.major, version.minor, version.patch);
+
 	  _mod_ogg_load_consts (snd_context);
 
 	  if (lw6sys_sdl_register ())
 	    {
-	      sdl_ok = !SDL_Init (0);
+	      sdl_ok = !SDL_Init (SDL_INIT_EVENTTHREAD);
+	    }
+
+	  if (!SDL_WasInit (SDL_INIT_EVENTTHREAD))
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _
+			  ("unable to start SDL event thread, using poll() function"));
 	    }
 
-	  sdl_ok = sdl_ok && (SDL_WasInit (SDL_INIT_TIMER)
-			      || !SDL_InitSubSystem (SDL_INIT_TIMER));
 	  sdl_ok = sdl_ok && (SDL_WasInit (SDL_INIT_AUDIO)
 			      || !SDL_InitSubSystem (SDL_INIT_AUDIO));
 
@@ -106,7 +122,6 @@ _mod_ogg_quit (_mod_ogg_context_t * snd_context)
   _mod_ogg_unload_sounds (snd_context);
 
   SDL_QuitSubSystem (SDL_INIT_AUDIO);
-  SDL_QuitSubSystem (SDL_INIT_TIMER);
 
   if (lw6sys_sdl_unregister ())
     {
