@@ -138,8 +138,15 @@ lw6snd_quit (lw6snd_backend_t * backend)
 
   if (backend->quit)
     {
-      backend->quit (backend->snd_context);
-      backend->snd_context = NULL;
+      /*
+       * It's important to check that backend is not NULL for
+       * quit can *really* be called several times on the same backend
+       */
+      if (backend->snd_context)
+	{
+	  backend->quit (backend->snd_context);
+	  backend->snd_context = NULL;
+	}
     }
   else
     {
@@ -148,3 +155,24 @@ lw6snd_quit (lw6snd_backend_t * backend)
 
   LW6SYS_BACKEND_FUNCTION_END;
 }
+
+char *
+lw6snd_repr (lw6snd_backend_t * backend)
+{
+  char *ret = NULL;
+
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->repr)
+    {
+      ret = backend->repr (backend->snd_context, backend->id);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+
+  return ret;
+}
