@@ -39,7 +39,18 @@ test_init (lw6snd_backend_t * backend)
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
+    char *repr = NULL;
+
     ret = ret && lw6snd_init (backend, TEST_SOUND_VOLUME, TEST_MUSIC_VOLUME);
+    if (ret)
+      {
+	repr = lw6snd_repr (backend);
+	if (repr)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("snd repr is \"%s\""), repr);
+	    LW6SYS_FREE (repr);
+	  }
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
