@@ -60,8 +60,15 @@ lw6srv_quit (lw6srv_backend_t * backend)
 
   if (backend->quit)
     {
-      backend->quit (backend->srv_context);
-      backend->srv_context = NULL;
+      /*
+       * It's important to check that backend is not NULL for
+       * quit can *really* be called several times on the same backend
+       */
+      if (backend->srv_context)
+	{
+	  backend->quit (backend->srv_context);
+	  backend->srv_context = NULL;
+	}
     }
   else
     {
