@@ -26,6 +26,7 @@
 
 #include <string.h>
 #include <unistd.h>
+#include <sys/time.h>
 
 #include "sys.h"
 #include "sys-internal.h"
@@ -36,41 +37,74 @@
 #define BAZOOKA_ERASER_REALLOC_2 'R'
 #define BAZOOKA_ERASER_FREE 'F'
 
+#define BAZOOKA_MODULO_MUL 9
+#define BAZOOKA_MODULO_DIV 10
+
 static int bazooka_size = 0;
 static _lw6sys_bazooka_t *bazooka_data = NULL;
-static void *bazooka_mutex = NULL;
+static void *bazooka_spinlock = NULL;
 static int bazooka_malloc_counter = 0;
 static int bazooka_free_counter = 0;
+static int bazooka_malloc_total = 0;
+static int bazooka_malloc_max = 0;
 static int bazooka_eraser = 1;
+static int bazooka_trustable = 1;
+
+/*
+ * The idea of this function is to provide a default index
+ * to store pointers. It avoids always starting loops at index 0
+ * and therefore wasting lots of time.
+ */
+static int
+_hash_index (void *p)
+{
+  int ret = 0;
+  u_int32_t checksum = 0;
+  u_int32_t modulo = 0;
+
+  modulo = (bazooka_size * BAZOOKA_MODULO_MUL) / BAZOOKA_MODULO_DIV;
+  if (modulo > 0)
+    {
+      checksum =
+	(lw6sys_checksum ((unsigned char *) &p, sizeof (void *))) % modulo;
+      ret = checksum;
+      if (ret < 0)
+	{
+	  ret = 0;
+	}
+    }
+
+  return ret;
+}
 
 static void
 bazooka_lock ()
 {
-  if (bazooka_mutex)
+  if (bazooka_spinlock)
     {
-      lw6sys_mutex_lock (bazooka_mutex);
+      lw6sys_spinlock_lock (bazooka_spinlock);
     }
 }
 
 static void
 bazooka_unlock ()
 {
-  if (bazooka_mutex)
+  if (bazooka_spinlock)
     {
-      lw6sys_mutex_unlock (bazooka_mutex);
+      lw6sys_spinlock_unlock (bazooka_spinlock);
     }
 }
 
 static void
-bazooka_destroy_mutex ()
+bazooka_destroy_spinlock ()
 {
-  void *tmp_mutex;
+  void *tmp_spinlock;
 
-  tmp_mutex = bazooka_mutex;
-  bazooka_mutex = NULL;
-  if (tmp_mutex)
+  tmp_spinlock = bazooka_spinlock;
+  bazooka_spinlock = NULL;
+  if (tmp_spinlock)
     {
-      lw6sys_mutex_destroy (tmp_mutex);
+      lw6sys_spinlock_destroy (tmp_spinlock);
     }
 }
 
@@ -86,11 +120,25 @@ bazooka_free_data ()
 }
 
 static void
+_big_cleanup ()
+{
+  if (bazooka_size > 0)
+    {
+      memset (bazooka_data, 0, bazooka_size * sizeof (_lw6sys_bazooka_t));
+      bazooka_trustable = 0;
+    }
+}
+
+static int
 bazooka_register_malloc (char *ptr, int size, char *file, int line, int erase)
 {
+  int ret = 1;
+
 #ifndef LW6_OPTIMIZE
   bazooka_lock ();
   bazooka_malloc_counter++;
+  bazooka_malloc_total++;
+  bazooka_malloc_max = lw6sys_max (bazooka_malloc_max, bazooka_malloc_total);
   if (bazooka_data)
     {
       int i;
@@ -101,7 +149,7 @@ bazooka_register_malloc (char *ptr, int size, char *file, int line, int erase)
 	  memset (ptr, BAZOOKA_ERASER_MALLOC, size);
 	}
 
-      for (i = 0; i < bazooka_size; ++i)
+      for (i = _hash_index (ptr); i < bazooka_size; ++i)
 	{
 	  if (bazooka_data[i].ptr == NULL)
 	    {
@@ -126,12 +174,13 @@ bazooka_register_malloc (char *ptr, int size, char *file, int line, int erase)
 	}
       if (i == bazooka_size)
 	{
-	  // OK, we're full, big cleanup...
-	  memset (bazooka_data, 0, bazooka_size * sizeof (_lw6sys_bazooka_t));
+	  _big_cleanup ();
 	}
     }
   bazooka_unlock ();
 #endif
+
+  return ret;
 }
 
 static void
@@ -140,10 +189,12 @@ report_line (_lw6sys_bazooka_t * bazooka)
   _lw6sys_bazooka_t local_bazooka;
   int sample_int = 0;
   char sample_str[_LW6SYS_BAZOOKA_SAMPLE_SIZE];
+  void *sample_void = NULL;
   char *pos;
-  char ctime_buf[_LW6SYS_LOG_CTIME_BUF_SIZE];
-  char *ctime_ret = NULL;
-  time_t t;
+  int64_t i_when;
+  time_t t_when;
+  struct tm tm_when;
+  struct tm *tm_ret = NULL;
 
   // make a local copy, log functions can modify our data...
   memcpy (&local_bazooka, bazooka, sizeof (_lw6sys_bazooka_t));
@@ -155,7 +206,8 @@ report_line (_lw6sys_bazooka_t * bazooka)
 	      lw6sys_min (local_bazooka.size - 1,
 			  _LW6SYS_BAZOOKA_SAMPLE_SIZE - 1));
     }
-  sample_int = *((int *) sample_str);
+  sample_void = (void *) sample_str;
+  sample_int = *((int *) sample_void);
   for (pos = sample_str; *pos; pos++)
     {
       // get rid of stange system characters
@@ -165,17 +217,23 @@ report_line (_lw6sys_bazooka_t * bazooka)
 	}
     }
 
-  t = time (NULL);
-  ctime_ret = ctime_r (&t, ctime_buf);
-  if (ctime_ret == ctime_buf)
-    {
-      ctime_buf[_LW6SYS_LOG_CTIME_ZERO] = '\0';
+  memset (&t_when, 0, sizeof (time_t));
+  memset (&tm_when, 0, sizeof (struct tm));
+  i_when = local_bazooka.timestamp;
+  t_when = i_when / LW6SYS_TICKS_PER_SEC;;
+  tm_ret = localtime_r (&t_when, &tm_when);
 
+  if (tm_ret == &tm_when)
+    {
       lw6sys_log (LW6SYS_LOG_NOTICE,
 		  _
-		  ("memory bazooka found unfreed data ptr=%p size=%d file:line=\"%s:%d\" time=\"%s\" sample_int=%d sample_str=\"%s\""),
+		  ("memory bazooka found unfreed data ptr=%p size=%d file:line=\"%s:%d\" time=\"%04d-%02d-%02d %02d:%02d:%02d,%03d\" sample_int=%d sample_str=\"%s\""),
 		  local_bazooka.ptr, local_bazooka.size, local_bazooka.file,
-		  local_bazooka.line, ctime_buf, sample_int, sample_str);
+		  local_bazooka.line, (int) tm_when.tm_year + 1900,
+		  (int) tm_when.tm_mon + 1, (int) tm_when.tm_mday,
+		  (int) tm_when.tm_hour, (int) tm_when.tm_min,
+		  (int) tm_when.tm_sec, (int) (i_when % LW6SYS_TICKS_PER_SEC),
+		  sample_int, sample_str);
     }
 }
 #endif
@@ -198,7 +256,7 @@ lw6sys_default_memory_bazooka ()
 #ifdef LW6_OPTIMIZE
   ret = 1;
 #else
-  ret = lw6sys_set_memory_bazooka_size (_LW6SYS_BAZOOKA_DEFAULT_SIZE);
+  ret = lw6sys_set_memory_bazooka_size (LW6SYS_BAZOOKA_DEFAULT_SIZE);
 #endif
 
   return ret;
@@ -242,8 +300,6 @@ lw6sys_set_memory_bazooka_size (int size)
   int ret = 0;
 
 #ifndef LW6_OPTIMIZE
-  int i;
-
   if (size == bazooka_size)
     {
       // nothing to do
@@ -257,59 +313,51 @@ lw6sys_set_memory_bazooka_size (int size)
 
 	  if (bazooka_data)
 	    {
-	      bazooka_data =
-		(_lw6sys_bazooka_t *) realloc (bazooka_data,
-					       size *
-					       sizeof (_lw6sys_bazooka_t));
-	      if (bazooka_data)
-		{
-		  // Performance killer, but works...
-		  for (i = bazooka_size; i < size; ++i)
-		    {
-		      memset (&(bazooka_data[i]), 0,
-			      sizeof (_lw6sys_bazooka_t));
-		    }
-		  bazooka_size = size;
-		  ret = 1;
-		}
-	      else
-		{
-		  bazooka_size = 0;
-		}
+	      /*
+	       * We can't realloc for the _hash_index() depends on
+	       * size and we would be left with lost pointers
+	       */
+	      bazooka_trustable = 0;
+	      free (bazooka_data);
+	      bazooka_data = NULL;
+	      bazooka_size = 0;
+	    }
+
+	  bazooka_data =
+	    (_lw6sys_bazooka_t *) calloc (size, sizeof (_lw6sys_bazooka_t));
+	  if (bazooka_data)
+	    {
+	      bazooka_size = size;
+	      ret = 1;
 	    }
 	  else
 	    {
-	      bazooka_data =
-		(_lw6sys_bazooka_t *) calloc (size,
-					      sizeof (_lw6sys_bazooka_t));
-	      if (bazooka_data)
-		{
-		  bazooka_size = size;
-		  ret = 1;
-		}
-	      else
-		{
-		  bazooka_size = 0;
-		}
+	      bazooka_size = 0;
 	    }
 
-	  if (bazooka_mutex)
+	  if (bazooka_spinlock)
 	    {
 	      bazooka_unlock ();
 	    }
 	  else
 	    {
 	      /*
-	       * It's important to create the mutex now only, for mutex
+	       * It's important to create the spinlock now only, for spinlock
 	       * creation calls memory allocation routines, and could
 	       * therefore wreck tracking.
 	       */
-	      bazooka_mutex = lw6sys_mutex_create ();
+	      bazooka_spinlock = lw6sys_spinlock_create ();
+	    }
+	  if (!bazooka_data)
+	    {
+	      lw6sys_log_critical (_
+				   ("can't allocate bazooka memory (%d bytes)"),
+				   size * sizeof (_lw6sys_bazooka_t));
 	    }
 	}
       else
 	{
-	  bazooka_destroy_mutex ();
+	  bazooka_destroy_spinlock ();
 	  bazooka_free_data ();
 
 	  ret = 1;
@@ -380,32 +428,42 @@ lw6sys_get_memory_bazooka_eraser ()
   return ret;
 }
 
-void
+int
 _lw6sys_bazooka_register_malloc (char *ptr, int size, char *file, int line)
 {
+  int ret = 1;
+
 #ifndef LW6_OPTIMIZE
-  bazooka_register_malloc (ptr, size, file, line, bazooka_eraser);
+  ret = bazooka_register_malloc (ptr, size, file, line, bazooka_eraser);
 #endif
+
+  return ret;
 }
 
-void
+int
 _lw6sys_bazooka_register_calloc (char *ptr, int size, char *file, int line)
 {
+  int ret = 1;
+
 #ifndef LW6_OPTIMIZE
-  bazooka_register_malloc (ptr, size, file, line, 0);
+  ret = bazooka_register_malloc (ptr, size, file, line, 0);
 #endif
+
+  return ret;
 }
 
-void
+int
 _lw6sys_bazooka_register_realloc_1 (char *ptr, int size, char *file, int line)
 {
+  int ret = 1;
+
 #ifndef LW6_OPTIMIZE
   bazooka_lock ();
   if (bazooka_data)
     {
       int i;
 
-      for (i = 0; i < bazooka_size; ++i)
+      for (i = _hash_index (ptr); i < bazooka_size; ++i)
 	{
 	  if (bazooka_data[i].ptr == ptr)
 	    {
@@ -418,15 +476,23 @@ _lw6sys_bazooka_register_realloc_1 (char *ptr, int size, char *file, int line)
 	      break;		// important to leave loop, else serious perfomance problem
 	    }
 	}
+      if (bazooka_trustable && i == bazooka_size)
+	{
+	  ret = 0;
+	}
     }
   bazooka_unlock ();
 #endif
+
+  return ret;
 }
 
-void
+int
 _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2, int size,
 				    char *file, int line)
 {
+  int ret = 1;
+
 #ifndef LW6_OPTIMIZE
   bazooka_lock ();
   if (bazooka_data)
@@ -434,7 +500,7 @@ _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2, int size,
       int i;
       char *file_only;
 
-      for (i = 0; i < bazooka_size; ++i)
+      for (i = _hash_index (ptr); i < bazooka_size; ++i)
 	{
 	  if (bazooka_data[i].ptr == ptr)
 	    {
@@ -445,40 +511,114 @@ _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2, int size,
 			  size - bazooka_data[i].size);
 		}
 	      memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
-	      bazooka_data[i].ptr = ptr2;
-	      bazooka_data[i].size = size;
-	      file_only = strrchr (file, '/');
-	      if (file_only && *file_only)
+	      if (ptr == ptr2)
 		{
-		  file_only++;
+		  bazooka_data[i].ptr = ptr2;	// was NULL because of memset
+		  bazooka_data[i].size = size;
+		  file_only = strrchr (file, '/');
+		  if (file_only && *file_only)
+		    {
+		      file_only++;
+		    }
+		  else
+		    {
+		      file_only = file;
+		    }
+		  strncpy (bazooka_data[i].file, file_only,
+			   _LW6SYS_BAZOOKA_FILE_SIZE - 1);
+		  bazooka_data[i].line = line;
+		  bazooka_data[i].timestamp = lw6sys_timestamp ();
 		}
-	      else
+	      break;		// important to leave loop, else serious perfomance problem           
+	    }
+	}
+      if (bazooka_trustable && i == bazooka_size)
+	{
+	  ret = 0;
+	}
+
+      if (ptr != ptr2)
+	{
+	  /*
+	   * It's really important to relocate
+	   * entry if ptr!= ptr2 else _hash_index()
+	   * will be useless
+	   */
+	  for (i = _hash_index (ptr2); i < bazooka_size; ++i)
+	    {
+	      if (bazooka_data[i].ptr == NULL)
 		{
-		  file_only = file;
+		  memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
+		  bazooka_data[i].ptr = ptr2;
+		  bazooka_data[i].size = size;
+		  file_only = strrchr (file, '/');
+		  if (file_only && *file_only)
+		    {
+		      file_only++;
+		    }
+		  else
+		    {
+		      file_only = file;
+		    }
+		  strncpy (bazooka_data[i].file, file_only,
+			   _LW6SYS_BAZOOKA_FILE_SIZE - 1);
+		  bazooka_data[i].line = line;
+		  bazooka_data[i].timestamp = lw6sys_timestamp ();
+		  break;	// important to leave loop, else serious perfomance problem
 		}
-	      strncpy (bazooka_data[i].file, file_only,
-		       _LW6SYS_BAZOOKA_FILE_SIZE - 1);
-	      bazooka_data[i].line = line;
-	      bazooka_data[i].timestamp = lw6sys_timestamp ();
-	      break;		// important to leave loop, else serious perfomance problem
+	    }
+	  if (i == bazooka_size)
+	    {
+	      _big_cleanup ();
 	    }
 	}
     }
   bazooka_unlock ();
 #endif
+
+  return ret;
 }
 
-void
+int
 _lw6sys_bazooka_register_free (char *ptr)
 {
+  int ret = 1;
+
 #ifndef LW6_OPTIMIZE
+  int i;
+
   bazooka_lock ();
   bazooka_free_counter++;
+  bazooka_malloc_total--;
+  if (bazooka_free_counter > bazooka_malloc_counter)
+    {
+      lw6sys_log_critical (_("problem, more free (%d) than malloc (%d)"),
+			   bazooka_free_counter, bazooka_malloc_counter);
+    }
+
+#ifdef LW6_PARANOID
+  {
+    int same = 0;
+
+    for (i = _hash_index (ptr), same = 1; i < _LW6SYS_BAZOOKA_ALLOC_MIN; ++i)
+      {
+	if (ptr[i] != BAZOOKA_ERASER_FREE)
+	  {
+	    same = 0;
+	    break;
+	  }
+      }
+
+    if (same)
+      {
+	ret = 0;
+      }
+  }
+#endif
+
   if (bazooka_data)
     {
-      int i;
-
-      for (i = 0; i < bazooka_size; ++i)
+      for (i = _hash_index (ptr); i < bazooka_size; ++i)
 	{
 	  if (bazooka_data[i].ptr == ptr)
 	    {
@@ -491,9 +631,16 @@ _lw6sys_bazooka_register_free (char *ptr)
 	      break;		// important to leave loop, else serious perfomance problem
 	    }
 	}
+      if (bazooka_trustable && i == bazooka_size)
+	{
+	  ret = 0;
+	}
     }
+
   bazooka_unlock ();
 #endif
+
+  return ret;
 }
 
 /**
@@ -539,6 +686,48 @@ lw6sys_get_memory_bazooka_free_count ()
   return ret;
 }
 
+/**
+ * lw6sys_get_memory_bazooka_malloc_max
+ *
+ * Provided you have always called the @LW6SYS_MALLOC an @LW6SYS_CALLOC to 
+ * allocate memory, this function will tell you the maximum of pointers
+ * returned by @malloc that were present at the same time on the heap.
+ *
+ * Return value: the number of calls to @lw6sys_malloc or @lw6sys_calloc since
+ *   program was started.
+ */
+int
+lw6sys_get_memory_bazooka_malloc_max ()
+{
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = bazooka_malloc_max;
+#endif
+
+  return ret;
+}
+
+/**
+ * lw6sys_is_memory_bazooka_trustable
+ *
+ * Returns true if memory bazooka data are perfectly trustable, that is,
+ * it has never been resetted or resized.
+ *
+ * Return value: 1 if trustable, 0 if not.
+ */
+int
+lw6sys_is_memory_bazooka_trustable ()
+{
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = bazooka_trustable;
+#endif
+
+  return ret;
+}
+
 /**
  * lw6sys_memory_bazooka_report
  *
@@ -561,26 +750,38 @@ lw6sys_memory_bazooka_report ()
    */
   lw6sys_log (LW6SYS_LOG_INFO, _("no memory check"));
 #else
-  int recreate_mutex = 0;
+  int recreate_spinlock = 0;
   int i;
   int malloc_counter;
   int free_counter;
+  int malloc_max;
 
-  if (bazooka_mutex)
+  if (bazooka_spinlock)
     {
-      bazooka_destroy_mutex ();
-      recreate_mutex = 1;
+      bazooka_destroy_spinlock ();
+      recreate_spinlock = 1;
     }
 
   malloc_counter = lw6sys_get_memory_bazooka_malloc_count ();
   free_counter = lw6sys_get_memory_bazooka_free_count ();
+  malloc_max = lw6sys_get_memory_bazooka_malloc_max ();
 
   if (malloc_counter == free_counter)
     {
       if (bazooka_data)
 	{
-	  lw6sys_log (LW6SYS_LOG_NOTICE, _("%d malloc calls"),
-		      malloc_counter);
+	  if (bazooka_trustable)
+	    {
+	      lw6sys_log (LW6SYS_LOG_NOTICE, _("%d malloc calls"),
+			  malloc_counter);
+	      lw6sys_log (LW6SYS_LOG_INFO, _("malloc_max=%d bazooka_size=%d"),
+			  bazooka_malloc_max, bazooka_size);
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_NOTICE, _("%d malloc calls (untrusted)"),
+			  malloc_counter);
+	    }
 	}
     }
   else
@@ -604,9 +805,9 @@ lw6sys_memory_bazooka_report ()
 	}
     }
 
-  if (recreate_mutex)
+  if (recreate_spinlock)
     {
-      bazooka_mutex = lw6sys_mutex_create ();
+      bazooka_spinlock = lw6sys_spinlock_create ();
     }
 #endif
 
