@@ -33,6 +33,8 @@
 #define LICENSE "GPLv3+ (GNU GPL version 3 or later)"
 #define TOP_SRCDIR_TEST_FILE "liquidwar6.spec.in"
 #define TOP_SRCDIR_MAX_UNPARENT 4
+#define ENABLE_YES "yes"
+#define ENABLE_NO "no"
 
 /**
  * lw6sys_build_get_package_tarname:
@@ -244,7 +246,8 @@ lw6sys_build_get_gcc_version ()
 char *
 lw6sys_build_get_cflags ()
 {
-  return "-I" LW6_INCLUDEDIR " -I" LW6_INCLUDEDIR "/" PACKAGE_TARNAME;
+  return "-I" LW6_INCLUDEDIR " -I" LW6_INCLUDEDIR "/" PACKAGE_TARNAME " "
+    LW6_CFLAGS;
 }
 
 /**
@@ -262,7 +265,7 @@ lw6sys_build_get_cflags ()
 char *
 lw6sys_build_get_ldflags ()
 {
-  return "-L" LW6_LIBDIR " -l" PACKAGE_TARNAME;
+  return "-L" LW6_LIBDIR " -l" PACKAGE_TARNAME " " LW6_LDFLAGS;
 }
 
 /**
@@ -360,6 +363,23 @@ lw6sys_build_get_pointer_size ()
   return sizeof (void *);
 }
 
+/**
+ * lw6sys_build_is_x86:
+ *
+ * Tells wether CPU belongs to x86 family or not.
+ *
+ * Return value: 1 if x86, 0 if not
+ */
+int
+lw6sys_build_is_x86 ()
+{
+#ifdef LW6_X86
+  return 1;
+#else
+  return 0;
+#endif
+}
+
 /**
  * lw6sys_build_get_target_os:
  *
@@ -378,7 +398,7 @@ lw6sys_build_get_target_os ()
  *
  * Tells wether the program was compiled for Microsoft Windows, or not.
  *
- * Return value: 1 if compiled on windows 32-bit, 0 if not
+ * Return value: 1 if compiled on windows, 0 if not
  */
 int
 lw6sys_build_is_ms_windows ()
@@ -390,6 +410,23 @@ lw6sys_build_is_ms_windows ()
 #endif
 }
 
+/**
+ * lw6sys_build_is_mac_os_x:
+ *
+ * Tells wether the program was compiled for Mac OS X, or not.
+ *
+ * Return value: 1 if compiled on OS X, 0 if not
+ */
+int
+lw6sys_build_is_mac_os_x ()
+{
+#ifdef LW6_MAC_OS_X
+  return 1;
+#else
+  return 0;
+#endif
+}
+
 /**
  * lw6sys_build_get_top_srcdir:
  *
@@ -550,9 +587,9 @@ char *
 lw6sys_build_get_enable_console ()
 {
 #ifdef LW6_CONSOLE
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -567,9 +604,9 @@ char *
 lw6sys_build_get_enable_mod_gl ()
 {
 #ifdef MOD_GL
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -584,9 +621,9 @@ char *
 lw6sys_build_get_enable_mod_csound ()
 {
 #ifdef MOD_CSOUND
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -601,9 +638,9 @@ char *
 lw6sys_build_get_enable_mod_ogg ()
 {
 #ifdef MOD_OGG
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -618,9 +655,9 @@ char *
 lw6sys_build_get_enable_mod_http ()
 {
 #ifdef MOD_HTTP
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -635,9 +672,9 @@ char *
 lw6sys_build_get_enable_optimize ()
 {
 #ifdef LW6_OPTIMIZE
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -652,9 +689,9 @@ char *
 lw6sys_build_get_enable_allinone ()
 {
 #ifdef LW6_ALLINONE
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -669,9 +706,26 @@ char *
 lw6sys_build_get_enable_fullstatic ()
 {
 #ifdef LW6_FULLSTATIC
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_paranoid
+ *
+ * Tells wether the game was compiled with paranoid memory management.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_paranoid ()
+{
+#ifdef LW6_PARANOID
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+#else
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -686,9 +740,43 @@ char *
 lw6sys_build_get_enable_gprof ()
 {
 #ifdef LW6_GPROF
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_instrument
+ *
+ * Tells wether the game was compiled with the '-finstrument-fonctions' GCC flag.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_instrument ()
+{
+#ifdef LW6_INSTRUMENT
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+#else
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_profiler
+ *
+ * Tells wether the game was compiled for later use with Google Profiler support.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_profiler ()
+{
+#ifdef LW6_PROFILER
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+#else
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -703,9 +791,9 @@ char *
 lw6sys_build_get_enable_gcov ()
 {
 #ifdef LW6_GCOV
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -720,9 +808,9 @@ char *
 lw6sys_build_get_enable_valgrind ()
 {
 #ifdef LW6_VALGRIND
-  return "yes";			// do not translate this, could be interpreted by a script
+  return ENABLE_YES;		// do not translate this, could be interpreted by a script
 #else
-  return "no";			// do not translate this, could be interpreted by a script
+  return ENABLE_NO;		// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -808,8 +896,14 @@ lw6sys_build_log_all ()
 	      lw6sys_build_get_enable_allinone ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable fullstatic is \"%s\""),
 	      lw6sys_build_get_enable_fullstatic ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable paranoid is \"%s\""),
+	      lw6sys_build_get_enable_paranoid ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable gprof is \"%s\""),
 	      lw6sys_build_get_enable_gprof ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable instrument is \"%s\""),
+	      lw6sys_build_get_enable_instrument ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable profiler is \"%s\""),
+	      lw6sys_build_get_enable_profiler ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable gcov is \"%s\""),
 	      lw6sys_build_get_enable_gcov ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable valgrind is \"%s\""),
