@@ -704,6 +704,26 @@ lw6sys_color_distance (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
   return distance;
 }
 
+/**
+ * lw6sys_color_is_same
+ *
+ * @color1: the first color to compare
+ * @color2: the second color to compare
+ *
+ * Compares two colors.
+ *
+ * Return value: 1 if they are the same, 0 if not.
+ */
+int
+lw6sys_color_is_same (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
+{
+  int ret = 0;
+
+  ret = memcmp (&color1, &color2, sizeof (lw6sys_color_8_t)) ? 0 : 1;
+
+  return ret;
+}
+
 /**
  * lw6sys_color_8_solid
  *
