@@ -43,6 +43,17 @@ lw6sys_clear_file (char *filename)
 {
   int ret = 0;
   FILE *f = NULL;
+  char *dir = NULL;
+
+  dir = lw6sys_path_parent (filename);
+  if (dir)
+    {
+      if (!lw6sys_dir_exists (dir))
+	{
+	  lw6sys_create_dir_silent (dir);
+	}
+      LW6SYS_FREE (dir);
+    }
 
   f = fopen (filename, "wb");
   if (f)
