@@ -25,20 +25,35 @@
 
 #include <pthread.h>
 #include <stdarg.h>
+#include <sys/time.h>
 
 #include "sys.h"
 
 #define _LW6SYS_EXIT_CRITICAL 1
 
-#define _LW6SYS_BAZOOKA_DEFAULT_SIZE 1000
+/*
+ * By default memory bazooka size is just hudge, will eat up to 7 or 8 megs.
+ * The game will set it up to a much lower value through its config, still
+ * we keep this very high value for the purpose of debugging. All test
+ * programs will use this.
+ */
+#ifdef LW6_PARANOID
+#define _LW6SYS_BAZOOKA_FILE_SIZE 80
+#define _LW6SYS_BAZOOKA_SAMPLE_SIZE 1000
+#define _LW6SYS_BAZOOKA_ALLOC_MIN 16
+#else
 #define _LW6SYS_BAZOOKA_FILE_SIZE 50
 #define _LW6SYS_BAZOOKA_SAMPLE_SIZE 100
-
-#define _LW6SYS_LOG_CTIME_BUF_SIZE 30	// more than 26 is enough
-#define _LW6SYS_LOG_CTIME_ZERO 24
+// ALLOC_MIN not defined in non-paranoid mode
+#endif
 
 #define _LW6SYS_DEBUG_DEFAULT 0
-#define _LW6SYS_LOG_DEFAULT_ID LW6SYS_LOG_INFO_ID
+
+// ticks limit set to 15 minutes
+#define _LW6SYS_TICKS_LIMIT 900000
+
+#define _LW6SYS_THREAD_JOIN_SLEEP 0.1f
+#define _LW6SYS_VTHREAD_ID -1
 
 typedef struct _lw6sys_bazooka_s
 {
@@ -54,16 +69,36 @@ typedef struct _lw6sys_mutex_s
   pthread_mutex_t mutex;
 } _lw6sys_mutex_t;
 
+#if ((_POSIX_SPIN_LOCKS - 200112L) >= 0L)
+typedef struct _lw6sys_spinlock_s
+{
+  pthread_spinlock_t spinlock;
+} _lw6sys_spinlock_t;
+#else
+#if LW6_X86
+typedef struct _lw6sys_spinlock_s
+{
+  int spinlock;
+} _lw6sys_spinlock_t;
+#else
+#define _lw6sys_spinlock_s _lw6sys_mutex_s
+#define _lw6sys_spinlock_t _lw6sys_mutex_t
+#endif
+#endif
+
 typedef struct _lw6sys_thread_handler_s
 {
   pthread_t thread;
   u_int32_t id;
   int callback_done;
+  int join_done;
   int can_join;
   void (*callback_func) (void *callback_data);
   void (*callback_join) (void *callback_data);
   void *callback_data;
-  int flag;
+#ifndef LW6_MS_WINDOWS
+  struct itimerval itimer;
+#endif
 } _lw6sys_thread_handler_t;
 
 typedef struct _lw6sys_global_s
@@ -74,16 +109,16 @@ typedef struct _lw6sys_global_s
 
 extern _lw6sys_global_t _lw6sys_global;
 
-extern void _lw6sys_bazooka_register_malloc (char *ptr, int size, char *file,
-					     int line);
-extern void _lw6sys_bazooka_register_calloc (char *ptr, int size, char *file,
-					     int line);
-extern void _lw6sys_bazooka_register_realloc_1 (char *ptr, int size,
-						char *file, int line);
-extern void _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2,
-						int size, char *file,
-						int line);
-extern void _lw6sys_bazooka_register_free (char *ptr);
+extern int _lw6sys_bazooka_register_malloc (char *ptr, int size, char *file,
+					    int line);
+extern int _lw6sys_bazooka_register_calloc (char *ptr, int size, char *file,
+					    int line);
+extern int _lw6sys_bazooka_register_realloc_1 (char *ptr, int size,
+					       char *file, int line);
+extern int _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2,
+					       int size, char *file,
+					       int line);
+extern int _lw6sys_bazooka_register_free (char *ptr);
 extern char *_lw6sys_new_vsnprintf (int n, char *fmt, va_list ap);
 
 #endif
