@@ -31,6 +31,7 @@
 #include <syslog.h>
 #endif
 #include <time.h>
+#include <sys/time.h>
 #include <errno.h>
 
 #define HISTORY_LENGTH 256
@@ -546,10 +547,11 @@ static void
 log_to_file (FILE * f, int level_id, char *level_str, char *file, int line,
 	     char *fmt, va_list ap)
 {
-  char ctime_buf[_LW6SYS_LOG_CTIME_BUF_SIZE];
-  char *ctime_ret = NULL;
-  time_t t;
-  char *file_only;
+  char *file_only = NULL;
+  time_t t_now;
+  struct tm tm_now;
+  struct tm *tm_ret = NULL;
+  struct timeval timeval_now;
 
   file_only = strrchr (file, '/');
   if (file_only && *file_only)
@@ -561,13 +563,20 @@ log_to_file (FILE * f, int level_id, char *level_str, char *file, int line,
       file_only = file;
     }
 
-  t = time (NULL);
-  ctime_ret = ctime_r (&t, ctime_buf);
-  if (ctime_ret == ctime_buf)
+  memset (&t_now, 0, sizeof (time_t));
+  memset (&tm_now, 0, sizeof (struct tm));
+  memset (&timeval_now, 0, sizeof (struct timeval));
+  gettimeofday (&timeval_now, NULL);
+  t_now = timeval_now.tv_sec;
+  tm_ret = localtime_r (&t_now, &tm_now);
+  if (tm_ret == &tm_now)
     {
-      ctime_buf[_LW6SYS_LOG_CTIME_ZERO] = '\0';
-
-      fprintf (f, "%s\t%s:%d\t%d\t%s\t", ctime_buf,
+      fprintf (f, "%04d-%02d-%02d %02d.%02d:%02d,%03d\t%s:%d\t%d\t%s\t",
+	       (int) tm_now.tm_year + 1900, (int) tm_now.tm_mon + 1,
+	       (int) tm_now.tm_mday, (int) tm_now.tm_hour,
+	       (int) tm_now.tm_min, (int) tm_now.tm_sec,
+	       (int) timeval_now.tv_usec / (int) (1000000 /
+						  LW6SYS_TICKS_PER_SEC),
 	       file_only, line, level_id, level_str);
     }
   vfprintf (f, fmt, ap);
@@ -663,8 +672,9 @@ msgbox_alert (char *fmt, va_list ap)
  *   LW6SYS_LOG_ERROR_ID (0), 
  *   LW6SYS_LOG_WARNING_ID (1), 
  *   LW6SYS_LOG_NOTICE_ID (2), 
- *   LW6SYS_LOG_INFO_ID (3) and 
- *   LW6SYS_LOG_DEBUG_ID (4).
+ *   LW6SYS_LOG_INFO_ID (3),
+ *   LW6SYS_LOG_DEBUG_ID (4) and
+ *   LW6SYS_LOG_TMP_ID (5).
  * @file: the name of the source file where the function is called,
  *   one can use __FILE__
  * @line: the line in the source file where the function is called,
@@ -673,9 +683,8 @@ msgbox_alert (char *fmt, va_list ap)
  * @...: printf-like arguments, corresponding to @fmt.
  *
  * This function is usually called with the first three arguments
- * packed into a single macro. A typical use is 
- * "lw6sys_log(LW6SYS_LOG_WARNING,"sys","problem %s %d","foo",1)".
- * The @LW6SYS_LOG_WARNING macro expands and fills the first 3
+ * packed into a single macro. For instance the
+ * @LW6SYS_LOG_WARNING macro expands and fills the first 3
  * args, so there's no need to type __FILE__ and __LINE__ again
  * and again. Note that this function will reset errno. The
  * idea is to call it whenever there's something to do with errno
@@ -689,9 +698,11 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 {
 #ifdef LW6_OPTIMIZE
   if ((level_id <= LW6SYS_LOG_NOTICE_ID
-       && level_id <= lw6sys_log_get_level ()) || lw6sys_debug_get ())
+       && level_id <= lw6sys_log_get_level ())
+      || level_id == LW6SYS_LOG_TMP_ID || lw6sys_debug_get ())
 #else
-  if (level_id <= lw6sys_log_get_level () || lw6sys_debug_get ())
+  if (level_id <= lw6sys_log_get_level () || level_id == LW6SYS_LOG_TMP_ID
+      || lw6sys_debug_get ())
 #endif
     {
       char *level_str = NULL;
@@ -749,6 +760,12 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 	  level_str = lw6sys_str_copy ("");
 #ifdef HAVE_SYSLOG_H
 	  syslog_priority = LOG_INFO;
+#endif
+	  break;
+	case LW6SYS_LOG_TMP_ID:
+	  level_str = lw6sys_str_copy (_("[tmp] "));
+#ifdef HAVE_SYSLOG_H
+	  syslog_priority = LOG_DEBUG;
 #endif
 	  break;
 	default:		// LW6SYS_LOG_DEBUG_ID
@@ -762,20 +779,23 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
       if (fmt != NULL)
 	{
 	  // exclude INFO & DEBUG from console in non-debug mode
-	  if (level_id <= LW6SYS_LOG_NOTICE_ID || lw6sys_debug_get ())
+	  if (level_id <= LW6SYS_LOG_NOTICE_ID
+	      || level_id == LW6SYS_LOG_TMP_ID || lw6sys_debug_get ())
 	    {
 	      va_copy (ap2, ap);
 	      log_to_console (stderr, level_str, fmt, ap2);
 	      va_end (ap2);
 	    }
-	  if (level_id <= LW6SYS_LOG_WARNING_ID)
+	  if (level_id <= LW6SYS_LOG_WARNING_ID
+	      || level_id == LW6SYS_LOG_TMP_ID)
 	    {
 	      va_copy (ap2, ap);
 	      log_to_history (level_str, fmt, ap2);
 	      va_end (ap2);
 	    }
 #ifdef HAVE_SYSLOG_H
-	  if (level_id <= LW6SYS_LOG_WARNING_ID)
+	  if (level_id <= LW6SYS_LOG_WARNING_ID
+	      || level_id == LW6SYS_LOG_TMP_ID)
 	    {
 	      va_copy (ap2, ap);
 	      vsyslog (syslog_priority, fmt, ap2);
