@@ -57,6 +57,10 @@ lw6sys_malloc (int size, char *file, int line)
 {
   void *ptr;
 
+#ifdef LW6_PARANOID
+  size = lw6sys_max (size, _LW6SYS_BAZOOKA_ALLOC_MIN);
+#endif
+
   ptr = malloc (size);
 
   if (ptr != NULL)
@@ -68,7 +72,7 @@ lw6sys_malloc (int size, char *file, int line)
   else
     {
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("Out of memory malloc(%d) failed in %s:%d)"), size, file,
+		  _("out of memory malloc (%d) failed in %s:%d)"), size, file,
 		  line);
     }
 
@@ -96,6 +100,10 @@ lw6sys_calloc (int size, char *file, int line)
 {
   void *ptr;
 
+#ifdef LW6_PARANOID
+  size = lw6sys_max (size, _LW6SYS_BAZOOKA_ALLOC_MIN);
+#endif
+
   ptr = calloc (size, sizeof (char));
 
   if (ptr != NULL)
@@ -107,7 +115,7 @@ lw6sys_calloc (int size, char *file, int line)
   else
     {
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("Out of memory calloc(%d) failed in %s:%d)"), size, file,
+		  _("out of memory calloc(%d) failed in %s:%d)"), size, file,
 		  line);
     }
 
@@ -135,8 +143,17 @@ lw6sys_realloc (void *ptr, int size, char *file, int line)
 {
   void *ptr2;
 
+#ifdef LW6_PARANOID
+  size = lw6sys_max (size, _LW6SYS_BAZOOKA_ALLOC_MIN);
+#endif
+
 #ifndef LW6_OPTIMIZE
-  _lw6sys_bazooka_register_realloc_1 (ptr, size, file, line);
+  if (!_lw6sys_bazooka_register_realloc_1 (ptr, size, file, line))
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("suspicious realloc (stage 1) at %s:%d"), file, line);
+    }
+
 #endif
 
   ptr2 = realloc (ptr, size);
@@ -144,14 +161,18 @@ lw6sys_realloc (void *ptr, int size, char *file, int line)
   if (ptr2)
     {
 #ifndef LW6_OPTIMIZE
-      _lw6sys_bazooka_register_realloc_2 (ptr, ptr2, size, file, line);
+      if (!_lw6sys_bazooka_register_realloc_2 (ptr, ptr2, size, file, line))
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("suspicious realloc (stage 2) at %s:%d"), file, line);
+	}
 #endif
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("Out of memory realloc(%d) failed in %s:%d)"), size, file,
-		  line);
+		  _("out of memory realloc (%d) failed in %s:%d)"), size,
+		  file, line);
     }
 
   return ptr2;
@@ -179,7 +200,11 @@ lw6sys_free (void *ptr, char *file, int line)
   if (ptr != NULL)
     {
 #ifndef LW6_OPTIMIZE
-      _lw6sys_bazooka_register_free (ptr);
+      if (!_lw6sys_bazooka_register_free (ptr))
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("double free suspected at %s:%d"),
+		      file, line);
+	}
 #endif
       /*
        * It's important to free the pointer after registering, since
@@ -190,7 +215,7 @@ lw6sys_free (void *ptr, char *file, int line)
   else
     {
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("Trying to free NULL pointer in %s:%d)"), file, line);
+		  _("trying to free NULL pointer in %s:%d)"), file, line);
     }
 }
 
@@ -241,7 +266,11 @@ lw6sys_megabytes_available ()
   GlobalMemoryStatus (&status);
   ret = status.dwAvailPhys / MEM_DIVIDE;
 #else
+#ifdef _SC_AVPHYS_PAGES
   ret = (sysconf (_SC_PAGESIZE) * sysconf (_SC_AVPHYS_PAGES)) / MEM_DIVIDE;
+#else
+  // Todo : find a way to get available memory on Mac OS X
+#endif
 #endif
 
   return ret;
