@@ -111,7 +111,8 @@ lw6sys_mutex_lock (void *mutex)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("pthread_lock failed with error code %d"), pthread_ret);
+		  _("pthread_mutex_lock failed with error code %d"),
+		  pthread_ret);
     }
 
   return ret;
@@ -151,7 +152,7 @@ lw6sys_mutex_trylock (void *mutex)
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("pthread_trylock failed with error code %d"),
+		      _("pthread_mutex_trylock failed with error code %d"),
 		      pthread_ret);
 	}
     }
@@ -183,7 +184,8 @@ lw6sys_mutex_unlock (void *mutex)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("pthread_unlock failed with error code %d"), pthread_ret);
+		  _("pthread_mutex_unlock failed with error code %d"),
+		  pthread_ret);
     }
 
   return ret;
