@@ -73,8 +73,10 @@ void
 lw6sys_progress_update (lw6sys_progress_t * progress, int min, int max,
 			int value)
 {
-  if (progress && progress->value)
+  if (progress && progress->value && (max > min))
     {
+      value = lw6sys_max (min, value);
+      value = lw6sys_min (max, value);
       (*(progress->value)) =
 	((((float) value) - ((float) min)) / (((float) max) -
 					      ((float) min))) *
@@ -280,6 +282,93 @@ lw6sys_progress_split4 (lw6sys_progress_t * progress1,
     }
 }
 
+/**
+ * lw6sys_progress_split5
+ *
+ * progress1: the first part of the splitted progress
+ * progress2: the second part of the splitted progress
+ * progress3: the third part of the splitted progress
+ * progress4: the fourth part of the splitted progress
+ * progress5: the fourth part of the splitted progress
+ * progress_src: the progress to split
+ *
+ * Utility function to split a progress struct, this one will split it
+ * into 5 equal parts.
+ *
+ * Return value: none
+ */
+void
+lw6sys_progress_split5 (lw6sys_progress_t * progress1,
+			lw6sys_progress_t * progress2,
+			lw6sys_progress_t * progress3,
+			lw6sys_progress_t * progress4,
+			lw6sys_progress_t * progress5,
+			lw6sys_progress_t * progress_src)
+{
+  float limit_a, limit_b, limit_c, limit_d;
+
+  if (progress_src)
+    {
+      limit_a = (4.0f * progress_src->min + progress_src->max) / 5.0f;
+      limit_b = (3.0f * progress_src->min + 2.0f * progress_src->max) / 5.0f;
+      limit_c = (2.0f * progress_src->min + 3.0f * progress_src->max) / 5.0f;
+      limit_d = (progress_src->min + 4.0f * progress_src->max) / 5.0f;
+      if (progress1)
+	{
+	  progress1->min = progress_src->min;
+	  progress1->max = limit_a;
+	  progress1->value = progress_src->value;
+	}
+      if (progress2)
+	{
+	  progress2->min = limit_a;
+	  progress2->max = limit_b;
+	  progress2->value = progress_src->value;
+	}
+      if (progress3)
+	{
+	  progress3->min = limit_b;
+	  progress3->max = limit_c;
+	  progress3->value = progress_src->value;
+	}
+      if (progress4)
+	{
+	  progress4->min = limit_c;
+	  progress4->max = limit_d;
+	  progress4->value = progress_src->value;
+	}
+      if (progress5)
+	{
+	  progress5->min = limit_d;
+	  progress5->max = progress_src->max;
+	  progress5->value = progress_src->value;
+	}
+    }
+  else
+    {
+      if (progress1)
+	{
+	  memset (progress1, 0, sizeof (lw6sys_progress_t));
+	}
+      if (progress2)
+	{
+	  memset (progress2, 0, sizeof (lw6sys_progress_t));
+	}
+      if (progress3)
+	{
+	  memset (progress3, 0, sizeof (lw6sys_progress_t));
+	}
+      if (progress4)
+	{
+	  memset (progress4, 0, sizeof (lw6sys_progress_t));
+	}
+      if (progress5)
+	{
+	  memset (progress5, 0, sizeof (lw6sys_progress_t));
+	}
+    }
+}
+
 /**
  * lw6sys_progress_begin
  *
