@@ -73,3 +73,24 @@ lw6sys_shape_check_pos (lw6sys_whd_t * shape, lw6sys_xyz_t * pos)
 
   return ret;
 }
+
+/**
+ * lw6sys_shape_is_same
+ *
+ * @shape_a: the first shape to compare
+ * @shape_b: the other shape to compare
+ *
+ * Compares two shapes.
+ *
+ * Return value: 1 if same, 0 if not.
+ */
+int
+lw6sys_shape_is_same (lw6sys_whd_t * shape_a, lw6sys_whd_t * shape_b)
+{
+  int ret = 0;
+
+  ret = (shape_a->w == shape_b->w) && (shape_a->h == shape_b->h)
+    && (shape_a->d == shape_b->d);
+
+  return ret;
+}
