@@ -215,6 +215,36 @@ lw6sys_str_is_blank (char *str)
   return ret;
 }
 
+/**
+ * lw6sys_str_is_same
+ *
+ * @str_a: 1st string to compare, can be NULL
+ * @str_b: 2nd string to compare, can be NULL
+ *
+ * Compares two strings for equality. Difference with strcmp
+ * is that this one won't check for alphabetical order and
+ * return -1 or +1, but will check for NULL args.
+ * of space, tabs, or carriage returns only.
+ *
+ * Return value: 1 if same, 0 if not.
+ */
+int
+lw6sys_str_is_same (char *str_a, char *str_b)
+{
+  int ret = 1;
+
+  if (((!str_a) && str_b) || (str_a && (!str_b)))
+    {
+      ret = 0;
+    }
+  if (str_a && str_b)
+    {
+      ret = strcmp (str_a, str_b) ? 0 : 1;
+    }
+
+  return ret;
+}
+
 /**
  * lw6sys_skip_blanks
  *
