@@ -63,7 +63,9 @@
 #define THREAD_SLEEP_CALLBACK 0.2f
 #define THREAD_TEXT "foo bar"
 #define THREAD_STRESS_DURATION 3.0f
+#define VTHREAD_N 3
 #define TEST_SLEEP_TIME 3
+#define TEST_DELAY_TIME 50
 #define TEST_SLEEP_TIME_SHORT_STEP 0.001f
 #define BLANK_STR "\t "
 #define ASCII_STR "foo,bar"
@@ -136,7 +138,7 @@
 #define TEST_HISTORY_MSG4 "4 message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated"
 #define TEST_HISTORY_MSG5 "5 most recent"
 #define TEST_HISTORY_SLEEP 5.0
-#define TEST_HISTORY_TIMEOUT 2
+#define TEST_HISTORY_TIMEOUT 2000
 #define TEST_SHAPE_W 640
 #define TEST_SHAPE_H 480
 #define TEST_SHAPE_D 3
@@ -146,6 +148,21 @@
 #define TEST_SHAPE_MIN_WH 10
 #define TEST_SHAPE_MAX_WH 1000
 #define TEST_SHAPE_MAX_D 5
+#define TEST_MATH_POLY_WY1Y2S1_NB_STEPS 20
+#define TEST_MATH_POLY_WY1Y2S1_W 5.0f
+#define TEST_MATH_POLY_WY1Y2S1_Y1 1.0f
+#define TEST_MATH_POLY_WY1Y2S1_Y2 10.0f
+#define TEST_MATH_POLY_WY1Y2S1_NB_V1S 4
+#define TEST_MATH_POLY_WY1Y2S1_V1_MIN -3.0f
+#define TEST_MATH_POLY_WY1Y2S1_V1_MAX +3.0f
+#define TEST_MATH_ANGLE_XY_MIN -2
+#define TEST_MATH_ANGLE_XY_MAX 2
+#define TEST_MATH_HEARTBEAT_N 60
+#define TEST_MATH_HEARTBEAT_PERIOD 30
+#define TEST_MATH_HEARTBEAT_Y1 1.0f
+#define TEST_MATH_HEARTBEAT_Y2 1.5f
+#define TEST_MATH_BLINK_N 10
+#define TEST_MATH_BLINK_PERIOD 3
 
 /*
  * Testing functions in arg.c
@@ -441,6 +458,11 @@ test_color ()
     lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("distance between green and blue is %.2f"), distance);
 
+    if (!lw6sys_color_is_same (color_8, color_8))
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("color comparison failed"));
+      }
+
     lw6sys_color_8_solid (&color_8);
     lw6sys_color_f_solid (&color_f);
   }
@@ -721,6 +743,24 @@ test_file ()
   return ret;
 }
 
+/*
+ * Testing functions in profiler.c
+ */
+static int
+test_profiler ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("Google Profiler support=%d"),
+		lw6sys_profiler_check (0));
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing functions in hash.c
  */
@@ -1357,6 +1397,76 @@ test_log ()
   return ret;
 }
 
+/*
+ * Testing functions in math.c
+ */
+static int
+test_math ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    float y = 0.0f;
+    float s = 0.0f;
+    float x = 0.0f;
+    float v1 = 0.0f;
+    int ix, iy;
+    float angle = 0.0f;
+    int t, b;
+
+    for (v1 = TEST_MATH_POLY_WY1Y2S1_V1_MIN;
+	 v1 <= TEST_MATH_POLY_WY1Y2S1_V1_MAX;
+	 v1 +=
+	 (TEST_MATH_POLY_WY1Y2S1_V1_MAX -
+	  TEST_MATH_POLY_WY1Y2S1_V1_MIN) / TEST_MATH_POLY_WY1Y2S1_NB_V1S)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("wy1y2s1 v1=%f"), v1);
+	for (x = 0.0f; x <= TEST_MATH_POLY_WY1Y2S1_W;
+	     x += TEST_MATH_POLY_WY1Y2S1_W / TEST_MATH_POLY_WY1Y2S1_NB_STEPS)
+	  {
+	    lw6sys_math_poly_wy1y2s1 (&y, &s, x, TEST_MATH_POLY_WY1Y2S1_W,
+				      TEST_MATH_POLY_WY1Y2S1_Y1,
+				      TEST_MATH_POLY_WY1Y2S1_Y2, v1);
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("wy1y2s1 x=%f y=%f s=%f"), x, y,
+			s);
+	  }
+      }
+    for (iy = TEST_MATH_ANGLE_XY_MIN; iy <= TEST_MATH_ANGLE_XY_MAX; ++iy)
+      {
+	for (ix = TEST_MATH_ANGLE_XY_MIN; ix <= TEST_MATH_ANGLE_XY_MAX; ++ix)
+	  {
+	    angle = lw6sys_math_angle_360 (ix, iy);
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("x=%d y=%d angle=%f"), ix, iy,
+			angle);
+	  }
+      }
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("heartbeat period=%d y1=%f y2=%f"),
+		TEST_MATH_HEARTBEAT_PERIOD, TEST_MATH_HEARTBEAT_Y1,
+		TEST_MATH_HEARTBEAT_Y2);
+    for (t = 0; t < TEST_MATH_HEARTBEAT_N; t++)
+      {
+	y =
+	  lw6sys_math_heartbeat (t, TEST_MATH_HEARTBEAT_PERIOD,
+				 TEST_MATH_HEARTBEAT_Y1,
+				 TEST_MATH_HEARTBEAT_Y2);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("heartbeat t=%d y=%f"), t, y);
+      }
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("blink period=%d"),
+		TEST_MATH_BLINK_PERIOD);
+    for (t = 0; t < TEST_MATH_BLINK_N; t++)
+      {
+	b = lw6sys_math_blink (t, TEST_MATH_BLINK_PERIOD);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("blink t=%d b=%d"), t, b);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing functions in mem.c
  */
@@ -1647,6 +1757,7 @@ test_progress ()
     lw6sys_progress_t progress2;
     lw6sys_progress_t progress3;
     lw6sys_progress_t progress4;
+    lw6sys_progress_t progress5;
     float value = 0.0f;
     int i = 0;
 
@@ -1677,6 +1788,14 @@ test_progress ()
 		("progress1 %0.2f/%0.2f progress2 %0.2f/%0.2f progress3 %0.2f/%0.2f progress4 %0.2f/%0.2f"),
 		progress1.min, progress1.max, progress2.min, progress2.max,
 		progress3.min, progress3.max, progress4.min, progress4.max);
+    lw6sys_progress_split5 (&progress1, &progress2, &progress3, &progress4,
+			    &progress5, &progress);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_
+		("progress1 %0.2f/%0.2f progress2 %0.2f/%0.2f progress3 %0.2f/%0.2f progress4 %0.2f/%0.2f progress5 %0.2f/%0.2f"),
+		progress1.min, progress1.max, progress2.min, progress2.max,
+		progress3.min, progress3.max, progress4.min, progress4.max,
+		progress5.min, progress5.max);
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -1904,6 +2023,45 @@ test_sort ()
   return ret;
 }
 
+/*
+ * Testing functions in spinlock.c
+ */
+static int
+test_spinlock ()
+{
+  int ret = 0;
+  void *spinlock = NULL;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing spinlock functions"));
+    spinlock = lw6sys_spinlock_create ();
+    if (spinlock)
+      {
+	if (lw6sys_spinlock_lock (spinlock))
+	  {
+	    if (lw6sys_spinlock_trylock (spinlock))
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _
+			    ("strange, trylock on locked spinlock should return 0"));
+	      }
+	    else
+	      {
+		if (lw6sys_spinlock_unlock (spinlock))
+		  {
+		    ret = 1;
+		  }
+	      }
+	  }
+	lw6sys_spinlock_destroy (spinlock);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Used to test lw6sys_split...
  */
@@ -1931,6 +2089,12 @@ test_str ()
     lw6sys_log (LW6SYS_LOG_NOTICE, _("testing is_blank on \"%s\""),
 		BLANK_STR);
     ret = ret && lw6sys_str_is_blank (BLANK_STR);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing is_same"));
+    ret = ret && lw6sys_str_is_same (BLANK_STR, BLANK_STR)
+      && lw6sys_str_is_same (NULL, NULL)
+      && (!lw6sys_str_is_same (NULL, BLANK_STR))
+      && (!lw6sys_str_is_same (BLANK_STR, NULL))
+      && (!lw6sys_str_is_same (BLANK_STR, TEST_REFORMAT_STR1));
     str =
       lw6sys_str_reformat (TEST_REFORMAT_STR1, TEST_REFORMAT_PREFIX,
 			   TEST_REFORMAT_COLUMNS);
@@ -2057,6 +2221,8 @@ test_shape ()
 
   {
     lw6sys_whd_t shape = { TEST_SHAPE_W, TEST_SHAPE_H, TEST_SHAPE_D };
+    lw6sys_whd_t shape2 =
+      { TEST_SHAPE_W + 1, TEST_SHAPE_H + 1, TEST_SHAPE_D + 1 };
     lw6sys_xyz_t pos = { TEST_SHAPE_X, TEST_SHAPE_Y, TEST_SHAPE_Z };
 
     if (lw6sys_shape_check_min_max_whd
@@ -2082,6 +2248,18 @@ test_shape ()
       {
 	ret = 0;
       }
+    if (lw6sys_shape_is_same (&shape, &shape)
+	&& !lw6sys_shape_is_same (&shape, &shape2))
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("shape %dx%dx%d reported different as %dx%dx%d"),
+		    (int) shape.w, (int) shape.h, (int) shape.d,
+		    (int) shape2.w, (int) shape2.h, (int) shape2.d);
+      }
+    else
+      {
+	ret = 0;
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -2103,9 +2281,19 @@ thread_func (void *callback_data)
     }
 }
 
+static void
+thread_join_nofree (void *callback_data)
+{
+  char *text = NULL;
+
+  text = (char *) callback_data;
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("thread_join text=\"%s\""), text);
+}
+
 static void
 thread_join (void *callback_data)
 {
+  thread_join_nofree (callback_data);
   LW6SYS_FREE (callback_data);
 }
 
@@ -2126,7 +2314,7 @@ thread_stress_func (void *callback_data)
 
   while (thread_stress_data->run)
     {
-      child = lw6sys_thread_create (NULL, NULL, NULL, 0);
+      child = lw6sys_thread_create (NULL, NULL, NULL);
       if (child)
 	{
 	  lw6sys_thread_join (child);
@@ -2159,7 +2347,7 @@ test_thread ()
     if (text)
       {
 	thread_handler =
-	  lw6sys_thread_create (&thread_func, &thread_join, (void *) text, 0);
+	  lw6sys_thread_create (&thread_func, &thread_join, (void *) text);
 	if (thread_handler)
 	  {
 	    for (i = 0; i < THREAD_N; ++i)
@@ -2188,7 +2376,7 @@ test_thread ()
 	thread_stress_data.ret = 1;
 	thread_handler =
 	  lw6sys_thread_create (&thread_stress_func, NULL,
-				&thread_stress_data, 0);
+				&thread_stress_data);
 	if (thread_handler)
 	  {
 	    lw6sys_sleep (THREAD_STRESS_DURATION);
@@ -2226,14 +2414,25 @@ test_time ()
   {
     int i = 0;
     int nb_steps = 0;
-    int last_uptime;
+    int64_t last_uptime;
+    int64_t uptime = 0;
+    int64_t timestamp = 0;
 
-    lw6sys_log (LW6SYS_LOG_NOTICE, _("timestamp %lld"), lw6sys_timestamp ());
-    lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %d"), lw6sys_uptime ());
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("timestamp %" LW6SYS_PRINTF_LL "d"),
+		lw6sys_timestamp ());
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %" LW6SYS_PRINTF_LL "d"),
+		lw6sys_uptime ());
+    lw6sys_idle ();
+    lw6sys_timer_update (&timestamp, &uptime);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("timestamp %" LW6SYS_PRINTF_LL "d uptime %" LW6SYS_PRINTF_LL
+		  "d"), timestamp, uptime);
     last_uptime = lw6sys_uptime ();
     lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds"), TEST_SLEEP_TIME);
     lw6sys_sleep (TEST_SLEEP_TIME);
-    lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %d"),
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("delay %d msec"), TEST_DELAY_TIME);
+    lw6sys_delay (TEST_DELAY_TIME);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %" LW6SYS_PRINTF_LL "d ms"),
 		lw6sys_uptime () - last_uptime);
     last_uptime = lw6sys_uptime ();
     nb_steps = TEST_SLEEP_TIME / TEST_SLEEP_TIME_SHORT_STEP;
@@ -2243,7 +2442,7 @@ test_time ()
       {
 	lw6sys_sleep (TEST_SLEEP_TIME_SHORT_STEP);
       }
-    lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %d"),
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %" LW6SYS_PRINTF_LL "d ms"),
 		lw6sys_uptime () - last_uptime);
   }
 
@@ -2251,6 +2450,97 @@ test_time ()
   return ret;
 }
 
+static void
+vthread_func (void *callback_data)
+{
+  int i;
+  char *text = NULL;
+
+  text = (char *) callback_data;
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("vthread_callback text=\"%s\""), text);
+
+  lw6sys_idle ();
+  if (!lw6sys_vthread_is_running ())
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("vthread marked as not running, when it is"));
+    }
+
+  if (lw6sys_vthread_create
+      (&thread_func, &thread_join_nofree, callback_data))
+    {
+      for (i = 0; i < THREAD_N; ++i)
+	{
+	  lw6sys_log (LW6SYS_LOG_NOTICE, _("vthread_main step %d"), i + 1);
+	  lw6sys_sleep (THREAD_SLEEP_MAIN);
+	}
+
+      lw6sys_vthread_join ();
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("can't create thread"));
+    }
+}
+
+static void
+vthread_join (void *callback_data)
+{
+  char *text = NULL;
+
+  text = (char *) callback_data;
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("vthread_join text=\"%s\""), text);
+  LW6SYS_FREE (callback_data);
+}
+
+/*
+ * Testing functions in vthread.c
+ */
+static int
+test_vthread ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *text = NULL;
+    int i = 0;
+
+    ret = 1;
+
+    if (lw6sys_vthread_is_running ())
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING,
+		    _("vthread marked as running, when it's not"));
+	ret = 0;
+      }
+    for (i = 0; i < VTHREAD_N; ++i)
+      {
+	text = lw6sys_str_copy (THREAD_TEXT);
+	if (text)
+	  {
+	    if (lw6sys_vthread_run
+		(&vthread_func, &vthread_join, (void *) text))
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("done with vthread"));
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("can't run vthread"));
+		ret = 0;
+	      }
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /**
  * lw6sys_test
  *
@@ -2268,12 +2558,13 @@ lw6sys_test ()
 
   ret = test_arg () && test_assoc () && test_build () && test_checksum ()
     && test_color () && test_convert () && test_dump () && test_env ()
-    && test_file () && test_hash () && test_hexa () && test_history ()
-    && test_i18n () && test_id () && test_keyword () && test_list ()
-    && test_log () && test_mem () && test_mutex () && test_options ()
-    && test_nop () && test_path () && test_progress () && test_random ()
-    && test_sdl () && test_serial () && test_shape () && test_sort ()
-    && test_str () && test_thread () && test_time ();
+    && test_file () && test_profiler () && test_hash () && test_hexa ()
+    && test_history () && test_i18n () && test_id () && test_keyword ()
+    && test_list () && test_log () && test_math () && test_mem ()
+    && test_mutex () && test_options () && test_nop () && test_path ()
+    && test_progress () && test_random () && test_sdl () && test_serial ()
+    && test_shape () && test_sort () && test_spinlock () && test_str ()
+    && test_thread () && test_time () && test_vthread ();
 
   return ret;
 }
