@@ -27,8 +27,6 @@
 #include "sys.h"
 #include "sys-internal.h"
 
-#define THREAD_JOIN_SLEEP 0.1f
-
 static int thread_create_counter = 0;
 static int thread_join_counter = 0;
 static u_int32_t seq_id = 0;
@@ -41,6 +39,21 @@ thread_callback (void *thread_handler)
 
   if (th)
     {
+#ifndef LW6_MS_WINDOWS
+#ifdef LW6_GPROF
+      /*
+       * We need this for good interoperation with gprof, read
+       * http://sam.zoy.org/writings/programming/gprof.html
+       * which explains why one needs to set up an itimer in each
+       * thread.
+       */
+      if (setitimer (ITIMER_PROF, &th->itimer, NULL))
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("setitimer failed"));
+	}
+#endif
+#endif
+
       if (th->callback_join)
 	{
 	  lw6sys_log (LW6SYS_LOG_INFO, _("begin thread id=%u"), th->id);
@@ -74,7 +87,7 @@ thread_callback (void *thread_handler)
 	       * Now the caller is supposed to set "can_join"
 	       * to allow this thread to actually finish.
 	       */
-	      lw6sys_sleep (THREAD_JOIN_SLEEP);
+	      lw6sys_sleep (_LW6SYS_THREAD_JOIN_SLEEP);
 	    }
 	  th->callback_join (th->callback_data);
 	}
@@ -102,7 +115,6 @@ thread_callback (void *thread_handler)
  * @callback_func: the main callback, the function that will run the thread
  * @callback_join: function which will be called when joining, at the end
  * @callback_data: data which will be passed to the callback
- * @flag: a user flag which will be associated to the thread
  *
  * Creates a thread. All threads must be joined. This is because we
  * really do not want the game to leak, and detached threads are typically
@@ -117,7 +129,7 @@ thread_callback (void *thread_handler)
 void *
 lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
 		      lw6sys_thread_callback_func_t callback_join,
-		      void *callback_data, int flag)
+		      void *callback_data)
 {
   _lw6sys_thread_handler_t *thread_handler = NULL;
 
@@ -133,10 +145,10 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
 	{
 	  thread_handler->id = ++seq_id;
 	}
-      thread_handler->flag = flag;
       thread_handler->callback_func = callback_func;
       thread_handler->callback_join = callback_join;
       thread_handler->callback_data = callback_data;
+
       if (thread_handler->callback_join)
 	{
 	  lw6sys_log (LW6SYS_LOG_INFO, _("creating thread id=%u"),
@@ -148,6 +160,22 @@ lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
 		      _("creating thread id=%u (fast mode, no join)"),
 		      thread_handler->id);
 	}
+
+#ifndef LW6_MS_WINDOWS
+#ifdef LW6_GPROF
+      /*
+       * We need this for good interoperation with gprof, read
+       * http://sam.zoy.org/writings/programming/gprof.html
+       * which explains why one needs to set up an itimer in each
+       * thread.
+       */
+      if (getitimer (ITIMER_PROF, &thread_handler->itimer))
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("getitimer failed"));
+	}
+#endif
+#endif
+
       if (!pthread_create (&(thread_handler->thread), NULL,
 			   (void *) thread_callback, (void *) thread_handler))
 	{
@@ -265,38 +293,6 @@ lw6sys_thread_get_data (void *thread_handler)
   return ret;
 }
 
-/**
- * lw6sys_thread_get_flag
- *
- * @thread_handler: thread to query
- *
- * Returns the flag associated to the thread, that is, the integer
- * which was given when creating the thread. This can be used in any way
- * you want to decide what to do when a thread is over, for instance.
- *
- * Return value: a pointer.
- */
-int
-lw6sys_thread_get_flag (void *thread_handler)
-{
-  int ret = 0;
-
-  if (thread_handler)
-    {
-      _lw6sys_thread_handler_t *th;
-      th = (_lw6sys_thread_handler_t *) thread_handler;
-
-      ret = th->flag;
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("can't call get_flag on NULL thread_handler"));
-    }
-
-  return ret;
-}
-
 /**
  * lw6sys_thread_join
  *
