@@ -88,6 +88,9 @@ typedef unsigned long long u_int64_t;
 typedef char *char_ptr_t;
 #endif
 
+#define LW6SYS_QUOTE(STR) #STR
+#define LW6SYS_TICKS_PER_SEC 1000L
+
 /*
  * Yet another MS-windows hack, printf %ll doesn't work
  * one needs to use a special "%I64" instead...
@@ -100,7 +103,13 @@ typedef char *char_ptr_t;
 
 #include "../def/def.h"
 
-#define LW6SYS_MAIN_BEGIN { setlocale (LC_ALL, ""); bindtextdomain (lw6sys_build_get_package_tarname (), lw6sys_build_get_localedir ()); textdomain (lw6sys_build_get_package_tarname ()); lw6sys_time_init(); lw6sys_history_init(); lw6sys_default_memory_bazooka(); }
+#ifdef LW6_PARANOID
+#define LW6SYS_BAZOOKA_DEFAULT_SIZE 1000000
+#else
+#define LW6SYS_BAZOOKA_DEFAULT_SIZE 100000
+#endif
+
+#define LW6SYS_MAIN_BEGIN { setlocale (LC_ALL, ""); bindtextdomain (lw6sys_build_get_package_tarname (), lw6sys_build_get_localedir ()); textdomain (lw6sys_build_get_package_tarname ()); lw6sys_time_init(); lw6sys_history_init(); lw6sys_default_memory_bazooka(); lw6sys_profiler_check(1); }
 #define LW6SYS_MAIN_END { ret = lw6sys_check_thread_count () && ret; ret = lw6sys_memory_bazooka_report() && ret; lw6sys_clear_memory_bazooka(); }
 
 #define LW6SYS_TEST_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_NOTICE,_("running tests in function \"%s\""),__FUNCTION__); }
@@ -287,21 +296,25 @@ extern lw6sys_color_hsv_t LW6SYS_COLOR_HSV_BLUE;
 #define LW6SYS_LOG_NOTICE_ID 2
 #define LW6SYS_LOG_INFO_ID 3
 #define LW6SYS_LOG_DEBUG_ID 4
+#define LW6SYS_LOG_TMP_ID 5
 #define LW6SYS_LOG_ERROR LW6SYS_LOG_ERROR_ID, __FILE__, __LINE__
 #define LW6SYS_LOG_WARNING LW6SYS_LOG_WARNING_ID, __FILE__, __LINE__
 #define LW6SYS_LOG_NOTICE LW6SYS_LOG_NOTICE_ID, __FILE__, __LINE__
 #define LW6SYS_LOG_INFO LW6SYS_LOG_INFO_ID, __FILE__, __LINE__
 #define LW6SYS_LOG_DEBUG LW6SYS_LOG_DEBUG_ID, __FILE__, __LINE__
+#define LW6SYS_LOG_TMP LW6SYS_LOG_TMP_ID, __FILE__, __LINE__
+
+#define LW6SYS_LOG_DEFAULT_ID LW6SYS_LOG_INFO_ID
 
 /*
- * macro D defined for quick-debugging / trace
+ * macro TMP defined for quick-debugging / trace
  */
-#define D(message) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message); lw6sys_debug_set(log_level);}
-#define D1(message,arg1) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1); lw6sys_debug_set(log_level);}
-#define D2(message,arg1,arg2) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2); lw6sys_debug_set(log_level);}
-#define D3(message,arg1,arg2,arg3) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2, arg3); lw6sys_debug_set(log_level);}
-#define D4(message,arg1,arg2,arg3,arg4) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2, arg3, arg4); lw6sys_debug_set(log_level);}
-#define D5(message,arg1,arg2,arg3,arg4,arg5) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2, arg3, arg4, arg5); lw6sys_debug_set(log_level);}
+#define TMP(message) lw6sys_log(LW6SYS_LOG_TMP, message)
+#define TMP1(message,arg1) lw6sys_log(LW6SYS_LOG_TMP, message, arg1)
+#define TMP2(message,arg1,arg2) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2)
+#define TMP3(message,arg1,arg2,arg3) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3)
+#define TMP4(message,arg1,arg2,arg3,arg4) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4)
+#define TMP5(message,arg1,arg2,arg3,arg4,arg5) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5)
 
 /*
  * Common indenting parameters
@@ -347,6 +360,7 @@ extern int lw6sys_set_memory_bazooka_eraser (int state);
 extern int lw6sys_get_memory_bazooka_eraser ();
 extern int lw6sys_get_memory_bazooka_malloc_count ();
 extern int lw6sys_get_memory_bazooka_free_count ();
+extern int lw6sys_get_memory_bazooka_malloc_max ();
 extern int lw6sys_memory_bazooka_report ();
 
 /* sys-build.c */
@@ -369,8 +383,10 @@ extern char *lw6sys_build_get_time ();
 extern char *lw6sys_build_get_target_cpu ();
 extern char *lw6sys_build_get_endianness ();
 extern int lw6sys_build_get_pointer_size ();
+extern int lw6sys_build_is_x86 ();
 extern char *lw6sys_build_get_target_os ();
 extern int lw6sys_build_is_ms_windows ();
+extern int lw6sys_build_is_mac_os_x ();
 extern char *lw6sys_build_get_top_srcdir ();
 extern char *lw6sys_build_get_prefix ();
 extern char *lw6sys_build_get_datadir ();
@@ -386,7 +402,10 @@ extern char *lw6sys_build_get_enable_mod_http ();
 extern char *lw6sys_build_get_enable_optimize ();
 extern char *lw6sys_build_get_enable_allinone ();
 extern char *lw6sys_build_get_enable_fullstatic ();
+extern char *lw6sys_build_get_enable_paranoid ();
 extern char *lw6sys_build_get_enable_gprof ();
+extern char *lw6sys_build_get_enable_instrument ();
+extern char *lw6sys_build_get_enable_profiler ();
 extern char *lw6sys_build_get_enable_gcov ();
 extern char *lw6sys_build_get_enable_valgrind ();
 extern void lw6sys_build_log_all ();
@@ -435,6 +454,8 @@ extern lw6sys_color_8_t lw6sys_color_ponderate (lw6sys_color_8_t color1,
 						float coeff);
 extern float lw6sys_color_distance (lw6sys_color_8_t color1,
 				    lw6sys_color_8_t color2);
+extern int lw6sys_color_is_same (lw6sys_color_8_t color1,
+				 lw6sys_color_8_t color2);
 extern void lw6sys_color_8_solid (lw6sys_color_8_t * color);
 extern void lw6sys_color_f_solid (lw6sys_color_f_t * color);
 
@@ -471,6 +492,9 @@ extern int lw6sys_clear_file (char *filename);
 extern char *lw6sys_read_file_content (char *filename);
 extern int lw6sys_write_file_content (char *filename, char *content);
 
+/* sys-profiler.c */
+extern int lw6sys_profiler_check (int verbose);
+
 /* sys-hash.c */
 extern lw6sys_hash_t *lw6sys_hash_new (lw6sys_free_func_t free_func,
 				       int size);
@@ -599,6 +623,14 @@ extern void lw6sys_log_critical (char *fmt, ...);
 extern int lw6sys_log_get_level ();
 extern void lw6sys_log_set_level (int level);
 
+/* sys-math.c */
+extern void lw6sys_math_poly_wy1y2s1 (float *y, float *s, float x, float w,
+				      float y1, float y2, float s1);
+extern float lw6sys_math_angle_360 (int x, int y);
+extern float lw6sys_math_heartbeat (int64_t x, int period, float y1,
+				    float y2);
+extern int lw6sys_math_blink (int64_t x, int period);
+
 /* sys-mem.c */
 #ifdef LW6_OPTIMIZE
 #define LW6SYS_MALLOC(SIZE) malloc((SIZE))
@@ -696,6 +728,12 @@ extern void lw6sys_progress_split4 (lw6sys_progress_t * progress1,
 				    lw6sys_progress_t * progress3,
 				    lw6sys_progress_t * progress4,
 				    lw6sys_progress_t * progress_src);
+extern void lw6sys_progress_split5 (lw6sys_progress_t * progress1,
+				    lw6sys_progress_t * progress2,
+				    lw6sys_progress_t * progress3,
+				    lw6sys_progress_t * progress4,
+				    lw6sys_progress_t * progress5,
+				    lw6sys_progress_t * progress_src);
 extern void lw6sys_progress_begin (lw6sys_progress_t * progress);
 extern void lw6sys_progress_half (lw6sys_progress_t * progress);
 extern void lw6sys_progress_end (lw6sys_progress_t * progress);
@@ -720,6 +758,8 @@ extern int16_t lw6sys_unserialize_int16 (unsigned char *data);
 extern int lw6sys_shape_check_min_max_whd (lw6sys_whd_t * shape, int min_wh,
 					   int max_wh, int max_d);;
 extern int lw6sys_shape_check_pos (lw6sys_whd_t * shape, lw6sys_xyz_t * pos);
+extern int lw6sys_shape_is_same (lw6sys_whd_t * shape_a,
+				 lw6sys_whd_t * shape_b);
 
 /* sys-sort.c */
 extern int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
@@ -737,11 +777,19 @@ extern int lw6sys_sort_str_desc_callback (lw6sys_list_t ** list_a,
 extern void lw6sys_sort (lw6sys_list_t ** list,
 			 lw6sys_sort_callback_func_t sort_func);
 
+/* sys-spinlock.c */
+extern void *lw6sys_spinlock_create ();
+extern void lw6sys_spinlock_destroy (void *spinlock);
+extern int lw6sys_spinlock_lock (void *spinlock);
+extern int lw6sys_spinlock_trylock (void *spinlock);
+extern int lw6sys_spinlock_unlock (void *spinlock);
+
 /* sys-str.c */
 extern char *lw6sys_str_copy (char *src);
 extern char *lw6sys_str_concat (char *str1, char *str2);
 extern char *lw6sys_new_sprintf (char *fmt, ...);
 extern int lw6sys_str_is_blank (char *str);
+extern int lw6sys_str_is_same (char *str_a, char *str_b);
 extern int lw6sys_skip_blanks (char **str_ptr);
 extern void lw6sys_str_cleanup (char *str);
 extern char *lw6sys_str_reformat (char *str, char *prefix, int nb_columns);
@@ -752,15 +800,17 @@ extern lw6sys_list_t *lw6sys_str_split_no_0 (char *str, char c);
 /* sys-test.c */
 extern int lw6sys_test ();
 
+/* sys-testandset.s */
+extern int lw6sys_test_and_set (int *spinlock);
+
 /* sys-thread.c */
 extern void
   *lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
 			 lw6sys_thread_callback_func_t callback_join,
-			 void *callback_data, int flag);
+			 void *callback_data);
 extern int lw6sys_thread_is_callback_done (void *thread_handler);
 extern int lw6sys_thread_get_id (void *thread_handler);
 extern void *lw6sys_thread_get_data (void *thread_handler);
-extern int lw6sys_thread_get_flag (void *thread_handler);
 extern void lw6sys_thread_join (void *thread_handler);
 extern int lw6sys_get_thread_create_count ();
 extern int lw6sys_get_thread_join_count ();
@@ -768,10 +818,24 @@ extern int lw6sys_check_thread_count ();
 
 /* sys-time.c */
 extern int64_t lw6sys_timestamp ();
-extern int32_t lw6sys_uptime ();
+extern int64_t lw6sys_uptime ();
+extern void lw6sys_timer_update (int64_t * timestamp, int64_t * uptime);
 extern void lw6sys_sleep (float seconds);
+extern void lw6sys_delay (int msec);
+extern void lw6sys_idle ();
 extern void lw6sys_time_init ();
 
+/* sys-vthread.c */
+extern int lw6sys_vthread_run (lw6sys_thread_callback_func_t callback_func,
+			       lw6sys_thread_callback_func_t callback_join,
+			       void *callback_data);
+extern int lw6sys_vthread_is_running ();
+extern int lw6sys_vthread_create (lw6sys_thread_callback_func_t callback_func,
+				  lw6sys_thread_callback_func_t callback_join,
+				  void *callback_data);
+extern void lw6sys_vthread_join ();
+
+
 /* inline utils */
 static inline int
 lw6sys_min (int a, int b)
