@@ -195,15 +195,15 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
 
   if (map_path && relative_path)
     {
-      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_MAP;
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_MAP;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
+      lw6sys_progress_begin (&progress);
       level =
 	lw6ldr_read_relative (map_path, relative_path, default_param,
 			      forced_param, display_w, display_h, &progress);
       if (level)
 	{
-	  (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
+	  lw6sys_progress_end (&progress);
 	}
     }
 
@@ -235,10 +235,14 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
       repr = lw6map_repr (level);
       if (repr)
 	{
-	  src2 = lw6map_dup (level);
+	  progress.min = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_DUP;
+	  progress.max = _LW6TSK_LOADER_PROGRESS_STAGE1_END_DUP;
+	  lw6sys_progress_begin (&progress);
+	  src2 = lw6map_dup (level, &progress);
 	  LOADER_LOCK;
 	  if (request_number == loader_data->request_number)
 	    {
+	      lw6sys_progress_end (&progress);
 	      stage1_clear_response (&(loader_data->stage1));
 	      loader_data->stage1.level = level;
 	      lw6sys_log (LW6SYS_LOG_INFO,
@@ -307,7 +311,11 @@ stage2 (_lw6tsk_loader_data_t * loader_data)
 		  _("async load stage2, request_number %d"), request_number);
       (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN;
 
-      level = lw6map_dup (loader_data->stage2.src);
+      progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_MAP;
+      progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_MAP;
+      lw6sys_progress_begin (&progress);
+      level = lw6map_dup (loader_data->stage2.src, &progress);
+      lw6sys_progress_end (&progress);
 
       stage2_clear_request (&(loader_data->stage2));
     }
@@ -315,13 +323,13 @@ stage2 (_lw6tsk_loader_data_t * loader_data)
 
   if (level)
     {
-      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STRUCT;
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STRUCT;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STRUCT;
+      lw6sys_progress_begin (&progress);
       game_struct = lw6ker_game_struct_new (level, &progress);
       if (game_struct)
 	{
-	  (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STRUCT;
+	  lw6sys_progress_end (&progress);
 	}
       else
 	{
@@ -331,13 +339,13 @@ stage2 (_lw6tsk_loader_data_t * loader_data)
     }
   if (level && game_struct)
     {
-      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STATE;
       progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STATE;
       progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STATE;
+      lw6sys_progress_begin (&progress);
       game_state = lw6ker_game_state_new (game_struct, &progress);
       if (game_state)
 	{
-	  (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STATE;
+	  lw6sys_progress_end (&progress);
 	}
       else
 	{
@@ -408,10 +416,6 @@ _lw6tsk_loader_poll (_lw6tsk_loader_data_t * loader_data)
   loader_data->stage = 2;
   stage2 (loader_data);
   loader_data->stage = 0;
-  if (loader_data->progress)
-    {
-      (*(loader_data->progress)) = 0.0f;
-    }
 }
 
 void
@@ -584,7 +588,7 @@ lw6tsk_loader_new (float sleep, float *progress)
 	    {
 	      loader->thread =
 		lw6sys_thread_create (loader_callback, loader_join,
-				      loader->data, 0);
+				      loader->data);
 	    }
 	  else
 	    {
