@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ extern void lw6tsk_loader_push (lw6tsk_loader_t * loader, char *map_path,
 				char *relative_path,
 				lw6sys_assoc_t * default_param,
 				lw6sys_assoc_t * forced_param,
-				lw6sys_wh_t * display_shape);
+				int display_w, int display_h);
 extern int lw6tsk_loader_pop (lw6map_level_t ** level,
 			      lw6ker_game_struct_t ** game_struct,
 			      lw6ker_game_state_t ** game_state,
