@@ -26,6 +26,10 @@
 
 #include "lib/liquidwar6.h"
 
+#ifdef LW6_MAC_OS_X
+#include <SDL/SDL.h>
+#endif
+
 int
 main (int argc, char *argv[])
 {
