@@ -43,7 +43,8 @@ find $SCRIPT_DIR -type f -a -name "*.scm" \
 # some specific cherry-picked files are translated.
 cd ..
 rm po/POTFILES.in
-for i in src/scriptpo.c src/lib/hlp/hlp-reference.c src/lib/sys/sys-log.c src/lib/sys/sys-mem.c src/lib/lw6-print.c src/lib/ldr/ldr-print.c src/lib/*/mod-*/mod-*-backend.c ; do
+#for i in src/scriptpo.c src/lib/hlp/hlp-reference.c src/lib/sys/sys-log.c src/lib/sys/sys-mem.c src/lib/lw6-print.c src/lib/ldr/ldr-print.c src/lib/*/mod-*/mod-*-backend.c ; do
+for i in src/scriptpo.c src/lib/sys/sys-log.c src/lib/sys/sys-mem.c src/lib/lw6-print.c ; do
     echo "$i" >> po/POTFILES.in
 done
 cd src
