@@ -41,7 +41,7 @@ auto_id () {
 	if [ -f ${BUILD_STAMP_H} ] && [ -f ${BUILD_MD5SUM_H} ]; then
 	    export LANG=C
 	    export LC_ALL=C # important for sort
-	    new_md5=`find lib -name "*.c" -a -not -name ".*" -a -not -path "*.libs*" | sort -u | xargs cat | tr --delete [:cntrl:] | tr --delete [:space:] | md5sum | cut -d " " -f 1`
+	    new_md5=`find lib -name "*.c" -a -not -name ".*" -a -not -path "*.libs*" | sort -u | xargs cat | tr -d [:cntrl:] | tr -d [:space:] | md5sum | cut -d " " -f 1`
 	    old_md5=`cat ${BUILD_MD5SUM_H} | cut -d "\"" -f 2`
 	    if [ "$new_md5" != "$old_md5" ] ; then
 		echo "C source files changed"
